---
--- Backlog Package 1.1.X
---

-- space
ALTER TABLE space ADD NEED_INDEXING  boolean default FALSE;

-- licence_type
ALTER TABLE licence_type ADD ATTACHMENT_NUM_LIMIT integer NOT NULL default '0';
ALTER TABLE licence_type ADD WIKI_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0';
ALTER TABLE licence_type ADD FILE_SHARING boolean NOT NULL default FALSE;
ALTER TABLE licence_type ADD SUBVERSION boolean NOT NULL default FALSE;
ALTER TABLE licence_type ADD SUBVERSION_EXTERNAL boolean NOT NULL default FALSE;
ALTER TABLE licence_type ADD STORAGE_LIMIT bigint NOT NULL default '0';

-- licence
ALTER TABLE licence ADD ATTACHMENT_NUM_LIMIT integer NOT NULL default '0';
ALTER TABLE licence ADD WIKI_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0';
ALTER TABLE licence ADD FILE_SHARING boolean NOT NULL default FALSE;
ALTER TABLE licence ADD SUBVERSION boolean NOT NULL default FALSE;
ALTER TABLE licence ADD SUBVERSION_EXTERNAL boolean NOT NULL default FALSE;
ALTER TABLE licence ADD STORAGE_LIMIT bigint NOT NULL default '0';

-- licence_changelog
ALTER TABLE licence_changelog ADD ATTACHMENT_NUM_LIMIT integer NULL default '0';
ALTER TABLE licence_changelog ADD WIKI_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0';
ALTER TABLE licence_changelog ADD FILE_SHARING boolean NOT NULL default FALSE;
ALTER TABLE licence_changelog ADD SUBVERSION boolean NOT NULL default FALSE;
ALTER TABLE licence_changelog ADD SUBVERSION_EXTERNAL boolean NOT NULL default FALSE;
ALTER TABLE licence_changelog ADD STORAGE_LIMIT bigint NOT NULL default '0';

-- users
ALTER TABLE users ADD DISABLED integer NOT NULL default '0';
ALTER TABLE users DROP CONSTRAINT users_space_id_key;
ALTER TABLE users ADD UNIQUE (SPACE_ID,USER_ID,DISABLED);

--
-- Table structure for table `dashboard`
--
CREATE TABLE "dashboard" (
  USER_ID integer NOT NULL default '0',
  SHOW_CREATED_ISSUE boolean default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  CONSTRAINT "FK_dashboard_USER_ID" FOREIGN KEY (USER_ID) REFERENCES "users" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_dashboard_USER_ID" ON "dashboard" (USER_ID);

-- project
ALTER TABLE project ADD ARCHIVED boolean NOT NULL default FALSE;

--
-- Table structure for table `default_issue_type`
--
CREATE TABLE "default_issue_type" (
  ID integer NOT NULL,
  NAME varchar(20) NOT NULL,
  DISPLAY_ORDER integer NOT NULL,
  COLOR varchar(20) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);

-- issue_type
DROP TABLE issue_type;
CREATE SEQUENCE "issue_type_id_seq";
CREATE TABLE "issue_type" (
  ID integer NOT NULL default nextval('issue_type_id_seq'),
  PROJECT_ID integer NOT NULL,
  NAME varchar(20) NOT NULL default '',
  DISPLAY_ORDER integer default NULL,
  COLOR varchar(20) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_issue_type_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);


CREATE TABLE "issue_component" (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,LINK_ID),
  CONSTRAINT "FK_issue_component_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_component_LINK_ID" FOREIGN KEY (LINK_ID) REFERENCES "component" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_component_ISSUE_ID" ON "issue_component" (ISSUE_ID);
CREATE INDEX "IX_issue_component_LINK_ID" ON "issue_component" (LINK_ID);

CREATE TABLE "issue_affectedversion" (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,LINK_ID),
  CONSTRAINT "FK_issue_affectedversion_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_affectedversion_LINK_ID" FOREIGN KEY (LINK_ID) REFERENCES "version" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_affectedversion_ISSUE_ID" ON "issue_affectedversion" (ISSUE_ID);
CREATE INDEX "IX_issue_affectedversion_LINK_ID" ON "issue_affectedversion" (LINK_ID);

CREATE TABLE "issue_fixedversion" (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,LINK_ID),
  CONSTRAINT "FK_issue_fixedversion_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_fixedversion_LINK_ID" FOREIGN KEY (LINK_ID) REFERENCES "version" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_fixedversion_ISSUE_ID" ON "issue_fixedversion" (ISSUE_ID);
CREATE INDEX "IX_issue_fixedversion_LINK_ID" ON "issue_fixedversion" (LINK_ID);

--- project_mail
ALTER TABLE project_mail ADD ALL_ISSUE boolean default NULL;
ALTER TABLE project_mail ADD ASSIGNED_ISSUE boolean default NULL;
ALTER TABLE project_mail ADD CREATED_ISSUE boolean default NULL;
ALTER TABLE project_mail ADD SUBVERSION boolean default NULL;

--- remote_address
ALTER TABLE remote_address ALTER CREATED SET NOT NULL;

--
-- Table structure for table `disk_usage`
--

CREATE TABLE "disk_usage" (
  PROJECT_ID integer NOT NULL,
  TYPE integer NOT NULL,
  AMOUNT bigint NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID,TYPE),
  CONSTRAINT FK_disk_usage_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_disk_usage_PROJECT_ID" ON "disk_usage" (PROJECT_ID);

CREATE SEQUENCE "shared_file_id_seq";
CREATE TABLE "shared_file" (
  ID integer NOT NULL default nextval('shared_file_id_seq'),
  PROJECT_ID integer NOT NULL,
  DIR text NOT NULL default '',
  NAME text default NULL,
  SIZE bigint default NULL,
  TYPE integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_shared_file_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_shared_file_PROJECT_ID" ON "shared_file" (PROJECT_ID);

CREATE SEQUENCE "subversion_id_seq";
CREATE TABLE "subversion" (
  ID integer NOT NULL default nextval('subversion_id_seq'),
  PROJECT_ID integer NOT NULL,
  TYPE integer NOT NULL,
  URL text default NULL,
  SVN_USER text default NULL,
  SVN_PASSWORD text default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (PROJECT_ID),
  CONSTRAINT FK_subversion_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID)
);

CREATE TABLE "issue_shared_file_link" (
  ISSUE_ID integer NOT NULL default '0',
  SHARED_FILE_ID integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,SHARED_FILE_ID),
  CONSTRAINT FK_issue_shared_file_link_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_shared_file_link_SHARED_FILE_ID FOREIGN KEY (SHARED_FILE_ID) REFERENCES shared_file (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_shared_file_link_ISSUE_ID" ON "issue_shared_file_link" (ISSUE_ID);
CREATE INDEX "IX_issue_shared_file_link_SHARED_FILE_ID" ON "issue_shared_file_link" (SHARED_FILE_ID);

CREATE TABLE "page_shared_file_link" (
  PAGE_ID integer NOT NULL default '0',
  SHARED_FILE_ID integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PAGE_ID,SHARED_FILE_ID),
  CONSTRAINT FK_page_shared_file_link_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE,
  CONSTRAINT FK_page_shared_file_link_SHARED_FILE_ID FOREIGN KEY (SHARED_FILE_ID) REFERENCES shared_file (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_shared_file_link_PAGE_ID" ON "page_shared_file_link" (PAGE_ID);
CREATE INDEX "IX_page_shared_file_link_SHARED_FILE_ID" ON "page_shared_file_link" (SHARED_FILE_ID);


--
-- Dumping data for table `issue_type`
--
INSERT INTO default_issue_type VALUES (1,'バグ',0,'#990000',NULL,'2005-04-19 03:23:59',NULL,'2005-04-18 17:31:06');
INSERT INTO default_issue_type VALUES (2,'タスク',1,'#7ea800',NULL,'2005-05-15 00:47:12',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (3,'要望',2,'#ff9200',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (4,'その他',3,'#2779ca',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31');


insert into issue_type (
select 
  project.id * 4 + default_issue_type.id as id,
  project.id as project_id,
  default_issue_type.name, 
  default_issue_type.display_order,
  default_issue_type.color,
  default_issue_type.created_user_id,
  default_issue_type.created,
  default_issue_type.updated_user_id,
  default_issue_type.updated
from 
  project, default_issue_type
order by
  id
);

CREATE TABLE "dual" (
  X integer
);
insert into dual values(1);
update dual set X= (SELECT setval('issue_type_id_seq', max(id)) FROM issue_type);
DROP TABLE dual;

update issue set issue_type_id=project_id * 4 + issue_type_id, UPDATED = UPDATED;

INSERT INTO dashboard (USER_ID, SHOW_CREATED_ISSUE, CREATED, UPDATED) SELECT id, false, now(), now() FROM users;

UPDATE project_mail SET ALL_ISSUE = true, ASSIGNED_ISSUE = false, CREATED_ISSUE = false;

insert into issue_component(ISSUE_ID, LINK_ID) select ID, COMPONENT_ID from issue where COMPONENT_ID is not null;
insert into issue_affectedversion(ISSUE_ID, LINK_ID) select ID, AFFECTED_VERSION_ID from issue where AFFECTED_VERSION_ID is not null;
insert into issue_fixedversion(ISSUE_ID, LINK_ID) select ID,  FIXED_VERSION_ID from issue where FIXED_VERSION_ID is not null;

update space set NEED_INDEXING=true;