SET NAMES 'utf8';

ALTER TABLE user_setting DROP COLUMN use_new_ui;
ALTER TABLE `shared_file` ADD COLUMN `CHECKSUM` VARCHAR(40) NULL DEFAULT NULL AFTER `TYPE`;
ALTER TABLE licence ADD NEW_UI tinyint(1) NOT NULL default '0' AFTER NULAB_ACCOUNT;
ALTER TABLE licence ADD PROJECT_GROUP tinyint(1) NOT NULL default '0' AFTER NEW_UI;
ALTER TABLE licence_type ADD NEW_UI tinyint(1) NOT NULL default '0' AFTER NULAB_ACCOUNT;
ALTER TABLE licence_type ADD PROJECT_GROUP tinyint(1) NOT NULL default '0' AFTER NEW_UI;

DROP TABLE user_watch_issue;

CREATE TABLE user_watch (
  ID int(11) NOT NULL auto_increment,
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  TYPE int(11) NOT NULL,
  ISSUE_ID int(11) default NULL,
  LAST_NOTICE_CHECKED_TIME datetime default NULL,
  LAST_CHECKED_TIME datetime NOT NULL default '0000-00-00 00:00:00',
  NOTE varchar(255) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_USER_ID_TYPE_ISSUE_ID (USER_ID,TYPE,ISSUE_ID),
  KEY IX_USER_ID_PROJECT_ID (USER_ID,PROJECT_ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  CONSTRAINT FK_user_watch_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_party (
  PROJECT_ID int(11) NOT NULL,
  PARTY_ID int(11) NOT NULL,
  PROJECT_LEADER tinyint(1) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (PROJECT_ID,PARTY_ID),
  KEY IX_PARTY_ID (PARTY_ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT project_party_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT project_party_PARTY_ID FOREIGN KEY (PARTY_ID) REFERENCES party (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE stamp (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11),
  URL VARCHAR(255) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PROJECT_ID (PROJECT_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE information_read_user (
  ID int(11) NOT NULL auto_increment,
  INFORMATION_ID int(11) NOT NULL,
  USER_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_INFORMATION_ID (INFORMATION_ID),
  KEY IX_USER_ID (USER_ID),
  CONSTRAINT FK_information_user_INFORMATION_ID FOREIGN KEY (INFORMATION_ID) REFERENCES information (ID) ON DELETE CASCADE,
  CONSTRAINT FK_information_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

ALTER TABLE nulab_account ADD ACCEPTED_INVITATION tinyint(1) NOT NULL default '1' AFTER NAME;
ALTER TABLE nulab_account ADD INVITATION_NULAB_ID varchar(255) BINARY default NULL AFTER NULAB_ID;
ALTER TABLE nulab_account ADD UNIQUE UQ_INVITATION_NULAB_ID (INVITATION_NULAB_ID);
ALTER TABLE party ADD NULAB_APPS_GROUP_KEY varchar(50) default NULL AFTER SPACE_ID;
ALTER TABLE party ADD UNIQUE UQ_NULAB_APPS_GROUP_KEY (NULAB_APPS_GROUP_KEY);
ALTER TABLE licence ADD NULAB_APPS_INTEGRATION tinyint(1) NOT NULL default '0' AFTER LICENCE_KEY;
ALTER TABLE licence_type ADD NULAB_APPS_INTEGRATION tinyint(1) NOT NULL default '0' AFTER SERVICE_TYPE_ID;
ALTER TABLE nulab_account ADD ROLE varchar(15) default NULL AFTER NAME;
ALTER TABLE nulab_account ADD USE_MFA tinyint(1) default NULL AFTER ROLE;
ALTER TABLE nulab_account MODIFY NULAB_ID varchar(255) BINARY;
ALTER TABLE space CHANGE `NAME` `NAME` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci;

CREATE TABLE nulab_apps_space (
  ID int(11) NOT NULL auto_increment,
  BACKLOG_SPACE_ID int(11) NOT NULL default '0',
  SPACE_KEY varchar(50) BINARY NOT NULL,
  NAME VARCHAR(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_SPACE_KEY (SPACE_KEY),
  CONSTRAINT FK_nulab_apps_space_BACKLOG_SPACE_ID FOREIGN KEY (BACKLOG_SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

SET AUTOCOMMIT=0;

update licence set NEW_UI = 1;
update licence_type set NEW_UI = 1;
update licence set PROJECT_GROUP = 1;
update licence_type set PROJECT_GROUP = 1;

INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/animal_hokkyokuusagi.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/animal_hokkyokuusagi_stand.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/LGTM-uchida-transparent.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_01_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_02_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_03_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_04_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_05_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_01_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_02_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_03_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_04_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_05_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_01_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_02_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_03_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_04_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_05_.png','2016-10-05 00:00:00','2016-10-05 00:00:00');

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-01-01 00.00.00', '元日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-01-01 00.00.00' and NAME='元日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-01-02 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-01-02 00.00.00' and NAME='振替休日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-01-09 00.00.00', '成人の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-01-09 00.00.00' and NAME='成人の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-02-11 00.00.00', '建国記念の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-02-11 00.00.00' and NAME='建国記念の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-03-20 00.00.00', '春分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-03-20 00.00.00' and NAME='春分の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-04-29 00.00.00', '昭和の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-04-29 00.00.00' and NAME='昭和の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-05-03 00.00.00', '憲法記念日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-05-03 00.00.00' and NAME='憲法記念日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-05-04 00.00.00', 'みどりの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-05-04 00.00.00' and NAME='みどりの日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-05-05 00.00.00', 'こどもの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-05-05 00.00.00' and NAME='こどもの日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-07-17 00.00.00', '海の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-07-17 00.00.00' and NAME='海の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-08-11 00.00.00', '山の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-08-11 00.00.00' and NAME='山の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-09-18 00.00.00', '敬老の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-09-18 00.00.00' and NAME='敬老の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-09-23 00.00.00', '秋分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-09-23 00.00.00' and NAME='秋分の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-10-09 00.00.00', '体育の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-10-09 00.00.00' and NAME='体育の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-11-03 00.00.00', '文化の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-11-03 00.00.00' and NAME='文化の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-11-23 00.00.00', '勤労感謝の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-11-23 00.00.00' and NAME='勤労感謝の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2017-12-23 00.00.00', '天皇誕生日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-12-23 00.00.00' and NAME='天皇誕生日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-01-01 00.00.00', '元日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-01-01 00.00.00' and NAME='元日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-01-08 00.00.00', '成人の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-01-08 00.00.00' and NAME='成人の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-02-11 00.00.00', '建国記念の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-02-11 00.00.00' and NAME='建国記念の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-02-12 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-02-12 00.00.00' and NAME='振替休日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-03-21 00.00.00', '春分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-03-21 00.00.00' and NAME='春分の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-04-29 00.00.00', '昭和の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-04-29 00.00.00' and NAME='昭和の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-04-30 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-04-30 00.00.00' and NAME='振替休日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-05-03 00.00.00', '憲法記念日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-05-03 00.00.00' and NAME='憲法記念日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-05-04 00.00.00', 'みどりの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-05-04 00.00.00' and NAME='みどりの日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-05-05 00.00.00', 'こどもの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-05-05 00.00.00' and NAME='こどもの日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-07-16 00.00.00', '海の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-07-16 00.00.00' and NAME='海の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-08-11 00.00.00', '山の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-08-11 00.00.00' and NAME='山の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-09-17 00.00.00', '敬老の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-09-17 00.00.00' and NAME='敬老の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-09-23 00.00.00', '秋分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-09-23 00.00.00' and NAME='秋分の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-09-24 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-09-24 00.00.00' and NAME='振替休日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-10-08 00.00.00', '体育の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-10-08 00.00.00' and NAME='体育の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-11-03 00.00.00', '文化の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-11-03 00.00.00' and NAME='文化の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-11-23 00.00.00', '勤労感謝の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-11-23 00.00.00' and NAME='勤労感謝の日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-12-23 00.00.00', '天皇誕生日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-12-23 00.00.00' and NAME='天皇誕生日') LIMIT 1;
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT * FROM (SELECT '2018-12-24 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00' as updated ) AS tmp WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-12-24 00.00.00' and NAME='振替休日') LIMIT 1;

UPDATE licence_type SET REMOTE_ADDRESS_LIMIT = 65535 WHERE ID = 100;
UPDATE licence SET REMOTE_ADDRESS_LIMIT = 65535 WHERE LICENCE_TYPE_ID = 100;

update licence_type set name='スターター' where id = 21;
update licence_type set name='スタンダード' where id = 41;
update licence_type set name='プレミアム' where id = 51;

COMMIT;
