ALTER TABLE "user_setting" DROP COLUMN USE_NEW_UI;
ALTER TABLE "shared_file" ADD COLUMN CHECKSUM VARCHAR(40) default NULL;
ALTER TABLE "licence" ADD NEW_UI boolean NOT NULL default FALSE;
ALTER TABLE "licence" ADD PROJECT_GROUP boolean NOT NULL default FALSE;
ALTER TABLE "licence_type" ADD NEW_UI boolean NOT NULL default FALSE;
ALTER TABLE "licence_type" ADD PROJECT_GROUP boolean NOT NULL default FALSE;

DROP TABLE user_watch_issue;

CREATE SEQUENCE "user_watch_id_seq";
CREATE TABLE user_watch (
  ID integer NOT NULL default nextval('user_watch_id_seq'),
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  TYPE integer NOT NULL,
  ISSUE_ID integer default NULL,
  LAST_NOTICE_CHECKED_TIME timestamp default NULL,
  LAST_CHECKED_TIME timestamp NOT NULL default CURRENT_TIMESTAMP,
  NOTE varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (USER_ID,TYPE,ISSUE_ID),
  CONSTRAINT FK_user_watch_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_watch_USER_ID_PROJECT_ID" ON "user_watch" (USER_ID,PROJECT_ID);
CREATE INDEX "IX_user_watch_USER_ID" ON "user_watch" (USER_ID);
CREATE INDEX "IX_user_watch_PROJECT_ID" ON "user_watch" (PROJECT_ID);
CREATE INDEX "IX_user_watch_ISSUE_ID" ON "user_watch" (ISSUE_ID);

CREATE TABLE project_party (
  PROJECT_ID integer NOT NULL,
  PARTY_ID integer NOT NULL,
  PROJECT_LEADER  boolean default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PROJECT_ID,PARTY_ID),
  CONSTRAINT project_party_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT project_party_PARTY_ID FOREIGN KEY (PARTY_ID) REFERENCES party (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_party_PARTY_ID" ON "project_party" (PARTY_ID);
CREATE INDEX "IX_project_party_PROJECT_ID" ON "project_party" (PROJECT_ID);

CREATE SEQUENCE "stamp_id_seq";
CREATE TABLE stamp (
  ID integer NOT NULL default nextval('stamp_id_seq'),
  PROJECT_ID integer,
  URL VARCHAR(255) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);
CREATE INDEX "IX_stamp_PROJECT_ID" ON "stamp" (PROJECT_ID);

CREATE SEQUENCE "information_read_user_id_seq";
CREATE TABLE information_read_user (
  ID integer NOT NULL default nextval('information_read_user_id_seq'),
  INFORMATION_ID integer NOT NULL,
  USER_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_information_user_INFORMATION_ID FOREIGN KEY (INFORMATION_ID) REFERENCES information (ID) ON DELETE CASCADE,
  CONSTRAINT FK_information_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_information_read_user_INFORMATION_ID" ON "information_read_user" (INFORMATION_ID);
CREATE INDEX "IX_information_read_user_USER_ID" ON "information_read_user" (USER_ID);

ALTER TABLE "nulab_account"
ADD COLUMN INVITATION_NULAB_ID varchar(255) default NULL,
ADD COLUMN ROLE varchar(15) default NULL,
ADD COLUMN USE_MFA boolean default NULL,
ADD COLUMN ACCEPTED_INVITATION boolean NOT NULL DEFAULT TRUE,
ADD UNIQUE(INVITATION_NULAB_ID)
;

ALTER TABLE "party"
ADD COLUMN NULAB_APPS_GROUP_KEY varchar(50) default NULL,
ADD UNIQUE(NULAB_APPS_GROUP_KEY)
;

ALTER TABLE licence ADD NULAB_APPS_INTEGRATION boolean NOT NULL default FALSE;
ALTER TABLE licence_type ADD NULAB_APPS_INTEGRATION boolean NOT NULL default FALSE;
ALTER TABLE space ALTER NAME TYPE varchar(100);

CREATE SEQUENCE "nulab_apps_space_id_seq";
CREATE TABLE nulab_apps_space (
  ID integer NOT NULL default nextval('nulab_apps_space_id_seq'),
  BACKLOG_SPACE_ID integer NOT NULL default 0,
  SPACE_KEY varchar(50) NOT NULL,
  NAME VARCHAR(100) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (SPACE_KEY),
  CONSTRAINT FK_nulab_apps_space_BACKLOG_SPACE_ID FOREIGN KEY (BACKLOG_SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

BEGIN;

update licence set NEW_UI = TRUE;
update licence_type set NEW_UI = TRUE;
update licence set PROJECT_GROUP = TRUE;
update licence_type set PROJECT_GROUP = TRUE;

INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/animal_hokkyokuusagi.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/animal_hokkyokuusagi_stand.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/LGTM-uchida-transparent.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_01_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_02_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_03_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_04_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/miho_05_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_01_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_02_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_03_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_04_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/illustya_05_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_01_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_02_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_03_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_04_.png','2016-10-05','2016-10-05');
INSERT INTO stamp (URL, CREATED, UPDATED) VALUES ('shared/default_stamp/nakagawa_05_.png','2016-10-05','2016-10-05');

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-01-01', '元日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-01-01' and NAME='元日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-01-02', '振替休日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-01-02' and NAME='振替休日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-01-09', '成人の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-01-09' and NAME='成人の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-02-11', '建国記念の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-02-11' and NAME='建国記念の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-03-20', '春分の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-03-20' and NAME='春分の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-04-29', '昭和の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-04-29' and NAME='昭和の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-05-03', '憲法記念日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-05-03' and NAME='憲法記念日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-05-04', 'みどりの日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-05-04' and NAME='みどりの日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-05-05', 'こどもの日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-05-05' and NAME='こどもの日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-07-17', '海の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-07-17' and NAME='海の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-08-11', '山の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-08-11' and NAME='山の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-09-18', '敬老の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-09-18' and NAME='敬老の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-09-23', '秋分の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-09-23' and NAME='秋分の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-10-09', '体育の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-10-09' and NAME='体育の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-11-03', '文化の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-11-03' and NAME='文化の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-11-23', '勤労感謝の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-11-23' and NAME='勤労感謝の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2017-12-23', '天皇誕生日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2017-12-23' and NAME='天皇誕生日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-01-01', '元日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-01-01' and NAME='元日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-01-08', '成人の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-01-08' and NAME='成人の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-02-11', '建国記念の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-02-11' and NAME='建国記念の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-02-12', '振替休日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-02-12' and NAME='振替休日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-03-21', '春分の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-03-21' and NAME='春分の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-04-29', '昭和の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-04-29' and NAME='昭和の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-04-30', '振替休日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-04-30' and NAME='振替休日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-05-03', '憲法記念日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-05-03' and NAME='憲法記念日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-05-04', 'みどりの日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-05-04' and NAME='みどりの日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-05-05', 'こどもの日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-05-05' and NAME='こどもの日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-07-16', '海の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-07-16' and NAME='海の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-08-11', '山の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-08-11' and NAME='山の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-09-17', '敬老の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-09-17' and NAME='敬老の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-09-23', '秋分の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-09-23' and NAME='秋分の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-09-24', '振替休日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-09-24' and NAME='振替休日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-10-08', '体育の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-10-08' and NAME='体育の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-11-03', '文化の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-11-03' and NAME='文化の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-11-23', '勤労感謝の日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-11-23' and NAME='勤労感謝の日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-12-23', '天皇誕生日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-12-23' and NAME='天皇誕生日');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) SELECT '2018-12-24', '振替休日', '2016-12-01', '2016-12-01' WHERE NOT EXISTS ( SELECT date FROM holiday WHERE DATE = '2018-12-24' and NAME='振替休日');

UPDATE licence_type SET REMOTE_ADDRESS_LIMIT = 65535 WHERE ID = 100;
UPDATE licence SET REMOTE_ADDRESS_LIMIT = 65535 WHERE LICENCE_TYPE_ID = 100;

update licence_type set name='スターター' where id = 21;
update licence_type set name='スタンダード' where id = 41;
update licence_type set name='プレミアム' where id = 51;

COMMIT;