---
--- Backlog Package 1.4.X
---
ALTER TABLE dashboard ADD USE_PRIVATE_ADDRESS boolean NOT NULL DEFAULT FALSE;
ALTER TABLE dashboard ADD PRIVATE_ADDRESS_KEY VARCHAR(255);
CREATE UNIQUE INDEX "UQ_dashboard_PRIVATE_ADDRESS_KEY" ON dashboard (PRIVATE_ADDRESS_KEY);
CREATE INDEX IX_USE_PRIVATE_ADDRESS_AND_PRIVATE_ADDRESS_KEY ON dashboard (USE_PRIVATE_ADDRESS,PRIVATE_ADDRESS_KEY);
ALTER TABLE dashboard RENAME TO user_setting;

ALTER TABLE licence ADD TRIAL_EXPIRY_DATE timestamp DEFAULT NULL;
ALTER TABLE licence_changelog ADD TRIAL_EXPIRY_DATE timestamp DEFAULT NULL;

ALTER TABLE space_contact ADD POST text default NULL;
ALTER TABLE space_contact ADD POSITION text default NULL;
ALTER TABLE space_contact_changelog ADD POST text default NULL;
ALTER TABLE space_contact_changelog ADD POSITION text default NULL;

CREATE SEQUENCE "star_id_seq";
CREATE TABLE star (
  ID integer NOT NULL default nextval('star_id_seq'),
  AWARD_ID integer default NULL,
  PRESENTER_ID integer default NULL,
  PROJECT_ID integer default NULL,
  URL varchar(735) NOT NULL default '',
  TITLE varchar(255) NOT NULL default '',
  COMMENT varchar(100) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_star_AWARD_ID FOREIGN KEY (AWARD_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_star_PRESENTER_ID FOREIGN KEY (PRESENTER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_star_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_star_URL" ON "star" (URL);
CREATE INDEX "IX_star_CREATED" ON "star" (CREATED);

CREATE SEQUENCE "star_notify_id_seq";
CREATE TABLE star_notify (
  ID integer NOT NULL default nextval('star_notify_id_seq'),
  STAR_ID integer default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_star_notify_STAR_ID FOREIGN KEY (STAR_ID) REFERENCES star (ID) ON DELETE CASCADE
);

CREATE TABLE user_profile (
  USER_ID integer NOT NULL,
  SEX boolean default NULL,
  LOCATION text default NULL,
  BIOGRAPHY text default NULL,
  URLS text default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID),
  CONSTRAINT FK_user_profile_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);

ALTER TABLE space ALTER COLUMN LANG TYPE varchar(5);
ALTER TABLE space ALTER COLUMN LANG SET NOT NULL;
ALTER TABLE space ALTER COLUMN LANG SET DEFAULT 'en';
ALTER TABLE users ALTER COLUMN LANG TYPE varchar(5);

DELETE FROM project_mail WHERE NOT EXISTS (SELECT * FROM project_user WHERE project_user.user_id = project_mail.user_id AND project_user.project_id = project_mail.project_id);

ALTER TABLE user_setting ADD LAST_UPDATED_NUM integer;
ALTER TABLE user_setting ADD LAST_UPDATED_DISABLED_TYPES varchar(255);

ALTER TABLE information ALTER COLUMN LANG TYPE varchar(5);
ALTER TABLE information ALTER COLUMN LANG SET NOT NULL;
ALTER TABLE information ALTER COLUMN LANG SET DEFAULT 'ja';

ALTER TABLE default_issue_type ALTER COLUMN LANG TYPE varchar(5);
ALTER TABLE default_issue_type ALTER COLUMN LANG SET NOT NULL;
ALTER TABLE default_issue_type ALTER COLUMN LANG SET DEFAULT 'ja';

CREATE INDEX "IX_autologin_user_CREATED" ON autologin_user (CREATED);

CREATE INDEX "IX_issue_CREATED_USER_ID_PROJECT_ID" ON issue (CREATED_USER_ID, PROJECT_ID);
CREATE INDEX "IX_issue_ASSIGNER_ID_PROJECT_ID" ON issue (ASSIGNER_ID, PROJECT_ID);

CREATE TABLE mobilelogin_user (
  ID varchar(255) NOT NULL,
  USER_ID integer NOT NULL default 0,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_mobilelogin_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);

CREATE TABLE user_recent_project (
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID),
  CONSTRAINT FK_recent_project_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_recent_project_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

UPDATE space SET NEED_INDEXING='1';
