CREATE TABLE reserved_space_key (
  SPACE_KEY varchar(255) NOT NULL,
  IS_REGEXP tinyint(1) NOT NULL default 0,
  PRIMARY KEY (SPACE_KEY)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
CREATE TABLE holiday (
  ID int(11) NOT NULL auto_increment,
  DATE datetime NOT NULL default '0000-00-00 00:00:00',
  NAME varchar(255) NOT NULL default '',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

UPDATE licence SET REMOTE_ADDRESS_LIMIT = 50 WHERE LICENCE_TYPE_ID IN (100) AND REMOTE_ADDRESS_LIMIT < 50;

ALTER TABLE comment MODIFY CONTENT MEDIUMTEXT, MODIFY CHANGELOG_XML LONGTEXT;
ALTER TABLE remote_address ADD MEMO varchar(255) default NULL AFTER MASK;

CREATE TABLE attribute (
  ID int(11) NOT NULL auto_increment,
  USE_ISSUE_TYPE tinyint(1) NOT NULL default '0',
  PROJECT_ID int(11) NOT NULL,
  ATTRIBUTE_TYPE_ID int(11) NOT NULL,
  REQUIRED tinyint(1) DEFAULT '0',
  LABEL varchar(255) NOT NULL default '''',
  DESCRIPTION varchar(255) NOT NULL default '''',
  PROPERTY_JSON text NOT NULL,
  DISPLAY_ORDER int(11) DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_attribute_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
) ENGINE=InnoDB AUTO_INCREMENT=1073741824 DEFAULT CHARSET=utf8;

CREATE TABLE issue_attribute (
  ID int(11) NOT NULL auto_increment,
  ISSUE_ID int(11) NOT NULL,
  ATTRIBUTE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_issue_attribute_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_attribute_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
) ENGINE=InnoDB AUTO_INCREMENT=1073741824 DEFAULT CHARSET=utf8;

CREATE TABLE issue_attribute_value (
  ID int(11) NOT NULL auto_increment,
  ISSUE_ATTRIBUTE_ID int(11) NOT NULL,
  ATTRIBUTE_ID int(11) NOT NULL,
  TEXT text,
  DATE date,
  NUMBER double,
  IDENTITY int(11),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_issue_attribute_value_ISSUE_ATTRIBUTE_ID FOREIGN KEY (ISSUE_ATTRIBUTE_ID) REFERENCES issue_attribute (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_attribute_value_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
) ENGINE=InnoDB AUTO_INCREMENT=1073741824 DEFAULT CHARSET=utf8;

CREATE TABLE attribute_issue_type(
  ATTRIBUTE_ID int(11) NOT NULL,
  ISSUE_TYPE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,  
  CONSTRAINT FK_attribute_issue_type_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  CONSTRAINT FK_attribute_issue_type_ISSUE_TYPE_ID FOREIGN KEY (ISSUE_TYPE_ID) REFERENCES issue_type (ID) ON DELETE CASCADE,  
  PRIMARY KEY (ATTRIBUTE_ID,ISSUE_TYPE_ID),
  KEY(ATTRIBUTE_ID),
  KEY(ISSUE_TYPE_ID)  
) ENGINE=InnoDB AUTO_INCREMENT=1073741824 DEFAULT CHARSET=utf8;

UPDATE users SET role_type = 255, updated = updated WHERE role_type = 127;

ALTER TABLE licence_type ADD ATTRIBUTE tinyint(1) NOT NULL default '0' AFTER BURNDOWN;
UPDATE licence_type SET attribute = false WHERE id IN (1,10,20,30,40,50,60,70);
UPDATE licence_type SET attribute = true WHERE id IN (100);

ALTER TABLE licence_type ADD ATTRIBUTE_LIMIT int(11) NOT NULL default '0' AFTER ATTRIBUTE;
UPDATE licence_type SET attribute_limit = 20 WHERE id IN (100);

ALTER TABLE licence ADD ATTRIBUTE tinyint(1) NOT NULL default '0' AFTER BURNDOWN;
UPDATE licence SET attribute = true;

ALTER TABLE licence ADD ATTRIBUTE_LIMIT int(11) NOT NULL default '0' AFTER ATTRIBUTE;
UPDATE licence SET ATTRIBUTE_LIMIT = 20;

ALTER TABLE licence_changelog ADD ATTRIBUTE tinyint(1) NOT NULL default '0' AFTER BURNDOWN;
ALTER TABLE licence_changelog ADD ATTRIBUTE_LIMIT int(11) NOT NULL default '0' AFTER ATTRIBUTE;

CREATE TABLE licence_change_request(
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  FROM_LICENCE_TYPE_ID int(11) NOT NULL,
  TO_LICENCE_TYPE_ID int(11) NOT NULL,
  CLOSE tinyint(1) NOT NULL default '0',
  CHANGED_ON datetime NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_licence_change_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_licence_change_request_FROM_LICENCE_TYPE_ID FOREIGN KEY (FROM_LICENCE_TYPE_ID) REFERENCES licence_type (ID),
  CONSTRAINT FK_licence_change_request_TO_LICENCE_TYPE_ID FOREIGN KEY (TO_LICENCE_TYPE_ID) REFERENCES licence_type (ID)  
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE payment_change_request(
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  FROM_PAYMENT int(11) NOT NULL,
  TO_PAYMENT int(11) NOT NULL,
  CONTENT text,
  CHANGED_ON datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),  
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_payment_change_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE  
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE billing (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  TYPE int(11) NOT NULL,
  PAYMENT int(11) NOT NULL,
  AMOUNT int(11) NOT NULL,
  DISCOUNT int(11) DEFAULT 0,
  DUE_DATE datetime NOT NULL,
  PAID_ON datetime DEFAULT NULL,
  PAID_NAME varchar(255) DEFAULT NULL,
  STARTED_ON datetime DEFAULT NULL,
  EXPIRED_ON datetime DEFAULT NULL,
  STATUS int(11) NOT NULL DEFAULT '1',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_billing_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE invoice (
  ID int(11) NOT NULL auto_increment,
  BILLING_ID int(11) NOT NULL,
  TYPE int(11) NOT NULL DEFAULT '1',
  STATUS int(11) NOT NULL DEFAULT '1',
  DUE_DATE datetime NOT NULL,
  SENDED_ON datetime DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_invoice_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE account_transfer_procedure (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  STATUS int(11) NOT NULL DEFAULT 0,
  SENDED_ON datetime DEFAULT NULL,
  DUE_DATE datetime DEFAULT NULL,
  RECEIVED_DUE_DATE datetime DEFAULT NULL,
  RECEIVED_ON datetime DEFAULT NULL,
  COMPLETED_ON datetime DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_account_transfer_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE account_transfer_result (
  ID int(11) NOT NULL auto_increment,
  STATUS int(11) NOT NULL,
  RESULT_DATE datetime NOT NULL,
  AMOUNT int(11) NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE billing_account_transfer_result (
  BILLING_ID int(11) NOT NULL,
  RESULT_ID int(11) NOT NULL,
  PRIMARY KEY (BILLING_ID, RESULT_ID),
  CONSTRAINT FK_billing_account_transfer_result_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE,
  CONSTRAINT FK_billing_account_transfer_result_RESULT_ID FOREIGN KEY (RESULT_ID) REFERENCES account_transfer_result (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE send_registration (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  STATUS int(11) NOT NULL DEFAULT 0,
  SENDED_ON datetime DEFAULT NULL,
  CREATED datetime NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_send_registration_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE send_registration_changed (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  OLD_PLAN varchar(255) NOT NULL,
  NEW_PLAN varchar(255) NOT NULL,
  STARTED_ON datetime NOT NULL,
  STATUS int(11) NOT NULL DEFAULT 0,
  SENDED_ON datetime DEFAULT NULL,
  CREATED datetime NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_send_registration_changed_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

ALTER TABLE subversion ADD COMMIT_ISSUE_UPDATE tinyint(1) DEFAULT 0 after SVN_PASSWORD;
ALTER TABLE billing ADD MEMO varchar(255) default NULL after STATUS;

ALTER TABLE users ADD AUTH_TYPE int(11) NOT NULL DEFAULT 0 after MAIL_ADDRESS;
ALTER TABLE users ADD AUTH_VALUE varchar(735) DEFAULT NULL after AUTH_TYPE;

SET NAMES 'utf8';
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (1, '2010-01-01 00.00.00', '元日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (2, '2010-01-11 00.00.00', '成人の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (3, '2010-02-11 00.00.00', '建国記念の日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (4, '2010-03-21 00.00.00', '春分の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (5, '2010-03-22 00.00.00', '振替休日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (6, '2010-04-29 00.00.00', '昭和の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (7, '2010-05-03 00.00.00', '憲法記念日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (8, '2010-05-04 00.00.00', 'みどりの日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (9, '2010-05-05 00.00.00', 'こどもの日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (10, '2010-07-19 00.00.00', '海の日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (11, '2010-09-20 00.00.00', '敬老の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (12, '2010-09-23 00.00.00', '秋分の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (13, '2010-10-11 00.00.00', '体育の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (14, '2010-11-03 00.00.00', '文化の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (15, '2010-11-23 00.00.00', '勤労感謝の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (16, '2010-12-23 00.00.00', '天皇誕生日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (17, '2011-01-01 00.00.00', '元日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (18, '2011-01-10 00.00.00', '成人の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (19, '2011-02-11 00.00.00', '建国記念の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (20, '2011-03-21 00.00.00', '春分の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (21, '2011-04-29 00.00.00', '昭和の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (22, '2011-05-03 00.00.00', '憲法記念日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (23, '2011-05-04 00.00.00', 'みどりの日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (24, '2011-05-05 00.00.00', 'こどもの日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (25, '2011-07-18 00.00.00', '海の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (26, '2011-09-19 00.00.00', '敬老の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (27, '2011-09-23 00.00.00', '秋分の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (28, '2011-10-10 00.00.00', '体育の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (29, '2011-11-03 00.00.00', '文化の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (30, '2011-11-23 00.00.00', '勤労感謝の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (31, '2011-12-23 00.00.00', '天皇誕生日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (32, '2012-01-01 00.00.00', '元日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (33, '2012-01-02 00.00.00', '振替休日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (34, '2012-01-09 00.00.00', '成人の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (35, '2012-02-11 00.00.00', '建国記念の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (36, '2012-03-20 00.00.00', '春分の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (37, '2012-04-29 00.00.00', '昭和の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (38, '2012-04-30 00.00.00', '振替休日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (39, '2012-05-03 00.00.00', '憲法記念日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (40, '2012-05-04 00.00.00', 'みどりの日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (41, '2012-05-05 00.00.00', 'こどもの日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (42, '2012-07-16 00.00.00', '海の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (43, '2012-09-17 00.00.00', '敬老の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (44, '2012-09-22 00.00.00', '秋分の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (45, '2012-10-08 00.00.00', '体育の日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (46, '2012-11-03 00.00.00', '文化の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (47, '2012-11-23 00.00.00', '勤労感謝の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (48, '2012-12-23 00.00.00', '天皇誕生日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (49, '2012-12-24 00.00.00', '振替休日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');


UPDATE space SET NEED_INDEXING='1';
