CREATE TABLE reserved_space_key (
  SPACE_KEY varchar(255) NOT NULL,
  IS_REGEXP boolean NOT NULL default FALSE,
  PRIMARY KEY (SPACE_KEY)
);

CREATE SEQUENCE "holiday_id_seq";
CREATE TABLE holiday (
  ID integer NOT NULL default nextval('holiday_id_seq'),
  DATE date NOT NULL,
  NAME varchar(255) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

UPDATE licence SET REMOTE_ADDRESS_LIMIT = 50 WHERE LICENCE_TYPE_ID IN (100) AND REMOTE_ADDRESS_LIMIT < 50;

ALTER TABLE remote_address ADD MEMO varchar(255) default NULL;

CREATE SEQUENCE "attribute_id_seq";
CREATE TABLE attribute (
  ID integer NOT NULL default nextval('attribute_id_seq'),
  USE_ISSUE_TYPE boolean NOT NULL default FALSE,
  PROJECT_ID integer NOT NULL,
  ATTRIBUTE_TYPE_ID integer NOT NULL,
  REQUIRED boolean DEFAULT FALSE,
  LABEL varchar(255) NOT NULL default '',
  DESCRIPTION varchar(255) NOT NULL default '',
  PROPERTY_JSON text NOT NULL,
  DISPLAY_ORDER integer DEFAULT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT "FK_attribute_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
);

CREATE SEQUENCE "issue_attribute_id_seq";
CREATE TABLE issue_attribute (
  ID integer NOT NULL default nextval('issue_attribute_id_seq'),
  ISSUE_ID integer NOT NULL,
  ATTRIBUTE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT "FK_issue_attribute_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_attribute_ATTRIBUTE_ID" FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
);

CREATE SEQUENCE "issue_attribute_value_id_seq";
CREATE TABLE issue_attribute_value (
  ID integer NOT NULL default nextval('issue_attribute_value_id_seq'),
  ISSUE_ATTRIBUTE_ID integer NOT NULL,
  ATTRIBUTE_ID integer NOT NULL,
  TEXT text,
  DATE date,
  NUMBER double precision,
  IDENTITY integer,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT "FK_issue_attribute_value_ISSUE_ATTRIBUTE_ID" FOREIGN KEY (ISSUE_ATTRIBUTE_ID) REFERENCES issue_attribute (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_attribute_value_ATTRIBUTE_ID" FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
);

CREATE TABLE attribute_issue_type (
  ATTRIBUTE_ID integer NOT NULL,
  ISSUE_TYPE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT "FK_attribute_issue_type_ATTRIBUTE_ID" FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_attribute_issue_type_ISSUE_TYPE_ID" FOREIGN KEY (ISSUE_TYPE_ID) REFERENCES issue_type (ID) ON DELETE CASCADE,  
  PRIMARY KEY (ATTRIBUTE_ID,ISSUE_TYPE_ID)
);
CREATE INDEX "IX_attribute_issue_type_ATTRIBUTE_ID" ON attribute_issue_type (ATTRIBUTE_ID);
CREATE INDEX "IX_attribute_issue_type_ISSUE_TYPE_ID" ON attribute_issue_type (ISSUE_TYPE_ID);

UPDATE users SET role_type = 255, updated = updated WHERE role_type = 127;

ALTER TABLE licence_type ADD ATTRIBUTE boolean NOT NULL default FALSE;
UPDATE licence_type SET attribute = FALSE WHERE id IN (1,10,20,30,40,50,60,70);
UPDATE licence_type SET attribute = TRUE WHERE id IN (100);

ALTER TABLE licence_type ADD ATTRIBUTE_LIMIT integer NOT NULL default '0';

ALTER TABLE licence ADD ATTRIBUTE boolean NOT NULL default FALSE;
UPDATE licence SET attribute = TRUE;

ALTER TABLE licence ADD ATTRIBUTE_LIMIT integer NOT NULL default '0';
UPDATE licence SET ATTRIBUTE_LIMIT = 20;

ALTER TABLE licence_changelog ADD ATTRIBUTE boolean NOT NULL default FALSE;
ALTER TABLE licence_changelog ADD ATTRIBUTE_LIMIT integer NOT NULL default '0';

CREATE SEQUENCE "licence_change_request_id_seq";
CREATE TABLE licence_change_request (
  ID integer NOT NULL default nextval('licence_change_request_id_seq'),
  SPACE_ID integer NOT NULL,
  FROM_LICENCE_TYPE_ID integer NOT NULL,
  TO_LICENCE_TYPE_ID integer NOT NULL,
  CLOSE boolean NOT NULL default FALSE,
  CHANGED_ON timestamp NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT "FK_licence_change_request_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_licence_change_request_FROM_LICENCE_TYPE_ID" FOREIGN KEY (FROM_LICENCE_TYPE_ID) REFERENCES licence_type (ID),
  CONSTRAINT "FK_licence_change_request_TO_LICENCE_TYPE_ID" FOREIGN KEY (TO_LICENCE_TYPE_ID) REFERENCES licence_type (ID)  
);
CREATE INDEX "IX_licence_change_request_SPACE_ID" ON licence_change_request (SPACE_ID);

CREATE SEQUENCE "payment_change_request_id_seq";
CREATE TABLE payment_change_request (
  ID integer NOT NULL default nextval('payment_change_request_id_seq'),
  SPACE_ID integer NOT NULL,
  FROM_PAYMENT integer NOT NULL,
  TO_PAYMENT integer NOT NULL,
  CONTENT text,
  CHANGED_ON timestamp default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),  
  CONSTRAINT "FK_payment_change_request_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE  
);
CREATE INDEX "IX_payment_change_request_SPACE_ID" ON payment_change_request (SPACE_ID);

CREATE SEQUENCE "billing_id_seq";
CREATE TABLE billing (
  ID integer NOT NULL default nextval('billing_id_seq'),
  SPACE_ID integer NOT NULL,
  TYPE integer NOT NULL,
  PAYMENT integer NOT NULL,
  AMOUNT integer NOT NULL,
  DISCOUNT integer DEFAULT 0,
  DUE_DATE date NOT NULL,
  PAID_ON date DEFAULT NULL,
  PAID_NAME varchar(255) DEFAULT NULL,
  STARTED_ON date DEFAULT NULL,
  EXPIRED_ON date DEFAULT NULL,
  STATUS integer NOT NULL DEFAULT '1',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_billing_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "invoice_id_seq";
CREATE TABLE invoice (
  ID integer NOT NULL default nextval('invoice_id_seq'),
  BILLING_ID integer NOT NULL,
  TYPE integer NOT NULL DEFAULT '1',
  STATUS integer NOT NULL DEFAULT '1',
  DUE_DATE date NOT NULL,
  SENDED_ON date DEFAULT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT "FK_invoice_BILLING_ID" FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "account_transfer_procedure_id_seq";
CREATE TABLE account_transfer_procedure (
  ID integer NOT NULL default nextval('account_transfer_procedure_id_seq'),
  SPACE_ID integer NOT NULL,
  STATUS integer NOT NULL DEFAULT 0,
  SENDED_ON date DEFAULT NULL,
  DUE_DATE date DEFAULT NULL,
  RECEIVED_DUE_DATE date DEFAULT NULL,
  RECEIVED_ON date DEFAULT NULL,
  COMPLETED_ON date DEFAULT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT "FK_account_transfer_request_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "account_transfer_result_id_seq";
CREATE TABLE account_transfer_result (
  ID integer NOT NULL default nextval('account_transfer_result_id_seq'),
  STATUS integer NOT NULL,
  RESULT_DATE date NOT NULL,
  AMOUNT integer NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

CREATE TABLE billing_account_transfer_result (
  BILLING_ID integer NOT NULL,
  RESULT_ID integer NOT NULL,
  PRIMARY KEY (BILLING_ID, RESULT_ID),
  CONSTRAINT "FK_billing_account_transfer_result_BILLING_ID" FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_billing_account_transfer_result_RESULT_ID" FOREIGN KEY (RESULT_ID) REFERENCES account_transfer_result (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "send_registration_id_seq";
CREATE TABLE send_registration (
  ID integer NOT NULL default nextval('send_registration_id_seq'),
  SPACE_ID integer NOT NULL,
  STATUS integer NOT NULL DEFAULT 0,
  SENDED_ON date DEFAULT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT "FK_send_registration_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "send_registration_changed_id_seq";
CREATE TABLE send_registration_changed (
  ID integer NOT NULL default nextval('send_registration_changed_id_seq'),
  SPACE_ID integer NOT NULL,
  OLD_PLAN varchar(255) NOT NULL,
  NEW_PLAN varchar(255) NOT NULL,
  STARTED_ON date NOT NULL,
  STATUS integer NOT NULL DEFAULT 0,
  SENDED_ON date DEFAULT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT "FK_send_registration_changed_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

ALTER TABLE subversion ADD COMMIT_ISSUE_UPDATE boolean DEFAULT FALSE;
ALTER TABLE billing ADD MEMO varchar(255) default NULL;

ALTER TABLE users ADD AUTH_TYPE integer NOT NULL DEFAULT 0;
ALTER TABLE users ADD AUTH_VALUE varchar(735) DEFAULT NULL;

INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (1, '2010-01-01', '元日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (2, '2010-01-11', '成人の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (3, '2010-02-11', '建国記念の日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (4, '2010-03-21', '春分の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (5, '2010-03-22', '振替休日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (6, '2010-04-29', '昭和の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (7, '2010-05-03', '憲法記念日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (8, '2010-05-04', 'みどりの日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (9, '2010-05-05', 'こどもの日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (10, '2010-07-19', '海の日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (11, '2010-09-20', '敬老の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (12, '2010-09-23', '秋分の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (13, '2010-10-11', '体育の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (14, '2010-11-03', '文化の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (15, '2010-11-23', '勤労感謝の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (16, '2010-12-23', '天皇誕生日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (17, '2011-01-01', '元日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (18, '2011-01-10', '成人の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (19, '2011-02-11', '建国記念の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (20, '2011-03-21', '春分の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (21, '2011-04-29', '昭和の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (22, '2011-05-03', '憲法記念日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (23, '2011-05-04', 'みどりの日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (24, '2011-05-05', 'こどもの日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (25, '2011-07-18', '海の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (26, '2011-09-19', '敬老の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (27, '2011-09-23', '秋分の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (28, '2011-10-10', '体育の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (29, '2011-11-03', '文化の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (30, '2011-11-23', '勤労感謝の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (31, '2011-12-23', '天皇誕生日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (32, '2012-01-01', '元日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (33, '2012-01-02', '振替休日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (34, '2012-01-09', '成人の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (35, '2012-02-11', '建国記念の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (36, '2012-03-20', '春分の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (37, '2012-04-29', '昭和の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (38, '2012-04-30', '振替休日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (39, '2012-05-03', '憲法記念日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (40, '2012-05-04', 'みどりの日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (41, '2012-05-05', 'こどもの日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (42, '2012-07-16', '海の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (43, '2012-09-17', '敬老の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (44, '2012-09-22', '秋分の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (45, '2012-10-08', '体育の日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (46, '2012-11-03', '文化の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (47, '2012-11-23', '勤労感謝の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (48, '2012-12-23', '天皇誕生日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (ID, DATE, NAME, CREATED, UPDATED) VALUES (49, '2012-12-24', '振替休日', '2009-04-12', '2009-04-12');

UPDATE space SET NEED_INDEXING='1';
