SET NAMES 'utf8';

ALTER TABLE users MODIFY COLUMN USER_ID varchar(255) binary NOT NULL default '';
ALTER TABLE users MODIFY COLUMN NAME varchar(100);
ALTER TABLE users MODIFY COLUMN MAIL_ADDRESS varchar(320);

ALTER TABLE project ADD ICON varchar(255) AFTER USE_BURNDOWN;

ALTER TABLE user_setting ADD USE_NEW_UI tinyint(1) DEFAULT 1 AFTER LAST_UPDATED_DISABLED_TYPES;

ALTER TABLE user_recent_project ADD CREATED_USER_ID int(11) AFTER PROJECT_ID;
ALTER TABLE user_recent_project ADD UPDATED_USER_ID int(11) AFTER CREATED;
ALTER TABLE user_recent_project ADD UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP AFTER UPDATED_USER_ID;
UPDATE user_recent_project SET UPDATED = CREATED;

ALTER TABLE mail ADD ANNOUNCEMENT tinyint(1) DEFAULT NULL AFTER COMMENT;

ALTER TABLE space ADD REPORT_SEND_TIME time DEFAULT null AFTER TIMEZONE;
UPDATE space SET REPORT_SEND_TIME = '08:00:00', updated = updated;

ALTER TABLE information ADD TARGET_USER_CREATED_AFTER datetime DEFAULT null AFTER TO_DATE;
ALTER TABLE information ADD TARGET_USER_CREATED_BEFORE datetime DEFAULT null AFTER TARGET_USER_CREATED_AFTER;
ALTER TABLE information MODIFY COLUMN INFO_KEY varchar(255);

CREATE INDEX IX_user_recent_project_USER_ID_CREATED ON user_recent_project (USER_ID, CREATED);

ALTER TABLE licence_type ADD GIT tinyint(1) NOT NULL default '0' AFTER SUBVERSION_EXTERNAL;
ALTER TABLE licence ADD GIT tinyint(1) NOT NULL default '0' AFTER SUBVERSION_EXTERNAL;
ALTER TABLE licence_changelog ADD GIT tinyint(1) NOT NULL default '0' AFTER SUBVERSION_EXTERNAL;

ALTER TABLE project_mail ADD GIT tinyint(1) default NULL AFTER SUBVERSION;
UPDATE project_mail SET git = subversion, updated = updated;

UPDATE licence_type SET attribute_limit = 100 WHERE id = 100;
UPDATE licence SET attribute_limit = 100, updated = updated;
UPDATE licence_type SET remote_address_limit = 50 WHERE id = 100;
UPDATE licence SET remote_address_limit = 50, updated = updated;

ALTER TABLE issue_attribute_value MODIFY `DATE` datetime;

CREATE TABLE space_information (
  SPACE_ID int(11) NOT NULL default '0',
  CONTENT mediumtext,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (SPACE_ID),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_space_information_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_activity (
  ID bigint(20) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE int(11) NOT NULL,
  CONTENT_JSON longtext,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID_CREATED_TYPE_CREATED_USER_ID (PROJECT_ID, CREATED DESC, TYPE, CREATED_USER_ID),
  CONSTRAINT FK_project_activity_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_recent_issue (
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  ISSUE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,ISSUE_ID),
  KEY IX_user_recent_issue_USER_ID_CREATED (USER_ID, CREATED),
  CONSTRAINT FK_user_recent_issue_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_recent_page (
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  PAGE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,PAGE_ID),
  KEY IX_user_recent_page_USER_ID_CREATED (USER_ID, CREATED),
  CONSTRAINT FK_user_recent_page_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_activity_notify (
  ID bigint(20) NOT NULL auto_increment,
  PROJECT_ACTIVITY_ID bigint(20) NOT NULL default '0',
  USER_ID int(11) NOT NULL default '0',
  REASON int(11),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ACTIVITY_ID_USER_ID (PROJECT_ACTIVITY_ID, USER_ID),
  CONSTRAINT FK_project_activity_notify_PROJECT_ACTIVITY_ID FOREIGN KEY (PROJECT_ACTIVITY_ID) REFERENCES project_activity (ID) ON DELETE CASCADE,
  CONSTRAINT FK_project_activity_notify_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_filter_condition (
  ID int(11) NOT NULL auto_increment,
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) default NULL,
  NAME text,
  CONDITION_XML longtext,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_issue_filter_condition_USER_ID_UPDATED (USER_ID, UPDATED),
  CONSTRAINT FK_issue_filter_condition_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_ssh_key (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  USER_ID int(11) NOT NULL,
  CONTENT mediumtext NOT NULL,
  FINGERPRINT varchar(47) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_USER_ID (USER_ID, FINGERPRINT),
  UNIQUE UQ_user_ssh_key_SPACE_ID_FINGERPRINT (SPACE_ID, FINGERPRINT),
  CONSTRAINT FK_user_ssh_key_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE git (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE SMALLINT NOT NULL,
  COMMIT_ISSUE_UPDATE tinyint(1) default 0,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_git_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE repository (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE SMALLINT NOT NULL,
  NAME varchar(255) BINARY NOT NULL default '',
  DESCRIPTION varchar(255) default NULL,
  DISPLAY_ORDER int(11) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE UQ_repository_PROJECT_ID_NAME (PROJECT_ID, TYPE, NAME),
  CONSTRAINT FK_repository_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE revision (
  ID int(11) NOT NULL auto_increment,
  REPOSITORY_ID int(11) NOT NULL default '0',
  REVISION varchar(255) NOT NULL,
  MESSAGE mediumtext,
  AUTHOR varchar(735),
  AUTHOR_MAIL_ADDRESS varchar(735),
  AUTHOR_USER_ID int(11) default NULL,
  COMMITTED_ON datetime NOT NULL default '0000-00-00 00:00:00',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_REVISION (REVISION),
  UNIQUE UQ_revision_REPOSITORY_ID_REVISION (REPOSITORY_ID, REVISION),
  CONSTRAINT FK_revesion_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE,
  CONSTRAINT FK_revesion_AUTHOR_USER_ID FOREIGN KEY (AUTHOR_USER_ID) REFERENCES users (ID) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE revision_change (
  ID int(11) NOT NULL auto_increment,
  REVISION_ID int(11) NOT NULL default '0',
  CHANGE_TYPE varchar(1) NOT NULL,
  PATH text NOT NULL,
  PATH_TYPE varchar(1) NOT NULL,
  BASE_PATH text,
  BASE_REVISION varchar(255),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_REVISION_ID (REVISION_ID),
  CONSTRAINT FK_revision_change_REVISION_ID FOREIGN KEY (REVISION_ID) REFERENCES revision (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_revision (
  ISSUE_ID int(11) NOT NULL,
  LINK_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ISSUE_ID,LINK_ID),
  CONSTRAINT FK_issue_revision_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_revision_LINK_ID FOREIGN KEY (LINK_ID) REFERENCES revision (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE job_page_updated (
  ID bigint(20) NOT NULL auto_increment,
  PAGE_ID int(11) NOT NULL,
  TYPE SMALLINT NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE job_shared_file_updated (
  ID bigint(20) NOT NULL auto_increment,
  SHARED_FILE_ID int(11) NOT NULL,
  TYPE SMALLINT NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-01 00.00.00', '元日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-14 00.00.00', '成人の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-02-11 00.00.00', '建国記念の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-03-20 00.00.00', '春分の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-04-29 00.00.00', '昭和の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-03 00.00.00', '憲法記念日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-04 00.00.00', 'みどりの日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-05 00.00.00', 'こどもの日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-06 00.00.00', '振替休日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-07-15 00.00.00', '海の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-16 00.00.00', '敬老の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-23 00.00.00', '秋分の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-10-14 00.00.00', '体育の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-03 00.00.00', '文化の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-04 00.00.00', '振替休日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-23 00.00.00', '勤労感謝の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-12-23 00.00.00', '天皇誕生日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');

UPDATE space SET NEED_INDEXING='1';
