ALTER TABLE users ALTER USER_ID TYPE varchar(255);
ALTER TABLE users ALTER NAME TYPE varchar(100);
ALTER TABLE users ALTER MAIL_ADDRESS TYPE varchar(320);

ALTER TABLE project ADD ICON varchar(255);

ALTER TABLE user_setting ADD USE_NEW_UI boolean DEFAULT TRUE;

ALTER TABLE user_recent_project ADD CREATED_USER_ID integer;
ALTER TABLE user_recent_project ADD UPDATED_USER_ID integer;
ALTER TABLE user_recent_project ADD UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP;
UPDATE user_recent_project SET UPDATED = CREATED;

ALTER TABLE mail ADD ANNOUNCEMENT boolean DEFAULT NULL;

ALTER TABLE space ADD REPORT_SEND_TIME time DEFAULT NULL;
UPDATE space SET REPORT_SEND_TIME = '08:00:00', updated = updated;

ALTER TABLE information ADD TARGET_USER_CREATED_AFTER timestamp DEFAULT NULL;
ALTER TABLE information ADD TARGET_USER_CREATED_BEFORE timestamp DEFAULT NULL;
ALTER TABLE information ALTER INFO_KEY TYPE varchar(255);

CREATE INDEX IX_user_recent_project_USER_ID_CREATED ON user_recent_project (USER_ID, CREATED);

ALTER TABLE licence_type ADD GIT boolean NOT NULL default FALSE;
ALTER TABLE licence ADD GIT boolean NOT NULL default FALSE;
ALTER TABLE licence_changelog ADD GIT boolean NOT NULL default FALSE;

ALTER TABLE project_mail ADD GIT boolean default NULL;
UPDATE project_mail SET git = subversion, updated = updated;

UPDATE licence_type SET attribute_limit = 100 WHERE id = 100;
UPDATE licence SET attribute_limit = 100, updated = updated;
UPDATE licence_type SET remote_address_limit = 50 WHERE id = 100;
UPDATE licence SET remote_address_limit = 50, updated = updated;

ALTER TABLE issue_attribute_value ALTER DATE TYPE timestamp;

CREATE TABLE space_remarks (
  SPACE_ID integer NOT NULL,
  CONTENT text,
  SPECIAL_SUPPORT integer default NULL,
  SPECIAL_SUPPORT_CONTENT text default NULL,
  SPECIAL_SUPPORT_CONSOLIDATED_BILLING_SPACES varchar(255) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_ID),
  CONSTRAINT FK_space_remarks_1 FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE TABLE space_information (
  SPACE_ID integer NOT NULL,
  CONTENT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (SPACE_ID),
  CONSTRAINT FK_space_information_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_space_information_SPACE_ID" ON "space_information" (SPACE_ID);

CREATE SEQUENCE "project_activity_id_seq";
CREATE TABLE project_activity (
  ID bigint NOT NULL default nextval('project_activity_id_seq'),
  PROJECT_ID integer NOT NULL default '0',
  TYPE integer NOT NULL,
  CONTENT_JSON text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_project_activity_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_activity_PROJECT_ID_CREATED_TYPE_CREATED_USER_ID" ON "project_activity" (PROJECT_ID, CREATED, TYPE, CREATED_USER_ID);

CREATE TABLE user_recent_issue (
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  ISSUE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,ISSUE_ID),
  CONSTRAINT FK_user_recent_issue_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_recent_issue_USER_ID_CREATED" ON "user_recent_issue" (USER_ID, CREATED);

CREATE TABLE user_recent_page (
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  PAGE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,PAGE_ID),
  CONSTRAINT FK_user_recent_page_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_recent_page_USER_ID_CREATED" ON "user_recent_page" (USER_ID, CREATED);

CREATE SEQUENCE "project_activity_notify_id_seq";
CREATE TABLE project_activity_notify (
  ID bigint NOT NULL default nextval('project_activity_notify_id_seq'),
  PROJECT_ACTIVITY_ID bigint NOT NULL,
  USER_ID integer NOT NULL,
  REASON integer,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_project_activity_notify_PROJECT_ACTIVITY_ID FOREIGN KEY (PROJECT_ACTIVITY_ID) REFERENCES project_activity (ID) ON DELETE CASCADE,
  CONSTRAINT FK_project_activity_notify_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_activity_notify_PROJECT_ACTIVITY_ID_USER_ID" ON "project_activity_notify" (PROJECT_ACTIVITY_ID, USER_ID);

CREATE SEQUENCE "issue_filter_condition_id_seq";
CREATE TABLE issue_filter_condition (
  ID integer NOT NULL default nextval('issue_filter_condition_id_seq'),
  USER_ID integer NOT NULL,
  PROJECT_ID integer default NULL,
  NAME text,
  CONDITION_XML text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_issue_filter_condition_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_filter_condition_USER_ID_UPDATED" ON "issue_filter_condition" (USER_ID, UPDATED);

CREATE SEQUENCE "user_ssh_key_id_seq";
CREATE TABLE user_ssh_key (
  ID integer NOT NULL default nextval('user_ssh_key_id_seq'),
  SPACE_ID integer NOT NULL,
  USER_ID integer NOT NULL,
  CONTENT text NOT NULL,
  FINGERPRINT varchar(47) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (SPACE_ID, FINGERPRINT),
  CONSTRAINT FK_user_ssh_key_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_ssh_key_USER_ID_FINGERPRINT" ON "user_ssh_key" (USER_ID, FINGERPRINT);

CREATE SEQUENCE "git_id_seq";
CREATE TABLE git (
  ID integer NOT NULL default nextval('git_id_seq'),
  PROJECT_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  COMMIT_ISSUE_UPDATE boolean default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (PROJECT_ID),
  CONSTRAINT FK_git_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "repository_id_seq";
CREATE TABLE repository (
  ID integer NOT NULL default nextval('repository_id_seq'),
  PROJECT_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  NAME varchar(255) NOT NULL,
  DESCRIPTION varchar(255) default NULL,
  DISPLAY_ORDER integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (PROJECT_ID, TYPE, NAME),
  CONSTRAINT FK_repository_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "revision_id_seq";
CREATE TABLE revision (
  ID integer NOT NULL default nextval('revision_id_seq'),
  REPOSITORY_ID integer NOT NULL,
  REVISION varchar(255) NOT NULL,
  MESSAGE text,
  AUTHOR varchar(735),
  AUTHOR_MAIL_ADDRESS varchar(735),
  AUTHOR_USER_ID integer default NULL,
  COMMITTED_ON timestamp NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (REPOSITORY_ID, REVISION),
  CONSTRAINT FK_revesion_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE,
  CONSTRAINT FK_revesion_AUTHOR_USER_ID FOREIGN KEY (AUTHOR_USER_ID) REFERENCES users (ID) ON DELETE SET NULL
);
CREATE INDEX "IX_revision_REVISION" ON "revision" (REVISION);

CREATE SEQUENCE "revision_change_id_seq";
CREATE TABLE revision_change (
  ID integer NOT NULL default nextval('revision_change_id_seq'),
  REVISION_ID integer NOT NULL,
  CHANGE_TYPE varchar(1) NOT NULL,
  PATH text NOT NULL,
  PATH_TYPE varchar(1) NOT NULL,
  BASE_PATH text,
  BASE_REVISION varchar(255),
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_revision_change_REVISION_ID FOREIGN KEY (REVISION_ID) REFERENCES revision (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_revision_change_REVISION_ID" ON "revision_change" (REVISION_ID);

CREATE TABLE issue_revision (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ISSUE_ID,LINK_ID),
  CONSTRAINT FK_issue_revision_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_revision_LINK_ID FOREIGN KEY (LINK_ID) REFERENCES revision (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "job_page_updated_id_seq";
CREATE TABLE job_page_updated (
  ID bigint NOT NULL default nextval('job_page_updated_id_seq'),
  PAGE_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_job_page_updated_CREATED" ON "job_page_updated" (CREATED);

CREATE SEQUENCE "job_shared_file_updated_id_seq";
CREATE TABLE job_shared_file_updated (
  ID bigint NOT NULL default nextval('job_shared_file_updated_id_seq'),
  SHARED_FILE_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_job_shared_file_updated_CREATED" ON "job_shared_file_updated" (CREATED);

SELECT setval('holiday_id_seq', 49);
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-01', '元日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-14', '成人の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-02-11', '建国記念の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-03-20', '春分の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-04-29', '昭和の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-03', '憲法記念日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-04', 'みどりの日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-05', 'こどもの日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-06', '振替休日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-07-15', '海の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-16', '敬老の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-23', '秋分の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-10-14', '体育の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-03', '文化の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-04', '振替休日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-23', '勤労感謝の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-12-23', '天皇誕生日', '2012-08-04', '2012-08-04');

UPDATE space SET NEED_INDEXING='1';
