SET NAMES 'utf8';

CREATE TABLE service_type (
  ID int(11) NOT NULL auto_increment,
  NAME varchar(20) NOT NULL default '',
  TARGET char(5) NOT NULL,
  DEFAULT_LICENCE_TYPE_ID int(11) default NULL,
  PREFIX_PATH char(6) NOT NULL,
  CURRENCY_CODE char(3) NOT NULL,
  CURRENCY_UNIT varchar(6) NOT NULL,
  CURRENCY_UNIT_HEAD tinyint(1) NOT NULL default 1,
  CURRENCY_UNIT_AMOUNT int(11) NOT NULL,
  CURRENCY_FORMAT char(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

ALTER TABLE space ADD SERVICE_TYPE_ID int(11) default null AFTER TIMEZONE;
ALTER TABLE space ADD TEXT_FORMATTING_RULE varchar(255) default NULL AFTER NEED_INDEXING;
ALTER TABLE space ADD CONSTRAINT `FK_space_SERVICE_TYPE_ID` FOREIGN KEY (`SERVICE_TYPE_ID`) REFERENCES `service_type` (`ID`) ON DELETE CASCADE;

ALTER TABLE project ADD COLUMN USE_PARENT_CHILD_ISSUE tinyint(1) default NULL AFTER USE_BURNDOWN;
ALTER TABLE project ADD TEXT_FORMATTING_RULE varchar(255) default NULL AFTER ICON;

ALTER TABLE issue ADD COLUMN PARENT_ISSUE_ID int(11) default NULL AFTER ACTUAL_HOURS;
CREATE INDEX IX_PARENT_ISSUE_ID ON issue (PARENT_ISSUE_ID);

ALTER TABLE licence_type ADD COLUMN PARENT_CHILD_ISSUE tinyint(1) NOT NULL default '0' AFTER BURNDOWN;
ALTER TABLE licence_type ADD SERVICE_TYPE_ID int(11) default null AFTER SELECTABLE;
ALTER TABLE licence_type ADD CONSTRAINT `FK_licence_type_SERVICE_TYPE_ID` FOREIGN KEY (`SERVICE_TYPE_ID`) REFERENCES `service_type` (`ID`) ON DELETE CASCADE;
UPDATE licence_type SET parent_child_issue = 1, updated = updated WHERE ID >= 20;

ALTER TABLE licence ADD COLUMN PARENT_CHILD_ISSUE tinyint(1) NOT NULL default '0' AFTER BURNDOWN;
UPDATE licence SET parent_child_issue = 1, updated = updated WHERE LICENCE_TYPE_ID >= 20;

ALTER TABLE licence_changelog ADD COLUMN PARENT_CHILD_ISSUE tinyint(1) NOT NULL default '0' AFTER BURNDOWN;

ALTER TABLE mail ADD FORCE_UTF8 tinyint(1) DEFAULT NULL AFTER ANNOUNCEMENT;
ALTER TABLE mail ADD COLUMN EXCLUDE_MAIL_TYPE_IN_SUBJECT TINYINT(1) default NULL AFTER FORCE_UTF8;

ALTER TABLE user_setting ADD COLUMN USE_COLLAPSE_COMMENT TINYINT(1) NULL DEFAULT 1 AFTER USE_NEW_UI;

ALTER TABLE project_user ADD PROJECT_LEADER tinyint(1) default NULL AFTER USER_ID;

ALTER TABLE space_contact ADD GENDER varchar(1) DEFAULT NULL AFTER PERSON;

ALTER TABLE space_contact_changelog ADD GENDER varchar(1) DEFAULT NULL AFTER PERSON;

ALTER TABLE shared_file MODIFY DIR text binary default NULL, MODIFY NAME text binary default NULL;
CREATE INDEX IX_PROJECT_ID_DIR_NAME ON shared_file (PROJECT_ID, DIR(255), NAME(255));

ALTER TABLE issue_attribute_value DROP COLUMN VALUE;

CREATE INDEX IX_USER_ID ON user_recent_issue (USER_ID);

CREATE INDEX IX_USER_ID ON user_recent_page (USER_ID);

ALTER TABLE project_activity_notify ADD COLUMN ALREADY_READ tinyint(1) NOT NULL DEFAULT '0' AFTER REASON;
CREATE INDEX IX_USER_ID_CREATED ON project_activity_notify  (USER_ID, CREATED DESC);
UPDATE project_activity_notify SET already_read = true, updated = updated;

CREATE TABLE notify_resource (
  ID bigint(20) NOT NULL auto_increment,
  PROJECT_ACTIVITY_NOTIFY_ID bigint(20) NOT NULL default '0',
  RESOURCE varchar(255) NOT NULL default '',
  ALREADY_READ tinyint(1) NOT NULL DEFAULT '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ACTIVITY_NOTIFY_ID (PROJECT_ACTIVITY_NOTIFY_ID),
  KEY IX_RESOURCE (RESOURCE),
  CONSTRAINT FK_notify_resource_PROJECT_ACTIVITY_NOTIFY_ID FOREIGN KEY (PROJECT_ACTIVITY_NOTIFY_ID) REFERENCES project_activity_notify (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

ALTER TABLE user_ssh_key ADD COLUMN MEMO varchar(255) default NULL AFTER FINGERPRINT;

ALTER TABLE repository ADD COLUMN HOOK_URL text default NULL AFTER DESCRIPTION;

CREATE TABLE issue_multi_update_tx (
  ID bigint(20) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  REQUEST_JSON longtext,
  MAIL_SENT tinyint(1) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED),
  CONSTRAINT FK_issue_multi_update_tx_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_multi_update_log (
  ID bigint(20) NOT NULL auto_increment,
  ISSUE_ID int(11) NOT NULL,
  TX_ID bigint(20) NOT NULL,
  COMMENT_ID int(11),
  RESULT tinyint(1) NOT NULL default '1',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_multi_update_log_TX_ID FOREIGN KEY (TX_ID) REFERENCES issue_multi_update_tx (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE page_history (
  ID bigint(20) NOT NULL auto_increment,
  PAGE_ID int(11) NOT NULL default '0',
  VERSION int(11) NOT NULL default '0',
  NAME varchar(255) NOT NULL default '',
  CONTENT mediumtext,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_page_history_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE paygate_initial (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  GOODS_NAME VARCHAR(255) NOT NULL,
  CARD_NUMBER VARCHAR(20) NOT NULL,
  EXPIRY_DATE datetime NOT NULL,
  PROFILE_ID VARCHAR(64) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_initial_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE paygate_subscription (
  ID int(11) NOT NULL auto_increment,
  PAYGATE_INITIAL_ID int(11) NOT NULL,
  TRANSACTION_ID varchar(64),
  STATUS int default 0 NOT NULL,
  RESULT text,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_subscription_PAYGATE_INITIAL_ID FOREIGN KEY (PAYGATE_INITIAL_ID) REFERENCES paygate_initial (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE paygate_subscription_billing (
  PAYGATE_SUBSCRIPTION_ID int(11) NOT NULL,
  BILLING_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (PAYGATE_SUBSCRIPTION_ID, BILLING_ID),
  CONSTRAINT FK_paygate_subscription_billing_PAYGATE_SUBSCRIPTION_ID FOREIGN KEY (PAYGATE_SUBSCRIPTION_ID) REFERENCES paygate_subscription (ID) ON DELETE CASCADE,
  CONSTRAINT FK_paygate_subscription_billing_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE licence_activation_log (
  ID bigint(20) NOT NULL auto_increment,
  TYPE int(11) NOT NULL,
  SPACE_ID int(11) NOT NULL default '0',
  SPACE_KEY varchar(20) NOT NULL default '',
  FROM_LICENCE_TYPE_ID int(11),
  TO_LICENCE_TYPE_ID int(11),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_theme (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL,
  THEME_TYPE int(11) NOT NULL default '0',
  HEADER_IMAGE tinyint(1) default 0,
  HEADER_IMAGE_REPEAT tinyint(1) default 1,
  HEADER_IMAGE_ALIGN VARCHAR(7) default 0,
  HEADER_BACKGROUND_COLOR VARCHAR(7) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_project_theme_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE login_history (
  ID bigint(20) NOT NULL auto_increment,
  LOCALE varchar(255),
  LOCAL_NAME varchar(255),
  LOCAL_ADDR varchar(255),
  LOCAL_PORT int(11),
  REMOTE_HOST varchar(255),
  REMOTE_ADDR varchar(255),
  REMOTE_PORT int(11),
  USER_AGENT varchar(255),
  ACCEPT_LANGUAGE varchar(255),
  ACCEPT_ENCODING varchar(255),
  ACCEPT_CHARSET varchar(255),
  CLIENT_TIMEZONE_OFFSET bigint(20),
  SPACE_ID bigint(20),
  USER_ID bigint(20),
  USER_USER_ID varchar(255),
  USER_LANG char(5),
  USER_TIMEZONE varchar(50),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE login_location (
  LOGIN_HISTORY_ID bigint(20) NOT NULL,
  COUNTRY_CONFIDENCE int(11),
  COUNTRY_GEONAME_ID varchar(255),
  COUNTRY_ISO_CODE varchar(255),
  COUNTRY_NAME varchar(255),
  CITY_CONFIDENCE int(11),
  CITY_GEONAME_ID varchar(255),
  CITY_NAME varchar(255),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (LOGIN_HISTORY_ID),
  CONSTRAINT FK_login_history_LOGIN_HISTORY_ID FOREIGN KEY (LOGIN_HISTORY_ID) REFERENCES login_history (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO default_issue_type VALUES (9,'zh_tw','Bug',0,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(10,'zh_tw','任務',1,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(11,'zh_tw','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(12,'zh_tw','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),
                                      (13,'zh_cn','Bug',0,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(14,'zh_cn','任务',1,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(15,'zh_cn','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(16,'zh_cn','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),
                                      (17,'ko','버그',0,'#990000',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00'),(18,'ko','태스크',1,'#7ea800',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00'),(19,'ko','요망',2,'#ff9200',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00'),(20,'ko','그 외',3,'#2779ca',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-01 00.00.00', '元日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-13 00.00.00', '成人の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-02-11 00.00.00', '建国記念の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-03-21 00.00.00', '春分の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-04-29 00.00.00', '昭和の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-03 00.00.00', '憲法記念日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-04 00.00.00', 'みどりの日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-05 00.00.00', 'こどもの日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-06 00.00.00', '振替休日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-07-21 00.00.00', '海の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-15 00.00.00', '敬老の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-23 00.00.00', '秋分の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-10-13 00.00.00', '体育の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-03 00.00.00', '文化の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-23 00.00.00', '勤労感謝の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-24 00.00.00', '振替休日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-12-23 00.00.00', '天皇誕生日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');

UPDATE space SET NEED_INDEXING='1';
