CREATE SEQUENCE "service_type_id_seq";
CREATE TABLE service_type (
  ID integer NOT NULL default nextval('service_type_id_seq'),
  NAME varchar(20) NOT NULL default '',
  TARGET varchar(5) NOT NULL,
  DEFAULT_LICENCE_TYPE_ID integer default NULL,
  PREFIX_PATH varchar(6) NOT NULL,
  CURRENCY_CODE varchar(3) NOT NULL,
  CURRENCY_UNIT varchar(6) NOT NULL,
  CURRENCY_UNIT_HEAD boolean NOT NULL default TRUE,
  CURRENCY_UNIT_AMOUNT integer NOT NULL,
  CURRENCY_FORMAT varchar(11) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

ALTER TABLE space ADD SERVICE_TYPE_ID integer default null;
ALTER TABLE space ADD TEXT_FORMATTING_RULE varchar(255) default NULL;
ALTER TABLE space ADD CONSTRAINT "FK_space_SERVICE_TYPE_ID" FOREIGN KEY (SERVICE_TYPE_ID) REFERENCES "service_type" (ID);

ALTER TABLE space_contact ADD GENDER varchar(1) DEFAULT NULL;

ALTER TABLE space_contact_changelog ADD GENDER varchar(1) DEFAULT NULL;

ALTER TABLE issue_attribute_value DROP COLUMN VALUE;

ALTER TABLE licence_type ADD COLUMN PARENT_CHILD_ISSUE boolean NOT NULL default FALSE;
ALTER TABLE licence_type ADD SERVICE_TYPE_ID integer default null;
ALTER TABLE licence_type ADD CONSTRAINT "FK_licence_type_SERVICE_TYPE_ID" FOREIGN KEY (SERVICE_TYPE_ID) REFERENCES "service_type" (ID);
UPDATE licence_type SET parent_child_issue = TRUE, updated = updated WHERE ID >= 20;

ALTER TABLE licence ADD COLUMN PARENT_CHILD_ISSUE boolean NOT NULL default FALSE;
UPDATE licence SET parent_child_issue = TRUE, updated = updated WHERE LICENCE_TYPE_ID >= 20;

ALTER TABLE licence_changelog ADD COLUMN PARENT_CHILD_ISSUE boolean NOT NULL default FALSE;

ALTER TABLE mail ADD FORCE_UTF8 boolean DEFAULT NULL;
ALTER TABLE mail ADD COLUMN EXCLUDE_MAIL_TYPE_IN_SUBJECT boolean default NULL;

ALTER TABLE user_setting ADD COLUMN USE_COLLAPSE_COMMENT boolean NULL DEFAULT TRUE;

ALTER TABLE project ADD COLUMN USE_PARENT_CHILD_ISSUE boolean default NULL;
ALTER TABLE project ADD TEXT_FORMATTING_RULE varchar(255) default NULL;

ALTER TABLE issue ADD COLUMN PARENT_ISSUE_ID integer default NULL;
CREATE INDEX "IX_issue_PARENT_ISSUE_ID" ON issue (PARENT_ISSUE_ID);

CREATE INDEX "IX_page_tag_PROJECT_ID" ON "page_tag" (PROJECT_ID);

ALTER TABLE project_user ADD PROJECT_LEADER boolean default NULL;

CREATE INDEX "IX_shared_file_PROJECT_ID_DIR_NAME" ON "shared_file" (PROJECT_ID, DIR, NAME);

CREATE INDEX "IX_subversion_PROJECT_ID" ON "subversion" (PROJECT_ID);

CREATE INDEX "IX_star_AWARD_ID" ON "star" (AWARD_ID);
CREATE INDEX "IX_star_PRESENTER_ID" ON "star" (PRESENTER_ID);
CREATE INDEX "IX_star_PROJECT_ID" ON "star" (PROJECT_ID);

CREATE INDEX "IX_star_notify_STAR_ID" ON "star_notify" (STAR_ID);

CREATE INDEX "IX_user_profile_USER_ID" ON "user_profile" (USER_ID);

CREATE INDEX "IX_mobilelogin_user_USER_ID" ON "mobilelogin_user" (USER_ID);

CREATE INDEX "IX_attribute_PROJECT_ID" ON "attribute" (PROJECT_ID);

CREATE INDEX "IX_issue_attribute_ISSUE_ID" ON "issue_attribute" (ISSUE_ID);
CREATE INDEX "IX_issue_attribute_ATTRIBUTE_ID" ON "issue_attribute" (ATTRIBUTE_ID);

CREATE INDEX "IX_issue_attribute_value_ISSUE_ATTRIBUTE_ID" ON "issue_attribute_value" (ISSUE_ATTRIBUTE_ID);
CREATE INDEX "IX_issue_attribute_value_ATTRIBUTE_ID" ON "issue_attribute_value" (ATTRIBUTE_ID);

ALTER TABLE project_activity_notify ADD COLUMN ALREADY_READ boolean NOT NULL DEFAULT FALSE;
CREATE INDEX "IX_project_activity_notify_USER_ID_CREATED" ON "project_activity_notify" (USER_ID, CREATED);
UPDATE project_activity_notify SET already_read = true, updated = updated;

CREATE SEQUENCE "notify_resource_id_seq";
CREATE TABLE notify_resource (
  ID bigint NOT NULL default nextval('notify_resource_id_seq'),
  PROJECT_ACTIVITY_NOTIFY_ID bigint NOT NULL,
  RESOURCE varchar(255) NOT NULL default '',
  ALREADY_READ boolean NOT NULL DEFAULT FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_notify_resource_PROJECT_ACTIVITY_NOTIFY_ID FOREIGN KEY (PROJECT_ACTIVITY_NOTIFY_ID) REFERENCES project_activity_notify (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_notify_resource_PROJECT_ACTIVITY_NOTIFY_ID" ON "notify_resource" (PROJECT_ACTIVITY_NOTIFY_ID);
CREATE INDEX "IX_notify_resource_RESOURCE" ON "notify_resource" (RESOURCE);

ALTER TABLE user_ssh_key ADD COLUMN MEMO varchar(255) default NULL;

CREATE INDEX "IX_git_PROJECT_ID" ON "git" (PROJECT_ID);

ALTER TABLE repository ADD COLUMN HOOK_URL text default NULL;
CREATE INDEX "IX_repository_PROJECT_ID" ON "repository" (PROJECT_ID);

CREATE INDEX "IX_revision_REPOSITORY_ID" ON "revision" (REPOSITORY_ID);
CREATE INDEX "IX_revision_AUTHOR_USER_ID" ON "revision" (AUTHOR_USER_ID);

CREATE INDEX "IX_issue_revision_ISSUE_ID" ON "issue_revision" (ISSUE_ID);

CREATE SEQUENCE "issue_multi_update_tx_id_seq";
CREATE TABLE issue_multi_update_tx (
  ID bigint NOT NULL default nextval('issue_multi_update_tx_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  REQUEST_JSON text,
  MAIL_SENT boolean NOT NULL default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_multi_update_tx_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_multi_update_tx_CREATED" ON "issue_multi_update_tx" (CREATED);

CREATE SEQUENCE "issue_multi_update_log_id_seq";
CREATE TABLE issue_multi_update_log (
  ID bigint NOT NULL default nextval('issue_multi_update_log_id_seq'),
  ISSUE_ID integer NOT NULL,
  TX_ID bigint NOT NULL,
  COMMENT_ID integer,
  RESULT boolean NOT NULL default TRUE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_multi_update_log_TX_ID FOREIGN KEY (TX_ID) REFERENCES issue_multi_update_tx (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_multi_update_log_TX_ID" ON "issue_multi_update_log" (TX_ID);

CREATE SEQUENCE "page_history_id_seq";
CREATE TABLE page_history (
  ID bigint NOT NULL default nextval('page_history_id_seq'),
  PAGE_ID integer NOT NULL default '0',
  VERSION integer NOT NULL default '0',
  NAME varchar(255) NOT NULL default '',
  CONTENT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_page_history_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_history_PAGE_ID" ON "page_history" (PAGE_ID);

CREATE SEQUENCE "paygate_initial_id_seq";
CREATE TABLE paygate_initial (
  ID integer NOT NULL default nextval('paygate_initial_id_seq'),
  SPACE_ID integer NOT NULL,
  GOODS_NAME VARCHAR(255) NOT NULL,
  CARD_NUMBER VARCHAR(20) NOT NULL,
  EXPIRY_DATE timestamp NOT NULL,
  PROFILE_ID VARCHAR(64) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_initial_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "paygate_subscription_id_seq";
CREATE TABLE paygate_subscription (
  ID integer NOT NULL default nextval('paygate_subscription_id_seq'),
  PAYGATE_INITIAL_ID integer NOT NULL,
  TRANSACTION_ID varchar(64),
  STATUS int default 0 NOT NULL,
  RESULT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_subscription_PAYGATE_INITIAL_ID FOREIGN KEY (PAYGATE_INITIAL_ID) REFERENCES paygate_initial (ID) ON DELETE CASCADE
);

CREATE TABLE paygate_subscription_billing (
  PAYGATE_SUBSCRIPTION_ID integer NOT NULL,
  BILLING_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PAYGATE_SUBSCRIPTION_ID, BILLING_ID),
  CONSTRAINT FK_paygate_subscription_billing_PAYGATE_SUBSCRIPTION_ID FOREIGN KEY (PAYGATE_SUBSCRIPTION_ID) REFERENCES paygate_subscription (ID) ON DELETE CASCADE,
  CONSTRAINT FK_paygate_subscription_billing_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "licence_activation_log_id_seq";
CREATE TABLE licence_activation_log (
  ID bigint NOT NULL default nextval('licence_activation_log_id_seq'),
  TYPE integer NOT NULL,
  SPACE_ID integer NOT NULL default '0',
  SPACE_KEY varchar(20) NOT NULL default '',
  FROM_LICENCE_TYPE_ID integer,
  TO_LICENCE_TYPE_ID integer,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

CREATE SEQUENCE "project_theme_id_seq";
CREATE TABLE project_theme (
  ID integer NOT NULL default nextval('project_theme_id_seq'),
  PROJECT_ID integer NOT NULL,
  THEME_TYPE integer NOT NULL default '0',
  HEADER_IMAGE boolean default FALSE,
  HEADER_IMAGE_REPEAT boolean default TRUE,
  HEADER_IMAGE_ALIGN VARCHAR(7) default 0,
  HEADER_BACKGROUND_COLOR VARCHAR(7) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (PROJECT_ID),
  CONSTRAINT FK_project_theme_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_theme_PROJECT_ID" ON "project_theme" (PROJECT_ID);

CREATE SEQUENCE "login_history_id_seq";
CREATE TABLE login_history (
  ID bigint NOT NULL default nextval('login_history_id_seq'),
  LOCALE varchar(255),
  LOCAL_NAME varchar(255),
  LOCAL_ADDR varchar(255),
  LOCAL_PORT integer,
  REMOTE_HOST varchar(255),
  REMOTE_ADDR varchar(255),
  REMOTE_PORT integer,
  USER_AGENT varchar(255),
  ACCEPT_LANGUAGE varchar(255),
  ACCEPT_ENCODING varchar(255),
  ACCEPT_CHARSET varchar(255),
  CLIENT_TIMEZONE_OFFSET bigint,
  SPACE_ID bigint,
  USER_ID bigint,
  USER_USER_ID varchar(255),
  USER_LANG char(5),
  USER_TIMEZONE varchar(50),
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

CREATE TABLE login_location (
  LOGIN_HISTORY_ID bigint NOT NULL,
  COUNTRY_CONFIDENCE integer,
  COUNTRY_GEONAME_ID varchar(255),
  COUNTRY_ISO_CODE varchar(255),
  COUNTRY_NAME varchar(255),
  CITY_CONFIDENCE integer,
  CITY_GEONAME_ID varchar(255),
  CITY_NAME varchar(255),
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (LOGIN_HISTORY_ID),
  CONSTRAINT FK_login_history_LOGIN_HISTORY_ID FOREIGN KEY (LOGIN_HISTORY_ID) REFERENCES login_history (ID) ON DELETE CASCADE
);

INSERT INTO default_issue_type VALUES (9,'zh_tw','Bug',0,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (10,'zh_tw','任務',1,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (11,'zh_tw','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (12,'zh_tw','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (13,'zh_cn','Bug',0,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (14,'zh_cn','任务',1,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (15,'zh_cn','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (16,'zh_cn','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (17,'ko','버그',0,'#990000',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');
INSERT INTO default_issue_type VALUES (18,'ko','태스크',1,'#7ea800',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');
INSERT INTO default_issue_type VALUES (19,'ko','요망',2,'#ff9200',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');
INSERT INTO default_issue_type VALUES (20,'ko','그 외',3,'#2779ca',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-01', '元日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-13', '成人の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-02-11', '建国記念の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-03-21', '春分の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-04-29', '昭和の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-03', '憲法記念日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-04', 'みどりの日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-05', 'こどもの日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-06', '振替休日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-07-21', '海の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-15', '敬老の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-23', '秋分の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-10-13', '体育の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-03', '文化の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-23', '勤労感謝の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-24', '振替休日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-12-23', '天皇誕生日', '2013-08-20', '2013-08-20');

UPDATE space SET NEED_INDEXING='1';
