SET NAMES 'utf8';

ALTER TABLE space
ADD COLUMN `USE_NULAB_ACCOUNT` TINYINT(1) NULL DEFAULT 0 AFTER `TEXT_FORMATTING_RULE`;

ALTER TABLE project
ADD COLUMN `DISABLED` INT(11) NOT NULL DEFAULT '0' AFTER `PROJECT_KEY`,
ADD COLUMN `USE_RESOLVED_FOR_CHART` TINYINT(1) NOT NULL DEFAULT '0' AFTER `USE_BURNDOWN`,
DROP INDEX `UQ_SPACE_ID_PROJECT_KEY` ,
ADD UNIQUE INDEX `UQ_SPACE_ID_PROJECT_KEY` (`SPACE_ID` ASC, `PROJECT_KEY` ASC, `DISABLED` ASC),
ADD INDEX `IX_DISABLED` (`DISABLED` ASC);

ALTER TABLE licence_type
ADD COLUMN `POST_ISSUE_BY_MAIL` TINYINT(1) NOT NULL DEFAULT '0' AFTER `PARENT_CHILD_ISSUE`,
ADD COLUMN `NULAB_ACCOUNT` TINYINT(1) NOT NULL DEFAULT '0' AFTER `POST_ISSUE_BY_MAIL`;

ALTER TABLE licence
ADD COLUMN `POST_ISSUE_BY_MAIL` TINYINT(1) NOT NULL DEFAULT '0' AFTER `PARENT_CHILD_ISSUE`,
ADD COLUMN `NULAB_ACCOUNT` TINYINT(1) NOT NULL DEFAULT '0' AFTER `POST_ISSUE_BY_MAIL`;

ALTER TABLE licence_changelog
ADD COLUMN `POST_ISSUE_BY_MAIL` TINYINT(1) NOT NULL DEFAULT '0' AFTER `PARENT_CHILD_ISSUE`,
ADD COLUMN `NULAB_ACCOUNT` TINYINT(1) NOT NULL DEFAULT '0' AFTER `POST_ISSUE_BY_MAIL`;

ALTER TABLE mail
ADD COLUMN `ISSUE` TINYINT(1) NULL DEFAULT NULL AFTER `MAIL`,
ADD COLUMN `ALL_ISSUE` TINYINT(1) NULL DEFAULT NULL AFTER `COMMENT`,
ADD COLUMN `ASSIGNED_ISSUE` TINYINT(1) NULL DEFAULT NULL AFTER `ALL_ISSUE`,
ADD COLUMN `CREATED_ISSUE` TINYINT(1) NULL DEFAULT NULL AFTER `ASSIGNED_ISSUE`,
ADD COLUMN `WIKI` TINYINT(1) NULL DEFAULT NULL AFTER `CREATED_ISSUE`,
ADD COLUMN `NOTIFIED` TINYINT(1) NULL DEFAULT NULL AFTER `WIKI`,
ADD COLUMN `SUMMARY` TINYINT(1) NULL DEFAULT NULL AFTER `NOTIFIED`,
ADD COLUMN `SUBVERSION` TINYINT(1) NULL DEFAULT NULL AFTER `SUMMARY`,
ADD COLUMN `GIT` TINYINT(1) NULL DEFAULT NULL AFTER `SUBVERSION`,
ADD COLUMN `MY_REPORT` TINYINT(1) NULL DEFAULT NULL AFTER `GIT`;

ALTER TABLE user_setting
ADD COLUMN `USE_SHORTCUT_KEY` TINYINT(1) NULL DEFAULT 1 AFTER `USE_COLLAPSE_COMMENT`;

ALTER TABLE project_mail
ADD COLUMN `ISSUE` TINYINT(1) NULL DEFAULT NULL AFTER `MAIL`,
ADD COLUMN `WIKI` TINYINT(1) NULL DEFAULT NULL AFTER `CREATED_ISSUE`,
ADD COLUMN `NOTIFIED` TINYINT(1) NULL DEFAULT NULL AFTER `WIKI`;

ALTER TABLE star
DROP INDEX `IX_URL` ,
ADD INDEX `IX_URL` (`URL`(255) ASC);

ALTER TABLE revision
ADD INDEX `IX_REPOSITORY_ID_CREATED` (`REPOSITORY_ID` ASC, `CREATED` ASC);

ALTER TABLE billing
ADD INDEX `IX_PAYMENT_STATUS_DUE_DATE` (`PAYMENT` ASC, `STATUS` ASC, `DUE_DATE` ASC);

ALTER TABLE login_history
ADD INDEX `IX_USER_ID_UPDATED` (`USER_ID` ASC, `UPDATED` ASC),
ADD INDEX `IX_UPDATED` (`UPDATED` ASC);

CREATE TABLE IF NOT EXISTS job_queue (
  `ID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `JOB_NAME` VARCHAR(255) NOT NULL,
  `STATUS` INT(11) NOT NULL,
  `STARTED` DATETIME NULL DEFAULT NULL,
  `FINISHED` DATETIME NULL DEFAULT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_JOB_NAME_STATUS_UPDATED` (`JOB_NAME` ASC, `STATUS` ASC, `UPDATED` ASC),
  INDEX `IX_STATUS_UPDATED` (`STATUS` ASC, `UPDATED` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS job_parameter (
  `ID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `JOB_QUEUE_ID` BIGINT(20) NOT NULL,
  `NAME` VARCHAR(255) NOT NULL,
  `VALUE` MEDIUMTEXT NOT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_JOB_PARAMETER_JOB_QUEUE_ID` (`JOB_QUEUE_ID` ASC),
  CONSTRAINT `FK_job_parameter_JOB_QUEUE_ID`
    FOREIGN KEY (`JOB_QUEUE_ID`)
    REFERENCES job_queue (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS job_blob_parameter (
  `ID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `JOB_QUEUE_ID` BIGINT(20) NOT NULL,
  `NAME` VARCHAR(255) NOT NULL,
  `DATA` LONGBLOB NOT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_JOB_BLOB_PARAMETER_JOB_QUEUE_ID` (`JOB_QUEUE_ID` ASC),
  CONSTRAINT `FK_job_blob_parameter_JOB_QUEUE_ID`
    FOREIGN KEY (`JOB_QUEUE_ID`)
    REFERENCES job_queue (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS job_fail_cause (
  `ID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `JOB_QUEUE_ID` BIGINT(20) NOT NULL,
  `CAUSE` MEDIUMTEXT NULL DEFAULT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_JOB_FAIL_CAUSE_JOB_QUEUE_ID` (`JOB_QUEUE_ID` ASC),
  CONSTRAINT `FK_job_fail_cause_JOB_QUEUE_ID`
    FOREIGN KEY (`JOB_QUEUE_ID`)
    REFERENCES job_queue (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS issue_post_mail_rule (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `PROJECT_ID` INT(11) NOT NULL,
  `RULE_NAME` VARCHAR(30) NOT NULL,
  `MAIL_ADDRESS` VARCHAR(255) NOT NULL,
  `AUTO_SETTING_XML` TEXT NOT NULL,
  `FILTERING_XML` TEXT NOT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `UQ_MAIL_ADDRESS` (`MAIL_ADDRESS` ASC),
  INDEX `IX_PROJECT_ID` (`PROJECT_ID` ASC),
  CONSTRAINT `FK_post_issue_PROJECT_ID`
    FOREIGN KEY (`PROJECT_ID`)
    REFERENCES project (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS issue_post_mail_log (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `ERRORS` TEXT NULL DEFAULT NULL,
  `PROJECT_ID` INT(11) NULL DEFAULT NULL,
  `ISSUE_ID` INT(11) NULL DEFAULT NULL,
  `ISSUE_POST_MAIL_RULE_ID` INT(11) NULL DEFAULT NULL,
  `MAIL_ADDRESS` VARCHAR(320) NULL DEFAULT NULL,
  `SUBJECT` TEXT NULL DEFAULT NULL,
  `BODY` TEXT NULL DEFAULT NULL,
  `CREATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_PROJECT_ID_CREATED` (`PROJECT_ID` ASC, `CREATED` ASC),
  INDEX `IX_CREATED` (`CREATED` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS issue_post_mail_source (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `ISSUE_POST_MAIL_LOG_ID` INT(11) NOT NULL,
  `MAIL_SOURCE` LONGBLOB NOT NULL,
  `CHARSET` VARCHAR(20) NULL DEFAULT NULL,
  `CREATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_ISSUE_POST_MAIL_LOG_ID` (`ISSUE_POST_MAIL_LOG_ID` ASC),
  CONSTRAINT `FK_issue_post_mail_source_ISSUE_POST_MAIL_LOG_ID`
    FOREIGN KEY (`ISSUE_POST_MAIL_LOG_ID`)
    REFERENCES issue_post_mail_log (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS nulab_account (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `SPACE_ID` INT(11) NOT NULL DEFAULT '0',
  `USER_ID` INT(11) NOT NULL,
  `SYNCHRONIZE` TINYINT(1) NULL DEFAULT 0,
  `NULAB_ID` VARCHAR(255) NOT NULL,
  `UNIQUE_ID` VARCHAR(255) NULL DEFAULT NULL,
  `MAIL_ADDRESS` VARCHAR(320) NULL DEFAULT NULL,
  `NAME` VARCHAR(255) NULL DEFAULT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `IX_USER_ID` (`USER_ID` ASC),
  INDEX `IX_NULAB_ID` (`NULAB_ID` ASC),
  INDEX `IX_NULAB_ACCOUNT_SPACE_ID_NULAB_ID` (`SPACE_ID` ASC, `NULAB_ID` ASC),
  CONSTRAINT `FK_nulab_account_SPACE_ID`
    FOREIGN KEY (`SPACE_ID`)
    REFERENCES space (`ID`)
    ON DELETE CASCADE,
  CONSTRAINT `FK_nulab_account_USER_ID`
    FOREIGN KEY (`USER_ID`)
    REFERENCES users (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS user_original_data (
  `USER_ID` INT(11) NOT NULL,
  `MAIL_ADDRESS` VARCHAR(320) NOT NULL DEFAULT '',
  `NAME` VARCHAR(100) NOT NULL DEFAULT '',
  `ICON` VARCHAR(50) NULL DEFAULT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`USER_ID`),
  CONSTRAINT `FK_user_original_data_USER_ID`
    FOREIGN KEY (`USER_ID`)
    REFERENCES users (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS oauth2_client (
  `CLIENT_ID` VARCHAR(32) NOT NULL DEFAULT '',
  `NAME` VARCHAR(64) NOT NULL DEFAULT '',
  `DESCRIPTION` VARCHAR(255) NOT NULL DEFAULT '',
  `CLIENT_TYPE` INT(11) NULL DEFAULT 0,
  `CLIENT_SECRET` VARCHAR(64) NOT NULL DEFAULT '',
  `GRANT_TYPE` VARCHAR(255) NOT NULL DEFAULT '',
  `REDIRECT_URI` VARCHAR(255) NOT NULL DEFAULT '',
  `SITE_URL` VARCHAR(255) NOT NULL DEFAULT '',
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`CLIENT_ID`),
  INDEX `IX_CREATED_USER_ID` (`CREATED_USER_ID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS oauth2_authorization_code (
  `ID` VARCHAR(64) NOT NULL DEFAULT '',
  `CODE` VARCHAR(64) NOT NULL DEFAULT '',
  `USER_ID` INT(11) NOT NULL,
  `OAUTH2_CLIENT_ID` VARCHAR(32) NOT NULL DEFAULT '',
  `STATE` VARCHAR(500) NULL DEFAULT NULL,
  `REDIRECT_URI` VARCHAR(255) NULL DEFAULT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `UQ_CODE` (`CODE` ASC),
  INDEX `IX_user_id_oauth2_client_id` (`USER_ID` ASC, `OAUTH2_CLIENT_ID` ASC),
  INDEX `FK_oauth2_authorization_code_OAUTH2_CLIENT_ID` (`OAUTH2_CLIENT_ID` ASC),
  CONSTRAINT `FK_oauth2_authorization_code_OAUTH2_CLIENT_ID`
    FOREIGN KEY (`OAUTH2_CLIENT_ID`)
    REFERENCES oauth2_client (`CLIENT_ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS oauth2_access_token (
  `USER_ID` INT(11) NOT NULL,
  `OAUTH2_CLIENT_ID` VARCHAR(32) NOT NULL DEFAULT '',
  `ACCESS_TOKEN` VARCHAR(64) NOT NULL DEFAULT '',
  `REFRESH_TOKEN` VARCHAR(64) NOT NULL DEFAULT '',
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`USER_ID`, `OAUTH2_CLIENT_ID`),
  INDEX `IX_USER_ID` (`USER_ID` ASC),
  UNIQUE INDEX `UQ_ACCESS_TOKEN` (`ACCESS_TOKEN` ASC),
  UNIQUE INDEX `UQ_REFRESH_TOKEN` (`REFRESH_TOKEN` ASC),
  INDEX `FK_oauth2_access_token_OAUTH2_CLIENT_ID` (`OAUTH2_CLIENT_ID` ASC),
  CONSTRAINT `FK_oauth2_access_token_OAUTH2_CLIENT_ID`
    FOREIGN KEY (`OAUTH2_CLIENT_ID`)
    REFERENCES oauth2_client (`CLIENT_ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS max_issue_identity (
  `PROJECT_ID` INT(11) NOT NULL,
  `MAX_KEY_ID` INT(11) NOT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`PROJECT_ID`),
  CONSTRAINT `FK_max_issue_identity_PROJECT_ID`
    FOREIGN KEY (`PROJECT_ID`)
    REFERENCES project (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS temporary_attachment (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `NAME` VARCHAR(100) NOT NULL DEFAULT '',
  `SIZE` INT(11) NOT NULL DEFAULT '0',
  `CONTENT` LONGBLOB NULL DEFAULT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_CREATED_USER_ID` (`CREATED_USER_ID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS api_key (
  `API_KEY` VARCHAR(64) NOT NULL DEFAULT '',
  `USER_ID` INT(11) NOT NULL,
  `SCOPE` INT(11) NOT NULL DEFAULT '0',
  `MEMO` VARCHAR(255) NOT NULL DEFAULT '',
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`API_KEY`),
  INDEX `IX_CREATED_USER_ID` (`CREATED_USER_ID` ASC),
  INDEX `FK_api_key_USER_ID` (`USER_ID` ASC),
  CONSTRAINT `FK_api_key_USER_ID`
    FOREIGN KEY (`USER_ID`)
    REFERENCES users (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS issue_component_summary (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `PROJECT_ID` INT(11) NOT NULL,
  `COMPONENT_ID` INT(11) NULL DEFAULT NULL,
  `STATUS_ID` INT(11) NOT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_PROJECT_ID` (`PROJECT_ID` ASC),
  INDEX `IX_COMPONENT_ID` (`COMPONENT_ID` ASC),
  INDEX `IX_PROJECT_ID_COMPONENT_ID_STATUS_ID` (`PROJECT_ID` ASC, `COMPONENT_ID` ASC, `STATUS_ID` ASC),
  CONSTRAINT `FK_issue_component_summary_PROJECT_ID`
    FOREIGN KEY (`PROJECT_ID`)
    REFERENCES project (`ID`)
    ON DELETE CASCADE,
  CONSTRAINT `FK_issue_component_summary_COMPONENT_ID`
    FOREIGN KEY (`COMPONENT_ID`)
    REFERENCES component (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS issue_fixed_version_summary (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `PROJECT_ID` INT(11) NOT NULL,
  `VERSION_ID` INT(11) NULL DEFAULT NULL,
  `STATUS_ID` INT(11) NOT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_PROJECT_ID` (`PROJECT_ID` ASC),
  INDEX `IX_VERSION_ID` (`VERSION_ID` ASC),
  INDEX `IX_PROJECT_ID_VERSION_ID_STATUS_ID` (`PROJECT_ID` ASC, `VERSION_ID` ASC, `STATUS_ID` ASC),
  CONSTRAINT `FK_issue_fixed_version_summary_PROJECT_ID`
    FOREIGN KEY (`PROJECT_ID`)
    REFERENCES project (`ID`)
    ON DELETE CASCADE,
  CONSTRAINT `FK_issue_fixed_version_summary_VERSION_ID`
    FOREIGN KEY (`VERSION_ID`)
    REFERENCES version (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

CREATE TABLE IF NOT EXISTS project_short_url (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `PROJECT_ID` INT(11) NOT NULL,
  `SHORT_URL_KEY` VARCHAR(20) BINARY NOT NULL,
  `URL` TEXT NOT NULL,
  `CREATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `CREATED` DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  `UPDATED_USER_ID` INT(11) NULL DEFAULT NULL,
  `UPDATED` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (`ID`),
  INDEX `IX_KEY` (`SHORT_URL_KEY` ASC),
  INDEX `IX_PROJECT_ID_URL` (`PROJECT_ID` ASC, `URL`(255) ASC),
  UNIQUE INDEX `UQ_project_short_url_SHORT_URL_KEY` (`SHORT_URL_KEY` ASC),
  CONSTRAINT `FK_project_short_url_PROJECT_ID`
    FOREIGN KEY (`PROJECT_ID`)
    REFERENCES project (`ID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_general_ci;

INSERT INTO default_issue_type VALUES (21,'vi','Lỗi',1,'#990000',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00'),(22,'vi','Công việc',0,'#7ea800',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00'),(23,'vi','Yêu cầu',2,'#ff9200',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00'),(24,'vi','Ngoài ra',3,'#2779ca',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');

INSERT INTO user_original_data (USER_ID, MAIL_ADDRESS, NAME, ICON, CREATED)
SELECT ID, MAIL_ADDRESS, NAME, ICON, CURRENT_TIMESTAMP FROM users
WHERE NOT EXISTS (SELECT 1 FROM user_original_data AS c WHERE c.USER_ID = users.ID);

UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=2;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=1;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=6;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=5;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=10;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=9;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=14;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=13;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=18;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=17;

UPDATE project_mail SET ISSUE = MAIL, UPDATED = UPDATED;
UPDATE project_mail SET WIKI = ISSUE, UPDATED = UPDATED;
UPDATE project_mail INNER JOIN mail ON project_mail.user_id = mail.user_id
   SET project_mail.COMMENT = false, project_mail.UPDATED = project_mail.UPDATED
 WHERE mail.comment = false;
UPDATE mail set ISSUE=true, ALL_ISSUE=true, WIKI = true, SUMMARY = true, UPDATED = UPDATED;

INSERT INTO issue_component_summary (PROJECT_ID, COMPONENT_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    issue.PROJECT_ID,
    issue_component.LINK_ID,
    issue.STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue_component
    INNER JOIN issue ON issue.id = issue_component.issue_id;

INSERT INTO issue_component_summary (PROJECT_ID, COMPONENT_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    PROJECT_ID,
    NULL,
    STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue
  WHERE COMPONENT_ID IS NULL;

INSERT INTO issue_fixed_version_summary (PROJECT_ID, VERSION_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    issue.PROJECT_ID,
    issue_fixedversion.LINK_ID,
    issue.STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue_fixedversion
    INNER JOIN issue ON issue.id = issue_fixedversion.issue_id;

INSERT INTO issue_fixed_version_summary (PROJECT_ID, VERSION_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    PROJECT_ID,
    NULL,
    STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue
  WHERE FIXED_VERSION_ID IS NULL;

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-01 00.00.00', '元日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-12 00.00.00', '成人の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-02-11 00.00.00', '建国記念の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-03-21 00.00.00', '春分の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-04-29 00.00.00', '昭和の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-03 00.00.00', '憲法記念日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-04 00.00.00', 'みどりの日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-05 00.00.00', 'こどもの日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-06 00.00.00', '振替休日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-07-20 00.00.00', '海の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-21 00.00.00', '敬老の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-22 00.00.00', '振替休日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-23 00.00.00', '秋分の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-10-12 00.00.00', '体育の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-03 00.00.00', '文化の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-23 00.00.00', '勤労感謝の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-12-23 00.00.00', '天皇誕生日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');

UPDATE space SET NEED_INDEXING='1';
