ALTER TABLE "space" ADD COLUMN USE_NULAB_ACCOUNT boolean default FALSE;

ALTER TABLE "project"
ADD COLUMN DISABLED integer NOT NULL default '0',
ADD COLUMN USE_RESOLVED_FOR_CHART boolean NOT NULL default FALSE,
-- DROP CONSTRAINT IF EXISTS project_space_id_project_key_key,
-- DROP CONSTRAINT IF EXISTS project_space_id_key,
ADD CONSTRAINT project_space_id_project_key_disabled_key UNIQUE(SPACE_ID, PROJECT_KEY, DISABLED);

CREATE INDEX "IX_project_DISABLED" ON "project" (DISABLED);

ALTER TABLE "licence_type"
ADD COLUMN POST_ISSUE_BY_MAIL boolean NOT NULL default FALSE,
ADD COLUMN NULAB_ACCOUNT boolean NOT NULL default FALSE;

ALTER TABLE "licence"
ADD COLUMN POST_ISSUE_BY_MAIL boolean NOT NULL default FALSE,
ADD COLUMN NULAB_ACCOUNT boolean NOT NULL default FALSE;

ALTER TABLE "licence_changelog"
ADD COLUMN POST_ISSUE_BY_MAIL boolean NOT NULL default FALSE,
ADD COLUMN NULAB_ACCOUNT boolean NOT NULL default FALSE;

ALTER TABLE "mail"
ADD COLUMN ISSUE boolean default NULL,
ADD COLUMN ALL_ISSUE boolean default NULL,
ADD COLUMN ASSIGNED_ISSUE boolean default NULL,
ADD COLUMN CREATED_ISSUE boolean default NULL,
ADD COLUMN WIKI boolean default NULL,
ADD COLUMN NOTIFIED boolean default NULL,
ADD COLUMN SUMMARY boolean default NULL,
ADD COLUMN SUBVERSION boolean default NULL,
ADD COLUMN GIT boolean default NULL,
ADD COLUMN MY_REPORT boolean default NULL;

ALTER TABLE "user_setting"
ADD COLUMN USE_SHORTCUT_KEY boolean default TRUE;

ALTER TABLE "project_mail"
ADD COLUMN ISSUE boolean default NULL,
ADD COLUMN WIKI boolean default NULL,
ADD COLUMN NOTIFIED boolean default NULL;

ALTER TABLE "star"
ALTER URL TYPE character varying(255);

-- CREATE INDEX "IX_star_URL" ON "star" (URL);

CREATE INDEX "IX_REPOSITORY_ID_CREATED" ON "revision" (REPOSITORY_ID,CREATED);

CREATE INDEX "IX_billing_id_seq_PAYMENT_STATUS_DUE_DATE" ON "billing" (PAYMENT, STATUS, DUE_DATE);

CREATE INDEX "IX_login_history_IX_USER_ID_UPDATED" ON "login_history" (USER_ID, UPDATED);
CREATE INDEX "IX_login_history_IX_UPDATED" ON "login_history" (UPDATED);

CREATE SEQUENCE "job_queue_id_seq";
CREATE TABLE "job_queue" (
  ID bigint NOT NULL default nextval('job_queue_id_seq'),
  JOB_NAME varchar(255) NOT NULL,
  STATUS integer NOT NULL,
  STARTED timestamp default NULL,
  FINISHED timestamp default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_job_queue_JOB_NAME_STATUS_UPDATED" ON "job_queue" (JOB_NAME, STATUS, UPDATED);
CREATE INDEX "IX_job_queue_STATUS_UPDATED" ON "job_queue" (STATUS, UPDATED);

CREATE SEQUENCE "job_parameter_id_seq";
CREATE TABLE "job_parameter" (
  ID bigint NOT NULL default nextval('job_parameter_id_seq'),
  JOB_QUEUE_ID bigint NOT NULL,
  NAME varchar(255) NOT NULL,
  VALUE text NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_job_parameter_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_job_parameter_seq_JOB_PARAMETER_JOB_QUEUE_ID" ON "job_parameter" (JOB_QUEUE_ID);

CREATE SEQUENCE "job_blob_parameter_id_seq";
CREATE TABLE job_blob_parameter (
  ID bigint NOT NULL default nextval('job_blob_parameter_id_seq'),
  JOB_QUEUE_ID bigint NOT NULL,
  NAME varchar(255) NOT NULL,
  DATA bytea NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_job_blob_parameter_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_job_blob_parameter_JOB_BLOB_PARAMETER_JOB_QUEUE_ID" ON "job_parameter" (JOB_QUEUE_ID);

CREATE SEQUENCE "job_fail_cause_id_seq";
CREATE TABLE job_fail_cause (
  ID bigint NOT NULL default nextval('job_fail_cause_id_seq'),
  JOB_QUEUE_ID bigint NOT NULL,
  CAUSE text default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_job_fail_cause_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_job_fail_cause_JOB_FAIL_CAUSE_JOB_QUEUE_ID" ON "job_parameter" (JOB_QUEUE_ID);

CREATE SEQUENCE "issue_post_mail_rule_id_seq";
CREATE TABLE issue_post_mail_rule (
  ID integer NOT NULL default nextval('issue_post_mail_rule_id_seq'),
  PROJECT_ID integer NOT NULL,
  RULE_NAME varchar(30) NOT NULL, -- 設定名
  MAIL_ADDRESS varchar(255) NOT NULL,
  AUTO_SETTING_XML text NOT NULL,
  FILTERING_XML text NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (MAIL_ADDRESS),
  CONSTRAINT FK_post_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_post_mail_rule_PROJECT_ID" ON "issue_post_mail_rule" (PROJECT_ID);

CREATE SEQUENCE "issue_post_mail_log_id_seq";
CREATE TABLE issue_post_mail_log (
  ID integer NOT NULL default nextval('issue_post_mail_log_id_seq'),
  ERRORS text default NULL, -- エラー情報
  PROJECT_ID integer default NULL, -- プロジェクトID
  ISSUE_ID integer default NULL, -- 課題ID
  ISSUE_POST_MAIL_RULE_ID integer default NULL, -- 課題の自動設定ID
  MAIL_ADDRESS varchar(320) default NULL, -- 課題登録に使用した宛先メールアドレス
  SUBJECT text default NULL, -- メールの件名
  BODY text default NULL, -- メール本文
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_PROJECT_ID_CREATED" ON "issue_post_mail_log" (PROJECT_ID, CREATED);
CREATE INDEX "IX_CREATED" ON "issue_post_mail_log" (CREATED);

CREATE SEQUENCE "issue_post_mail_source_id_seq";
CREATE TABLE issue_post_mail_source (
  ID integer NOT NULL default nextval('issue_post_mail_source_id_seq'),
  ISSUE_POST_MAIL_LOG_ID integer not NULL, -- メールによる課題登録ログ
  MAIL_SOURCE bytea not NULL, -- メールのソース
  CHARSET varchar(20) default NULL, -- 文字コード
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_post_mail_source_ISSUE_POST_MAIL_LOG_ID FOREIGN KEY (ISSUE_POST_MAIL_LOG_ID) REFERENCES issue_post_mail_log (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_ISSUE_POST_MAIL_LOG_ID" ON "issue_post_mail_source" (ISSUE_POST_MAIL_LOG_ID);

CREATE SEQUENCE "nulab_account_id_seq";
CREATE TABLE nulab_account (
  ID integer NOT NULL default nextval('nulab_account_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  USER_ID integer NOT NULL,
  SYNCHRONIZE boolean default FALSE,
  NULAB_ID varchar(255) NOT NULL,
  UNIQUE_ID varchar(255),
  MAIL_ADDRESS varchar(320),
  NAME varchar(255),
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (USER_ID),
  CONSTRAINT FK_nulab_account_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_nulab_account_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);

CREATE INDEX "IX_nulab_account_NULAB_ID" ON "nulab_account" (NULAB_ID);
CREATE INDEX "IX_nulab_account_NULAB_ACCOUNT_SPACE_ID_NULAB_ID" ON "nulab_account" (SPACE_ID, NULAB_ID);
CREATE TABLE user_original_data (
  USER_ID integer NOT NULL,
  MAIL_ADDRESS varchar(320) NOT NULL default '',
  NAME varchar(100) NOT NULL default '',
  ICON varchar(50) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  CONSTRAINT FK_user_original_data_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);

CREATE TABLE oauth2_client (
  CLIENT_ID varchar(32) NOT NULL default '',
  NAME varchar(64) NOT NULL default '',
  DESCRIPTION varchar(255) NOT NULL default '',
  CLIENT_TYPE integer default 0,
  CLIENT_SECRET varchar(64) NOT NULL default '',
  GRANT_TYPE varchar(255) NOT NULL default '',
  REDIRECT_URI varchar(255) NOT NULL default '',
  SITE_URL varchar(255) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (CLIENT_ID)
);
CREATE INDEX "IX_nulab_account_CREATED_USER_ID" ON "oauth2_client" (CREATED_USER_ID);

CREATE TABLE oauth2_authorization_code (
  ID varchar(64) NOT NULL default '',
  CODE varchar(64) NOT NULL default '',
  USER_ID integer NOT NULL,
  OAUTH2_CLIENT_ID varchar(32) NOT NULL default '',
  STATE varchar(500) default NULL,
  REDIRECT_URI varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (CODE),
  CONSTRAINT FK_oauth2_authorization_code_OAUTH2_CLIENT_ID FOREIGN KEY (OAUTH2_CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
);
CREATE INDEX "IX_oauth2_authorization_code_CREATED_USER_ID" ON "oauth2_authorization_code" (USER_ID,OAUTH2_CLIENT_ID);

CREATE TABLE oauth2_access_token (
  USER_ID integer NOT NULL,
  OAUTH2_CLIENT_ID varchar(32) NOT NULL default '',
  ACCESS_TOKEN varchar(64) NOT NULL default '',
  REFRESH_TOKEN varchar(64) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID, OAUTH2_CLIENT_ID),
  UNIQUE (ACCESS_TOKEN),
  UNIQUE (REFRESH_TOKEN),
  CONSTRAINT FK_oauth2_access_token_OAUTH2_CLIENT_ID FOREIGN KEY (OAUTH2_CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
);
CREATE INDEX "IX_USER_ID" ON "oauth2_access_token" (USER_ID);

CREATE TABLE max_issue_identity (
  PROJECT_ID integer NOT NULL,
  MAX_KEY_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID),
  CONSTRAINT FK_max_issue_identity_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "temporary_attachment_id_seq";
CREATE TABLE temporary_attachment (
  ID integer NOT NULL default nextval('temporary_attachment_id_seq'),
  NAME varchar(100) NOT NULL default '',
  SIZE integer NOT NULL default '0',
  CONTENT bytea,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_temporary_attachment_CREATED_USER_ID" ON "temporary_attachment" (CREATED_USER_ID);

CREATE TABLE api_key (
  API_KEY varchar(64) NOT NULL default '',
  USER_ID integer NOT NULL,
  SCOPE integer NOT NULL default '0',
  MEMO varchar(255) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (API_KEY),
  CONSTRAINT FK_api_key_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_api_key_CREATED_USER_ID" ON "api_key" (CREATED_USER_ID);

CREATE SEQUENCE "issue_component_summary_id_seq";
CREATE TABLE issue_component_summary (
  ID integer NOT NULL default nextval('issue_component_summary_id_seq'),
  PROJECT_ID integer NOT NULL,
  COMPONENT_ID integer DEFAULT NULL,
  STATUS_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_component_summary_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_component_summary_COMPONENT_ID FOREIGN KEY (COMPONENT_ID) REFERENCES component (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_component_summary_PROJECT_ID" ON "issue_component_summary" (PROJECT_ID);
CREATE INDEX "IX_issue_component_summary_COMPONENT_ID" ON "issue_component_summary" (COMPONENT_ID);
CREATE INDEX "IX_issue_component_summary_PROJECT_ID_COMPONENT_ID_STATUS_ID" ON "issue_component_summary" (PROJECT_ID, COMPONENT_ID, STATUS_ID);

CREATE SEQUENCE "issue_fixed_version_summary_id_seq";
CREATE TABLE issue_fixed_version_summary (
  ID integer NOT NULL default nextval('issue_fixed_version_summary_id_seq'),
  PROJECT_ID integer NOT NULL,
  VERSION_ID integer DEFAULT NULL,
  STATUS_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_fixed_version_summary_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_fixed_version_summary_VERSION_ID FOREIGN KEY (VERSION_ID) REFERENCES version (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_fixed_version_summary_PROJECT_ID" ON "issue_fixed_version_summary" (PROJECT_ID);
CREATE INDEX "IX_issue_fixed_version_summary_VERSION_ID" ON "issue_fixed_version_summary" (VERSION_ID);
CREATE INDEX "IX_issue_fixed_version_summary_PROJECT_ID_VERSION_ID_STATUS_ID" ON "issue_fixed_version_summary" (PROJECT_ID, VERSION_ID, STATUS_ID);

CREATE SEQUENCE "project_short_url_id_seq";
CREATE TABLE project_short_url (
  ID integer NOT NULL default nextval('project_short_url_id_seq'),
  PROJECT_ID integer NOT NULL,
  SHORT_URL_KEY varchar(20) NOT NULL,
  URL text NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (SHORT_URL_KEY),
  CONSTRAINT FK_project_short_url_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

CREATE INDEX "IX_KEY" ON "project_short_url" (SHORT_URL_KEY);
CREATE INDEX "IX_PROJECT_ID_URL" ON "project_short_url" (PROJECT_ID, URL);

INSERT INTO default_issue_type VALUES (21,'vi','Lỗi',1,'#990000',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');
INSERT INTO default_issue_type VALUES (22,'vi','Công việc',0,'#7ea800',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');
INSERT INTO default_issue_type VALUES (23,'vi','Yêu cầu',2,'#ff9200',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');
INSERT INTO default_issue_type VALUES (24,'vi','Ngoài ra',3,'#2779ca',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');

INSERT INTO user_original_data (USER_ID, MAIL_ADDRESS, NAME, ICON, CREATED)
SELECT ID, MAIL_ADDRESS, NAME, ICON, CURRENT_TIMESTAMP FROM users
WHERE NOT EXISTS (SELECT 1 FROM user_original_data AS c WHERE c.USER_ID = users.ID);

UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=2;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=1;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=6;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=5;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=10;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=9;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=14;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=13;
UPDATE default_issue_type SET DISPLAY_ORDER=0 WHERE ID=18;
UPDATE default_issue_type SET DISPLAY_ORDER=1 WHERE ID=17;

UPDATE project_mail SET ISSUE = MAIL, UPDATED = UPDATED;
UPDATE project_mail SET WIKI = ISSUE, UPDATED = UPDATED;

UPDATE project_mail
SET COMMENT = FALSE, UPDATED = project_mail.UPDATED
FROM mail
WHERE project_mail.user_id = mail.user_id
  AND mail.comment = FALSE;

UPDATE mail set ISSUE=true, ALL_ISSUE=true, WIKI = true, SUMMARY = true, UPDATED = UPDATED;

INSERT INTO issue_component_summary (PROJECT_ID, COMPONENT_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    issue.PROJECT_ID,
    issue_component.LINK_ID,
    issue.STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue_component
    INNER JOIN issue ON issue.id = issue_component.issue_id;

INSERT INTO issue_component_summary (PROJECT_ID, COMPONENT_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    PROJECT_ID,
    NULL,
    STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue
  WHERE COMPONENT_ID IS NULL;

INSERT INTO issue_fixed_version_summary (PROJECT_ID, VERSION_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    issue.PROJECT_ID,
    issue_fixedversion.LINK_ID,
    issue.STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue_fixedversion
    INNER JOIN issue ON issue.id = issue_fixedversion.issue_id;

INSERT INTO issue_fixed_version_summary (PROJECT_ID, VERSION_ID, STATUS_ID, CREATED, UPDATED)
  SELECT
    PROJECT_ID,
    NULL,
    STATUS_ID,
    current_timestamp,
    current_timestamp
  FROM issue
  WHERE FIXED_VERSION_ID IS NULL;

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-01', '元日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-12', '成人の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-02-11', '建国記念の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-03-21', '春分の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-04-29', '昭和の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-03', '憲法記念日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-04', 'みどりの日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-05', 'こどもの日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-06', '振替休日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-07-20', '海の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-21', '敬老の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-22', '振替休日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-23', '秋分の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-10-12', '体育の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-03', '文化の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-23', '勤労感謝の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-12-23', '天皇誕生日', '2014-08-07', '2014-08-07');

UPDATE space SET NEED_INDEXING='1';
