SET NAMES 'utf8';

ALTER TABLE star ADD INDEX IX_PROJECT_ID_CREATED (PROJECT_ID, CREATED);

CREATE TABLE archived_project_activity (
  ID bigint(20) NOT NULL,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE int(11) NOT NULL,
  CONTENT_JSON longtext,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED datetime NOT NULL,
  ARCHIVE_CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID_CREATED_TYPE_CREATED_USER_ID (PROJECT_ID, CREATED DESC, TYPE, CREATED_USER_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_activity_stat (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  TOTAL int(11) NOT NULL default '0',
  NOTIFY_COUNT int(11) NOT NULL default '0',
  LAST_ARCHIVED datetime,
  LAST_ARCHIVED_RATIO int(11),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED datetime NOT NULL,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_SPACE_ID_PROJECT_ACTIVITY_STAT ( SPACE_ID ),
  CONSTRAINT FK_project_activity_stat_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

ALTER TABLE oauth2_client ADD COLUMN DEFAULT_LANG VARCHAR(32)  NOT NULL DEFAULT '' AFTER REDIRECT_URI;
ALTER TABLE oauth2_client ADD COLUMN ICON_URL VARCHAR(255) NOT NULL DEFAULT '' AFTER DEFAULT_LANG;
ALTER TABLE oauth2_client ADD COLUMN DISABLED TINYINT(1) NOT NULL DEFAULT 0 AFTER ICON_URL;

CREATE TABLE oauth2_client_description (
  ID int(11) NOT NULL,
  CLIENT_ID VARCHAR(32) NOT NULL DEFAULT '',
  LANG VARCHAR(32) NOT NULL DEFAULT '',
  NAME VARCHAR(64) NOT NULL DEFAULT '',
  DESCRIPTION VARCHAR(1000) NOT NULL DEFAULT '',
  SITE_URI VARCHAR(255) NOT NULL DEFAULT '',
  CREATED DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  UPDATED TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IDX_OAUTH2_CLIENT_DESCRIPTION_CLIENT_ID (CLIENT_ID),
  UNIQUE KEY (CLIENT_ID, LANG),
  CONSTRAINT FK_oauth2_client_description_CLIENT_ID FOREIGN KEY (CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
) ENGINE=innodb DEFAULT CHARSET=utf8;

INSERT INTO repository (PROJECT_ID, TYPE, NAME, CREATED, UPDATED, DISPLAY_ORDER)
  SELECT
    project.id,
    2,
    project.project_key,
    current_timestamp,
    current_timestamp,
    2147483646
  FROM project
    INNER JOIN subversion ON project.id = subversion.project_id and subversion.type=2
    INNER JOIN space ON project.space_id = space.id
    INNER JOIN licence ON space.id = licence.space_id and licence.active = 1
 where project.disabled = 0;

CREATE TABLE myreport_message (
  ID int(11) NOT NULL auto_increment,
  ICON varchar(255) NOT NULL default '',
  LANG char(5) NOT NULL default '',
  COMMENT text NOT NULL,
  PAGE_NAME text,
  PAGE_URL text,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_LANG (LANG)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'タスクは適切な粒度で。大きすぎるタスクがあるときは、適度なサイズに分割するといいと思うよ。', '親子課題について', 'http://www.backlog.jp/kr/help/usersguide/subtasking/userguide1722.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '目標の日が決まっているときはマイルストーンを使うと便利だよ。', '発生バージョン/マイルストーン', 'http://www.backlog.jp/help/usersguide/version-milestone/userguide106.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ja', 'GitとかSubversionのコミットで課題の状態を更新できるとよ。', 'Backlog 小技集： Gitのコミットから課題の状態を更新する', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-5/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '管理者はプロジェクト毎に設定することもできるんだよ。', 'Backlog 小技集： プロジェクト毎に管理者を設定する', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-4/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'プロジェクト全体を把握したいときはガントチャートが便利だよ。', 'Backlogビデオチュートリアル「ガントチャート編」', 'https://www.youtube.com/watch?v=qPuOiN4cbK8', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'よく使う検索条件は保存しておくと時間短縮になるよ！', '検索条件の保存', 'http://www.backlog.jp/help/usersguide/search-issue/userguide1440.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ja', '受信メールが多すぎる場合、自分が受け取りたいメールだけを受信できるよう設定し直すことをオススメします。', 'Backlogがバージョンアップ、メール受信設定に機能が追加されました。', 'https://nulab-inc.com/ja/blog/backlog/new-mail-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '複数の課題をまとめて、状態変更したり担当者を替えたりできるんだよ。', 'Backlog 小技集：自分の課題をまとめて操作', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '「あの人にこのコメントを読んでほしい...」という時は「お知らせ」しておこう！', 'お知らせ機能の概要', 'http://www.backlog.jp/help/usersguide/notification/userguide1453.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'Wiki の見出しを元に自動的に目次を作ってくれるって知ってた？', 'Backlog記法の目次', 'http://www.backlog.jp/help/usersguide/rule-to-formatting-texts/userguide205.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '検索後の課題一覧を誰かに送りたいときは短いURLを送ったほうがスマートだよ！', 'Backlog 小技集： 短いURL', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'バーンダウンチャートでは、ざっくりとしたプロジェクトの進行状況が見れるんだよ。', 'バーンダウンチャートの概要', 'http://www.backlog.jp/help/usersguide/burn-down-chart/userguide289.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'このコメントのここがナイスアイデア！と思ったらその部分を選択してスターをつけるといいよ。', 'スターを付ける', 'http://www.backlog.jp/help/usersguide/star/userguide456.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '出先でプロジェクトの状況が気になったら、iPhone版のBacklogを見ればいいよ。', 'Backlog for iPhone の機能', 'http://www.backlog.jp/help/usersguide/mobile/userguide2354.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'あの人最近何やってるのかな...？と気になったらプロフィールで確認だ！', 'プロフィールの”最近の活動”', 'http://www.backlog.jp/help/usersguide/member/userguide1016.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ja', 'Gitでファイルをバージョン管理するとよかよ。', 'サルでもわかるGit入門', 'http://www.backlog.jp/git-guide/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '図を書いて説明したくなったら、Cacooで図を書いてそのURLを Wiki とかコメントに貼ればいいよ。', 'Cacooの図をBacklogに表示する方法', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'Markdown記法って人気あるよね。Backlogでも使えるよ。', 'プロジェクトの基本設定', 'http://www.backlog.jp/help/adminsguide/project-setting/userguide355.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'WikiはPDFで出力できるよ。Backlog を見れない人にはPDFで見せてね。', 'PDF出力', 'http://www.backlog.jp/help/usersguide/wiki/userguide218.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'BacklogにはWebフック機能もあって、外部システムと連携できるよ。', 'Git Webフック', 'http://www.backlog.jp/help/usersguide/git/userguide1710.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ja', 'お問い合わせメールなどの内容をBacklogの課題として手動で登録してる場合、簡単な設定で自動登録に変更することが可能です。', 'メールによる課題登録', 'http://www.backlog.jp/help/adminsguide/add-issues-via-email/userguide2306.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'ねぇ 知ってる？ヌーラボアカウントを使えば1つのユーザIDとパスワードで複数のBacklogスペースにログインできるんだよ。', 'ヌーラボアカウントとは', 'http://www.backlog.jp/help/usersguide/nulab-account/userguide2272.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'ねぇ 知ってる？ヌーラボアカウントを使えば1つのユーザIDとパスワードでCacooとかTypetalkにもログインできるんだよ。', 'ヌーラボアカウントとは', 'http://www.backlog.jp/help/usersguide/nulab-account/userguide2272.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '課題の件名はできるだけ具体的に。分かりやすさや後から探すときの検索しやすさが全然違うよ。', '件名', 'http://www.backlog.jp/help/usersguide/issue/userguide8.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'ガントチャートってどうやって使うの？という人は、とりあえず各タスクに開始日と期限日を入れるとガントチャートが表示されるよ。', 'ガントチャートの概要', 'http://www.backlog.jp/help/usersguide/gantt-chart/userguide274.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'リリース日を手動でカレンダーに登録してる人は、マイルストーンカレンダーを使うといいかもね。', 'マイルストーンカレンダー', 'http://www.backlog.jp/help/usersguide/project-home/userguide76.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'BacklogAPIで自分好みのBacklogアプリを作ってる人もいるんだって。すごいね！君もやってみない？', 'Backlog API', 'http://developer.nulab-inc.com/ja/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'Backlogは6言語に対応！外国人のプロジェクトメンバーがいたら教えてあげてね。', '多言語対応', 'http://www.backlog.jp/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '新規ユーザを登録するときにアイコンをデフォルト以外にしておくと、本人が自分が気に入ったアイコンを登録してくれる確率があがるらしいよ。', 'ユーザの追加', 'http://www.backlog.jp/help/adminsguide/user-setting/userguide325.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '議事録とか日報をWikiで書いている人はフォーマットを登録しておくと便利だよ。', 'Backlog 小技集： Wikiのコピー', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-6/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '「Backlogを使いこなそう」を見ると、今まで知らなかった機能が発見できるかもしれないよ。', 'Backlogを使いこなそう', 'http://www.backlog.jp/help/usersguide/issue/userguide1.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'チームで運用ルールを決めているなら、Wikiに書いて共有しよう！', 'Wiki', 'http://www.backlog.jp/help/usersguide/wiki/userguide209.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '上手くいったことも失敗したことも、すべてBacklogに書いておけば誰かの役に立つかもしない。', 'コメント', 'http://www.backlog.jp/help/usersguide/issue/userguide32.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '「わざわざコメントするまでもないけど感謝の気持ちを表したい...」という時にもスターが使えるよ。', 'スターを付ける', 'http://www.backlog.jp/help/usersguide/star/userguide456.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '課題の状態や担当者は状況に合わせてこまめに変更しよう。', '課題の状態', 'http://www.backlog.jp/help/usersguide/issue/userguide1.html', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'An issue has become too big to manage? Divide it into smaller issues!', 'Subtasking', 'http://backlogtool.com/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'If the due date is fixed, use the milestone feature.', 'Version/Milestone', 'http://backlogtool.com/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'The Ghantt chart is incredibly useful when you want to keep track of an entire project.', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Save frequently used search conditions to save time!', 'Saving search criteria', 'http://backlogtool.com/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'en', 'Receiving too many emails from Backlog? Check and modify your email settings!', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Change multiple issue statuses or assignees the easy way.', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Need to inform other members of an update or comment?  Use the notification feature!', 'Summary of notification feature', 'http://backlogtool.com/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Do you know how to add headings automatically to a Wiki?', 'Backlog:Index', 'http://backlogtool.com/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Send shortened URLs of issues to make them more managable for sharing!', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'The Burndown chart gives you a general idea of how the project is progressing.', 'Summary of Burndown Chart', 'http://backlogtool.com/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'If you think someone has just posted a great idea, add stars to it!', 'Add Star', 'http://backlogtool.com/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Check your project''s status on the iPhone app while you are out and about. ', 'Backlog for iPhone Features', 'http://backlogtool.com/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Curious to know what your colleagues are up to?  Check their recent activities on their Profile page.', 'Recent Activity in Profile', 'http://backlogtool.com/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'en', 'It is easy to manage multiple versions of files on Git.', 'Git Beginner''s Guide for Dummies', 'http://backlogtool.com/git-guide/en/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'A picture is worth a thousand words. You can post a Cacoo diagram''s URL in you comment or Wiki to give your ideas a visual aid. ', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Markdown, a popular formatting rule, can be used on Backlog too.', 'Project Setting', 'http://backlogtool.com/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Export a Wiki to PDF to share it with people who don''t have access to your Backlog space.', 'Export to PDF', 'http://backlogtool.com/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'With the webhook function of Backlog, you can connect it with external systems.', 'Git Webhook', 'http://backlogtool.com/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'en', 'Are you still adding issues mannually when you receive inquiries from your customers?  Check out our Help page on how to add them automatically!  ', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Did you know you access multiple Backlog spaces in a single sign-in by using the Nulab account?', 'About Nulab Account', 'http://backlogtool.com/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Tip of the week: Nulab Account is a convenient, single sign-in service that lets you sign in to your Backlog, Cacoo and Typetalk accounts with a single sign in.  ', 'About Nulab Account', 'http://backlogtool.com/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Make sure to give your issues a subject heading! It will save you a lot of time searching the issue later.  ', 'Subject Status', 'http://backlogtool.com/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Want to put your issue on the Ghantt chart? It''s simple! All you have to do is set the Start Date and Due Date.', 'Summary of Gantt Chart', 'http://backlogtool.com/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Sync your milestone schedule with your calendar so you won''t forget issue deadlines.', 'Milestone Calendar (iCalendar)', 'http://backlogtool.com/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'I heard some people are developing some cool new applications with the BacklogAPI. Why don''t you give it a try too?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Backlog supports six languages!  You can use Backlog with a multicultural team. ', 'Multilingual', 'http://backlogtool.com/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'New users are more likely to add their own icons if you pick an icon for them at the outset rather than use the default icon of Backlog. ', 'Add User', 'http://backlogtool.com/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Check out the Help pages to discover new features you haven''t learned about!', 'Backlog Help', 'http://backlogtool.com/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Use Wiki to share certain rules among the team!', 'Wiki', 'http://backlogtool.com/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Make a record of all successes and failures on Backlog so that other members can use them as a learning reference in future.', 'Comment', 'http://backlogtool.com/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Show your appreciation with stars.', 'Add Star', 'http://backlogtool.com/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Make sure to update the issue status and assignee as you make progresses with the task.', 'Status of Issue', 'http://backlogtool.com/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'en', 'Of course you know that issues can be updated by Git and Subversion''s commits.', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Administrators can be set for each project too!', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'If you create Wiki pages often, having formats, such as notes or daily report templates, will save your time.', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Một chủ đề trở nên quá lớn để quản lý? Hãy chia nó thành những chủ đề nhỏ hơn!', 'Về chủ đề cha', 'http://backlogtool.com/vn/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Nếu ngày hết hạn cố định, hãy sử dụng chức năng milestone.', 'Phiên bản phát sinh/ cột mốc', 'http://backlogtool.com/vn/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Biểu đồ Ghantt thì vô cùng hữu ích khi bạn muốn theo dõi toàn bộ dự án.', 'Video hướng dẫn Backlog Video "Hướng dẫn Gantt Chart"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Lưu thường xuyên những điều kiện tìm kiếm đã sử dụng để tiết kiệm thời gian!', 'Lưu điều kiện tìm kiếm', 'http://backlogtool.com/vn/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'vi', 'Nhận được quá nhiều email từ Backlog? Kiểm tra và sửa đổi các thiết lập email của bạn!', 'Cập nhật Backlog – Cải thiện chức năng thông báo bằng email', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Thay đổi trạng thái của nhiều chủ đề hoặc người được giao việc một cách dễ dàng.', 'Cập nhật nhiều chủ đề cùng lúc trên Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Cần thông báo đến những thành viên khác khi có cập nhật hoặc bình luận? Sử dụng chức năng gửi thông báo!', 'Khái quát về chức năng thông báo', 'http://backlogtool.com/vn/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Bạn có biết làm thế nào để thêm tiêu đề một cách tự động đến một Wiki?', 'Mục lục', 'http://backlogtool.com/vn/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Gửi URL rút gọn của chủ đề để giúp chúng dễ quản lý hơn khi chia sẻ!', 'Tạo URLs ngắn gọn để chia sẻ trên Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Các biểu đồ Burndown cung cấp cho bạn một cái nhìn tổng thể về tiến độ tiến triển của dự án.', 'Khái quát về biểu đồ Burn down', 'http://backlogtool.com/vn/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Nếu bạn nghĩ ai đó vừa đề xuất một ý tưởng tuyệt vời, hãy thêm những ngôi sao cho điều đó! ', 'Thêm vào ngôi sao', 'http://backlogtool.com/vn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Kiểm tra tình trạng dự án của bạn trên các ứng dụng iPhone trong khi bạn ra ngoài và về.', 'Tính năng của Backlog cho iPhone', 'http://backlogtool.com/vn/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tò mò muốn biết các đồng nghiệp của bạn đang làm những gì? Kiểm tra các hoạt động gần đây trên trang Profile của họ.', 'Hoạt động gần đây trong Profile', 'http://backlogtool.com/vn/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'vi', 'Thật dễ dàng để quản lý nhiều phiên bản của các tập tin trên Git.', 'Hướng dẫn sử dụng Git cho người mới bắt đầu', 'http://backlogtool.com/git-guide/vn/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Một bức hình có thể đáng giá hơn ngàn lời nói. Bạn có thể gửi URL của biểu đồ Cacoo trong bình luận hoặc Wiki để hỗ trợ trực quan cho việc đưa ra ý tưởng của bạn.', 'Làm thế nào để đưa biểu đồ Cacoo vào Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Markdown, một quy tắc định dạng phổ biến, cũng có thể sử dụng được trên Backlog.', 'Thiết lập cơ bản của dự án', 'http://backlogtool.com/vn/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Xuất một Wiki định dạng PDF để chia sẻ cho người không có quyền truy cập vào Backlog space của bạn.', 'Xuất ra PDF', 'http://backlogtool.com/vn/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Với các chức năng webhook của Backlog, bạn có thể kết nối với các hệ thống bên ngoài.', 'Git Webhook', 'http://backlogtool.com/vn/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'vi', 'Bạn vẫn thêm chủ đề một cách thủ công khi nhận được yêu cầu từ khách hàng? Hãy kiểm tra trang Trợ giúp của chúng tôi về cách thêm chủ đề tự động!', 'Thêm yêu cầu qua email như những chủ đề trên Backlog.', 'http://backlogtool.com/vn/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Bạn đã biết bạn truy cập nhiều Backlog space chỉ với một lần đăng nhập bằng cách sử dụng tài khoản Nulab?', 'Về tài khoản Nulab', 'http://backlogtool.com/vn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Mẹo trong tuần: Tài khoản Nulab là một dịch vụ tiện lợi, đăng nhập một lần nhưng có thể cho phép bạn đăng nhập vào tài khoản Backlog, Cacoo và Typetalk của bạn chỉ với việc đăng nhập một lần duy nhất. ', 'Về tài khoản Nulab', 'http://backlogtool.com/vn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Hãy chắc chắn đặt một đề mục cho chủ đề của bạn! Nó sẽ giúp bạn tiết kiệm rất nhiều thời gian tìm kiếm các chủ đề sau này.', 'Tên chủ đề', 'http://backlogtool.com/vn/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Bạn muốn đặt chủ đề của bạn trên biểu đồ Ghantt? Thật đơn giản! Tất cả bạn phải làm là thiết lập ngày bắt đầu và ngày hết hạn.', 'Khái quát biểu đồ Gantt', 'http://backlogtool.com/vn/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Đồng bộ hóa các milestone của bạn với lịch của bạn, bạn sẽ không bị quên ngày hết hạn của chủ đề.', 'Lịch cột mốc ( iCalendar )', 'http://backlogtool.com/vn/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tôi được biết một số người đang phát triển một vài ứng dụng rất "cool" với BacklogAPI. Tại sao bạn không thử dùng nó?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Backlog hỗ trợ sáu ngôn ngữ! Bạn có thể sử dụng Backlog với một đội ngũ đa văn hóa.', 'Đa ngôn ngữ', 'http://backlogtool.com/vn/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Người dùng mới thường thích thêm icon riêng của họ nếu bạn chọn một icon cho họ ngay từ đầu thay vì icon mặc định của Backlog.', 'Thêm người sử dụng', 'http://backlogtool.com/vn/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Kiểm tra các trang Trợ giúp để khám phá các tính năng mới mà bạn chưa biết!', 'Backlog Help', 'http://backlogtool.com/vn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Sử dụng Wiki để chia se một số quy định trong nhóm!', 'Wiki', 'http://backlogtool.com/vn/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tạo một hồ sơ lưu trữ tất cả những thành công và thất bại trên Backlog để những thành viên khác có thể sử dụng chúng để rút kinh nghiệm cho tương lai.', 'Bình luận', 'http://backlogtool.com/vn/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Thể hiện sự cảm kích của bạn với những ngôi sao.', 'Thêm vào ngôi sao', 'http://backlogtool.com/vn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Hãy chắc chắn việc cập nhật trạng thái chủ đề và người được giao việc khi bạn thực hiện tiến trình công việc.', 'Trạng thái của chủ đề', 'http://backlogtool.com/vn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'vi', 'Hiển nhiên bạn biết rằng những chủ để có thể được cập nhật bằng Git và commit Subversion.', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Người quản trị cũng có thể được thiết lập cho từng dự án!', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Nếu bạn thường tạo ra các trang Wiki, có định dạng, chẳng hạn như ghi chú hay các mẫu báo cáo hàng ngày, sẽ tiết kiệm thời gian của bạn.', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '태스크는 적절한 크기로. 너무 큰 태스크가 있을 땐 적절한 크기로 나누는 편이 좋을 거야.', '부모자식 과제에 대하여', 'http://backlogtool.com/kr/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '기한일이 정해져 있을 땐 마일스톤을 사용하면 편리해.', '발생 버전/마일스톤', 'http://backlogtool.com/kr/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '프로젝트 전체를 파악하고 싶을 땐 갠트 차트가 편리해.', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '자주 사용하는 검색 조건을 저장해 두면 시간을 단축할 수 있어!', '검색 조건 저장', 'http://backlogtool.com/kr/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ko', '메일 수신함이 가득 차 있을 경우에는 자신이 받고 싶은 메일만을 수신할 수 있도록 설정할 것을 추천합니다.', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '복수의 과제를 한꺼번에 형식을 변경하거나 담당자를 바꾸는 일도 가능하지.', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '<저 사람이 이 코멘트를 읽어 주면 줬으면...> 할 땐 <공지>를 보내 봐!', '공지 기능의 개요', 'http://backlogtool.com/kr/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Wiki의 색인을 바탕으로 자동으로 목차를 만들어 주는 거 알고 있었어?', '목차', 'http://backlogtool.com/kr/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '검색 후의 과제 일람을 누군가에게 보내고 싶을 때에는 짧은 URL을 보내는 편이 스마트하지!', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '번다운 차트로 프로젝트의 진행 상황을 일목요연하게 볼 수 있어.', '번다운 차트 개요', 'http://backlogtool.com/kr/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '이 코멘트의 이 부분이 나이스 아이디어! 하고 감탄했다면 그 부분을 선택하여 별을 달아 주면 좋을 거야.', '스타를 단다', 'http://backlogtool.com/kr/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '외출했을 때 프로젝트의 상황을 알고 싶다면 iPhone판 Backlog를 보면 되지.', 'Backlog for iPhone의 기능', 'http://backlogtool.com/kr/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '그 사람 요새 무슨 일 하고 있을까..? 하고 궁금해졌다면 프로필 확인!', '프로필의 “최근 활동”', 'http://backlogtool.com/kr/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ko', 'Git로 파일을 버전 관리하면 완전 편하지.', '누구나 쉽게 이해할 수 있는 Git 입문 버전 관리를 완벽하게 이용해보자!', 'http://backlogtool.com/git-guide/kr/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '그림을 그려서 설명하고 싶다면 Cacoo로 그림을 그려서 그 URL을 Wiki나 코멘트에 붙여넣으면 될 거야.', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'Markdown 요새 인기 많지? Backlog에서도 사용할 수 있어.', '프로젝트의 기본 설정', 'http://backlogtool.com/kr/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Wiki는 PDF로 변환할 수 있어. Backlog를 볼 수 없는 사람에게는 PDF로 보여 줘!', 'PDF 출력', 'http://backlogtool.com/kr/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'Backlog에는 webhook기능도 있으니까 외부 시스템과 연계시킬 수도 있어.', 'Git Webhook', 'http://backlogtool.com/kr/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ko', '문의 메일 등의 내용을 Backlog의 과제로써 수동으로 등록하고 있을 경우에는 간단한 설정으로 자동 등록으로 변경하는 것도 가능합니다.', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/kr/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '너 그거 알아? 누라보 계정을 사용하면 하나의 유저 아이디와 비밀먼호로 여러 Backlog스페이스에 로그인할 수 있어!', '누라보 계정이란', 'http://backlogtool.com/kr/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '너 그거 알아? 누라보 계정을 사용하면 하나의 유저 아이디와 비밀먼호로 Cacoo나 Typetalk에 로그인할 수 있다는 거.', '누라보 계정이란', 'http://backlogtool.com/kr/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '과제 제목은 될 수 있는 대로 구체적으로. 알기 쉽고, 나중에 찾을 때 검색하기도 아주 편리해.', '건명', 'http://backlogtool.com/kr/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '갠트 차트는 어떻게 사용해? 라는 사람에게. 먼저 각 태스크에 시작 날짜와 기한을 입력하면 갠트 차트가 뜰 거야.', '갠트 차트 개요', 'http://backlogtool.com/kr/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '릴리스 예정일을 수동으로 캘린더에 등록하고 있는 사람은 마일스톤 캘린더를 사용하면 좋을지도?', '마일스톤 캘린더 (iCalendar)', 'http://backlogtool.com/kr/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'BacklogAPI로 내 마음에 드는 Backlog앱을 만드는 사람도 있대. 끝내주지? 너도 해보지 않을래?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Backlog는 6개 국어로 제공된대. 외국인 프로젝트 멤버가 있다면 꼭 가르쳐줘!', '다언어 대응', 'http://backlogtool.com/kr/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '신규 유저를 등록할 때에는 초기에 설정된 아이콘을 바꿔 놓으면 다른 사람이 내 아이콘이 마음에 들어서 등록해 줄 확률이 오른대.', '유저 추가', 'http://backlogtool.com/kr/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '<Backlog 를 능숙히 써보자>를 보면 지금까지 몰랐던 기능을 발견할 수 있을지도 몰라!', 'Backlog Help', 'http://backlogtool.com/kr/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '팀에서 운용 규칙을 만들었다면 Wiki에 적어서 공유하자!', 'Wiki', 'http://backlogtool.com/kr/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '성공한 일도 실패한 일도 모두 다 Backlog에 적어 놓으면 누군가에게 도움이 될지도 몰라.', '코멘트', 'http://backlogtool.com/kr/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '<일부러 코멘트를 남길 필요까지는 없지만 감사의 마음은 전하고 싶은데..>라는 때에도 별을 사용할 수 있지.', '스타를 단다', 'http://backlogtool.com/kr/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '과제 상태나 담당자는 상황에 맞춰서 부지런히 변경하자.', '과제의 상태', 'http://backlogtool.com/kr/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ko', 'Git 나 Subversion 의 커밋으로 과제 상태를 갱신할 수 있다는데?', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '관리자는 프로젝트별로 설정하는 일도 할 수 있어.', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '회의록이나 일보를 Wiki로 쓰는 사람은 포맷을 등록해 놓으면 편리할걸?', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', ' 一個課題裡有太多任務要管理，處理起來相當困難，怎麼辦？把課題分成更多子課題吧！', '主和子課題功能（Subtasking）', 'http://backlogtool.com/tw/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', ' 如果期限日已確定，試著使用里程碑來設定課題的階段進度。', '版本／里程碑', 'http://backlogtool.com/tw/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '甘特圖可以協助您輕鬆掌握專案的進度。', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '儲存常用的搜尋條件可以節省您更多時間呦！', '儲存搜尋課題的條件', 'http://backlogtool.com/tw/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_tw', '收到太多貝格樂寄來的電子郵件？快來檢查和變更您的郵件設定！', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '簡單快速變更多個課題的狀態或責任者。', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '更新或添加評論時想要通知其他的成員？使用通知功能就對了！', '通知功能概要', 'http://backlogtool.com/tw/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '您知道如何自動添加目次到Wiki嗎？', '目次', 'http://backlogtool.com/tw/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '建立課題的短URL以利於分享！', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '燃盡圖可以提供專案大概的進度狀態。', '燃盡圖概要', 'http://backlogtool.com/tw/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '快送個獎勵星星給剛剛提出超棒點子的成員！', '給予星星', 'http://backlogtool.com/tw/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '使用貝格樂iPhone App隨時隨地查看專案的最新狀態。', '貝格樂iPhone App的功能', 'http://backlogtool.com/tw/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '好奇最近同事們都在忙什麼嗎？查看他們個人簡介的「最近活動」就知道啦。', '個人簡介的「最近活動」', 'http://backlogtool.com/tw/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_tw', '使用Git輕鬆管理多個版本的檔案。', '連猴子都能懂的Git入門指南', 'http://backlogtool.com/git-guide/tw/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '千言萬語抵不過一張圖，在評論或Wiki貼上Cacoo圖表的URL，視覺化您的點子吧。 ', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '貝格樂支援Markdown格式化規則。', '專案基本設定', 'http://backlogtool.com/tw/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '將Wiki以PDF檔案匯出，和無法存取您的貝格樂空間的朋友分享。', 'PDF輸出', 'http://backlogtool.com/tw/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '具備Webhook功能，貝格樂也可以連接到外部系統。', 'Git Webhook', 'http://backlogtool.com/tw/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_tw', '您還在用手動方式將收到的客戶洽詢郵件建立成課題嗎？閱讀我們的支援頁面了解如何自動添加課題！', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/tw/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '只要登入Nulab帳號，您就可以一次使用多個貝格樂空間。', '關於Nulab帳號', 'http://backlogtool.com/tw/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '小知識分享：只要擁有一個Nulab帳號就可以同時登入貝格樂、Cacoo和Typetalk，Nulab帳號提供單一登入機制，方便使用。', '關於Nulab帳號', 'http://backlogtool.com/tw/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', ' 一定要幫您的課題訂一個標題！以後搜尋課題時就可以省去您大量的時間。', '標題', 'http://backlogtool.com/tw/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '想要在您的課題使用甘特圖？只要設定課題的開始日期和期限日就可以了，很簡單吧！', '甘特圖概要', 'http://backlogtool.com/tw/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '立刻同步里程碑時間表到您的行事曆，以避免忘記課題的期限日。', '里程碑行事曆', 'http://backlogtool.com/tw/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '有些開發者使用貝格樂API 開發了很酷的應用程式呦，您要不要也試試看？', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '貝格樂支援6種語言！最適合多元文化的工作團隊使用。', '多語言適用', 'http://backlogtool.com/tw/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '您知道嗎？在添加新用戶時，如果您幫新用戶選擇的圖標不是貝格樂內建的圖標時，他們會更想要變更及添加自己的圖標呦。 ', '添加用戶', 'http://backlogtool.com/tw/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '快來查看FAQ頁面，可以學習到您不知道的新功能呦。', 'Backlog Help', 'http://backlogtool.com/tw/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '運用Wiki來和工作團隊分享重要的規則條件。', 'Wiki', 'http://backlogtool.com/tw/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '建立一個記錄來儲存在貝格樂上所有成功和失敗案例，未來可以讓其他成員從中學習，吸取經驗。', '評論', 'http://backlogtool.com/tw/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '透過給予星星來表達您的讚賞。', '給予星星', 'http://backlogtool.com/tw/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '隨著任務的進展程度，確實做到即時更新課題和責任者。', '課題的狀態', 'http://backlogtool.com/tw/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_tw', '可以透過Git和Subversion的提交更新課題嗎？', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '每個專案都可以設定管理者！', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '如果您經常建立Wiki頁面，設定像是公告或每日報表等等的格式，會更節省您的時間。', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '课题太大了，管理有难度？请把它分成几个小课题吧！', '母子课题功能', 'http://backlogtool.com/cn/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果期限日已经确定了，就请使用里程碑功能吧。', '版本／里程碑', 'http://backlogtool.com/cn/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果您想了解整个项目的进度状况，甘特图必不可少喔。', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '保存常用的查询课题的条件可以节省不少时间！', '保存查询课题的条件', 'http://backlogtool.com/cn/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_cn', '收到太多来自贝格乐的电子邮件？请检查并变更您的邮件设置!', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '简单快捷地一次变更多个课题的状态或责任者。', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想让其他成员知道您更新了课题或发布了评论？用通知功能噢！', '通知功能概述', 'http://backlogtool.com/cn/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '您知道怎样自动地添加Wiki标题吗？', '索引', 'http://backlogtool.com/cn/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想跟成员分享搜索出来的多个课题？发送简短URL会更方便！', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '燃尽图让您大致了解项目的进展状况。', '燃尽图概述', 'http://backlogtool.com/cn/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '如果有成员发布了一个超棒的评论，给评论添加个星星吧！', '添加星星', 'http://backlogtool.com/cn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '当您出门在外时，可以使用iPhone app查看您的项目状态噢。', 'iPhone 贝格乐的功能', 'http://backlogtool.com/cn/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '好奇您的同事们在忙些什么？查看他们的“用户资料” 页面上的 “最近的活动”就知道啦。', '“用户资料” 页面的 “最近的活动”', 'http://backlogtool.com/cn/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_cn', '使用Git可以轻松管理多个版本的文件。', '猴子都能懂的GIT入门', 'http://backlogtool.com/git-guide/cn/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '一张图胜过千言万语。您可以在评论部分或Wiki张贴Cacoo 图表URL，能起到视觉辅助效果噢。', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '贝格乐当然支持人气格式规则—Markdown啦。', '项目设置', 'http://backlogtool.com/cn/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '以PDF格式导出Wiki，然后跟不能访问您的贝格乐空间的人分享Wiki上的信息噢。', '以PDF格式导出', 'http://backlogtool.com/cn/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '由于具备webhook功能，贝格乐可以跟外部系统连接咯。', 'Git Webhook', 'http://backlogtool.com/cn/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_cn', '您还在将客户的邮件逐个地添加为课题吗？请参阅我们的帮助页面看看怎样自动添加课题的！', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/cn/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '您知道吗？只用一个Nulab帐户就可以访问多个贝格乐空间哟。', '关于Nulab帐户', 'http://backlogtool.com/cn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '本周小贴士：Nulab帐户是一个简便的单点登录服务 ( Single Sign-On )。只需登录一个Nulab帐户，您就可以登入贝格乐，Cacoo 和 Typetalk。', '关于Nulab帐户', 'http://backlogtool.com/cn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '一定要给您的课题写上标题喔。有了标题以后就容易查询课题了。  ', '标题', 'http://backlogtool.com/cn/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想要把您的课题放上甘特图？简单，设定开始日和结束日就行了。', '甘特图概述', 'http://backlogtool.com/cn/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '把您的里程碑日程表跟日历设定同步，您就不会忘记课题的期限日了。', '里程碑日历(iCalendar)', 'http://backlogtool.com/cn/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '我听说有人使用BacklogAPI开发出很酷的新应用程序。您也试试嘛。', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '贝格乐支持6种语言！它是您的多元文化团队的最佳选择。', '多种语言', 'http://backlogtool.com/cn/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '注册新用户时，您给他们选一个图标，而不用贝格乐的默认图标。他们之后更有可能上载他们专属的图标喔。', '添加用户', 'http://backlogtool.com/cn/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '请看看帮助页面，发掘您不知道的新功能吧！', 'Backlog Help', 'http://backlogtool.com/cn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '要跟成员共享一些格式规则的话，请用Wiki吧！', 'Wiki', 'http://backlogtool.com/cn/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '在贝格乐上记录所有的成功和失败，以便其他成员日后可以参考学习噢。', '评论', 'http://backlogtool.com/cn/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '点星星以表达您的谢意哟。', '添加星星', 'http://backlogtool.com/cn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '在您执行任务取得进展时，不要忘记即时更新课题状态或责任者哦。', '课题的状态', 'http://backlogtool.com/cn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_cn', '您肯定知道可以通过Git或Subversion提交来更新课题的，是不是？', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '可以给每个项目设定管理员哦！', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果您经常要建立Wiki页面，使用格式 (例如：笔记或每日报告模板), 可以省时省力喔。', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

CREATE TABLE webhook (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  NAME varchar(255) NOT NULL default '',
  DESCRIPTION varchar(255) NOT NULL default '',
  HOOK_URL text NOT NULL,
  ALL_EVENT tinyint(1) NOT NULL default '0',
  EVENTS varchar(255) NOT NULL default '',
  DISPLAY_ORDER int(11) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_webhook_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE webhook_execution_history (
  ID bigint(20) NOT NULL auto_increment,
  JOB_QUEUE_ID bigint(20) NOT NULL,
  PROJECT_ID int(11) NOT NULL default '0',
  WEBHOOK_ID int(11) default NULL,
  NAME varchar(255) NOT NULL default '',
  HOOK_URL text NOT NULL,
  EVENT int(11) NOT NULL default '0',
  CONTENT mediumtext default NULL,
  STATUS_CODE int(11) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  INDEX IX_WEBHOOK_EXECUTION_HISTORY_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_webhook_execution_history_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_webhook_execution_history_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_setting (
  PROJECT_ID int(11) NOT NULL,
  PROJECT_LEADER_CAN_EDIT_PROJECT_LEADER TINYINT(1) NOT NULL,
  USE_WIKI_TREE_VIEW TINYINT(1) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID),
  CONSTRAINT FK_project_setting_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE pull_request (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  REPOSITORY_ID int(11) NOT NULL default '0',
  NUMBER int(11) NOT NULL default '0',
  SUMMARY varchar(255) NOT NULL default '',
  DESCRIPTION mediumtext NOT NULL ,
  BASE varchar(1000) NOT NULL,
  BRANCH varchar(1000) NOT NULL,
  STATUS_ID int(11) NOT NULL,
  ASSIGNER_ID int(11) default NULL,
  ISSUE_ID int(11) default NULL,
  MERGE_COMMIT varchar(255) default NULL,
  BASE_COMMIT varchar(255) default NULL,
  BRANCH_COMMIT varchar(255) default NULL,
  CLOSED_AT datetime default NULL,
  MERGED_AT datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_REPOSITORY_ID_NUMBER (REPOSITORY_ID, NUMBER),
  KEY IX_PROJECT_ID (PROJECT_ID),
  KEY IX_REPOSITORY_ID (REPOSITORY_ID),
  KEY IX_STATUS_ID (STATUS_ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  KEY IX_ASSIGNER_ID (ASSIGNER_ID),
  CONSTRAINT FK_pull_request_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_pull_request_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE,
  CONSTRAINT FK_pull_request_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE max_pull_request_number (
  REPOSITORY_ID int(11) NOT NULL,
  MAX_NUMBER int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (REPOSITORY_ID),
  CONSTRAINT FK_max_pull_request_number_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE pull_request_comment (
  ID int(11) NOT NULL auto_increment,
  PULL_REQUEST_ID int(11) NOT NULL,
  OLD_BLOB_ID varchar(255) default NULL,
  NEW_BLOB_ID varchar(255) default NULL,
  FILE_PATH text default NULL,
  POSITION int(11) default NULL,
  CONTENT mediumtext NOT NULL,
  CHANGELOG longtext,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PULL_REQUEST_ID (PULL_REQUEST_ID),
  KEY IX_CREATED (CREATED),
  CONSTRAINT FK_pull_request_PULL_REQUEST_ID FOREIGN KEY (PULL_REQUEST_ID) REFERENCES pull_request (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE pull_request_attachment (
  ID int(11) NOT NULL auto_increment,
  PULL_REQUEST_ID int(11) NOT NULL default '0',
  NAME varchar(100) NOT NULL default '',
  SIZE int(11) NOT NULL default '0',
  PATH varchar(255) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PULL_REQUEST_ID (PULL_REQUEST_ID),
  CONSTRAINT FK_pull_request_attachment_PULL_REQUEST_ID FOREIGN KEY (PULL_REQUEST_ID) REFERENCES pull_request (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_watch_issue (
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  ISSUE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,ISSUE_ID),
  KEY IX_USER_ID (USER_ID),
  CONSTRAINT FK_user_watch_issue_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_issue_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

ALTER TABLE licence_type ADD PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0' AFTER GIT;
ALTER TABLE licence_type ADD PULL_REQUEST_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0' AFTER PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE=5242880, UPDATED = UPDATED WHERE ID < 20;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE=10485760, UPDATED = UPDATED WHERE ID >= 20;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=1, UPDATED = UPDATED WHERE ID BETWEEN 1 AND 19;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=10, UPDATED = UPDATED WHERE ID BETWEEN 20 AND 29;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=20, UPDATED = UPDATED WHERE ID BETWEEN 30 AND 39;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=30, UPDATED = UPDATED WHERE ID BETWEEN 40 AND 49;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=50, UPDATED = UPDATED WHERE ID BETWEEN 50 AND 70;
UPDATE licence_type SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=0, UPDATED = UPDATED WHERE ID IN (100);

ALTER TABLE licence ADD PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0' AFTER GIT;
ALTER TABLE licence ADD PULL_REQUEST_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0' AFTER PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE=5242880, UPDATED = UPDATED WHERE LICENCE_TYPE_ID < 20;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE=10485760, UPDATED = UPDATED WHERE LICENCE_TYPE_ID >= 20;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=1, UPDATED = UPDATED WHERE LICENCE_TYPE_ID BETWEEN 1 AND 19;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=10, UPDATED = UPDATED WHERE LICENCE_TYPE_ID BETWEEN 20 AND 29;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=20, UPDATED = UPDATED WHERE LICENCE_TYPE_ID BETWEEN 30 AND 39;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=30, UPDATED = UPDATED WHERE LICENCE_TYPE_ID BETWEEN 40 AND 49;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=50, UPDATED = UPDATED WHERE LICENCE_TYPE_ID BETWEEN 50 AND 70;
UPDATE licence SET PULL_REQUEST_ATTACHMENT_NUM_LIMIT=0, UPDATED = UPDATED WHERE LICENCE_TYPE_ID IN (100);

ALTER TABLE licence_changelog ADD PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0' AFTER GIT;
ALTER TABLE licence_changelog ADD PULL_REQUEST_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0' AFTER PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE;

CREATE TABLE user_icon (
  USER_ID           int(11)       PRIMARY KEY,
  DIRECTORY         VARCHAR(255)  NOT NULL,
  FILE_NAME         VARCHAR(255)  NOT NULL,
  WIDTH             INTEGER       default 0,
  HEIGHT            INTEGER       default 0,
  CREATED_USER_ID   int(11)       default NULL,
  CREATED           datetime      NOT NULL,
  UPDATED_USER_ID   int(11)       default NULL,
  UPDATED           timestamp     NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_user_icon_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

ALTER TABLE mail
  ADD HTML_MAIL tinyint(1) default NULL AFTER MY_REPORT;

UPDATE licence SET REMOTE_ADDRESS_LIMIT = 50, UPDATED = UPDATED WHERE LICENCE_TYPE_ID IN (100) AND REMOTE_ADDRESS_LIMIT < 50;
UPDATE licence_type SET REMOTE_ADDRESS_LIMIT = 50, UPDATED = UPDATED WHERE ID IN (100) AND REMOTE_ADDRESS_LIMIT < 50;

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-01-01 00.00.00', '元日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-01-11 00.00.00', '成人の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-02-11 00.00.00', '建国記念の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-03-20 00.00.00', '春分の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-03-21 00.00.00', '振替休日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-04-29 00.00.00', '昭和の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-03 00.00.00', '憲法記念日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-04 00.00.00', 'みどりの日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-05 00.00.00', 'こどもの日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-07-18 00.00.00', '海の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-08-11 00.00.00', '山の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-09-19 00.00.00', '敬老の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-09-22 00.00.00', '秋分の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-10-10 00.00.00', '体育の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-11-03 00.00.00', '文化の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-11-23 00.00.00', '勤労感謝の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-12-23 00.00.00', '天皇誕生日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');

update licence_type set price=2000, updated=updated where id=20 or id=21;
update licence_type set price=9800, updated=updated where id=40 or id=41;
update licence_type set price=16800, updated=updated where id=50 or id=51;

update licence set price=price+200, updated=updated where (licence_type_id=20 or licence_type_id=21) and (price=1800 or price=6800 or price=4800);
update licence set price=price+2000, updated=updated where (licence_type_id=40 or licence_type_id=41) and (price=7800 or price=12800 or price=10800);
update licence set price=price+3800, updated=updated where (licence_type_id=50 or licence_type_id=51) and (price=13000 or price=18000 or price=16000);

INSERT INTO licence_type VALUES
    (81,'プラチナ',0,0,0,0,0,0,0,10485760,50,1,5000,1,10485760,50,1,1,1,1,10485760,50,322122547200,1,1,1,1,1,1,100,0,50000,1,NULL,NULL,NOW(),NULL,NOW());

INSERT INTO reserved_space_key (SPACE_KEY, IS_REGEXP) VALUES ('^usercontent.*$', 1);
