SET NAMES 'utf8';
-- SET time_zone='Asia/Tokyo';

CREATE TABLE service_type (
  ID int(11) NOT NULL auto_increment,
  NAME varchar(20) NOT NULL default '',
  TARGET char(5) NOT NULL,
  DEFAULT_LICENCE_TYPE_ID int(11) default NULL,
  PREFIX_PATH char(6) NOT NULL,
  CURRENCY_CODE char(3) NOT NULL,
  CURRENCY_UNIT varchar(6) NOT NULL,
  CURRENCY_UNIT_HEAD tinyint(1) NOT NULL default 1,
  CURRENCY_UNIT_AMOUNT int(11) NOT NULL,
  CURRENCY_FORMAT char(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE space (
  ID int(11) NOT NULL auto_increment,
  SPACE_KEY varchar(20) NOT NULL default '',
  NAME varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  OWNER_ID int(11) default NULL,
  IMG tinyint(1) default '0',
  BASE_URL text default NULL,
  LANG char(5) NOT NULL default 'en',
  TIMEZONE varchar(50) NOT NULL default 'GMT',
  SERVICE_TYPE_ID int(11) default NULL,
  REPORT_SEND_TIME time DEFAULT null,
  NEED_INDEXING tinyint(1) default '0',
  TEXT_FORMATTING_RULE varchar(255) default NULL,
  USE_NULAB_ACCOUNT tinyint(1) default 0,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_SPACE_KEY (SPACE_KEY),
  CONSTRAINT FK_space_SERVICE_TYPE_ID FOREIGN KEY (SERVICE_TYPE_ID) REFERENCES service_type (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  PROJECT_KEY varchar(50) NOT NULL default '',
  DISABLED int(11) NOT NULL default '0',
  NAME varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  DISPLAY_ORDER int(11) default NULL,
  ARCHIVED tinyint(1) NOT NULL default '0',
  USE_GANTT tinyint(1) default NULL,
  USE_BURNDOWN tinyint(1) default NULL,
  USE_RESOLVED_FOR_CHART tinyint(1) NOT NULL default '0',
  USE_PARENT_CHILD_ISSUE tinyint(1) default NULL,
  ICON varchar(255) default NULL,
  TEXT_FORMATTING_RULE varchar(255) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_SPACE_ID_PROJECT_KEY (SPACE_ID,PROJECT_KEY,DISABLED),
  KEY IX_SPACE_ID (SPACE_ID),
  INDEX IX_DISABLED (DISABLED),
  CONSTRAINT FK_project_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE users (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  USER_ID varchar(255) BINARY NOT NULL default '',
  MAIL_ADDRESS varchar(320) NOT NULL default '',
  AUTH_TYPE int(11) NOT NULL default '0',
  AUTH_VALUE varchar(735) default NULL,
  PASSWORD varchar(255) default NULL,
  NAME varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  ROLE_TYPE int(11) NOT NULL default '0',
  ICON varchar(50) default NULL,
  LANG char(5) default NULL,
  TIMEZONE varchar(50) default NULL,
  LAST_LOGIN_TIME datetime default NULL,
  DISABLED int(11) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_SPACE_ID_USER_ID (SPACE_ID,USER_ID,DISABLED),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_users_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE autologin_user (
  ID varchar(255) NOT NULL default '',
  SPACE_ID int(11) NOT NULL default '0',
  USER_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_SPACE_ID (SPACE_ID),
  KEY IX_CREATED (CREATED),
  CONSTRAINT FK_autologin_user_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_autologin_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE component (
  ID int(11) NOT NULL auto_increment,
  NAME varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  PROJECT_ID int(11) NOT NULL default '0',
  DISPLAY_ORDER int(11) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_COMPONENT_DISPLAY_ORDER (DISPLAY_ORDER),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_component_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE information (
  ID int(11) NOT NULL auto_increment,
  INFO_KEY varchar(255) NOT NULL default '',
  LANG char(5) NOT NULL default 'ja',
  CONTENT text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  FROM_DATE datetime NOT NULL default '0000-00-00 00:00:00',
  TO_DATE datetime NOT NULL default '0000-00-00 00:00:00',
  TARGET_USER_CREATED_AFTER datetime default NULL,
  TARGET_USER_CREATED_BEFORE datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_INFO_KEY (INFO_KEY)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE status (
  ID int(11) NOT NULL default '0',
  LABEL varchar(20) NOT NULL default '',
  DISPLAY_ORDER int(11) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE version (
  ID int(11) NOT NULL auto_increment,
  NAME varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  PROJECT_ID int(11) default NULL,
  DESCRIPTION mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  START_DATE datetime default NULL,
  REFERENCE_DATE datetime default NULL,
  DISPLAY_ORDER int(11) default NULL,
  ARCHIVED tinyint(1) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_REFERENCE_DATE (REFERENCE_DATE),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_version_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE default_issue_type (
  ID int(11) NOT NULL default '0',
  LANG char(5) NOT NULL default 'ja',
  NAME varchar(20) NOT NULL,
  DISPLAY_ORDER int(11) NOT NULL,
  COLOR varchar(20) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_type (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL,
  NAME varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  DISPLAY_ORDER int(11) default NULL,
  COLOR varchar(20) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_issue_type_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  KEY_ID int(11) default NULL,
  ISSUE_TYPE_ID int(11) NOT NULL default '0',
  COMPONENT_ID int(11) default NULL,
  SUMMARY varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  DESCRIPTION mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  STATUS_ID int(11) default NULL,
  RESOLUTION_ID int(11) default NULL,
  PRIORITY int(11) NOT NULL default '0',
  AFFECTED_VERSION_ID int(11) default NULL,
  FIXED_VERSION_ID int(11) default NULL,
  ASSIGNER_ID int(11) default NULL,
  START_DATE datetime default NULL,
  LIMIT_DATE datetime default NULL,
  ESTIMATED_HOURS float default NULL,
  ACTUAL_HOURS float default NULL,
  PARENT_ISSUE_ID int(11) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_PROJECT_ID_KEY_ID (PROJECT_ID,KEY_ID),
  KEY IX_RESOLUTION_ID (RESOLUTION_ID),
  KEY IX_PRIORITY (PRIORITY),
  KEY IX_KEY_ID (KEY_ID),
  KEY IX_UPDATED (UPDATED),
  KEY IX_STATUS_ID (STATUS_ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  KEY IX_COMPONENT_ID (COMPONENT_ID),
  KEY IX_FIXED_VERSION_ID (FIXED_VERSION_ID),
  KEY IX_ASSIGNER_ID (ASSIGNER_ID),
  KEY IX_AFFECTED_VERSION_ID (AFFECTED_VERSION_ID),
  KEY IX_CREATED_USER_ID (CREATED_USER_ID),
  KEY IX_CREATED (CREATED),
  KEY IX_START_DATE (START_DATE),
  KEY IX_PROJECT_ID_UPDATED (PROJECT_ID, UPDATED DESC),
  KEY IX_CREATED_USER_ID_PROJECT_ID (created_user_id, project_id),
  KEY IX_ASSIGNER_ID_PROJECT_ID (assigner_id, project_id),
  KEY IX_PARENT_ISSUE_ID (PARENT_ISSUE_ID),
  CONSTRAINT FK_issue_STATUS_ID FOREIGN KEY (STATUS_ID) REFERENCES status (ID),
  CONSTRAINT FK_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_COMPONENT_ID FOREIGN KEY (COMPONENT_ID) REFERENCES component (ID) ON DELETE SET NULL,
  CONSTRAINT FK_issue_FIXED_VERSION_ID FOREIGN KEY (FIXED_VERSION_ID) REFERENCES version (ID) ON DELETE SET NULL,
  CONSTRAINT FK_issue_ASSIGNER_ID FOREIGN KEY (ASSIGNER_ID) REFERENCES users (ID) ON DELETE SET NULL,
  CONSTRAINT FK_issue_AFFECTED_VERSION_ID FOREIGN KEY (AFFECTED_VERSION_ID) REFERENCES version (ID) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_component (
  ISSUE_ID int(11) NOT NULL,
  LINK_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ISSUE_ID,LINK_ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  KEY IX_LINK_ID (LINK_ID),
  CONSTRAINT FK_issue_component_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_component_LINK_ID FOREIGN KEY (LINK_ID) REFERENCES component (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_affectedversion (
  ISSUE_ID int(11) NOT NULL,
  LINK_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ISSUE_ID,LINK_ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  KEY IX_LINK_ID (LINK_ID),
  CONSTRAINT FK_issue_affectedversion_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_affectedversion_LINK_ID FOREIGN KEY (LINK_ID) REFERENCES version (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_fixedversion (
  ISSUE_ID int(11) NOT NULL,
  LINK_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ISSUE_ID,LINK_ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  KEY IX_LINK_ID (LINK_ID),
  CONSTRAINT FK_issue_fixedversion_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_fixedversion_LINK_ID FOREIGN KEY (LINK_ID) REFERENCES version (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE attachment (
  ID int(11) NOT NULL auto_increment,
  ISSUE_ID int(11) NOT NULL default '0',
  NAME varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  SIZE int(11) NOT NULL default '0',
  CONTENT longblob,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  CONSTRAINT FK_attachment_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE comment (
  ID int(11) NOT NULL auto_increment,
  ISSUE_ID int(11) default NULL,
  PROJECT_ID int(11) NOT NULL,
  CONTENT mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CHANGELOG_XML longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_UPDATED (UPDATED),
  KEY IX_ISSUE_ID (ISSUE_ID),
  KEY IX_CREATED_USER_ID (CREATED_USER_ID),
  KEY IX_CREATED (CREATED),
  KEY IX_PROJECT_ID_UPDATED (PROJECT_ID, UPDATED),
  CONSTRAINT FK_comment_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE licence_type (
  ID int(11) NOT NULL,
  NAME text NOT NULL,
  PROJECT_LIMIT int(11) NOT NULL,
  USER_LIMIT int(11) NOT NULL,
  COMPONENT_LIMIT int(11) NOT NULL,
  VERSION_LIMIT int(11) NOT NULL,
  ISSUE_LIMIT int(11) NOT NULL,
  COMMENT_LIMIT int(11) NOT NULL,
  ATTACHMENT_LIMIT int(11) NOT NULL default '0',
  ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  REMOTE_ADDRESS tinyint(1) NOT NULL default '0',
  REMOTE_ADDRESS_LIMIT int(11) NOT NULL default '0',
  WIKI_ATTACHMENT tinyint(1) NOT NULL default '0',
  WIKI_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  WIKI_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  FILE_SHARING tinyint(1) NOT NULL default '0',
  SUBVERSION tinyint(1) NOT NULL default '0',
  SUBVERSION_EXTERNAL tinyint(1) NOT NULL default '0',
  GIT tinyint(1) NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  STORAGE_LIMIT bigint(20) NOT NULL default '0',
  GANTT tinyint(1) default '0',
  BURNDOWN tinyint(1) default '0',
  PARENT_CHILD_ISSUE tinyint(1) NOT NULL default '0',
  POST_ISSUE_BY_MAIL tinyint(1) NOT NULL default '0',
  NULAB_ACCOUNT tinyint(1) NOT NULL default '0',
  NEW_UI tinyint(1) NOT NULL default '0',
  PROJECT_GROUP tinyint(1) NOT NULL default '0',
  ATTRIBUTE tinyint(1) NOT NULL default '0',
  ATTRIBUTE_LIMIT int(11) NOT NULL default '0',
  INITIAL_COSTS int(11),
  PRICE int(11),
  SELECTABLE tinyint(1) NOT NULL default '0',
  SERVICE_TYPE_ID int(11) default NULL,
  NULAB_APPS_INTEGRATION tinyint(1) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_licence_type_SERVICE_TYPE_ID FOREIGN KEY (SERVICE_TYPE_ID) REFERENCES service_type (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE licence (
  SPACE_ID int(11) NOT NULL,
  LICENCE_TYPE_ID int(11) NOT NULL,
  PROJECT_LIMIT int(11) NOT NULL default '0',
  USER_LIMIT int(11) NOT NULL default '0',
  COMPONENT_LIMIT int(11) NOT NULL default '0',
  VERSION_LIMIT int(11) NOT NULL default '0',
  ISSUE_LIMIT int(11) NOT NULL default '0',
  COMMENT_LIMIT int(11) NOT NULL default '0',
  ATTACHMENT_LIMIT int(11) NOT NULL default '0',
  ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  REMOTE_ADDRESS tinyint(1) NOT NULL default '0',
  REMOTE_ADDRESS_LIMIT int(11) NOT NULL default '0',
  WIKI_ATTACHMENT tinyint(1) NOT NULL default '0',
  WIKI_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  WIKI_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  FILE_SHARING tinyint(1) NOT NULL default '0',
  SUBVERSION tinyint(1) NOT NULL default '0',
  SUBVERSION_EXTERNAL tinyint(1) NOT NULL default '0',
  GIT tinyint(1) NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  STORAGE_LIMIT bigint(20) NOT NULL default '0',
  GANTT tinyint(1) default '0',
  BURNDOWN tinyint(1) default '0',
  PARENT_CHILD_ISSUE tinyint(1) NOT NULL default '0',
  POST_ISSUE_BY_MAIL tinyint(1) NOT NULL default '0',
  NULAB_ACCOUNT tinyint(1) NOT NULL default '0',
  NEW_UI tinyint(1) NOT NULL default '0',
  PROJECT_GROUP tinyint(1) NOT NULL default '0',
  ATTRIBUTE tinyint(1) NOT NULL default '0',
  ATTRIBUTE_LIMIT int(11) NOT NULL default '0',
  STARTED_ON datetime default NULL,
  LIMIT_DATE datetime default NULL,
  ACTIVE tinyint(1) default '1',
  PAYMENT int(11) default NULL,
  SUBSCRIBED_ON datetime default NULL,
  TRIAL_EXPIRY_DATE datetime default NULL,
  INITIAL_COSTS int(11) default NULL,
  PRICE int(11) default NULL,
  LICENCE_KEY text default NULL,
  NULAB_APPS_INTEGRATION tinyint(1) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_ID),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_licence_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_licence_LICENCE_TYPE_ID FOREIGN KEY (LICENCE_TYPE_ID) REFERENCES licence_type (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE licence_changelog (
  ID int(11) NOT NULL auto_increment,
  CHANGED_ON datetime NOT NULL,
  SPACE_ID int(11) NOT NULL,
  LICENCE_TYPE_ID int(11) NOT NULL,
  PROJECT_LIMIT int(11) NOT NULL default '0',
  USER_LIMIT int(11) NOT NULL default '0',
  COMPONENT_LIMIT int(11) NOT NULL default '0',
  VERSION_LIMIT int(11) NOT NULL default '0',
  ISSUE_LIMIT int(11) NOT NULL default '0',
  COMMENT_LIMIT int(11) NOT NULL default '0',
  ATTACHMENT_LIMIT int(11) NOT NULL default '0',
  ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  REMOTE_ADDRESS tinyint(1) NOT NULL default '0',
  REMOTE_ADDRESS_LIMIT int(11) NOT NULL default '0',
  WIKI_ATTACHMENT tinyint(1) NOT NULL default '0',
  WIKI_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  WIKI_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  FILE_SHARING tinyint(1) NOT NULL default '0',
  SUBVERSION tinyint(1) NOT NULL default '0',
  SUBVERSION_EXTERNAL tinyint(1) NOT NULL default '0',
  GIT tinyint(1) NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE int(11) NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_NUM_LIMIT int(11) NOT NULL default '0',
  STORAGE_LIMIT bigint(20) NOT NULL default '0',
  GANTT tinyint(1) default '0',
  BURNDOWN tinyint(1) default '0',
  PARENT_CHILD_ISSUE tinyint(1) NOT NULL default '0',
  POST_ISSUE_BY_MAIL tinyint(1) NOT NULL default '0',
  NULAB_ACCOUNT tinyint(1) NOT NULL default '0',
  ATTRIBUTE tinyint(1) NOT NULL default '0',
  ATTRIBUTE_LIMIT int(11) NOT NULL default '0',
  STARTED_ON datetime NOT NULL,
  LIMIT_DATE datetime default NULL,
  ACTIVE tinyint(1) default '1',
  PAYMENT int(11) default NULL,
  SUBSCRIBED_ON datetime NOT NULL,
  TRIAL_EXPIRY_DATE datetime default NULL,
  INITIAL_COSTS int(11) NOT NULL,
  PRICE int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (ID),
  KEY IX_SPACE_ID (SPACE_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE mail (
  USER_ID int(11) NOT NULL default '0',
  MAIL tinyint(1) default NULL,
  ISSUE tinyint(1) default NULL,
  COMMENT tinyint(1) default NULL,
  ALL_ISSUE tinyint(1) default NULL,
  ASSIGNED_ISSUE tinyint(1) default NULL,
  CREATED_ISSUE tinyint(1) default NULL,
  WIKI tinyint(1) default NULL,
  NOTIFIED tinyint(1) default NULL,
  SUMMARY tinyint(1) default NULL,
  SUBVERSION tinyint(1) default NULL,
  GIT tinyint(1) default NULL,
  MY_REPORT tinyint(1) default NULL,
  HTML_MAIL tinyint(1) default NULL,
  ANNOUNCEMENT tinyint(1) default NULL,
  FORCE_UTF8 tinyint(1) default NULL,
  EXCLUDE_MAIL_TYPE_IN_SUBJECT tinyint(1) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  CONSTRAINT FK_mail_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_setting (
  USER_ID int(11) NOT NULL default '0',
  SHOW_CREATED_ISSUE tinyint(1) default NULL,
  USE_PRIVATE_ADDRESS tinyint(1) NOT NULL DEFAULT 0,
  PRIVATE_ADDRESS_KEY VARCHAR(255) default NULL,
  LAST_UPDATED_NUM int(11) default NULL,
  LAST_UPDATED_DISABLED_TYPES varchar(255) default NULL,
  USE_COLLAPSE_COMMENT tinyint(1) default 1,
  USE_SHORTCUT_KEY tinyint(1) default 1,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID),
  UNIQUE KEY UQ_PRIVATE_ADDRESS_KEY (PRIVATE_ADDRESS_KEY),
  KEY IX_USER_ID (USER_ID),
  KEY IX_USE_PRIVATE_ADDRESS_AND_PRIVATE_ADDRESS_KEY (USE_PRIVATE_ADDRESS,PRIVATE_ADDRESS_KEY),
  CONSTRAINT FK_user_setting_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE page (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  PROJECT_ID int(11) NOT NULL default '0',
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  CONTENT mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_PROJECT_ID_NAME (PROJECT_ID,NAME),
  KEY IX_SPACE_ID (SPACE_ID),
  KEY IX_CREATED (CREATED),
  KEY IX_UPDATED (UPDATED),
  KEY IX_PROJECT_ID_UPDATED (PROJECT_ID, UPDATED DESC),
  CONSTRAINT FK_page_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_page_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

CREATE TABLE page_attachment (
  ID int(11) NOT NULL auto_increment,
  PAGE_ID int(11) NOT NULL default '0',
  NAME varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  SIZE int(11) NOT NULL default '0',
  CONTENT longblob,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PAGE_ID (PAGE_ID),
  CONSTRAINT FK_page_attachment_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE page_tag (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_PROJECT_ID_NAME (PROJECT_ID,NAME),
  CONSTRAINT FK_page_tag_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

CREATE TABLE page_tag_link (
  PAGE_ID int(11) NOT NULL default '0',
  PAGE_TAG_ID int(11) NOT NULL default '0',
  DISPLAY_ORDER int(11) NOT NULL default '0',
  PRIMARY KEY  (PAGE_ID,PAGE_TAG_ID),
  KEY IX_PAGE_TAG_ID (PAGE_TAG_ID),
  CONSTRAINT FK_page_tag_link_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE,
  CONSTRAINT FK_page_tag_link_PAGE_TAG_ID FOREIGN KEY (PAGE_TAG_ID) REFERENCES page_tag (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE party (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  NULAB_APPS_GROUP_KEY varchar(50) default NULL,
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  DISPLAY_ORDER int(11) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_NULAB_APPS_GROUP_KEY (NULAB_APPS_GROUP_KEY),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_party_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE party_user (
  PARTY_ID int(11) NOT NULL,
  USER_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PARTY_ID,USER_ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_PARTY_ID (PARTY_ID),
  CONSTRAINT FK_party_user_PARTY_ID FOREIGN KEY (PARTY_ID) REFERENCES party (ID) ON DELETE CASCADE,
  CONSTRAINT FK_party_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_user (
  PROJECT_ID int(11) NOT NULL default '0',
  USER_ID int(11) NOT NULL default '0',
  PROJECT_LEADER tinyint(1) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (PROJECT_ID,USER_ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT project_user_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT project_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_mail (
  USER_ID int(11) NOT NULL default '0',
  PROJECT_ID int(11) NOT NULL default '0',
  MAIL tinyint(1) default NULL,
  ISSUE tinyint(1) default NULL,
  COMMENT tinyint(1) default NULL,
  ALL_ISSUE tinyint(1) default NULL,
  ASSIGNED_ISSUE tinyint(1) default NULL,
  CREATED_ISSUE tinyint(1) default NULL,
  WIKI tinyint(1) default NULL,
  NOTIFIED tinyint(1) default NULL,
  SUMMARY tinyint(1) default NULL,
  SUBVERSION tinyint(1) default NULL,
  GIT tinyint(1) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID, PROJECT_ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT project_mail_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT project_mail_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE reminder (
  ID varchar(255) NOT NULL,
  USER_ID int(11) NOT NULL,
  SPACE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE remote_address (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) default NULL,
  IP_ADDRESS varchar(255) default NULL,
  MASK varchar(255) default NULL,
  MEMO varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_remote_address_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


CREATE TABLE space_contact (
  SPACE_ID int(11) NOT NULL,
  NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  KANA text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  PERSON text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  GENDER varchar(1),
  MAIL_ADDRESS text,
  POST text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  POSITION text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  TEL text,
  ZIPCODE varchar(8) default NULL,
  PREF_NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  ADDRESS text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  URL text,
  BILLING_NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_PERSON text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_MAIL_ADDRESS text default NULL,
  BILLING_POST text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_POSITION text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_TEL text default NULL,
  BILLING_ZIPCODE text default NULL,
  BILLING_PREF_NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_ADDRESS text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_ID),
  CONSTRAINT FK_space_contact_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE space_contact_changelog (
  ID int(11) NOT NULL auto_increment,
  CHANGED_ON datetime NOT NULL,
  SPACE_ID int(11) NOT NULL,
  NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  KANA text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  PERSON text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  GENDER varchar(1),
  MAIL_ADDRESS text,
  POST text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  POSITION text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  TEL text,
  ZIPCODE varchar(8) default NULL,
  PREF_NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  ADDRESS text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  URL text,
  BILLING_NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_PERSON text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_MAIL_ADDRESS text default NULL,
  BILLING_POST text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_POSITION text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_TEL text default NULL,
  BILLING_ZIPCODE text default NULL,
  BILLING_PREF_NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BILLING_ADDRESS text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED datetime NOT NULL default '0000-00-00 00:00:00',
  PRIMARY KEY  (ID),
  KEY IX_SPACE_ID (SPACE_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE space_order (
  SPACE_KEY varchar(20) NOT NULL default '',
  AUTH_KEY varchar(20) NOT NULL default '',
  ORDER_XML text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_KEY),
  UNIQUE KEY UQ_AUTH_KEY (AUTH_KEY)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE space_remarks (
  SPACE_ID int(11) NOT NULL,
  CONTENT text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  SPECIAL_SUPPORT int(11) default NULL,
  SPECIAL_SUPPORT_CONTENT text default NULL,
  SPECIAL_SUPPORT_CONSOLIDATED_BILLING_SPACES varchar(255) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_ID),
  CONSTRAINT FK_space_remarks_1 FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE space_field (
  SPACE_ID int(11) NOT NULL,
  FIELD_KEY varchar(255) NOT NULL,
  VALUE text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11),
  CREATED datetime,
  UPDATED_USER_ID int(11),
  UPDATED timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (SPACE_ID, FIELD_KEY),
  INDEX (SPACE_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE disk_usage (
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE int(11) NOT NULL,
  AMOUNT bigint(20) NOT NULL default '0',
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID,TYPE),
  CONSTRAINT FK_disk_usage_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE shared_file (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  DIR text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  SIZE bigint(20) default NULL,
  TYPE int(11) NOT NULL,
  CHECKSUM VARCHAR(40) NULL DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PROJECT_ID_UPDATED (PROJECT_ID, UPDATED DESC),
  KEY IX_PROJECT_ID_DIR_NAME (PROJECT_ID, DIR(255), NAME(255)),
  CONSTRAINT FK_shared_file_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

CREATE TABLE subversion (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE SMALLINT NOT NULL,
  URL text default NULL,
  SVN_USER text default NULL,
  SVN_PASSWORD text default NULL,
  COMMIT_ISSUE_UPDATE tinyint(1) default 0,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_subversion_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_shared_file_link (
  ISSUE_ID int(11) NOT NULL default '0',
  SHARED_FILE_ID int(11) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,SHARED_FILE_ID),
  CONSTRAINT FK_issue_shared_file_link_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_shared_file_link_SHARED_FILE_ID FOREIGN KEY (SHARED_FILE_ID) REFERENCES shared_file (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE page_shared_file_link (
  PAGE_ID int(11) NOT NULL default '0',
  SHARED_FILE_ID int(11) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PAGE_ID,SHARED_FILE_ID),
  CONSTRAINT FK_page_shared_file_link_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE,
  CONSTRAINT FK_page_shared_file_link_SHARED_FILE_ID FOREIGN KEY (SHARED_FILE_ID) REFERENCES shared_file (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE work_item (
  ID int(11) NOT NULL auto_increment,
  WORK_ITEM_ID int(11) default NULL,
  WORKFLOW_NAME varchar(10) default NULL,
  START_DATE datetime default NULL,
  END_DATE datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_WORK_ITEM_ID (WORK_ITEM_ID),
  CONSTRAINT FK_work_item_WORK_ITEM_ID FOREIGN KEY (WORK_ITEM_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE step (
  ID int(11) NOT NULL auto_increment,
  NEXT int(11) default NULL,
  PREVIOUS int(11) default NULL,
  WORK_ITEM_ID int(11) default NULL,
  STEP_ID int(11) default NULL,
  OWNER varchar(10) default NULL,
  START_DATE datetime default NULL,
  END_DATE datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_WORK_ITEM_ID (WORK_ITEM_ID),
  CONSTRAINT FK_step_WORK_ITEM_ID FOREIGN KEY (WORK_ITEM_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE star (
  ID int(11) NOT NULL auto_increment,
  AWARD_ID int(11) default NULL,
  PRESENTER_ID int(11) default NULL,
  PROJECT_ID int(11) default NULL,
  URL varchar(735) NOT NULL default '',
  TITLE varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  COMMENT varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_URL (URL(255)),
  KEY IX_CREATED (CREATED),
  KEY IX_PROJECT_ID_CREATED (PROJECT_ID, CREATED),
  CONSTRAINT FK_star_AWARD_ID FOREIGN KEY (AWARD_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_star_PRESENTER_ID FOREIGN KEY (PRESENTER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_star_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE star_notify (
  ID int(11) NOT NULL auto_increment,
  STAR_ID int(11) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_star_notify_STAR_ID FOREIGN KEY (STAR_ID) REFERENCES star (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_profile (
  USER_ID int(11) NOT NULL,
  SEX tinyint(1) default NULL,
  LOCATION text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  BIOGRAPHY text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  URLS text default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID),
  CONSTRAINT FK_user_profile_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_recent_project (
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID),
  KEY IX_user_recent_project_USER_ID_CREATED (USER_ID, CREATED),
  CONSTRAINT FK_recent_project_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_recent_project_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE mobilelogin_user (
  ID varchar(255) BINARY NOT NULL,
  USER_ID int(11) NOT NULL default 0,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_mobilelogin_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE reserved_space_key (
  SPACE_KEY varchar(255) NOT NULL,
  IS_REGEXP tinyint(1) NOT NULL default 0,
  PRIMARY KEY (SPACE_KEY)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE holiday (
  ID int(11) NOT NULL auto_increment,
  DATE datetime NOT NULL default '0000-00-00 00:00:00',
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE attribute (
  ID int(11) NOT NULL auto_increment,
  USE_ISSUE_TYPE tinyint(1) NOT NULL default '0',
  PROJECT_ID int(11) NOT NULL,
  ATTRIBUTE_TYPE_ID int(11) NOT NULL,
  REQUIRED tinyint(1) DEFAULT '0',
  LABEL varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '''',
  DESCRIPTION varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '''',
  PROPERTY_JSON text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  DISPLAY_ORDER int(11) DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_attribute_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_attribute (
  ID int(11) NOT NULL auto_increment,
  ISSUE_ID int(11) NOT NULL,
  ATTRIBUTE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_issue_attribute_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_attribute_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE issue_attribute_value (
  ID int(11) NOT NULL auto_increment,
  ISSUE_ATTRIBUTE_ID int(11) NOT NULL,
  ATTRIBUTE_ID int(11) NOT NULL,
  TEXT text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  DATE datetime,
  NUMBER double,
  IDENTITY int(11),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_issue_attribute_value_ISSUE_ATTRIBUTE_ID FOREIGN KEY (ISSUE_ATTRIBUTE_ID) REFERENCES issue_attribute (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_attribute_value_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE attribute_issue_type(
  ATTRIBUTE_ID int(11) NOT NULL,
  ISSUE_TYPE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_attribute_issue_type_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  CONSTRAINT FK_attribute_issue_type_ISSUE_TYPE_ID FOREIGN KEY (ISSUE_TYPE_ID) REFERENCES issue_type (ID) ON DELETE CASCADE,
  PRIMARY KEY (ATTRIBUTE_ID,ISSUE_TYPE_ID),
  KEY(ATTRIBUTE_ID),
  KEY(ISSUE_TYPE_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 課金
--
-- type       =  1:初回, 2:更新, 3:プラン変更差額, 99:その他
-- payment    =  1:口座振替, 2:銀行振込
-- status     =  1:請求前, 2:入金待ち, 3:入金確認済, 4:口座引落失敗, 5:破棄(解約含む), 6:クーポン利用
-- due_date   = 支払期日
-- paid_on    = 入金された日
-- started_on = 利用期間 開始日
-- expired_on = 利用期間 終了日
--
CREATE TABLE billing (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  TYPE int(11) NOT NULL,
  PAYMENT int(11) NOT NULL,
  AMOUNT int(11) NOT NULL,
  DISCOUNT int(11) DEFAULT 0,
  DUE_DATE datetime NOT NULL,
  PAID_ON datetime DEFAULT NULL,
  PAID_NAME varchar(255) DEFAULT NULL,
  STARTED_ON datetime DEFAULT NULL,
  EXPIRED_ON datetime DEFAULT NULL,
  STATUS int(11) NOT NULL DEFAULT '1',
  MEMO varchar(255) DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PAYMENT_STATUS_DUE_DATE (PAYMENT, STATUS, DUE_DATE),
  CONSTRAINT FK_billing_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 請求書発行
--
-- type      = 1:通常, 2:メール, 3:再発行
-- status    = 1:未発行, 2:発行済, 3:発行取消
-- due_date  = 送付予定日
-- sended_on = 発送した日
--
CREATE TABLE invoice (
  ID int(11) NOT NULL auto_increment,
  BILLING_ID int(11) NOT NULL,
  TYPE int(11) NOT NULL DEFAULT '1',
  STATUS int(11) NOT NULL DEFAULT '1',
  DUE_DATE datetime NOT NULL,
  SENDED_ON datetime DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_invoice_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 口座振替依頼書の手続
--
-- status            = 1:書類準備中, 2:返信待ち, 3:リコーからのFAX待ち, 4:手続完了, 5:手続取消
-- sended_on         = 依頼書発送日
-- due_date          = 口座振替依頼書の送付予定日
-- received_due_date = 口座振替依頼書を返送して欲しい期限日 (申込みの翌月第一金曜日)
-- received_on       = 依頼書が返信された日(リコーにチェック依頼した日)
-- completed_on      = リコーからの審査OKが届いた日
--
CREATE TABLE account_transfer_procedure (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  STATUS int(11) NOT NULL DEFAULT 0,
  SENDED_ON datetime DEFAULT NULL,
  DUE_DATE datetime DEFAULT NULL,
  RECEIVED_DUE_DATE datetime DEFAULT NULL,
  RECEIVED_ON datetime DEFAULT NULL,
  COMPLETED_ON datetime DEFAULT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_account_transfer_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 口座振替 回収結果
--
-- status            = 0:入金OK, 1:残高不足, 2: TODO, 3: TODO, 4:取引無し
-- result_date       = 引き落し日
--
CREATE TABLE account_transfer_result (
  ID int(11) NOT NULL auto_increment,
  STATUS int(11) NOT NULL,
  RESULT_DATE datetime NOT NULL,
  AMOUNT int(11) NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE billing_account_transfer_result (
  BILLING_ID int(11) NOT NULL,
  RESULT_ID int(11) NOT NULL,
  PRIMARY KEY (BILLING_ID, RESULT_ID),
  CONSTRAINT FK_billing_account_transfer_result_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE,
  CONSTRAINT FK_billing_account_transfer_result_RESULT_ID FOREIGN KEY (RESULT_ID) REFERENCES account_transfer_result (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- ライセンス変更リクエスト (プランダウンのバッチ用途)
--
CREATE TABLE licence_change_request(
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  FROM_LICENCE_TYPE_ID int(11) NOT NULL,
  TO_LICENCE_TYPE_ID int(11) NOT NULL,
  CLOSE tinyint(1) NOT NULL default '0',
  CHANGED_ON datetime NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_licence_change_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_licence_change_request_FROM_LICENCE_TYPE_ID FOREIGN KEY (FROM_LICENCE_TYPE_ID) REFERENCES licence_type (ID),
  CONSTRAINT FK_licence_change_request_TO_LICENCE_TYPE_ID FOREIGN KEY (TO_LICENCE_TYPE_ID) REFERENCES licence_type (ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 支払い方法変更リクエスト
-- CHANGED_ON はリクエスト時には空、前回の支払い方法での入金確認後に切り替える場合に設定
--
CREATE TABLE payment_change_request(
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  FROM_PAYMENT int(11) NOT NULL,
  TO_PAYMENT int(11) NOT NULL,
  CONTENT text,
  CHANGED_ON datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_payment_change_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE space_information (
  SPACE_ID int(11) NOT NULL default '0',
  CONTENT mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (SPACE_ID),
  KEY IX_SPACE_ID (SPACE_ID),
  CONSTRAINT FK_space_information_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_activity (
  ID bigint(20) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE int(11) NOT NULL,
  CONTENT_JSON longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID_CREATED_TYPE_CREATED_USER_ID (PROJECT_ID, CREATED DESC, TYPE, CREATED_USER_ID),
  CONSTRAINT FK_project_activity_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_recent_issue (
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  ISSUE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,ISSUE_ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_user_recent_issue_USER_ID_CREATED (USER_ID, CREATED),
  CONSTRAINT FK_user_recent_issue_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_recent_page (
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  PAGE_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,PAGE_ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_user_recent_page_USER_ID_CREATED (USER_ID, CREATED),
  CONSTRAINT FK_user_recent_page_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- BLG-2835
--
-- project_activity_notify
--
CREATE TABLE project_activity_notify (
  ID bigint(20) NOT NULL auto_increment,
  PROJECT_ACTIVITY_ID bigint(20) NOT NULL default '0',
  USER_ID int(11) NOT NULL default '0',
  REASON int(11),
  ALREADY_READ tinyint(1) NOT NULL DEFAULT '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ACTIVITY_ID_USER_ID (PROJECT_ACTIVITY_ID, USER_ID),
  KEY IX_USER_ID_CREATED (USER_ID, CREATED DESC),
  CONSTRAINT FK_project_activity_notify_PROJECT_ACTIVITY_ID FOREIGN KEY (PROJECT_ACTIVITY_ID) REFERENCES project_activity (ID) ON DELETE CASCADE,
  CONSTRAINT FK_project_activity_notify_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- BLG-4007 誰宛に通知したかを分かるようにする
--
-- notify_resource
--
CREATE TABLE notify_resource (
  ID bigint(20) NOT NULL auto_increment,
  PROJECT_ACTIVITY_NOTIFY_ID bigint(20) NOT NULL default '0',
  RESOURCE varchar(255) NOT NULL default '',
  ALREADY_READ tinyint(1) NOT NULL DEFAULT '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ACTIVITY_NOTIFY_ID (PROJECT_ACTIVITY_NOTIFY_ID),
  KEY IX_RESOURCE (RESOURCE),
  CONSTRAINT FK_notify_resource_PROJECT_ACTIVITY_NOTIFY_ID FOREIGN KEY (PROJECT_ACTIVITY_NOTIFY_ID) REFERENCES project_activity_notify (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- BLG-2693
--
-- issue_filter_condition
--
CREATE TABLE issue_filter_condition (
  ID int(11) NOT NULL auto_increment,
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) default NULL,
  NAME text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CONDITION_XML longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_issue_filter_condition_USER_ID_UPDATED (USER_ID, UPDATED),
  CONSTRAINT FK_issue_filter_condition_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- ユーザのSSH公開鍵
--
-- 公開鍵の fingerprint はコロン入りの 47 文字のフォーマットを想定
-- 例) "c1:b1:30:29:d7:b8:de:6c:97:77:10:d7:46:41:63:87"
-- http://www.ipa.go.jp/security/rfc/RFC4716EN.html
--
CREATE TABLE user_ssh_key (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  USER_ID int(11) NOT NULL,
  CONTENT mediumtext NOT NULL,
  FINGERPRINT varchar(47) NOT NULL,
  MEMO varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_USER_ID (USER_ID, FINGERPRINT),
  UNIQUE UQ_user_ssh_key_SPACE_ID_FINGERPRINT (SPACE_ID, FINGERPRINT),
  CONSTRAINT FK_user_ssh_key_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- git 設定 ( TYPE: 1=使用しない, 2=Backlogにリポジトリ作成 )
--
CREATE TABLE git (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE SMALLINT NOT NULL,
  COMMIT_ISSUE_UPDATE tinyint(1) default 0,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY UQ_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_git_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- リポジトリ情報 ( TYPE: 1=git, 2=subversion )
--
CREATE TABLE repository (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE SMALLINT NOT NULL,
  NAME varchar(255) BINARY NOT NULL default '',
  DESCRIPTION varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  HOOK_URL text default NULL,
  DISPLAY_ORDER int(11) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE UQ_repository_PROJECT_ID_NAME (PROJECT_ID, TYPE, NAME),
  CONSTRAINT FK_repository_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- リビジョン (コミット) 情報
--
CREATE TABLE revision (
  ID int(11) NOT NULL auto_increment,
  REPOSITORY_ID int(11) NOT NULL default '0',
  REVISION varchar(255) NOT NULL,
  MESSAGE mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  AUTHOR varchar(735) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  AUTHOR_MAIL_ADDRESS varchar(735),
  AUTHOR_USER_ID int(11) default NULL,
  COMMITTED_ON datetime NOT NULL default '0000-00-00 00:00:00',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_REVISION (REVISION),
  KEY IX_REPOSITORY_ID_CREATED (REPOSITORY_ID,CREATED),
  UNIQUE UQ_revision_REPOSITORY_ID_REVISION (REPOSITORY_ID, REVISION),
  CONSTRAINT FK_revesion_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE,
  CONSTRAINT FK_revesion_AUTHOR_USER_ID FOREIGN KEY (AUTHOR_USER_ID) REFERENCES users (ID) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- リビジョン ( コミット ) で変更があったパスの情報
--  CHANGE_TYPE : A (追加) M (変更) D (削除)
--  PATH_TYPE : D (ディレクトリ) F (ファイル)
--
CREATE TABLE revision_change (
  ID int(11) NOT NULL auto_increment,
  REVISION_ID int(11) NOT NULL default '0',
  CHANGE_TYPE varchar(1) NOT NULL,
  PATH text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  PATH_TYPE varchar(1) NOT NULL,
  BASE_PATH text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin,
  BASE_REVISION varchar(255),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_REVISION_ID (REVISION_ID),
  CONSTRAINT FK_revision_change_REVISION_ID FOREIGN KEY (REVISION_ID) REFERENCES revision (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- リビジョン <-> 課題 のリンクテーブル
--
CREATE TABLE issue_revision (
  ISSUE_ID int(11) NOT NULL,
  LINK_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime default NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ISSUE_ID,LINK_ID),
  CONSTRAINT FK_issue_revision_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_revision_LINK_ID FOREIGN KEY (LINK_ID) REFERENCES revision (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Wikiページの更新後ジョブ
-- ( TYPE: 1=追加, 2=更新, 3=削除 )
--
CREATE TABLE job_page_updated (
  ID bigint(20) NOT NULL auto_increment,
  PAGE_ID int(11) NOT NULL,
  TYPE SMALLINT NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 共有ファイルの更新後ジョブ
-- ( TYPE: 1=追加, 2=更新, 3=削除 )
--
CREATE TABLE job_shared_file_updated (
  ID bigint(20) NOT NULL auto_increment,
  SHARED_FILE_ID int(11) NOT NULL,
  TYPE SMALLINT NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 課題の一括操作で複数の更新処理をまとめるトランザクション
--
CREATE TABLE issue_multi_update_tx (
  ID bigint(20) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  REQUEST_JSON longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  MAIL_SENT tinyint(1) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED),
  CONSTRAINT FK_issue_multi_update_tx_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 課題の一括操作で更新した課題の情報
--
CREATE TABLE issue_multi_update_log (
  ID bigint(20) NOT NULL auto_increment,
  ISSUE_ID int(11) NOT NULL,
  TX_ID bigint(20) NOT NULL,
  COMMENT_ID int(11),
  RESULT tinyint(1) NOT NULL default '1',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_multi_update_log_TX_ID FOREIGN KEY (TX_ID) REFERENCES issue_multi_update_tx (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Wikiの履歴
--
CREATE TABLE page_history (
  ID bigint(20) NOT NULL auto_increment,
  PAGE_ID int(11) NOT NULL default '0',
  VERSION int(11) NOT NULL default '0',
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  CONTENT mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_page_history_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- paypal_ipn_log
--
CREATE TABLE paypal_ipn_log (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  TXN_TYPE text,
  PAYER_EMAIL text,
  REMOTE_ADDR text,
  ERROR tinyint default 0,
  CONTENT text,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paypal_ipn_log_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- paypal_subscription
--
CREATE TABLE paypal_subscription (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  PROFILE_ID text,
  PROFILE_STATUS text,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paypal_subscription_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- paypal_subscription_billing
--
CREATE TABLE paypal_subscription_billing (
  PAYPAL_SUBSCRIPTION_ID int(11) NOT NULL,
  BILLING_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (PAYPAL_SUBSCRIPTION_ID,BILLING_ID),
  CONSTRAINT FK_paypal_subscription_billing_PAYPAL_SUBSCRIPTION_ID FOREIGN KEY (PAYPAL_SUBSCRIPTION_ID) REFERENCES paypal_subscription (ID) ON DELETE CASCADE,
  CONSTRAINT FK_paypal_subscription_billing_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE  
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- クレジットカード初回決済
--
CREATE TABLE paygate_initial (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL,
  GOODS_NAME VARCHAR(255) NOT NULL,
  CARD_NUMBER VARCHAR(20) NOT NULL,
  EXPIRY_DATE datetime NOT NULL,
  PROFILE_ID VARCHAR(64) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_initial_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- PayGate 決済購読情報
--
CREATE TABLE paygate_subscription (
  ID int(11) NOT NULL auto_increment,
  PAYGATE_INITIAL_ID int(11) NOT NULL,
  TRANSACTION_ID varchar(64),
  STATUS int default 0 NOT NULL,
  RESULT text,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_subscription_PAYGATE_INITIAL_ID FOREIGN KEY (PAYGATE_INITIAL_ID) REFERENCES paygate_initial (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- PayGate 決済請求情報
--
CREATE TABLE paygate_subscription_billing (
  PAYGATE_SUBSCRIPTION_ID int(11) NOT NULL,
  BILLING_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (PAYGATE_SUBSCRIPTION_ID, BILLING_ID),
  CONSTRAINT FK_paygate_subscription_billing_PAYGATE_SUBSCRIPTION_ID FOREIGN KEY (PAYGATE_SUBSCRIPTION_ID) REFERENCES paygate_subscription (ID) ON DELETE CASCADE,
  CONSTRAINT FK_paygate_subscription_billing_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 正式登録・プラン変更・解約手続 のログ (BLG-4351)
--
CREATE TABLE licence_activation_log (
  ID bigint(20) NOT NULL auto_increment,
  TYPE int(11) NOT NULL,
  SPACE_ID int(11) NOT NULL default '0',
  SPACE_KEY varchar(20) NOT NULL default '',
  FROM_LICENCE_TYPE_ID int(11),
  TO_LICENCE_TYPE_ID int(11),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED (CREATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- プロジェクトテーマ
--
CREATE TABLE project_theme (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL,
  THEME_TYPE int(11) NOT NULL default '0',
  HEADER_IMAGE tinyint(1) default 0,
  HEADER_IMAGE_REPEAT tinyint(1) default 1,
  HEADER_IMAGE_ALIGN VARCHAR(7) default 0,
  HEADER_BACKGROUND_COLOR VARCHAR(7) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_project_theme_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- ログイン履歴
--
CREATE TABLE login_history (
  ID bigint(20) NOT NULL auto_increment,
  LOCALE varchar(255),
  LOCAL_NAME varchar(255),
  LOCAL_ADDR varchar(255),
  LOCAL_PORT int(11),
  REMOTE_HOST varchar(255),
  REMOTE_ADDR varchar(255),
  REMOTE_PORT int(11),
  USER_AGENT varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  ACCEPT_LANGUAGE varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  ACCEPT_ENCODING varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  ACCEPT_CHARSET varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CLIENT_TIMEZONE_OFFSET bigint(20),
  SPACE_ID bigint(20),
  USER_ID bigint(20),
  USER_USER_ID varchar(255),
  USER_LANG char(5),
  USER_TIMEZONE varchar(50),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  INDEX IX_USER_ID_UPDATED (USER_ID, UPDATED),
  INDEX IX_UPDATED (UPDATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- ログイン場所
--
CREATE TABLE login_location (
  LOGIN_HISTORY_ID bigint(20) NOT NULL,
  COUNTRY_CONFIDENCE int(11),
  COUNTRY_GEONAME_ID varchar(255),
  COUNTRY_ISO_CODE varchar(255),
  COUNTRY_NAME varchar(255),
  CITY_CONFIDENCE int(11),
  CITY_GEONAME_ID varchar(255),
  CITY_NAME varchar(255),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (LOGIN_HISTORY_ID),
  CONSTRAINT FK_login_history_LOGIN_HISTORY_ID FOREIGN KEY (LOGIN_HISTORY_ID) REFERENCES login_history (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- BLG-5224 プロジェクトの削除を物理削除から論理削除に変更する
CREATE TABLE job_queue (
  ID bigint(20) NOT NULL auto_increment,
  JOB_NAME varchar(255) NOT NULL,
  STATUS int(11) NOT NULL,
  STARTED datetime default NULL,
  FINISHED datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  INDEX IX_JOB_NAME_STATUS_UPDATED (JOB_NAME, STATUS, UPDATED),
  INDEX IX_STATUS_UPDATED (STATUS, UPDATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE job_parameter (
  ID bigint(20) NOT NULL auto_increment,
  JOB_QUEUE_ID bigint(20) NOT NULL,
  NAME varchar(255) NOT NULL,
  VALUE MEDIUMTEXT CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  INDEX IX_JOB_PARAMETER_JOB_QUEUE_ID (JOB_QUEUE_ID),
  CONSTRAINT FK_job_parameter_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE job_blob_parameter (
  ID bigint(20) NOT NULL auto_increment,
  JOB_QUEUE_ID bigint(20) NOT NULL,
  NAME varchar(255) NOT NULL,
  DATA longblob NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  INDEX IX_JOB_BLOB_PARAMETER_JOB_QUEUE_ID (JOB_QUEUE_ID),
  CONSTRAINT FK_job_blob_parameter_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE job_fail_cause (
  ID bigint(20) NOT NULL auto_increment,
  JOB_QUEUE_ID bigint(20) NOT NULL,
  CAUSE mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  INDEX IX_JOB_FAIL_CAUSE_JOB_QUEUE_ID (JOB_QUEUE_ID),
  CONSTRAINT FK_job_fail_cause_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- メールによる課題登録ルール
--
CREATE TABLE issue_post_mail_rule (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL,
  RULE_NAME varchar(30) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL, -- 設定名
  MAIL_ADDRESS varchar(255) NOT NULL,
  AUTO_SETTING_XML text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  FILTERING_XML text NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_MAIL_ADDRESS (MAIL_ADDRESS),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_post_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- メールによる課題登録後のログ
--
CREATE TABLE issue_post_mail_log (
  ID int(11) NOT NULL auto_increment,
  ERRORS text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL, -- エラー情報
  PROJECT_ID int(11) default NULL, -- プロジェクトID
  ISSUE_ID int(11) default NULL, -- 課題ID
  ISSUE_POST_MAIL_RULE_ID int(11) default NULL, -- 課題の自動設定ID
  MAIL_ADDRESS varchar(320) default NULL, -- 課題登録に使用した宛先メールアドレス
  SUBJECT text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL, -- メールの件名
  BODY text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL, -- メール本文
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID_CREATED (PROJECT_ID, CREATED),
  KEY IX_CREATED (CREATED)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- メールによる課題登録後のログ（メールのソースのみ）
--
CREATE TABLE issue_post_mail_source (
  ID int(11) NOT NULL auto_increment,
  ISSUE_POST_MAIL_LOG_ID int(11) not NULL, -- メールによる課題登録ログ
  MAIL_SOURCE longblob not NULL, -- メールのソース
  CHARSET varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL, -- 文字コード
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_ISSUE_POST_MAIL_LOG_ID (ISSUE_POST_MAIL_LOG_ID),
  CONSTRAINT FK_issue_post_mail_source_ISSUE_POST_MAIL_LOG_ID FOREIGN KEY (ISSUE_POST_MAIL_LOG_ID) REFERENCES issue_post_mail_log (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- BLG-5332 Integrate Nulab Account (Single Sign-On)
--
CREATE TABLE nulab_account (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  USER_ID int(11) NOT NULL,
  SYNCHRONIZE tinyint(1) default 0,
  NULAB_ID varchar(255) BINARY NOT NULL,
  INVITATION_NULAB_ID varchar(255) BINARY default NULL,
  UNIQUE_ID varchar(255),
  MAIL_ADDRESS varchar(320),
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  ROLE varchar(15) default NULL,
  USE_MFA tinyint(1) default NULL,
  ACCEPTED_INVITATION tinyint(1) NOT NULL default 1,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE KEY IX_USER_ID (USER_ID),
  UNIQUE KEY UQ_INVITATION_NULAB_ID (INVITATION_NULAB_ID),
  KEY IX_NULAB_ID (NULAB_ID),
  KEY IX_NULAB_ACCOUNT_SPACE_ID_NULAB_ID (SPACE_ID, NULAB_ID),
  CONSTRAINT FK_nulab_account_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_nulab_account_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
  ) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_original_data (
  USER_ID int(11) NOT NULL,
  MAIL_ADDRESS varchar(320) NOT NULL default '',
  NAME varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  ICON varchar(50) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  CONSTRAINT FK_user_original_data_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE user_icon (
  USER_ID           int(11)       PRIMARY KEY,
  DIRECTORY         VARCHAR(255)  NOT NULL,
  FILE_NAME         VARCHAR(255)  NOT NULL,
  WIDTH             INTEGER       default 0,
  HEIGHT            INTEGER       default 0,
  CREATED_USER_ID   int(11)       default NULL,
  CREATED           datetime      NOT NULL,
  UPDATED_USER_ID   int(11)       default NULL,
  UPDATED           timestamp     NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  CONSTRAINT FK_user_icon_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Client Registration
--
CREATE TABLE oauth2_client (
  CLIENT_ID varchar(32) NOT NULL default '',
  NAME varchar(64) NOT NULL default '',
  DESCRIPTION varchar(255) NOT NULL default '',
  CLIENT_TYPE int(11) default 0,
  CLIENT_SECRET varchar(64) NOT NULL default '',
  GRANT_TYPE varchar(255) NOT NULL default '',
  REDIRECT_URI varchar(255) NOT NULL default '',
  DEFAULT_LANG VARCHAR(32)  NOT NULL DEFAULT '',
  ICON_URL VARCHAR(255) NOT NULL DEFAULT '',
  DISABLED TINYINT(1) NOT NULL DEFAULT 0,
  SITE_URL varchar(255) NOT NULL default '',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (CLIENT_ID),
  KEY IX_CREATED_USER_ID (CREATED_USER_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Client Description
--
CREATE TABLE oauth2_client_description (
  ID int(11) NOT NULL,
  CLIENT_ID VARCHAR(32) NOT NULL DEFAULT '',
  LANG VARCHAR(32) NOT NULL DEFAULT '',
  NAME VARCHAR(64) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  DESCRIPTION VARCHAR(1000) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL DEFAULT '',
  SITE_URI VARCHAR(255) NOT NULL DEFAULT '',
  CREATED DATETIME NOT NULL DEFAULT '0000-00-00 00:00:00',
  UPDATED TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IDX_OAUTH2_CLIENT_DESCRIPTION_CLIENT_ID (CLIENT_ID),
  UNIQUE KEY (CLIENT_ID, LANG),
  CONSTRAINT FK_oauth2_client_description_CLIENT_ID FOREIGN KEY (CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
) ENGINE=innodb DEFAULT CHARSET=utf8;

--
-- Authorization Code Grant
-- 基本的に Backlog アプリ側から登録するデータ
--
CREATE TABLE oauth2_authorization_code (
  ID varchar(64) NOT NULL default '',
  CODE varchar(64) NOT NULL default '',
  USER_ID int(11) NOT NULL,
  OAUTH2_CLIENT_ID varchar(32) NOT NULL default '',
  STATE varchar(500) default NULL,
  REDIRECT_URI varchar(255) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE UQ_CODE (CODE),
  KEY IX_user_id_oauth2_client_id (USER_ID,OAUTH2_CLIENT_ID),
  CONSTRAINT FK_oauth2_authorization_code_OAUTH2_CLIENT_ID FOREIGN KEY (OAUTH2_CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Access Token
--
CREATE TABLE oauth2_access_token (
  USER_ID int(11) NOT NULL,
  OAUTH2_CLIENT_ID varchar(32) NOT NULL default '',
  ACCESS_TOKEN varchar(64) NOT NULL default '',
  REFRESH_TOKEN varchar(64) NOT NULL default '',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID, OAUTH2_CLIENT_ID),
  KEY IX_USER_ID (USER_ID),
  UNIQUE UQ_ACCESS_TOKEN (ACCESS_TOKEN),
  UNIQUE UQ_REFRESH_TOKEN (REFRESH_TOKEN),
  CONSTRAINT FK_oauth2_access_token_OAUTH2_CLIENT_ID FOREIGN KEY (OAUTH2_CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 課題キー カウントアップ
--
CREATE TABLE max_issue_identity (
  PROJECT_ID int(11) NOT NULL,
  MAX_KEY_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID),
  CONSTRAINT FK_max_issue_identity_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


--
-- 一時添付ファイル
--
CREATE TABLE temporary_attachment (
  ID int(11) NOT NULL auto_increment,
  NAME varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  SIZE int(11) NOT NULL default '0',
  CONTENT longblob,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_CREATED_USER_ID (CREATED_USER_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- API キー
--
CREATE TABLE api_key (
  API_KEY varchar(64) NOT NULL default '',
  USER_ID int(11) NOT NULL,
  SCOPE int(11) NOT NULL default '0',
  MEMO varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (API_KEY),
  KEY IX_CREATED_USER_ID (CREATED_USER_ID),
  CONSTRAINT FK_api_key_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 課題のカテゴリー毎のサマリー
--
CREATE TABLE issue_component_summary (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL,
  COMPONENT_ID int(11) DEFAULT NULL,
  STATUS_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  KEY IX_COMPONENT_ID (COMPONENT_ID),
  KEY IX_PROJECT_ID_COMPONENT_ID_STATUS_ID (PROJECT_ID, COMPONENT_ID, STATUS_ID),
  CONSTRAINT FK_issue_component_summary_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_component_summary_COMPONENT_ID FOREIGN KEY (COMPONENT_ID) REFERENCES component (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 課題のマイルストーン毎のサマリー
--
CREATE TABLE issue_fixed_version_summary (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL,
  VERSION_ID int(11) DEFAULT NULL,
  STATUS_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  KEY IX_VERSION_ID (VERSION_ID),
  KEY IX_PROJECT_ID_VERSION_ID_STATUS_ID (PROJECT_ID, VERSION_ID, STATUS_ID),
  CONSTRAINT FK_issue_fixed_version_summary_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_fixed_version_summary_VERSION_ID FOREIGN KEY (VERSION_ID) REFERENCES version (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- BLG-6050 Copy a short link for Find Issue
--
CREATE TABLE project_short_url (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL,
  SHORT_URL_KEY varchar(20) BINARY NOT NULL,
  URL text NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_KEY (SHORT_URL_KEY),
  KEY IX_PROJECT_ID_URL (PROJECT_ID, URL(255)),
  UNIQUE UQ_project_short_url_SHORT_URL_KEY (SHORT_URL_KEY),
  CONSTRAINT FK_project_short_url_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Webhook
--
CREATE TABLE webhook (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  DESCRIPTION varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  HOOK_URL text NOT NULL,
  ALL_EVENT tinyint(1) NOT NULL default '0',
  EVENTS varchar(255) NOT NULL default '',
  DISPLAY_ORDER int(11) NOT NULL default '0',
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_webhook_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- マイレポートのBacklogTips
--
CREATE TABLE myreport_message (
  ID int(11) NOT NULL auto_increment,
  ICON varchar(255) NOT NULL default '',
  LANG char(5) NOT NULL default '',
  COMMENT text NOT NULL,
  PAGE_NAME text,
  PAGE_URL text,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_LANG (LANG)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE webhook_execution_history (
  ID bigint(20) NOT NULL auto_increment,
  JOB_QUEUE_ID bigint(20) NOT NULL,
  PROJECT_ID int(11) NOT NULL default '0',
  WEBHOOK_ID int(11) default NULL,
  NAME varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  HOOK_URL text NOT NULL,
  EVENT int(11) NOT NULL default '0',
  CONTENT mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  STATUS_CODE int(11) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  INDEX IX_WEBHOOK_EXECUTION_HISTORY_PROJECT_ID (PROJECT_ID),
  CONSTRAINT FK_webhook_execution_history_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_webhook_execution_history_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- BLG-6902 project_activity テーブルの古いデータアーカイブ化の仕組みを各環境に展開する
--
CREATE TABLE archived_project_activity (
  ID bigint(20) NOT NULL,
  PROJECT_ID int(11) NOT NULL default '0',
  TYPE int(11) NOT NULL,
  CONTENT_JSON longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED datetime NOT NULL,
  ARCHIVE_CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  KEY IX_PROJECT_ID_CREATED_TYPE_CREATED_USER_ID (PROJECT_ID, CREATED DESC, TYPE, CREATED_USER_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE project_activity_stat (
  ID int(11) NOT NULL auto_increment,
  SPACE_ID int(11) NOT NULL default '0',
  TOTAL int(11) NOT NULL default '0',
  NOTIFY_COUNT int(11) NOT NULL default '0',
  LAST_ARCHIVED datetime,
  LAST_ARCHIVED_RATIO int(11),
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED datetime NOT NULL,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_SPACE_ID_PROJECT_ACTIVITY_STAT ( SPACE_ID ),
  CONSTRAINT FK_project_activity_stat_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- PullRequest
--
CREATE TABLE pull_request (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11) NOT NULL default '0',
  REPOSITORY_ID int(11) NOT NULL default '0',
  NUMBER int(11) NOT NULL default '0',
  SUMMARY varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  DESCRIPTION mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL ,
  BASE varchar(1000) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  BRANCH varchar(1000) CHARACTER SET utf8mb4 COLLATE utf8mb4_bin NOT NULL,
  STATUS_ID int(11) NOT NULL,
  ASSIGNER_ID int(11) default NULL,
  ISSUE_ID int(11) default NULL,
  MERGE_COMMIT varchar(255) default NULL,
  BASE_COMMIT varchar(255) default NULL,
  BRANCH_COMMIT varchar(255) default NULL,
  CLOSED_AT datetime default NULL,
  MERGED_AT datetime default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_REPOSITORY_ID_NUMBER (REPOSITORY_ID, NUMBER),
  KEY IX_PROJECT_ID (PROJECT_ID),
  KEY IX_REPOSITORY_ID (REPOSITORY_ID),
  KEY IX_STATUS_ID (STATUS_ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  KEY IX_ASSIGNER_ID (ASSIGNER_ID),
  CONSTRAINT FK_pull_request_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_pull_request_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE,
  CONSTRAINT FK_pull_request_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE SET NULL
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- 課題キー カウントアップ
--
CREATE TABLE max_pull_request_number (
  REPOSITORY_ID int(11) NOT NULL,
  MAX_NUMBER int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (REPOSITORY_ID),
  CONSTRAINT FK_max_pull_request_number_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- PullRequest comment
--
CREATE TABLE pull_request_comment (
  ID int(11) NOT NULL auto_increment,
  PULL_REQUEST_ID int(11) NOT NULL,
  OLD_BLOB_ID varchar(255) default NULL,
  NEW_BLOB_ID varchar(255) default NULL,
  FILE_PATH text CHARACTER SET utf8mb4 COLLATE utf8mb4_bin default NULL,
  POSITION int(11) default NULL,
  CONTENT mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  CHANGELOG longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PULL_REQUEST_ID (PULL_REQUEST_ID),
  KEY IX_CREATED (CREATED),
  CONSTRAINT FK_pull_request_PULL_REQUEST_ID FOREIGN KEY (PULL_REQUEST_ID) REFERENCES pull_request (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Watch list
--
CREATE TABLE user_watch (
  ID int(11) NOT NULL auto_increment,
  USER_ID int(11) NOT NULL,
  PROJECT_ID int(11) NOT NULL,
  TYPE int(11) NOT NULL,
  ISSUE_ID int(11) default NULL,
  LAST_NOTICE_CHECKED_TIME datetime default NULL,
  LAST_CHECKED_TIME datetime NOT NULL default '0000-00-00 00:00:00',
  NOTE varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_USER_ID_TYPE_ISSUE_ID (USER_ID,TYPE,ISSUE_ID),
  KEY IX_USER_ID_PROJECT_ID (USER_ID,PROJECT_ID),
  KEY IX_USER_ID (USER_ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  KEY IX_ISSUE_ID (ISSUE_ID),
  CONSTRAINT FK_user_watch_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Project setting
--
CREATE TABLE project_setting (
  PROJECT_ID int(11) NOT NULL,
  PROJECT_LEADER_CAN_EDIT_PROJECT_LEADER TINYINT(1) NOT NULL,
  USE_WIKI_TREE_VIEW TINYINT(1) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID),
  CONSTRAINT FK_project_setting_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- プルリクエスト添付ファイル
--
CREATE TABLE pull_request_attachment (
  ID int(11) NOT NULL auto_increment,
  PULL_REQUEST_ID int(11) NOT NULL default '0',
  NAME varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL default '',
  SIZE int(11) NOT NULL default '0',
  PATH varchar(255) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PULL_REQUEST_ID (PULL_REQUEST_ID),
  CONSTRAINT FK_pull_request_attachment_PULL_REQUEST_ID FOREIGN KEY (PULL_REQUEST_ID) REFERENCES pull_request (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- プロジェクトに参加しているグループ
--
CREATE TABLE project_party (
  PROJECT_ID int(11) NOT NULL,
  PARTY_ID int(11) NOT NULL,
  PROJECT_LEADER tinyint(1) default NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (PROJECT_ID,PARTY_ID),
  KEY IX_PARTY_ID (PARTY_ID),
  KEY IX_PROJECT_ID (PROJECT_ID),
  CONSTRAINT project_party_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT project_party_PARTY_ID FOREIGN KEY (PARTY_ID) REFERENCES party (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- スタンプ
--
CREATE TABLE stamp (
  ID int(11) NOT NULL auto_increment,
  PROJECT_ID int(11),
  URL VARCHAR(255) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL,
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_PROJECT_ID (PROJECT_ID)
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

CREATE TABLE information_read_user (
  ID int(11) NOT NULL auto_increment,
  INFORMATION_ID int(11) NOT NULL,
  USER_ID int(11) NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  KEY IX_INFORMATION_ID (INFORMATION_ID),
  KEY IX_USER_ID (USER_ID),
  CONSTRAINT FK_information_user_INFORMATION_ID FOREIGN KEY (INFORMATION_ID) REFERENCES information (ID) ON DELETE CASCADE,
  CONSTRAINT FK_information_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

--
-- Backlogスペースと連携しているNulabAppsのスペース(組織)
--
CREATE TABLE nulab_apps_space (
  ID int(11) NOT NULL auto_increment,
  BACKLOG_SPACE_ID int(11) NOT NULL default '0',
  SPACE_KEY varchar(50) BINARY NOT NULL,
  NAME VARCHAR(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL,
  CREATED_USER_ID int(11) default NULL,
  CREATED datetime NOT NULL default '0000-00-00 00:00:00',
  UPDATED_USER_ID int(11) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP on update CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE KEY UQ_SPACE_KEY (SPACE_KEY),
  CONSTRAINT FK_nulab_apps_space_BACKLOG_SPACE_ID FOREIGN KEY (BACKLOG_SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

INSERT INTO default_issue_type VALUES (1,'ja','バグ',1,'#990000',NULL,'2005-04-19 03:23:59',NULL,'2005-04-18 17:31:06'),(2,'ja','タスク',0,'#7ea800',NULL,'2005-05-15 00:47:12',NULL,'2007-09-24 15:31:31'),(3,'ja','要望',2,'#ff9200',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31'),(4,'ja','その他',3,'#2779ca',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31'),
                                      (5,'en','Bug',1,'#990000',NULL,'2005-04-19 03:23:59',NULL,'2008-06-17 17:31:06'),(6,'en','Task',0,'#7ea800',NULL,'2005-05-15 00:47:12',NULL,'2008-06-17 15:31:31'),(7,'en','Request',2,'#ff9200',NULL,'2005-05-15 00:49:53',NULL,'2008-06-17 15:31:31'),(8,'en','Other',3,'#2779ca',NULL,'2005-05-15 00:49:53',NULL,'2008-06-17 15:31:31'),
                                      (9,'zh_tw','Bug',1,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(10,'zh_tw','任務',0,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(11,'zh_tw','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(12,'zh_tw','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),
                                      (13,'zh_cn','Bug',1,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(14,'zh_cn','任务',0,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(15,'zh_cn','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),(16,'zh_cn','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00'),
                                      (17,'ko','버그',1,'#990000',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00'),(18,'ko','태스크',0,'#7ea800',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00'),(19,'ko','요망',2,'#ff9200',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00'),(20,'ko','그 외',3,'#2779ca',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00'),
                                      (21,'vi','Lỗi',1,'#990000',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00'),(22,'vi','Công việc',0,'#7ea800',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00'),(23,'vi','Yêu cầu',2,'#ff9200',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00'),(24,'vi','Ngoài ra',3,'#2779ca',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');

INSERT INTO licence_type VALUES
    (1,'旧無料版',3,50,20,20,300,100,5242880,5242880,1,0,0,0,1048576,0,0,0,0,1,5242880,1,0,0,0,0,1,1,1,1,0,0,0,0,0,NULL,0,NULL,'2006-06-19 23:40:54',NULL,'2007-09-24 15:31:31'),
    (10,'旧フリー',1,10,0,0,0,0,20971520,5242880,1,0,0,0,1048576,0,1,1,0,1,5242880,1,10485760,0,0,0,1,1,1,1,0,0,0,0,0,NULL,0,NULL,'2006-06-19 23:41:49',NULL,'2007-09-24 15:31:31'),
    (20,'旧ベーシック',5,30,0,0,0,0,0,10485760,10,0,0,1,1048576,10,1,1,0,1,10485760,10,52428800,0,0,1,1,1,1,1,0,0,3000,2000,0,NULL,0,NULL,'2006-06-19 23:41:49',NULL,'2007-09-24 15:31:31'),
    (30,'旧プラス',30,0,0,0,0,0,0,10485760,20,1,5,1,1048576,20,1,1,0,1,10485760,20,104857600,0,0,1,1,1,1,1,0,0,6000,4800,0,NULL,0,NULL,'2006-06-19 23:41:49',NULL,'2007-09-24 15:31:31'),
    (40,'旧プレミアム',0,0,0,0,0,0,0,10485760,30,1,5,1,10485760,30,1,1,1,1,10485760,30,1073741824,1,1,1,1,1,1,1,0,0,6000,9800,0,NULL,0,NULL,'2006-06-19 23:41:50',NULL,'2007-09-24 15:31:31'),
    (50,'旧マックス5',0,0,0,0,0,0,0,10485760,50,1,5,1,10485760,50,1,1,1,1,10485760,50,5368709120,1,1,1,1,1,1,1,1,100,6000,16800,0,NULL,0,NULL,'2007-09-25 00:31:31',NULL,'2007-09-24 15:31:31'),
    (60,'旧マックス25',0,0,0,0,0,0,0,10485760,50,1,5,1,10485760,50,1,1,1,1,10485760,50,26843545600,1,1,1,1,1,1,1,1,100,6000,28000,0,NULL,0,NULL,'2007-09-25 00:31:31',NULL,'2007-09-24 15:31:31'),
    (70,'旧マックス50',0,0,0,0,0,0,0,10485760,50,1,5,1,10485760,50,1,1,1,1,10485760,50,53687091200,1,1,1,1,1,1,1,1,100,6000,47000,0,NULL,0,NULL,'2007-09-25 00:31:31',NULL,'2007-09-24 15:31:31'),
    (100,'パッケージライセンス',0,0,0,0,0,0,0,10485760,0,1,65535,1,10485760,0,0,0,0,1,10485760,0,0,1,1,1,0,0,1,1,1,100,0,0,0,NULL,0,NULL,'2006-06-19 23:41:50',NULL,'2007-02-28 01:34:18'),
    (11,'フリー',1,10,0,0,0,0,0,5242880,1,0,0,0,1048576,0,1,1,0,1,5242880,1,104857600,0,0,0,1,1,1,1,0,0,0,0,1,NULL,0,NULL,NOW(),NULL,NOW()),
    (21,'スターター',5,30,0,0,0,0,0,10485760,10,0,0,1,1048576,10,1,1,0,1,10485760,10,1073741824,0,0,1,1,1,1,1,0,0,0,2000,1,NULL,0,NULL,NOW(),NULL,NOW()),
    (41,'スタンダード',100,0,0,0,0,0,0,10485760,30,1,50,1,10485760,30,1,1,1,1,10485760,30,32212254720,1,1,1,1,1,1,1,0,0,0,9800,1,NULL,0,NULL,NOW(),NULL,NOW()),
    (51,'プレミアム',0,0,0,0,0,0,0,10485760,50,1,100,1,10485760,50,1,1,1,1,10485760,50,107374182400,1,1,1,1,1,1,1,1,100,0,16800,1,NULL,0,NULL,NOW(),NULL,NOW()),
    (81,'プラチナ',0,0,0,0,0,0,0,10485760,50,1,5000,1,10485760,50,1,1,1,1,10485760,50,322122547200,1,1,1,1,1,1,1,1,100,0,50000,1,NULL,0,NULL,NOW(),NULL,NOW());

INSERT INTO status VALUES (0,'新規作成',0,NULL,'2005-04-19 03:14:58',NULL,'2005-04-18 17:30:36'),(1,'未対応',1,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19'),(2,'処理中',2,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19'),(3,'処理済み',3,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19'),(4,'完了',4,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19');

INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-01-01 00.00.00', '元日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-01-11 00.00.00', '成人の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-02-11 00.00.00', '建国記念の日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-03-21 00.00.00', '春分の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-03-22 00.00.00', '振替休日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-04-29 00.00.00', '昭和の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-05-03 00.00.00', '憲法記念日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-05-04 00.00.00', 'みどりの日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-05-05 00.00.00', 'こどもの日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-07-19 00.00.00', '海の日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-09-20 00.00.00', '敬老の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-09-23 00.00.00', '秋分の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-10-11 00.00.00', '体育の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-11-03 00.00.00', '文化の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-11-23 00.00.00', '勤労感謝の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-12-23 00.00.00', '天皇誕生日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-01-01 00.00.00', '元日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-01-10 00.00.00', '成人の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-02-11 00.00.00', '建国記念の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-03-21 00.00.00', '春分の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-04-29 00.00.00', '昭和の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-05-03 00.00.00', '憲法記念日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-05-04 00.00.00', 'みどりの日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-05-05 00.00.00', 'こどもの日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-07-18 00.00.00', '海の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-09-19 00.00.00', '敬老の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-09-23 00.00.00', '秋分の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-10-10 00.00.00', '体育の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-11-03 00.00.00', '文化の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-11-23 00.00.00', '勤労感謝の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-12-23 00.00.00', '天皇誕生日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-01-01 00.00.00', '元日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-01-02 00.00.00', '振替休日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-01-09 00.00.00', '成人の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-02-11 00.00.00', '建国記念の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-03-20 00.00.00', '春分の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-04-29 00.00.00', '昭和の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-04-30 00.00.00', '振替休日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-05-03 00.00.00', '憲法記念日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-05-04 00.00.00', 'みどりの日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-05-05 00.00.00', 'こどもの日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-07-16 00.00.00', '海の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-09-17 00.00.00', '敬老の日', '2009-04-07 00.00.00', '2009-04-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-09-22 00.00.00', '秋分の日', '2009-04-08 00.00.00', '2009-04-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-10-08 00.00.00', '体育の日', '2009-04-09 00.00.00', '2009-04-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-11-03 00.00.00', '文化の日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-11-23 00.00.00', '勤労感謝の日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-12-23 00.00.00', '天皇誕生日', '2009-04-11 00.00.00', '2009-04-11 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-12-24 00.00.00', '振替休日', '2009-04-12 00.00.00', '2009-04-12 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-01 00.00.00', '元日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-14 00.00.00', '成人の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-02-11 00.00.00', '建国記念の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-03-20 00.00.00', '春分の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-04-29 00.00.00', '昭和の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-03 00.00.00', '憲法記念日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-04 00.00.00', 'みどりの日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-05 00.00.00', 'こどもの日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-06 00.00.00', '振替休日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-07-15 00.00.00', '海の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-16 00.00.00', '敬老の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-23 00.00.00', '秋分の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-10-14 00.00.00', '体育の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-03 00.00.00', '文化の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-04 00.00.00', '振替休日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-23 00.00.00', '勤労感謝の日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-12-23 00.00.00', '天皇誕生日', '2012-08-04 00.00.00', '2012-08-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-01 00.00.00', '元日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-13 00.00.00', '成人の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-02-11 00.00.00', '建国記念の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-03-21 00.00.00', '春分の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-04-29 00.00.00', '昭和の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-03 00.00.00', '憲法記念日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-04 00.00.00', 'みどりの日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-05 00.00.00', 'こどもの日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-06 00.00.00', '振替休日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-07-21 00.00.00', '海の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-15 00.00.00', '敬老の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-23 00.00.00', '秋分の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-10-13 00.00.00', '体育の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-03 00.00.00', '文化の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-23 00.00.00', '勤労感謝の日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-24 00.00.00', '振替休日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-12-23 00.00.00', '天皇誕生日', '2013-08-20 00.00.00', '2013-08-20 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-01 00.00.00', '元日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-12 00.00.00', '成人の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-02-11 00.00.00', '建国記念の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-03-21 00.00.00', '春分の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-04-29 00.00.00', '昭和の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-03 00.00.00', '憲法記念日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-04 00.00.00', 'みどりの日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-05 00.00.00', 'こどもの日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-06 00.00.00', '振替休日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-07-20 00.00.00', '海の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-21 00.00.00', '敬老の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-22 00.00.00', '振替休日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-23 00.00.00', '秋分の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-10-12 00.00.00', '体育の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-03 00.00.00', '文化の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-23 00.00.00', '勤労感謝の日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-12-23 00.00.00', '天皇誕生日', '2014-08-07 00.00.00', '2014-08-07 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-01-01 00.00.00', '元日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-01-11 00.00.00', '成人の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-02-11 00.00.00', '建国記念の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-03-20 00.00.00', '春分の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-03-21 00.00.00', '振替休日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-04-29 00.00.00', '昭和の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-03 00.00.00', '憲法記念日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-04 00.00.00', 'みどりの日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-05 00.00.00', 'こどもの日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-07-18 00.00.00', '海の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-08-11 00.00.00', '山の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-09-19 00.00.00', '敬老の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-09-22 00.00.00', '秋分の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-10-10 00.00.00', '体育の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-11-03 00.00.00', '文化の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-11-23 00.00.00', '勤労感謝の日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-12-23 00.00.00', '天皇誕生日', '2015-09-04 00.00.00', '2015-09-04 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-01-01 00.00.00', '元日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-01-02 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-01-09 00.00.00', '成人の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-02-11 00.00.00', '建国記念の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-03-20 00.00.00', '春分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-04-29 00.00.00', '昭和の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-05-03 00.00.00', '憲法記念日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-05-04 00.00.00', 'みどりの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-05-05 00.00.00', 'こどもの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-07-17 00.00.00', '海の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-08-11 00.00.00', '山の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-09-18 00.00.00', '敬老の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-09-23 00.00.00', '秋分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-10-09 00.00.00', '体育の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-11-03 00.00.00', '文化の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-11-23 00.00.00', '勤労感謝の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-12-23 00.00.00', '天皇誕生日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-01-01 00.00.00', '元日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-01-08 00.00.00', '成人の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-02-11 00.00.00', '建国記念の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-02-12 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-03-21 00.00.00', '春分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-04-29 00.00.00', '昭和の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-04-30 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-05-03 00.00.00', '憲法記念日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-05-04 00.00.00', 'みどりの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-05-05 00.00.00', 'こどもの日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-07-16 00.00.00', '海の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-08-11 00.00.00', '山の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-09-17 00.00.00', '敬老の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-09-23 00.00.00', '秋分の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-09-24 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-10-08 00.00.00', '体育の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-11-03 00.00.00', '文化の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-11-23 00.00.00', '勤労感謝の日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-12-23 00.00.00', '天皇誕生日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-12-24 00.00.00', '振替休日', '2016-12-01 00.00.00', '2016-12-01 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-01-01 00.00.00', '元日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-01-14 00.00.00', '成人の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-02-11 00.00.00', '建国記念の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-03-21 00.00.00', '春分の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-04-29 00.00.00', '昭和の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-03 00.00.00', '憲法記念日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-04 00.00.00', 'みどりの日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-05 00.00.00', 'こどもの日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-06 00.00.00', '振替休日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-07-15 00.00.00', '海の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-08-11 00.00.00', '山の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-08-12 00.00.00', '振替休日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-09-16 00.00.00', '敬老の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-09-23 00.00.00', '秋分の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-10-14 00.00.00', '体育の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-11-03 00.00.00', '文化の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-11-04 00.00.00', '振替休日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-11-23 00.00.00', '勤労感謝の日', '2018-10-29 00.00.00', '2018-10-29 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-04-30 00.00.00', '国民の休日', '2019-01-22 00.00.00', '2019-01-22 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-01 00.00.00', '天皇の即位の日', '2019-01-22 00.00.00', '2019-01-22 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-02 00.00.00', '国民の休日', '2019-01-22 00.00.00', '2019-01-22 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-10-22 00.00.00', '即位礼正殿の儀の行われる日', '2019-01-22 00.00.00', '2019-01-22 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-01-01 00.00.00', '元日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-01-13 00.00.00', '成人の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-02-11 00.00.00', '建国記念の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-02-23 00.00.00', '天皇誕生日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-02-24 00.00.00', '休日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-03-20 00.00.00', '春分の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-04-29 00.00.00', '昭和の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-03 00.00.00', '憲法記念日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-04 00.00.00', 'みどりの日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-05 00.00.00', 'こどもの日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-06 00.00.00', '休日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-07-23 00.00.00', '海の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-07-24 00.00.00', 'スポーツの日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-08-10 00.00.00', '山の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-09-21 00.00.00', '敬老の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-09-22 00.00.00', '秋分の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-11-03 00.00.00', '文化の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-11-23 00.00.00', '勤労感謝の日', '2019-09-03 00.00.00', '2019-09-03 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-01-01 00.00.00', '元日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-01-11 00.00.00', '成人の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-02-11 00.00.00', '建国記念の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-02-23 00.00.00', '天皇誕生日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-03-20 00.00.00', '春分の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-04-29 00.00.00', '昭和の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-05-03 00.00.00', '憲法記念日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-05-04 00.00.00', 'みどりの日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-05-05 00.00.00', 'こどもの日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-07-22 00.00.00', '海の日', '2020-12-15 00.00.00', '2020-12-15 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-07-23 00.00.00', 'スポーツの日', '2020-12-15 00.00.00', '2020-12-15 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-08-08 00.00.00', '山の日', '2020-12-15 00.00.00', '2020-12-15 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-08-09 00.00.00', '振替休日', '2020-12-15 00.00.00', '2020-12-15 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-09-20 00.00.00', '敬老の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-09-23 00.00.00', '秋分の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-11-03 00.00.00', '文化の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-11-23 00.00.00', '勤労感謝の日', '2020-09-09 00.00.00', '2020-09-09 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-01-01 00.00.00', '元日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-01-10 00.00.00', '成人の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-02-11 00.00.00', '建国記念の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-02-23 00.00.00', '天皇誕生日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-03-21 00.00.00', '春分の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-04-29 00.00.00', '昭和の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-05-03 00.00.00', '憲法記念日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-05-04 00.00.00', 'みどりの日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-05-05 00.00.00', 'こどもの日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-07-18 00.00.00', '海の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-08-11 00.00.00', '山の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-09-19 00.00.00', '敬老の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-09-23 00.00.00', '秋分の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-10-10 00.00.00', 'スポーツの日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-11-03 00.00.00', '文化の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-11-23 00.00.00', '勤労感謝の日', '2021-07-08 00.00.00', '2021-07-08 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-01-01 00.00.00', '元日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-01-02 00.00.00', '振替休日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-01-09 00.00.00', '成人の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-02-11 00.00.00', '建国記念の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-02-23 00.00.00', '天皇誕生日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-03-21 00.00.00', '春分の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-04-29 00.00.00', '昭和の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-05-03 00.00.00', '憲法記念日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-05-04 00.00.00', 'みどりの日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-05-05 00.00.00', 'こどもの日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-07-17 00.00.00', '海の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-08-11 00.00.00', '山の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-09-18 00.00.00', '敬老の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-09-23 00.00.00', '秋分の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-10-09 00.00.00', 'スポーツの日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-11-03 00.00.00', '文化の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-11-23 00.00.00', '勤労感謝の日', '2022-02-14 00.00.00', '2022-02-14 00.00.00');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-01-01 00:00:00', '元日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-01-08 00:00:00', '成人の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-02-11 00:00:00', '建国記念の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-02-12 00:00:00', '休日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-02-23 00:00:00', '天皇誕生日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-03-20 00:00:00', '春分の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-04-29 00:00:00', '昭和の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-05-03 00:00:00', '憲法記念日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-05-04 00:00:00', 'みどりの日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-05-05 00:00:00', 'こどもの日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-05-06 00:00:00', '休日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-07-15 00:00:00', '海の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-08-11 00:00:00', '山の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-08-12 00:00:00', '休日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-09-16 00:00:00', '敬老の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-09-22 00:00:00', '秋分の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-09-23 00:00:00', '休日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-10-14 00:00:00', 'スポーツの日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-11-03 00:00:00', '文化の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-11-04 00:00:00', '休日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2024-11-23 00:00:00', '勤労感謝の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-01-01 00:00:00', '元日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-01-13 00:00:00', '成人の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-02-11 00:00:00', '建国記念の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-02-23 00:00:00', '天皇誕生日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-02-24 00:00:00', '休日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-03-20 00:00:00', '春分の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-04-29 00:00:00', '昭和の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-05-03 00:00:00', '憲法記念日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-05-04 00:00:00', 'みどりの日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-05-05 00:00:00', 'こどもの日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-05-06 00:00:00', '休日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-07-21 00:00:00', '海の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-08-11 00:00:00', '山の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-09-15 00:00:00', '敬老の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-09-23 00:00:00', '秋分の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-10-13 00:00:00', 'スポーツの日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-11-03 00:00:00', '文化の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-11-23 00:00:00', '勤労感謝の日', NOW(), NOW());
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2025-11-24 00:00:00', '休日', NOW(), NOW());

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'タスクは適切な粒度で。大きすぎるタスクがあるときは、適度なサイズに分割するといいと思うよ。', '親子課題について', 'http://www.backlog.jp/kr/help/usersguide/subtasking/userguide1722.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '目標の日が決まっているときはマイルストーンを使うと便利だよ。', '発生バージョン/マイルストーン', 'http://www.backlog.jp/help/usersguide/version-milestone/userguide106.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ja', 'GitとかSubversionのコミットで課題の状態を更新できるとよ。', 'Backlog 小技集： Gitのコミットから課題の状態を更新する', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-5/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '管理者はプロジェクト毎に設定することもできるんだよ。', 'Backlog 小技集： プロジェクト毎に管理者を設定する', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-4/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'プロジェクト全体を把握したいときはガントチャートが便利だよ。', 'Backlogビデオチュートリアル「ガントチャート編」', 'https://www.youtube.com/watch?v=qPuOiN4cbK8', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'よく使う検索条件は保存しておくと時間短縮になるよ！', '検索条件の保存', 'http://www.backlog.jp/help/usersguide/search-issue/userguide1440.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ja', '受信メールが多すぎる場合、自分が受け取りたいメールだけを受信できるよう設定し直すことをオススメします。', 'Backlogがバージョンアップ、メール受信設定に機能が追加されました。', 'https://nulab-inc.com/ja/blog/backlog/new-mail-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '複数の課題をまとめて、状態変更したり担当者を替えたりできるんだよ。', 'Backlog 小技集：自分の課題をまとめて操作', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '「あの人にこのコメントを読んでほしい...」という時は「お知らせ」しておこう！', 'お知らせ機能の概要', 'http://www.backlog.jp/help/usersguide/notification/userguide1453.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'Wiki の見出しを元に自動的に目次を作ってくれるって知ってた？', 'Backlog記法の目次', 'http://www.backlog.jp/help/usersguide/rule-to-formatting-texts/userguide205.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '検索後の課題一覧を誰かに送りたいときは短いURLを送ったほうがスマートだよ！', 'Backlog 小技集： 短いURL', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'バーンダウンチャートでは、ざっくりとしたプロジェクトの進行状況が見れるんだよ。', 'バーンダウンチャートの概要', 'http://www.backlog.jp/help/usersguide/burn-down-chart/userguide289.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'このコメントのここがナイスアイデア！と思ったらその部分を選択してスターをつけるといいよ。', 'スターを付ける', 'http://www.backlog.jp/help/usersguide/star/userguide456.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '出先でプロジェクトの状況が気になったら、iPhone版のBacklogを見ればいいよ。', 'Backlog for iPhone の機能', 'http://www.backlog.jp/help/usersguide/mobile/userguide2354.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'あの人最近何やってるのかな...？と気になったらプロフィールで確認だ！', 'プロフィールの”最近の活動”', 'http://www.backlog.jp/help/usersguide/member/userguide1016.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ja', 'Gitでファイルをバージョン管理するとよかよ。', 'サルでもわかるGit入門', 'http://www.backlog.jp/git-guide/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '図を書いて説明したくなったら、Cacooで図を書いてそのURLを Wiki とかコメントに貼ればいいよ。', 'Cacooの図をBacklogに表示する方法', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'Markdown記法って人気あるよね。Backlogでも使えるよ。', 'プロジェクトの基本設定', 'http://www.backlog.jp/help/adminsguide/project-setting/userguide355.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'WikiはPDFで出力できるよ。Backlog を見れない人にはPDFで見せてね。', 'PDF出力', 'http://www.backlog.jp/help/usersguide/wiki/userguide218.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'BacklogにはWebフック機能もあって、外部システムと連携できるよ。', 'Git Webフック', 'http://www.backlog.jp/help/usersguide/git/userguide1710.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ja', 'お問い合わせメールなどの内容をBacklogの課題として手動で登録してる場合、簡単な設定で自動登録に変更することが可能です。', 'メールによる課題登録', 'http://www.backlog.jp/help/adminsguide/add-issues-via-email/userguide2306.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'ねぇ 知ってる？ヌーラボアカウントを使えば1つのユーザIDとパスワードで複数のBacklogスペースにログインできるんだよ。', 'ヌーラボアカウントとは', 'http://www.backlog.jp/help/usersguide/nulab-account/userguide2272.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'ねぇ 知ってる？ヌーラボアカウントを使えば1つのユーザIDとパスワードでCacooとかTypetalkにもログインできるんだよ。', 'ヌーラボアカウントとは', 'http://www.backlog.jp/help/usersguide/nulab-account/userguide2272.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '課題の件名はできるだけ具体的に。分かりやすさや後から探すときの検索しやすさが全然違うよ。', '件名', 'http://www.backlog.jp/help/usersguide/issue/userguide8.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'ガントチャートってどうやって使うの？という人は、とりあえず各タスクに開始日と期限日を入れるとガントチャートが表示されるよ。', 'ガントチャートの概要', 'http://www.backlog.jp/help/usersguide/gantt-chart/userguide274.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'リリース日を手動でカレンダーに登録してる人は、マイルストーンカレンダーを使うといいかもね。', 'マイルストーンカレンダー', 'http://www.backlog.jp/help/usersguide/project-home/userguide76.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'BacklogAPIで自分好みのBacklogアプリを作ってる人もいるんだって。すごいね！君もやってみない？', 'Backlog API', 'http://developer.nulab-inc.com/ja/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'Backlogは6言語に対応！外国人のプロジェクトメンバーがいたら教えてあげてね。', '多言語対応', 'http://www.backlog.jp/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '新規ユーザを登録するときにアイコンをデフォルト以外にしておくと、本人が自分が気に入ったアイコンを登録してくれる確率があがるらしいよ。', 'ユーザの追加', 'http://www.backlog.jp/help/adminsguide/user-setting/userguide325.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '議事録とか日報をWikiで書いている人はフォーマットを登録しておくと便利だよ。', 'Backlog 小技集： Wikiのコピー', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-6/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '「Backlogを使いこなそう」を見ると、今まで知らなかった機能が発見できるかもしれないよ。', 'Backlogを使いこなそう', 'http://www.backlog.jp/help/usersguide/issue/userguide1.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'チームで運用ルールを決めているなら、Wikiに書いて共有しよう！', 'Wiki', 'http://www.backlog.jp/help/usersguide/wiki/userguide209.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '上手くいったことも失敗したことも、すべてBacklogに書いておけば誰かの役に立つかもしない。', 'コメント', 'http://www.backlog.jp/help/usersguide/issue/userguide32.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '「わざわざコメントするまでもないけど感謝の気持ちを表したい...」という時にもスターが使えるよ。', 'スターを付ける', 'http://www.backlog.jp/help/usersguide/star/userguide456.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '課題の状態や担当者は状況に合わせてこまめに変更しよう。', '課題の状態', 'http://www.backlog.jp/help/usersguide/issue/userguide1.html', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'An issue has become too big to manage? Divide it into smaller issues!', 'Subtasking', 'http://backlogtool.com/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'If the due date is fixed, use the milestone feature.', 'Version/Milestone', 'http://backlogtool.com/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'The Ghantt chart is incredibly useful when you want to keep track of an entire project.', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Save frequently used search conditions to save time!', 'Saving search criteria', 'http://backlogtool.com/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'en', 'Receiving too many emails from Backlog? Check and modify your email settings!', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Change multiple issue statuses or assignees the easy way.', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Need to inform other members of an update or comment?  Use the notification feature!', 'Summary of notification feature', 'http://backlogtool.com/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Do you know how to add headings automatically to a Wiki?', 'Backlog:Index', 'http://backlogtool.com/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Send shortened URLs of issues to make them more managable for sharing!', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'The Burndown chart gives you a general idea of how the project is progressing.', 'Summary of Burndown Chart', 'http://backlogtool.com/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'If you think someone has just posted a great idea, add stars to it!', 'Add Star', 'http://backlogtool.com/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Check your project''s status on the iPhone app while you are out and about. ', 'Backlog for iPhone Features', 'http://backlogtool.com/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Curious to know what your colleagues are up to?  Check their recent activities on their Profile page.', 'Recent Activity in Profile', 'http://backlogtool.com/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'en', 'It is easy to manage multiple versions of files on Git.', 'Git Beginner''s Guide for Dummies', 'http://backlogtool.com/git-guide/en/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'A picture is worth a thousand words. You can post a Cacoo diagram''s URL in you comment or Wiki to give your ideas a visual aid. ', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Markdown, a popular formatting rule, can be used on Backlog too.', 'Project Setting', 'http://backlogtool.com/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Export a Wiki to PDF to share it with people who don''t have access to your Backlog space.', 'Export to PDF', 'http://backlogtool.com/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'With the webhook function of Backlog, you can connect it with external systems.', 'Git Webhook', 'http://backlogtool.com/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'en', 'Are you still adding issues mannually when you receive inquiries from your customers?  Check out our Help page on how to add them automatically!  ', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Did you know you access multiple Backlog spaces in a single sign-in by using the Nulab account?', 'About Nulab Account', 'http://backlogtool.com/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Tip of the week: Nulab Account is a convenient, single sign-in service that lets you sign in to your Backlog, Cacoo and Typetalk accounts with a single sign in.  ', 'About Nulab Account', 'http://backlogtool.com/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Make sure to give your issues a subject heading! It will save you a lot of time searching the issue later.  ', 'Subject Status', 'http://backlogtool.com/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Want to put your issue on the Ghantt chart? It''s simple! All you have to do is set the Start Date and Due Date.', 'Summary of Gantt Chart', 'http://backlogtool.com/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Sync your milestone schedule with your calendar so you won''t forget issue deadlines.', 'Milestone Calendar (iCalendar)', 'http://backlogtool.com/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'I heard some people are developing some cool new applications with the BacklogAPI. Why don''t you give it a try too?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Backlog supports six languages!  You can use Backlog with a multicultural team. ', 'Multilingual', 'http://backlogtool.com/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'New users are more likely to add their own icons if you pick an icon for them at the outset rather than use the default icon of Backlog. ', 'Add User', 'http://backlogtool.com/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Check out the Help pages to discover new features you haven''t learned about!', 'Backlog Help', 'http://backlogtool.com/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Use Wiki to share certain rules among the team!', 'Wiki', 'http://backlogtool.com/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Make a record of all successes and failures on Backlog so that other members can use them as a learning reference in future.', 'Comment', 'http://backlogtool.com/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Show your appreciation with stars.', 'Add Star', 'http://backlogtool.com/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Make sure to update the issue status and assignee as you make progresses with the task.', 'Status of Issue', 'http://backlogtool.com/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'en', 'Of course you know that issues can be updated by Git and Subversion''s commits.', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Administrators can be set for each project too!', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'If you create Wiki pages often, having formats, such as notes or daily report templates, will save your time.', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Một chủ đề trở nên quá lớn để quản lý? Hãy chia nó thành những chủ đề nhỏ hơn!', 'Về chủ đề cha', 'http://backlogtool.com/vn/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Nếu ngày hết hạn cố định, hãy sử dụng chức năng milestone.', 'Phiên bản phát sinh/ cột mốc', 'http://backlogtool.com/vn/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Biểu đồ Ghantt thì vô cùng hữu ích khi bạn muốn theo dõi toàn bộ dự án.', 'Video hướng dẫn Backlog Video "Hướng dẫn Gantt Chart"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Lưu thường xuyên những điều kiện tìm kiếm đã sử dụng để tiết kiệm thời gian!', 'Lưu điều kiện tìm kiếm', 'http://backlogtool.com/vn/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'vi', 'Nhận được quá nhiều email từ Backlog? Kiểm tra và sửa đổi các thiết lập email của bạn!', 'Cập nhật Backlog – Cải thiện chức năng thông báo bằng email', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Thay đổi trạng thái của nhiều chủ đề hoặc người được giao việc một cách dễ dàng.', 'Cập nhật nhiều chủ đề cùng lúc trên Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Cần thông báo đến những thành viên khác khi có cập nhật hoặc bình luận? Sử dụng chức năng gửi thông báo!', 'Khái quát về chức năng thông báo', 'http://backlogtool.com/vn/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Bạn có biết làm thế nào để thêm tiêu đề một cách tự động đến một Wiki?', 'Mục lục', 'http://backlogtool.com/vn/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Gửi URL rút gọn của chủ đề để giúp chúng dễ quản lý hơn khi chia sẻ!', 'Tạo URLs ngắn gọn để chia sẻ trên Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Các biểu đồ Burndown cung cấp cho bạn một cái nhìn tổng thể về tiến độ tiến triển của dự án.', 'Khái quát về biểu đồ Burn down', 'http://backlogtool.com/vn/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Nếu bạn nghĩ ai đó vừa đề xuất một ý tưởng tuyệt vời, hãy thêm những ngôi sao cho điều đó! ', 'Thêm vào ngôi sao', 'http://backlogtool.com/vn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Kiểm tra tình trạng dự án của bạn trên các ứng dụng iPhone trong khi bạn ra ngoài và về.', 'Tính năng của Backlog cho iPhone', 'http://backlogtool.com/vn/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tò mò muốn biết các đồng nghiệp của bạn đang làm những gì? Kiểm tra các hoạt động gần đây trên trang Profile của họ.', 'Hoạt động gần đây trong Profile', 'http://backlogtool.com/vn/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'vi', 'Thật dễ dàng để quản lý nhiều phiên bản của các tập tin trên Git.', 'Hướng dẫn sử dụng Git cho người mới bắt đầu', 'http://backlogtool.com/git-guide/vn/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Một bức hình có thể đáng giá hơn ngàn lời nói. Bạn có thể gửi URL của biểu đồ Cacoo trong bình luận hoặc Wiki để hỗ trợ trực quan cho việc đưa ra ý tưởng của bạn.', 'Làm thế nào để đưa biểu đồ Cacoo vào Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Markdown, một quy tắc định dạng phổ biến, cũng có thể sử dụng được trên Backlog.', 'Thiết lập cơ bản của dự án', 'http://backlogtool.com/vn/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Xuất một Wiki định dạng PDF để chia sẻ cho người không có quyền truy cập vào Backlog space của bạn.', 'Xuất ra PDF', 'http://backlogtool.com/vn/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Với các chức năng webhook của Backlog, bạn có thể kết nối với các hệ thống bên ngoài.', 'Git Webhook', 'http://backlogtool.com/vn/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'vi', 'Bạn vẫn thêm chủ đề một cách thủ công khi nhận được yêu cầu từ khách hàng? Hãy kiểm tra trang Trợ giúp của chúng tôi về cách thêm chủ đề tự động!', 'Thêm yêu cầu qua email như những chủ đề trên Backlog.', 'http://backlogtool.com/vn/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Bạn đã biết bạn truy cập nhiều Backlog space chỉ với một lần đăng nhập bằng cách sử dụng tài khoản Nulab?', 'Về tài khoản Nulab', 'http://backlogtool.com/vn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Mẹo trong tuần: Tài khoản Nulab là một dịch vụ tiện lợi, đăng nhập một lần nhưng có thể cho phép bạn đăng nhập vào tài khoản Backlog, Cacoo và Typetalk của bạn chỉ với việc đăng nhập một lần duy nhất. ', 'Về tài khoản Nulab', 'http://backlogtool.com/vn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Hãy chắc chắn đặt một đề mục cho chủ đề của bạn! Nó sẽ giúp bạn tiết kiệm rất nhiều thời gian tìm kiếm các chủ đề sau này.', 'Tên chủ đề', 'http://backlogtool.com/vn/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Bạn muốn đặt chủ đề của bạn trên biểu đồ Ghantt? Thật đơn giản! Tất cả bạn phải làm là thiết lập ngày bắt đầu và ngày hết hạn.', 'Khái quát biểu đồ Gantt', 'http://backlogtool.com/vn/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Đồng bộ hóa các milestone của bạn với lịch của bạn, bạn sẽ không bị quên ngày hết hạn của chủ đề.', 'Lịch cột mốc ( iCalendar )', 'http://backlogtool.com/vn/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tôi được biết một số người đang phát triển một vài ứng dụng rất "cool" với BacklogAPI. Tại sao bạn không thử dùng nó?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Backlog hỗ trợ sáu ngôn ngữ! Bạn có thể sử dụng Backlog với một đội ngũ đa văn hóa.', 'Đa ngôn ngữ', 'http://backlogtool.com/vn/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Người dùng mới thường thích thêm icon riêng của họ nếu bạn chọn một icon cho họ ngay từ đầu thay vì icon mặc định của Backlog.', 'Thêm người sử dụng', 'http://backlogtool.com/vn/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Kiểm tra các trang Trợ giúp để khám phá các tính năng mới mà bạn chưa biết!', 'Backlog Help', 'http://backlogtool.com/vn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Sử dụng Wiki để chia se một số quy định trong nhóm!', 'Wiki', 'http://backlogtool.com/vn/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tạo một hồ sơ lưu trữ tất cả những thành công và thất bại trên Backlog để những thành viên khác có thể sử dụng chúng để rút kinh nghiệm cho tương lai.', 'Bình luận', 'http://backlogtool.com/vn/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Thể hiện sự cảm kích của bạn với những ngôi sao.', 'Thêm vào ngôi sao', 'http://backlogtool.com/vn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Hãy chắc chắn việc cập nhật trạng thái chủ đề và người được giao việc khi bạn thực hiện tiến trình công việc.', 'Trạng thái của chủ đề', 'http://backlogtool.com/vn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'vi', 'Hiển nhiên bạn biết rằng những chủ để có thể được cập nhật bằng Git và commit Subversion.', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Người quản trị cũng có thể được thiết lập cho từng dự án!', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Nếu bạn thường tạo ra các trang Wiki, có định dạng, chẳng hạn như ghi chú hay các mẫu báo cáo hàng ngày, sẽ tiết kiệm thời gian của bạn.', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '태스크는 적절한 크기로. 너무 큰 태스크가 있을 땐 적절한 크기로 나누는 편이 좋을 거야.', '부모자식 과제에 대하여', 'http://backlogtool.com/kr/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '기한일이 정해져 있을 땐 마일스톤을 사용하면 편리해.', '발생 버전/마일스톤', 'http://backlogtool.com/kr/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '프로젝트 전체를 파악하고 싶을 땐 갠트 차트가 편리해.', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '자주 사용하는 검색 조건을 저장해 두면 시간을 단축할 수 있어!', '검색 조건 저장', 'http://backlogtool.com/kr/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ko', '메일 수신함이 가득 차 있을 경우에는 자신이 받고 싶은 메일만을 수신할 수 있도록 설정할 것을 추천합니다.', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '복수의 과제를 한꺼번에 형식을 변경하거나 담당자를 바꾸는 일도 가능하지.', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '<저 사람이 이 코멘트를 읽어 주면 줬으면...> 할 땐 <공지>를 보내 봐!', '공지 기능의 개요', 'http://backlogtool.com/kr/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Wiki의 색인을 바탕으로 자동으로 목차를 만들어 주는 거 알고 있었어?', '목차', 'http://backlogtool.com/kr/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '검색 후의 과제 일람을 누군가에게 보내고 싶을 때에는 짧은 URL을 보내는 편이 스마트하지!', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '번다운 차트로 프로젝트의 진행 상황을 일목요연하게 볼 수 있어.', '번다운 차트 개요', 'http://backlogtool.com/kr/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '이 코멘트의 이 부분이 나이스 아이디어! 하고 감탄했다면 그 부분을 선택하여 별을 달아 주면 좋을 거야.', '스타를 단다', 'http://backlogtool.com/kr/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '외출했을 때 프로젝트의 상황을 알고 싶다면 iPhone판 Backlog를 보면 되지.', 'Backlog for iPhone의 기능', 'http://backlogtool.com/kr/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '그 사람 요새 무슨 일 하고 있을까..? 하고 궁금해졌다면 프로필 확인!', '프로필의 “최근 활동”', 'http://backlogtool.com/kr/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ko', 'Git로 파일을 버전 관리하면 완전 편하지.', '누구나 쉽게 이해할 수 있는 Git 입문 버전 관리를 완벽하게 이용해보자!', 'http://backlogtool.com/git-guide/kr/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '그림을 그려서 설명하고 싶다면 Cacoo로 그림을 그려서 그 URL을 Wiki나 코멘트에 붙여넣으면 될 거야.', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'Markdown 요새 인기 많지? Backlog에서도 사용할 수 있어.', '프로젝트의 기본 설정', 'http://backlogtool.com/kr/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Wiki는 PDF로 변환할 수 있어. Backlog를 볼 수 없는 사람에게는 PDF로 보여 줘!', 'PDF 출력', 'http://backlogtool.com/kr/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'Backlog에는 webhook기능도 있으니까 외부 시스템과 연계시킬 수도 있어.', 'Git Webhook', 'http://backlogtool.com/kr/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ko', '문의 메일 등의 내용을 Backlog의 과제로써 수동으로 등록하고 있을 경우에는 간단한 설정으로 자동 등록으로 변경하는 것도 가능합니다.', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/kr/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '너 그거 알아? 누라보 계정을 사용하면 하나의 유저 아이디와 비밀먼호로 여러 Backlog스페이스에 로그인할 수 있어!', '누라보 계정이란', 'http://backlogtool.com/kr/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '너 그거 알아? 누라보 계정을 사용하면 하나의 유저 아이디와 비밀먼호로 Cacoo나 Typetalk에 로그인할 수 있다는 거.', '누라보 계정이란', 'http://backlogtool.com/kr/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '과제 제목은 될 수 있는 대로 구체적으로. 알기 쉽고, 나중에 찾을 때 검색하기도 아주 편리해.', '건명', 'http://backlogtool.com/kr/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '갠트 차트는 어떻게 사용해? 라는 사람에게. 먼저 각 태스크에 시작 날짜와 기한을 입력하면 갠트 차트가 뜰 거야.', '갠트 차트 개요', 'http://backlogtool.com/kr/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '릴리스 예정일을 수동으로 캘린더에 등록하고 있는 사람은 마일스톤 캘린더를 사용하면 좋을지도?', '마일스톤 캘린더 (iCalendar)', 'http://backlogtool.com/kr/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'BacklogAPI로 내 마음에 드는 Backlog앱을 만드는 사람도 있대. 끝내주지? 너도 해보지 않을래?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Backlog는 6개 국어로 제공된대. 외국인 프로젝트 멤버가 있다면 꼭 가르쳐줘!', '다언어 대응', 'http://backlogtool.com/kr/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '신규 유저를 등록할 때에는 초기에 설정된 아이콘을 바꿔 놓으면 다른 사람이 내 아이콘이 마음에 들어서 등록해 줄 확률이 오른대.', '유저 추가', 'http://backlogtool.com/kr/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '<Backlog 를 능숙히 써보자>를 보면 지금까지 몰랐던 기능을 발견할 수 있을지도 몰라!', 'Backlog Help', 'http://backlogtool.com/kr/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '팀에서 운용 규칙을 만들었다면 Wiki에 적어서 공유하자!', 'Wiki', 'http://backlogtool.com/kr/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '성공한 일도 실패한 일도 모두 다 Backlog에 적어 놓으면 누군가에게 도움이 될지도 몰라.', '코멘트', 'http://backlogtool.com/kr/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '<일부러 코멘트를 남길 필요까지는 없지만 감사의 마음은 전하고 싶은데..>라는 때에도 별을 사용할 수 있지.', '스타를 단다', 'http://backlogtool.com/kr/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '과제 상태나 담당자는 상황에 맞춰서 부지런히 변경하자.', '과제의 상태', 'http://backlogtool.com/kr/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ko', 'Git 나 Subversion 의 커밋으로 과제 상태를 갱신할 수 있다는데?', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '관리자는 프로젝트별로 설정하는 일도 할 수 있어.', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '회의록이나 일보를 Wiki로 쓰는 사람은 포맷을 등록해 놓으면 편리할걸?', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', ' 一個課題裡有太多任務要管理，處理起來相當困難，怎麼辦？把課題分成更多子課題吧！', '主和子課題功能（Subtasking）', 'http://backlogtool.com/tw/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', ' 如果期限日已確定，試著使用里程碑來設定課題的階段進度。', '版本／里程碑', 'http://backlogtool.com/tw/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '甘特圖可以協助您輕鬆掌握專案的進度。', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '儲存常用的搜尋條件可以節省您更多時間呦！', '儲存搜尋課題的條件', 'http://backlogtool.com/tw/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_tw', '收到太多貝格樂寄來的電子郵件？快來檢查和變更您的郵件設定！', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '簡單快速變更多個課題的狀態或責任者。', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '更新或添加評論時想要通知其他的成員？使用通知功能就對了！', '通知功能概要', 'http://backlogtool.com/tw/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '您知道如何自動添加目次到Wiki嗎？', '目次', 'http://backlogtool.com/tw/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '建立課題的短URL以利於分享！', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '燃盡圖可以提供專案大概的進度狀態。', '燃盡圖概要', 'http://backlogtool.com/tw/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '快送個獎勵星星給剛剛提出超棒點子的成員！', '給予星星', 'http://backlogtool.com/tw/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '使用貝格樂iPhone App隨時隨地查看專案的最新狀態。', '貝格樂iPhone App的功能', 'http://backlogtool.com/tw/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '好奇最近同事們都在忙什麼嗎？查看他們個人簡介的「最近活動」就知道啦。', '個人簡介的「最近活動」', 'http://backlogtool.com/tw/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_tw', '使用Git輕鬆管理多個版本的檔案。', '連猴子都能懂的Git入門指南', 'http://backlogtool.com/git-guide/tw/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '千言萬語抵不過一張圖，在評論或Wiki貼上Cacoo圖表的URL，視覺化您的點子吧。 ', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '貝格樂支援Markdown格式化規則。', '專案基本設定', 'http://backlogtool.com/tw/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '將Wiki以PDF檔案匯出，和無法存取您的貝格樂空間的朋友分享。', 'PDF輸出', 'http://backlogtool.com/tw/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '具備Webhook功能，貝格樂也可以連接到外部系統。', 'Git Webhook', 'http://backlogtool.com/tw/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_tw', '您還在用手動方式將收到的客戶洽詢郵件建立成課題嗎？閱讀我們的支援頁面了解如何自動添加課題！', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/tw/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '只要登入Nulab帳號，您就可以一次使用多個貝格樂空間。', '關於Nulab帳號', 'http://backlogtool.com/tw/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '小知識分享：只要擁有一個Nulab帳號就可以同時登入貝格樂、Cacoo和Typetalk，Nulab帳號提供單一登入機制，方便使用。', '關於Nulab帳號', 'http://backlogtool.com/tw/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', ' 一定要幫您的課題訂一個標題！以後搜尋課題時就可以省去您大量的時間。', '標題', 'http://backlogtool.com/tw/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '想要在您的課題使用甘特圖？只要設定課題的開始日期和期限日就可以了，很簡單吧！', '甘特圖概要', 'http://backlogtool.com/tw/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '立刻同步里程碑時間表到您的行事曆，以避免忘記課題的期限日。', '里程碑行事曆', 'http://backlogtool.com/tw/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '有些開發者使用貝格樂API 開發了很酷的應用程式呦，您要不要也試試看？', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '貝格樂支援6種語言！最適合多元文化的工作團隊使用。', '多語言適用', 'http://backlogtool.com/tw/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '您知道嗎？在添加新用戶時，如果您幫新用戶選擇的圖標不是貝格樂內建的圖標時，他們會更想要變更及添加自己的圖標呦。 ', '添加用戶', 'http://backlogtool.com/tw/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '快來查看FAQ頁面，可以學習到您不知道的新功能呦。', 'Backlog Help', 'http://backlogtool.com/tw/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '運用Wiki來和工作團隊分享重要的規則條件。', 'Wiki', 'http://backlogtool.com/tw/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '建立一個記錄來儲存在貝格樂上所有成功和失敗案例，未來可以讓其他成員從中學習，吸取經驗。', '評論', 'http://backlogtool.com/tw/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '透過給予星星來表達您的讚賞。', '給予星星', 'http://backlogtool.com/tw/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '隨著任務的進展程度，確實做到即時更新課題和責任者。', '課題的狀態', 'http://backlogtool.com/tw/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_tw', '可以透過Git和Subversion的提交更新課題嗎？', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '每個專案都可以設定管理者！', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '如果您經常建立Wiki頁面，設定像是公告或每日報表等等的格式，會更節省您的時間。', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '课题太大了，管理有难度？请把它分成几个小课题吧！', '母子课题功能', 'http://backlogtool.com/cn/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果期限日已经确定了，就请使用里程碑功能吧。', '版本／里程碑', 'http://backlogtool.com/cn/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果您想了解整个项目的进度状况，甘特图必不可少喔。', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '保存常用的查询课题的条件可以节省不少时间！', '保存查询课题的条件', 'http://backlogtool.com/cn/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_cn', '收到太多来自贝格乐的电子邮件？请检查并变更您的邮件设置!', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '简单快捷地一次变更多个课题的状态或责任者。', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想让其他成员知道您更新了课题或发布了评论？用通知功能噢！', '通知功能概述', 'http://backlogtool.com/cn/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '您知道怎样自动地添加Wiki标题吗？', '索引', 'http://backlogtool.com/cn/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想跟成员分享搜索出来的多个课题？发送简短URL会更方便！', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '燃尽图让您大致了解项目的进展状况。', '燃尽图概述', 'http://backlogtool.com/cn/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '如果有成员发布了一个超棒的评论，给评论添加个星星吧！', '添加星星', 'http://backlogtool.com/cn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '当您出门在外时，可以使用iPhone app查看您的项目状态噢。', 'iPhone 贝格乐的功能', 'http://backlogtool.com/cn/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '好奇您的同事们在忙些什么？查看他们的“用户资料” 页面上的 “最近的活动”就知道啦。', '“用户资料” 页面的 “最近的活动”', 'http://backlogtool.com/cn/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_cn', '使用Git可以轻松管理多个版本的文件。', '猴子都能懂的GIT入门', 'http://backlogtool.com/git-guide/cn/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '一张图胜过千言万语。您可以在评论部分或Wiki张贴Cacoo 图表URL，能起到视觉辅助效果噢。', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '贝格乐当然支持人气格式规则—Markdown啦。', '项目设置', 'http://backlogtool.com/cn/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '以PDF格式导出Wiki，然后跟不能访问您的贝格乐空间的人分享Wiki上的信息噢。', '以PDF格式导出', 'http://backlogtool.com/cn/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '由于具备webhook功能，贝格乐可以跟外部系统连接咯。', 'Git Webhook', 'http://backlogtool.com/cn/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_cn', '您还在将客户的邮件逐个地添加为课题吗？请参阅我们的帮助页面看看怎样自动添加课题的！', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/cn/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '您知道吗？只用一个Nulab帐户就可以访问多个贝格乐空间哟。', '关于Nulab帐户', 'http://backlogtool.com/cn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '本周小贴士：Nulab帐户是一个简便的单点登录服务 ( Single Sign-On )。只需登录一个Nulab帐户，您就可以登入贝格乐，Cacoo 和 Typetalk。', '关于Nulab帐户', 'http://backlogtool.com/cn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '一定要给您的课题写上标题喔。有了标题以后就容易查询课题了。  ', '标题', 'http://backlogtool.com/cn/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想要把您的课题放上甘特图？简单，设定开始日和结束日就行了。', '甘特图概述', 'http://backlogtool.com/cn/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '把您的里程碑日程表跟日历设定同步，您就不会忘记课题的期限日了。', '里程碑日历(iCalendar)', 'http://backlogtool.com/cn/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '我听说有人使用BacklogAPI开发出很酷的新应用程序。您也试试嘛。', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '贝格乐支持6种语言！它是您的多元文化团队的最佳选择。', '多种语言', 'http://backlogtool.com/cn/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '注册新用户时，您给他们选一个图标，而不用贝格乐的默认图标。他们之后更有可能上载他们专属的图标喔。', '添加用户', 'http://backlogtool.com/cn/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '请看看帮助页面，发掘您不知道的新功能吧！', 'Backlog Help', 'http://backlogtool.com/cn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '要跟成员共享一些格式规则的话，请用Wiki吧！', 'Wiki', 'http://backlogtool.com/cn/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '在贝格乐上记录所有的成功和失败，以便其他成员日后可以参考学习噢。', '评论', 'http://backlogtool.com/cn/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '点星星以表达您的谢意哟。', '添加星星', 'http://backlogtool.com/cn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '在您执行任务取得进展时，不要忘记即时更新课题状态或责任者哦。', '课题的状态', 'http://backlogtool.com/cn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_cn', '您肯定知道可以通过Git或Subversion提交来更新课题的，是不是？', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '可以给每个项目设定管理员哦！', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果您经常要建立Wiki页面，使用格式 (例如：笔记或每日报告模板), 可以省时省力喔。', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO reserved_space_key (SPACE_KEY, IS_REGEXP) VALUES ('^usercontent.*$', 1);

UPDATE space SET NEED_INDEXING='1';
