--
-- Table structure for table `service_type`
--

CREATE SEQUENCE "service_type_id_seq";
CREATE TABLE service_type (
  ID integer NOT NULL default nextval('service_type_id_seq'),
  NAME varchar(20) NOT NULL default '',
  TARGET varchar(5) NOT NULL,
  DEFAULT_LICENCE_TYPE_ID integer default NULL,
  PREFIX_PATH varchar(6) NOT NULL,
  CURRENCY_CODE varchar(3) NOT NULL,
  CURRENCY_UNIT varchar(6) NOT NULL,
  CURRENCY_UNIT_HEAD boolean NOT NULL default TRUE,
  CURRENCY_UNIT_AMOUNT integer NOT NULL,
  CURRENCY_FORMAT varchar(11) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

--
-- Table structure for table `space`
--

CREATE SEQUENCE "space_id_seq";
CREATE TABLE "space" (
  ID integer NOT NULL default nextval('space_id_seq'),
  SPACE_KEY varchar(20) NOT NULL default '',
  NAME varchar(100) NOT NULL default '',
  OWNER_ID integer default NULL,
  IMG boolean default FALSE,
  BASE_URL text default NULL,
  LANG varchar(5) NOT NULL default 'en',
  TIMEZONE varchar(50) NOT NULL default 'GMT',
  SERVICE_TYPE_ID integer default NULL,
  REPORT_SEND_TIME time default NULL,
  NEED_INDEXING boolean default FALSE,
  TEXT_FORMATTING_RULE varchar(255) default NULL,
  USE_NULAB_ACCOUNT boolean default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (SPACE_KEY),
  CONSTRAINT "FK_space_SERVICE_TYPE_ID" FOREIGN KEY (SERVICE_TYPE_ID) REFERENCES "service_type" (ID)
);

--
-- Table structure for table `space_contact`
--

CREATE TABLE "space_contact" (
  SPACE_ID integer NOT NULL,
  NAME text,
  KANA text,
  PERSON text,
  GENDER varchar(1),
  MAIL_ADDRESS text,
  POST text,
  POSITION text,
  TEL text,
  ZIPCODE varchar(8) default NULL,
  PREF_NAME text,
  ADDRESS text,
  URL text,
  BILLING_NAME text default NULL,
  BILLING_PERSON text default NULL,
  BILLING_MAIL_ADDRESS text default NULL,
  BILLING_POST text default NULL,
  BILLING_POSITION text default NULL,
  BILLING_TEL text default NULL,
  BILLING_ZIPCODE text default NULL,
  BILLING_PREF_NAME text default NULL,
  BILLING_ADDRESS text default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_ID),
  CONSTRAINT "FK_space_contact_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_space_contact_SPACE_ID" ON "space_contact" (SPACE_ID);

--
-- Table structure for table `space_contact_changelog`
--

CREATE SEQUENCE "space_contact_changelog_id_seq";
CREATE TABLE "space_contact_changelog" (
  ID integer NOT NULL default nextval('space_contact_changelog_id_seq'),
  CHANGED_ON timestamp NOT NULL,
  SPACE_ID integer NOT NULL,
  NAME text,
  KANA text,
  PERSON text,
  GENDER varchar(1),
  MAIL_ADDRESS text,
  POST text,
  POSITION text,
  TEL text,
  ZIPCODE varchar(8) default NULL,
  PREF_NAME text,
  ADDRESS text,
  URL text,
  BILLING_NAME text default NULL,
  BILLING_PERSON text default NULL,
  BILLING_MAIL_ADDRESS text default NULL,
  BILLING_POST text default NULL,
  BILLING_POSITION text default NULL,
  BILLING_TEL text default NULL,
  BILLING_ZIPCODE text default NULL,
  BILLING_PREF_NAME text default NULL,
  BILLING_ADDRESS text default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL,
  PRIMARY KEY  (ID)
);
CREATE INDEX "IX_space_contact_changelog_SPACE_ID" ON "space_contact_changelog" (SPACE_ID);

--
-- Table structure for table `licence_type`
--

CREATE TABLE "licence_type" (
  ID integer NOT NULL,
  NAME text NOT NULL,
  PROJECT_LIMIT integer NOT NULL,
  USER_LIMIT integer NOT NULL,
  COMPONENT_LIMIT integer NOT NULL,
  VERSION_LIMIT integer NOT NULL,
  ISSUE_LIMIT integer NOT NULL,
  COMMENT_LIMIT integer NOT NULL,
  ATTACHMENT_LIMIT integer NOT NULL,
  ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  REMOTE_ADDRESS boolean NOT NULL default FALSE,
  REMOTE_ADDRESS_LIMIT integer NOT NULL default '0',
  WIKI_ATTACHMENT boolean NOT NULL default FALSE,
  WIKI_ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  WIKI_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  FILE_SHARING boolean NOT NULL default FALSE,
  SUBVERSION boolean NOT NULL default FALSE,
  SUBVERSION_EXTERNAL boolean NOT NULL default FALSE,
  GIT boolean NOT NULL default FALSE,
  PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  STORAGE_LIMIT bigint NOT NULL default '0',
  GANTT boolean DEFAULT FALSE,
  BURNDOWN boolean DEFAULT FALSE,
  PARENT_CHILD_ISSUE boolean NOT NULL default FALSE,
  POST_ISSUE_BY_MAIL boolean NOT NULL default FALSE,
  NULAB_ACCOUNT boolean NOT NULL default FALSE,
  NEW_UI boolean NOT NULL default FALSE,
  PROJECT_GROUP boolean NOT NULL default FALSE,
  ATTRIBUTE boolean DEFAULT FALSE,
  ATTRIBUTE_LIMIT integer NOT NULL default '0',
  INITIAL_COSTS integer default NULL,
  PRICE integer default NULL,
  SELECTABLE boolean NOT NULL default FALSE,
  SERVICE_TYPE_ID integer default NULL,
  NULAB_APPS_INTEGRATION boolean NOT NULL default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_licence_type_SERVICE_TYPE_ID" FOREIGN KEY (SERVICE_TYPE_ID) REFERENCES "service_type" (ID)
);

--
-- Table structure for table `licence`
--

CREATE TABLE "licence" (
  SPACE_ID integer NOT NULL,
  LICENCE_TYPE_ID integer NOT NULL,
  PROJECT_LIMIT integer NOT NULL default '0',
  USER_LIMIT integer NOT NULL default '0',
  COMPONENT_LIMIT integer NOT NULL default '0',
  VERSION_LIMIT integer NOT NULL default '0',
  ISSUE_LIMIT integer NOT NULL default '0',
  COMMENT_LIMIT integer NOT NULL default '0',
  ATTACHMENT_LIMIT integer NOT NULL default '0',
  ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  REMOTE_ADDRESS boolean NOT NULL default FALSE,
  REMOTE_ADDRESS_LIMIT integer NOT NULL default '0',
  WIKI_ATTACHMENT boolean NOT NULL default FALSE,
  WIKI_ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  WIKI_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  FILE_SHARING boolean NOT NULL default FALSE,
  SUBVERSION boolean NOT NULL default FALSE,
  SUBVERSION_EXTERNAL boolean NOT NULL default FALSE,
  GIT boolean NOT NULL default FALSE,
  PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  STORAGE_LIMIT bigint NOT NULL default '0',
  GANTT boolean DEFAULT FALSE,
  BURNDOWN boolean DEFAULT FALSE,
  PARENT_CHILD_ISSUE boolean NOT NULL default FALSE,
  POST_ISSUE_BY_MAIL boolean NOT NULL default FALSE,
  NULAB_ACCOUNT boolean NOT NULL default FALSE,
  NEW_UI boolean NOT NULL default FALSE,
  PROJECT_GROUP boolean NOT NULL default FALSE,
  ATTRIBUTE boolean DEFAULT FALSE,
  ATTRIBUTE_LIMIT integer NOT NULL default '0',
  STARTED_ON timestamp default NULL,
  LIMIT_DATE timestamp default NULL,
  ACTIVE boolean default '1',
  PAYMENT integer default NULL,
  SUBSCRIBED_ON timestamp default NULL,
  TRIAL_EXPIRY_DATE timestamp default NULL,
  INITIAL_COSTS integer default NULL,
  PRICE integer default NULL,
  LICENCE_KEY text default NULL,
  NULAB_APPS_INTEGRATION boolean NOT NULL default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_ID),
  CONSTRAINT "FK_licence_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_licence_LICENCE_TYPE_ID" FOREIGN KEY (LICENCE_TYPE_ID) REFERENCES "licence_type" (ID)
);
CREATE INDEX "IX_licence_SPACE_ID" ON "licence" (SPACE_ID);
CREATE INDEX "IX_licence_LICENCE_TYPE_ID" ON "licence" (LICENCE_TYPE_ID);

--
-- Table structure for table `licence_changelog`
--

CREATE SEQUENCE "licence_changelog_id_seq";
CREATE TABLE "licence_changelog" (
  ID integer NOT NULL default nextval('licence_changelog_id_seq'),
  CHANGED_ON timestamp NOT NULL,
  SPACE_ID integer NOT NULL,
  LICENCE_TYPE_ID integer NOT NULL,
  PROJECT_LIMIT integer NOT NULL default '0',
  USER_LIMIT integer NOT NULL default '0',
  COMPONENT_LIMIT integer NOT NULL default '0',
  VERSION_LIMIT integer NOT NULL default '0',
  ISSUE_LIMIT integer NOT NULL default '0',
  COMMENT_LIMIT integer NOT NULL default '0',
  ATTACHMENT_LIMIT integer NOT NULL default '0',
  ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  ATTACHMENT_NUM_LIMIT integer NULL default '0',
  REMOTE_ADDRESS boolean NOT NULL default FALSE,
  REMOTE_ADDRESS_LIMIT integer NOT NULL default '0',
  WIKI_ATTACHMENT boolean NOT NULL default FALSE,
  WIKI_ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  WIKI_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  FILE_SHARING boolean NOT NULL default FALSE,
  SUBVERSION boolean NOT NULL default FALSE,
  SUBVERSION_EXTERNAL boolean NOT NULL default FALSE,
  GIT boolean NOT NULL default FALSE,
  PULL_REQUEST_ATTACHMENT_LIMIT_PER_FILE integer NOT NULL default '0',
  PULL_REQUEST_ATTACHMENT_NUM_LIMIT integer NOT NULL default '0',
  STORAGE_LIMIT bigint NOT NULL default '0',
  GANTT boolean DEFAULT FALSE,
  BURNDOWN boolean DEFAULT FALSE,
  PARENT_CHILD_ISSUE boolean NOT NULL default FALSE,
  POST_ISSUE_BY_MAIL boolean NOT NULL default FALSE,
  NULAB_ACCOUNT boolean NOT NULL default FALSE,
  ATTRIBUTE boolean DEFAULT FALSE,
  ATTRIBUTE_LIMIT integer NOT NULL default '0',
  STARTED_ON timestamp NOT NULL,
  LIMIT_DATE timestamp default NULL,
  ACTIVE boolean default '1',
  PAYMENT integer default NULL,
  SUBSCRIBED_ON timestamp NOT NULL,
  TRIAL_EXPIRY_DATE timestamp DEFAULT NULL,
  INITIAL_COSTS integer NOT NULL,
  PRICE integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);
CREATE INDEX "IX_licence_changelog_SPACE_ID" ON "licence_changelog" (SPACE_ID);


--
-- Table structure for table `space_order`
--

CREATE TABLE "space_order" (
  SPACE_KEY varchar(20) NOT NULL default '',
  AUTH_KEY varchar(20) NOT NULL default '',
  ORDER_XML text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_KEY),
  UNIQUE (AUTH_KEY)
);

--
-- Table structure for table `users`
--

CREATE SEQUENCE "users_id_seq";
CREATE TABLE "users" (
  ID integer NOT NULL default nextval('users_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  USER_ID varchar(255) NOT NULL default '',
  MAIL_ADDRESS varchar(320) NOT NULL default '',
  AUTH_TYPE integer NOT NULL default '0',
  AUTH_VALUE varchar(735) default NULL,
  PASSWORD varchar(255) default NULL,
  NAME varchar(100) NOT NULL default '',
  ROLE_TYPE integer NOT NULL default '0',
  ICON varchar(50) default NULL,
  LANG varchar(5) default NULL,
  TIMEZONE varchar(50) default NULL,
  LAST_LOGIN_TIME timestamp default NULL,
  DISABLED integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (SPACE_ID,USER_ID,DISABLED),
  CONSTRAINT "FK_users_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_users_SPACE_ID" ON "users" (SPACE_ID);

--
-- Table structure for table `mail`
--

CREATE TABLE "mail" (
  USER_ID integer NOT NULL default '0',
  MAIL boolean default NULL,
  ISSUE boolean default NULL,
  COMMENT boolean default NULL,
  ALL_ISSUE boolean default NULL,
  ASSIGNED_ISSUE boolean default NULL,
  CREATED_ISSUE boolean default NULL,
  WIKI boolean default NULL,
  NOTIFIED boolean default NULL,
  SUMMARY boolean default NULL,
  SUBVERSION boolean default NULL,
  GIT boolean default NULL,
  MY_REPORT boolean default NULL,
  HTML_MAIL boolean default NULL,
  ANNOUNCEMENT boolean default NULL,
  FORCE_UTF8 boolean default NULL,
  EXCLUDE_MAIL_TYPE_IN_SUBJECT boolean default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  CONSTRAINT "FK_mail_USER_ID" FOREIGN KEY (USER_ID) REFERENCES "users" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_mail_USER_ID" ON "mail" (USER_ID);

--
-- Table structure for table `user_setting`
--

CREATE TABLE "user_setting" (
  USER_ID integer NOT NULL default '0',
  SHOW_CREATED_ISSUE boolean default NULL,
  USE_PRIVATE_ADDRESS boolean NOT NULL DEFAULT FALSE,
  PRIVATE_ADDRESS_KEY VARCHAR(255),
  LAST_UPDATED_NUM integer,
  LAST_UPDATED_DISABLED_TYPES varchar(255),
  USE_COLLAPSE_COMMENT boolean default TRUE,
  USE_SHORTCUT_KEY boolean default TRUE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  UNIQUE (PRIVATE_ADDRESS_KEY),
  CONSTRAINT "FK_user_setting_USER_ID" FOREIGN KEY (USER_ID) REFERENCES "users" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_setting_USER_ID" ON "user_setting" (USER_ID);
CREATE INDEX "IX_user_setting_USE_PRIVATE_ADDRESS_AND_PRIVATE_ADDRESS_KEY" ON user_setting (USE_PRIVATE_ADDRESS,PRIVATE_ADDRESS_KEY);

--
-- Table structure for table `project`
--

CREATE SEQUENCE "project_id_seq";
CREATE TABLE "project" (
  ID integer NOT NULL default nextval('project_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  PROJECT_KEY varchar(50) NOT NULL default '',
  DISABLED integer NOT NULL default '0',
  NAME varchar(50) NOT NULL default '',
  DISPLAY_ORDER integer default NULL,
  ARCHIVED boolean NOT NULL default FALSE,
  USE_GANTT boolean,
  USE_BURNDOWN boolean,
  USE_RESOLVED_FOR_CHART boolean NOT NULL default FALSE,
  USE_PARENT_CHILD_ISSUE boolean default NULL,
  ICON varchar(255) default NULL,
  TEXT_FORMATTING_RULE varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (SPACE_ID,PROJECT_KEY,DISABLED),
  CONSTRAINT "FK_project_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_DISABLED" ON "project" (DISABLED);
CREATE INDEX "IX_project_SPACE_ID" ON "project" (SPACE_ID);

--
-- Table structure for table `autologin_user`
--

CREATE TABLE "autologin_user" (
  ID varchar(255) NOT NULL default '',
  SPACE_ID integer NOT NULL default '0',
  USER_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_autologin_user_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_autologin_user_USER_ID" FOREIGN KEY (USER_ID) REFERENCES "users" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_autologin_user_USER_ID" ON "autologin_user" (USER_ID);
CREATE INDEX "IX_autologin_user_SPACE_ID" ON "autologin_user" (SPACE_ID);
CREATE INDEX "IX_autologin_user_CREATED" ON autologin_user (CREATED);

--
-- Table structure for table `component`
--

CREATE SEQUENCE "component_id_seq";
CREATE TABLE "component" (
  ID integer NOT NULL default nextval('component_id_seq'),
  NAME varchar(50) NOT NULL default '',
  PROJECT_ID integer NOT NULL default '0',
  DISPLAY_ORDER integer default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_component_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_DISPLAY_ORDER" ON "component" (DISPLAY_ORDER);
CREATE INDEX "IX_PROJECT_ID" ON "component" (PROJECT_ID);

--
-- Table structure for table `version`
--

CREATE SEQUENCE "version_id_seq";
CREATE TABLE "version" (
  ID integer NOT NULL default nextval('version_id_seq'),
  NAME varchar(50) NOT NULL default '',
  PROJECT_ID integer default NULL,
  DESCRIPTION text,
  START_DATE date default NULL,
  REFERENCE_DATE date default NULL,
  DISPLAY_ORDER integer default NULL,
  ARCHIVED boolean NOT NULL default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_version_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_version_REFERENCE_DATE" ON "version" (REFERENCE_DATE);
CREATE INDEX "IX_version_PROJECT_ID" ON "version" (PROJECT_ID);

--
-- Table structure for table `issue_type`
--

CREATE TABLE "default_issue_type" (
  ID integer NOT NULL,
  LANG varchar(5) NOT NULL default 'ja',
  NAME varchar(20) NOT NULL,
  DISPLAY_ORDER integer NOT NULL,
  COLOR varchar(20) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);

--
-- Table structure for table `issue_type`
--

CREATE SEQUENCE "issue_type_id_seq";
CREATE TABLE "issue_type" (
  ID integer NOT NULL default nextval('issue_type_id_seq'),
  PROJECT_ID integer NOT NULL,
  NAME varchar(20) NOT NULL default '',
  DISPLAY_ORDER integer default NULL,
  COLOR varchar(20) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_issue_type_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

--
-- Table structure for table `status`
--

CREATE TABLE "status" (
  ID integer NOT NULL,
  LABEL varchar(20) NOT NULL default '',
  DISPLAY_ORDER integer default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);

--
-- Table structure for table `issue`
--

CREATE SEQUENCE "issue_id_seq";
CREATE TABLE "issue" (
  ID integer NOT NULL default nextval('issue_id_seq'),
  PROJECT_ID integer NOT NULL default '0',
  KEY_ID integer default NULL,
  ISSUE_TYPE_ID integer NOT NULL default '0',
  COMPONENT_ID integer default NULL,
  SUMMARY varchar(255) NOT NULL default '',
  DESCRIPTION text,
  STATUS_ID integer default NULL,
  RESOLUTION_ID integer default NULL,
  PRIORITY integer NOT NULL default '0',
  AFFECTED_VERSION_ID integer default NULL,
  FIXED_VERSION_ID integer default NULL,
  ASSIGNER_ID integer default NULL,
  START_DATE date default NULL,
  LIMIT_DATE date default NULL,
  ESTIMATED_HOURS real DEFAULT NULL,
  ACTUAL_HOURS real DEFAULT NULL,
  PARENT_ISSUE_ID integer default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (PROJECT_ID,KEY_ID),
  CONSTRAINT "FK_issue_STATUS_ID" FOREIGN KEY (STATUS_ID) REFERENCES "status" (ID),
  CONSTRAINT "FK_issue_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE DEFERRABLE INITIALLY DEFERRED,
  CONSTRAINT "FK_issue_COMPONENT_ID" FOREIGN KEY (COMPONENT_ID) REFERENCES "component" (ID) ON DELETE SET NULL DEFERRABLE INITIALLY DEFERRED,
  CONSTRAINT "FK_issue_FIXED_VERSION_ID" FOREIGN KEY (FIXED_VERSION_ID) REFERENCES "version" (ID) ON DELETE SET NULL DEFERRABLE INITIALLY DEFERRED,
  CONSTRAINT "FK_issue_ASSIGNER_ID" FOREIGN KEY (ASSIGNER_ID) REFERENCES "users" (ID) ON DELETE SET NULL,
  CONSTRAINT "FK_issue_AFFECTED_VERSION_ID" FOREIGN KEY (AFFECTED_VERSION_ID) REFERENCES "version" (ID) ON DELETE SET NULL DEFERRABLE INITIALLY DEFERRED
);
CREATE INDEX "IX_issue_RESOLUTION_ID" ON "issue" (RESOLUTION_ID);
CREATE INDEX "IX_issue_PRIORITY" ON "issue" (PRIORITY);
CREATE INDEX "IX_issue_KEY_ID" ON "issue" (KEY_ID);
CREATE INDEX "IX_issue_UPDATED" ON "issue" (UPDATED);
CREATE INDEX "IX_issue_STATUS_ID" ON "issue" (STATUS_ID);
CREATE INDEX "IX_issue_PROJECT_ID" ON "issue" (PROJECT_ID);
CREATE INDEX "IX_issue_COMPONENT_ID" ON "issue" (COMPONENT_ID);
CREATE INDEX "IX_issue_FIXED_VERSION_ID" ON "issue" (FIXED_VERSION_ID);
CREATE INDEX "IX_issue_ASSIGNER_ID" ON "issue" (ASSIGNER_ID);
CREATE INDEX "IX_issue_AFFECTED_VERSION_ID" ON "issue" (AFFECTED_VERSION_ID);
CREATE INDEX "IX_issue_CREATED_USER_ID" ON "issue" (CREATED_USER_ID);
CREATE INDEX "IX_issue_START_DATE" ON "issue" (START_DATE);
CREATE INDEX "IX_issue_PROJECT_ID_UPDATED" ON "issue" (PROJECT_ID, UPDATED);
CREATE INDEX "IX_issue_CREATED_USER_ID_PROJECT_ID" ON issue (CREATED_USER_ID, PROJECT_ID);
CREATE INDEX "IX_issue_ASSIGNER_ID_PROJECT_ID" ON issue (ASSIGNER_ID, PROJECT_ID);
CREATE INDEX "IX_issue_PARENT_ISSUE_ID" ON issue (PARENT_ISSUE_ID);

CREATE TABLE "issue_component" (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,LINK_ID),
  CONSTRAINT "FK_issue_component_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_component_LINK_ID" FOREIGN KEY (LINK_ID) REFERENCES "component" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_component_ISSUE_ID" ON "issue_component" (ISSUE_ID);
CREATE INDEX "IX_issue_component_LINK_ID" ON "issue_component" (LINK_ID);

CREATE TABLE "issue_affectedversion" (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,LINK_ID),
  CONSTRAINT "FK_issue_affectedversion_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_affectedversion_LINK_ID" FOREIGN KEY (LINK_ID) REFERENCES "version" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_affectedversion_ISSUE_ID" ON "issue_affectedversion" (ISSUE_ID);
CREATE INDEX "IX_issue_affectedversion_LINK_ID" ON "issue_affectedversion" (LINK_ID);

CREATE TABLE "issue_fixedversion" (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,LINK_ID),
  CONSTRAINT "FK_issue_fixedversion_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_issue_fixedversion_LINK_ID" FOREIGN KEY (LINK_ID) REFERENCES "version" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_fixedversion_ISSUE_ID" ON "issue_fixedversion" (ISSUE_ID);
CREATE INDEX "IX_issue_fixedversion_LINK_ID" ON "issue_fixedversion" (LINK_ID);


--
-- Table structure for table `attachment`
--

CREATE SEQUENCE "attachment_id_seq";
CREATE TABLE "attachment" (
  ID integer NOT NULL default nextval('attachment_id_seq'),
  ISSUE_ID integer NOT NULL default '0',
  NAME varchar(100) NOT NULL default '',
  SIZE integer NOT NULL default '0',
  CONTENT bytea,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_attachment_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_attachment_ISSUE_ID" ON "attachment" (ISSUE_ID);

--
-- Table structure for table `comment`
--

CREATE SEQUENCE "comment_id_seq";
CREATE TABLE "comment" (
  ID integer NOT NULL default nextval('comment_id_seq'),
  ISSUE_ID integer default NULL,
  PROJECT_ID integer NOT NULL,
  CONTENT text,
  CHANGELOG_XML text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_comment_ISSUE_ID" FOREIGN KEY (ISSUE_ID) REFERENCES "issue" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_comment_UPDATED" ON "comment" (UPDATED);
CREATE INDEX "IX_comment_ISSUE_ID" ON "comment" (ISSUE_ID);
CREATE INDEX "IX_comment_CREATED_USER_ID" ON "comment" (CREATED_USER_ID);
CREATE INDEX "IX_comment_CREATED" ON "comment" (CREATED);
CREATE INDEX "IX_comment_PROJECT_ID_UPDATED" ON "comment" (PROJECT_ID, UPDATED);

--
-- Table structure for table `information`
--

CREATE SEQUENCE "information_id_seq";
CREATE TABLE "information" (
  ID integer NOT NULL default nextval('information_id_seq'),
  INFO_KEY varchar(255) NOT NULL default '',
  LANG varchar(5) NOT NULL default 'ja',
  CONTENT text,
  FROM_DATE timestamp NOT NULL default CURRENT_TIMESTAMP,
  TO_DATE timestamp NOT NULL default CURRENT_TIMESTAMP,
  TARGET_USER_CREATED_AFTER timestamp default NULL,
  TARGET_USER_CREATED_BEFORE timestamp default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);
CREATE INDEX "IX_information_INFO_KEY" ON "information" (INFO_KEY);

--
-- Table structure for table `page`
--

CREATE SEQUENCE "page_id_seq";
CREATE TABLE "page" (
  ID integer NOT NULL default nextval('page_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  PROJECT_ID integer NOT NULL default '0',
  NAME varchar(255) NOT NULL default '',
  CONTENT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (PROJECT_ID,NAME),
  CONSTRAINT "FK_page_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_page_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_SPACE_ID" ON "page" (SPACE_ID);
CREATE INDEX "IX_page_PROJECT_ID_UPDATED" ON "page" (PROJECT_ID, UPDATED);

--
-- Table structure for table `page_attachment`
--

CREATE SEQUENCE "page_attachment_id_seq";
CREATE TABLE "page_attachment" (
  ID integer NOT NULL default nextval('page_attachment_id_seq'),
  PAGE_ID integer NOT NULL default '0',
  NAME varchar(100) NOT NULL default '',
  SIZE integer NOT NULL default '0',
  CONTENT bytea,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_page_attachment_PAGE_ID" FOREIGN KEY (PAGE_ID) REFERENCES "page" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_attachment_PAGE_ID" ON "page_attachment" (PAGE_ID);

--
-- Table structure for table `page_tag`
--

CREATE SEQUENCE "page_tag_id_seq";
CREATE TABLE "page_tag" (
  ID integer NOT NULL default nextval('page_tag_id_seq'),
  PROJECT_ID integer NOT NULL default '0',
  NAME varchar(255) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (PROJECT_ID,NAME),
  CONSTRAINT "FK_page_tag_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_tag_PROJECT_ID" ON "page_tag" (PROJECT_ID);

--
-- Table structure for table `page_tag_link`
--

CREATE TABLE "page_tag_link" (
  PAGE_ID integer NOT NULL default '0',
  PAGE_TAG_ID integer NOT NULL default '0',
  DISPLAY_ORDER integer NOT NULL default '0',
  PRIMARY KEY  (PAGE_ID,PAGE_TAG_ID),
  CONSTRAINT "FK_page_tag_link_PAGE_ID" FOREIGN KEY (PAGE_ID) REFERENCES "page" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_page_tag_link_PAGE_TAG_ID" FOREIGN KEY (PAGE_TAG_ID) REFERENCES "page_tag" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_tag_link_PAGE_ID" ON "page_tag_link" (PAGE_ID);
CREATE INDEX "IX_page_tag_link_PAGE_TAG_ID" ON "page_tag_link" (PAGE_TAG_ID);

--
-- Table structure for table `party`
--

CREATE SEQUENCE "party_id_seq";
CREATE TABLE "party" (
  ID integer NOT NULL default nextval('party_id_seq'),
  SPACE_ID integer NOT NULL,
  NULAB_APPS_GROUP_KEY varchar(50) default NULL,
  NAME varchar(255) default NULL,
  DISPLAY_ORDER integer default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (NULAB_APPS_GROUP_KEY),
  CONSTRAINT "FK_party_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_party_SPACE_ID" ON "party" (SPACE_ID);

--
-- Table structure for table `party_user`
--

CREATE TABLE "party_user" (
  PARTY_ID integer NOT NULL,
  USER_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PARTY_ID,USER_ID),
  CONSTRAINT "FK_party_user_PARTY_ID" FOREIGN KEY (PARTY_ID) REFERENCES "party" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_party_user_USER_ID" FOREIGN KEY (USER_ID) REFERENCES "users" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_party_user_USER_ID" ON "party_user" (USER_ID);
CREATE INDEX "IX_party_user_PARTY_ID" ON "party_user" (PARTY_ID);

--
-- Table structure for table `project_user`
--

CREATE TABLE "project_user" (
  PROJECT_ID integer NOT NULL default '0',
  USER_ID integer NOT NULL default '0',
  PROJECT_LEADER boolean default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PROJECT_ID,USER_ID),
  CONSTRAINT "FK_project_user_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_project_user_USER_ID" FOREIGN KEY (USER_ID) REFERENCES "users" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_user_USER_ID" ON "project_user" (USER_ID);
CREATE INDEX "IX_project_user_PROJECT_ID" ON "project_user" (PROJECT_ID);

--
-- Table structure for table `project_mail`
--

CREATE TABLE "project_mail" (
  USER_ID integer NOT NULL default '0',
  PROJECT_ID integer NOT NULL default '0',
  MAIL boolean default NULL,
  ISSUE boolean default NULL,
  COMMENT boolean default NULL,
  ALL_ISSUE boolean default NULL,
  ASSIGNED_ISSUE boolean default NULL,
  CREATED_ISSUE boolean default NULL,
  WIKI boolean default NULL,
  NOTIFIED boolean default NULL,
  SUMMARY boolean default NULL,
  SUBVERSION boolean default NULL,
  GIT boolean default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID, PROJECT_ID),
  CONSTRAINT "FK_project_mail_USER_ID" FOREIGN KEY (USER_ID) REFERENCES "users" (ID) ON DELETE CASCADE,
  CONSTRAINT "FK_project_mail_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_mail_USER_ID" ON "project_mail" (USER_ID);
CREATE INDEX "IX_project_mail_PROJECT_ID" ON "project_mail" (PROJECT_ID);

--
-- Table structure for table `reminder`
--

CREATE TABLE "reminder" (
  ID varchar(255) NOT NULL,
  USER_ID integer NOT NULL,
  SPACE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);

--
-- Table structure for table `remote_address`
--

CREATE SEQUENCE "remote_address_id_seq";
CREATE TABLE "remote_address" (
  ID integer NOT NULL default nextval('remote_address_id_seq'),
  SPACE_ID integer default NULL,
  IP_ADDRESS varchar(255) default NULL,
  MASK varchar(255) default NULL,
  MEMO varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_remote_address_SPACE_ID" FOREIGN KEY (SPACE_ID) REFERENCES "space" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_remote_address_SPACE_ID" ON "remote_address" (SPACE_ID);

--
-- Table structure for table `disk_usage`
--

CREATE TABLE "disk_usage" (
  PROJECT_ID integer NOT NULL,
  TYPE integer NOT NULL,
  AMOUNT bigint NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID,TYPE),
  CONSTRAINT FK_disk_usage_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_disk_usage_PROJECT_ID" ON "disk_usage" (PROJECT_ID);

CREATE SEQUENCE "shared_file_id_seq";
CREATE TABLE "shared_file" (
  ID integer NOT NULL default nextval('shared_file_id_seq'),
  PROJECT_ID integer NOT NULL,
  DIR text NOT NULL default '',
  NAME text default NULL,
  SIZE bigint default NULL,
  TYPE integer NOT NULL,
  CHECKSUM varchar(40) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_shared_file_PROJECT_ID" FOREIGN KEY (PROJECT_ID) REFERENCES "project" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_shared_file_PROJECT_ID" ON "shared_file" (PROJECT_ID);
CREATE INDEX "IX_shared_file_PROJECT_ID_UPDATED" ON "shared_file" (PROJECT_ID, UPDATED);
CREATE INDEX "IX_shared_file_PROJECT_ID_DIR_NAME" ON "shared_file" (PROJECT_ID, DIR, NAME);

CREATE SEQUENCE "subversion_id_seq";
CREATE TABLE "subversion" (
  ID integer NOT NULL default nextval('subversion_id_seq'),
  PROJECT_ID integer NOT NULL,
  TYPE integer NOT NULL,
  URL text default NULL,
  SVN_USER text default NULL,
  SVN_PASSWORD text default NULL,
  COMMIT_ISSUE_UPDATE boolean default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (PROJECT_ID),
  CONSTRAINT FK_subversion_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_subversion_PROJECT_ID" ON "subversion" (PROJECT_ID);

CREATE TABLE "issue_shared_file_link" (
  ISSUE_ID integer NOT NULL default '0',
  SHARED_FILE_ID integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ISSUE_ID,SHARED_FILE_ID),
  CONSTRAINT FK_issue_shared_file_link_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_shared_file_link_SHARED_FILE_ID FOREIGN KEY (SHARED_FILE_ID) REFERENCES shared_file (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_shared_file_link_ISSUE_ID" ON "issue_shared_file_link" (ISSUE_ID);
CREATE INDEX "IX_issue_shared_file_link_SHARED_FILE_ID" ON "issue_shared_file_link" (SHARED_FILE_ID);

CREATE TABLE "page_shared_file_link" (
  PAGE_ID integer NOT NULL default '0',
  SHARED_FILE_ID integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PAGE_ID,SHARED_FILE_ID),
  CONSTRAINT FK_page_shared_file_link_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE,
  CONSTRAINT FK_page_shared_file_link_SHARED_FILE_ID FOREIGN KEY (SHARED_FILE_ID) REFERENCES shared_file (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_shared_file_link_PAGE_ID" ON "page_shared_file_link" (PAGE_ID);
CREATE INDEX "IX_page_shared_file_link_SHARED_FILE_ID" ON "page_shared_file_link" (SHARED_FILE_ID);

--
-- Table structure for table `step`
--

CREATE SEQUENCE "step_id_seq";
CREATE TABLE "step" (
  ID integer NOT NULL default nextval('step_id_seq'),
  NEXT integer default NULL,
  PREVIOUS integer default NULL,
  WORK_ITEM_ID integer default NULL,
  STEP_ID integer default NULL,
  OWNER varchar(10) default NULL,
  START_DATE timestamp default NULL,
  END_DATE timestamp default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_step_WORK_ITEM_ID" FOREIGN KEY (WORK_ITEM_ID) REFERENCES "issue" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_step_WORK_ITEM_ID" ON "step"(WORK_ITEM_ID);

--
-- Table structure for table `work_item`
--

CREATE SEQUENCE "work_item_id_seq";
CREATE TABLE "work_item" (
  ID integer NOT NULL default nextval('work_item_id_seq'),
  WORK_ITEM_ID integer default NULL,
  WORKFLOW_NAME varchar(10) default NULL,
  START_DATE timestamp default NULL,
  END_DATE timestamp default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT "FK_work_item_WORK_ITEM_ID" FOREIGN KEY (WORK_ITEM_ID) REFERENCES "issue" (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_work_item_WORK_ITEM_ID" ON "work_item" (WORK_ITEM_ID);

--
-- Table structure for table `space_field`
--
CREATE TABLE space_field (
  SPACE_ID integer NOT NULL,
  FIELD_KEY VARCHAR(255) NOT NULL,
  VALUE TEXT,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP
);
CREATE INDEX "IX_space_field_SPACE_ID" ON "space_field" (SPACE_ID);

CREATE SEQUENCE "star_id_seq";
CREATE TABLE star (
  ID integer NOT NULL default nextval('star_id_seq'),
  AWARD_ID integer default NULL,
  PRESENTER_ID integer default NULL,
  PROJECT_ID integer default NULL,
  URL varchar(255) NOT NULL default '',
  TITLE varchar(255) NOT NULL default '',
  COMMENT varchar(100) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_star_AWARD_ID FOREIGN KEY (AWARD_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_star_PRESENTER_ID FOREIGN KEY (PRESENTER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_star_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_star_URL" ON "star" (URL);
CREATE INDEX "IX_star_CREATED" ON "star" (CREATED);
CREATE INDEX "IX_star_PROJECT_ID_CREATED" ON "star" (PROJECT_ID, CREATED);
CREATE INDEX "IX_star_AWARD_ID" ON "star" (AWARD_ID);
CREATE INDEX "IX_star_PRESENTER_ID" ON "star" (PRESENTER_ID);
CREATE INDEX "IX_star_PROJECT_ID" ON "star" (PROJECT_ID);

CREATE SEQUENCE "star_notify_id_seq";
CREATE TABLE star_notify (
  ID integer NOT NULL default nextval('star_notify_id_seq'),
  STAR_ID integer default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_star_notify_STAR_ID FOREIGN KEY (STAR_ID) REFERENCES star (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_star_notify_STAR_ID" ON "star_notify" (STAR_ID);

CREATE TABLE user_profile (
  USER_ID integer NOT NULL,
  SEX boolean default NULL,
  LOCATION text default NULL,
  BIOGRAPHY text default NULL,
  URLS text default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID),
  CONSTRAINT FK_user_profile_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_profile_USER_ID" ON "user_profile" (USER_ID);

CREATE TABLE user_recent_project (
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID),
  CONSTRAINT FK_recent_project_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_recent_project_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_recent_project_USER_ID_CREATED" ON "user_recent_project" (USER_ID, CREATED);

CREATE TABLE mobilelogin_user (
  ID varchar(255) NOT NULL,
  USER_ID integer NOT NULL,
  CREATED timestamp NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_mobilelogin_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_mobilelogin_user_USER_ID" ON "mobilelogin_user" (USER_ID);

CREATE TABLE reserved_space_key (
  SPACE_KEY varchar(255) NOT NULL,
  IS_REGEXP boolean NOT NULL default FALSE,
  PRIMARY KEY (SPACE_KEY)
);

CREATE SEQUENCE "holiday_id_seq";
CREATE TABLE holiday (
  ID integer NOT NULL default nextval('holiday_id_seq'),
  DATE timestamp NOT NULL,
  NAME varchar(255) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_holiday_DATE" ON "holiday" (DATE);

CREATE SEQUENCE "attribute_id_seq";
CREATE TABLE attribute (
  ID integer NOT NULL default nextval('attribute_id_seq'),
  USE_ISSUE_TYPE boolean default FALSE,
  PROJECT_ID integer NOT NULL,
  ATTRIBUTE_TYPE_ID integer NOT NULL,
  REQUIRED boolean DEFAULT FALSE,
  LABEL varchar(255) NOT NULL default '',
  DESCRIPTION varchar(255) NOT NULL default '',
  PROPERTY_JSON text NOT NULL,
  DISPLAY_ORDER integer DEFAULT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT FK_attribute_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_attribute_PROJECT_ID" ON "attribute" (PROJECT_ID);

CREATE SEQUENCE "issue_attribute_id_seq";
CREATE TABLE issue_attribute (
  ID integer NOT NULL default nextval('issue_attribute_id_seq'),
  ISSUE_ID integer NOT NULL,
  ATTRIBUTE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT FK_issue_attribute_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_attribute_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_issue_attribute_ISSUE_ID" ON "issue_attribute" (ISSUE_ID);
CREATE INDEX "IX_issue_attribute_ATTRIBUTE_ID" ON "issue_attribute" (ATTRIBUTE_ID);

CREATE SEQUENCE "issue_attribute_value_id_seq";
CREATE TABLE issue_attribute_value (
  ID integer NOT NULL default nextval('issue_attribute_value_id_seq'),
  ISSUE_ATTRIBUTE_ID integer NOT NULL,
  ATTRIBUTE_ID integer NOT NULL,
  TEXT text,
  DATE timestamp,
  NUMBER double precision,
  IDENTITY integer,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT FK_issue_attribute_value_ISSUE_ATTRIBUTE_ID FOREIGN KEY (ISSUE_ATTRIBUTE_ID) REFERENCES issue_attribute (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_attribute_value_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_issue_attribute_value_ISSUE_ATTRIBUTE_ID" ON "issue_attribute_value" (ISSUE_ATTRIBUTE_ID);
CREATE INDEX "IX_issue_attribute_value_ATTRIBUTE_ID" ON "issue_attribute_value" (ATTRIBUTE_ID);

CREATE TABLE attribute_issue_type (
  ATTRIBUTE_ID integer NOT NULL,
  ISSUE_TYPE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  CONSTRAINT FK_attribute_issue_type_ATTRIBUTE_ID FOREIGN KEY (ATTRIBUTE_ID) REFERENCES attribute (ID) ON DELETE CASCADE,
  CONSTRAINT FK_attribute_issue_type_ISSUE_TYPE_ID FOREIGN KEY (ISSUE_TYPE_ID) REFERENCES issue_type (ID) ON DELETE CASCADE,
  PRIMARY KEY (ATTRIBUTE_ID,ISSUE_TYPE_ID)
);
CREATE INDEX "IX_attribute_issue_type_ATTRIBUTE_ID" ON "attribute_issue_type" (ATTRIBUTE_ID);
CREATE INDEX "IX_attribute_issue_type_ISSUE_TYPE_ID" ON "attribute_issue_type" (ISSUE_TYPE_ID);

CREATE SEQUENCE "billing_id_seq";
CREATE TABLE billing (
  ID integer NOT NULL default nextval('billing_id_seq'),
  SPACE_ID integer NOT NULL,
  TYPE integer NOT NULL,
  PAYMENT integer NOT NULL,
  AMOUNT integer NOT NULL,
  DISCOUNT integer DEFAULT 0,  
  DUE_DATE date NOT NULL,
  PAID_ON date DEFAULT NULL,
  PAID_NAME varchar(255) DEFAULT NULL,
  STARTED_ON date DEFAULT NULL,
  EXPIRED_ON date DEFAULT NULL,
  STATUS integer NOT NULL DEFAULT '1',
  MEMO varchar(255) DEFAULT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_billing_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_billing_id_seq_PAYMENT_STATUS_DUE_DATE" ON "billing" (PAYMENT, STATUS, DUE_DATE);

CREATE SEQUENCE "invoice_id_seq";
CREATE TABLE invoice (
  ID integer NOT NULL default nextval('invoice_id_seq'),
  BILLING_ID integer NOT NULL,
  TYPE integer NOT NULL DEFAULT '1',
  STATUS integer NOT NULL DEFAULT '1',
  DUE_DATE date NOT NULL,
  SENDED_ON date DEFAULT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_invoice_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "account_transfer_procedure_id_seq";
CREATE TABLE account_transfer_procedure (
  ID integer NOT NULL default nextval('account_transfer_procedure_id_seq'),
  SPACE_ID integer NOT NULL,
  STATUS integer NOT NULL DEFAULT 0,
  SENDED_ON date DEFAULT NULL,
  DUE_DATE date DEFAULT NULL,
  RECEIVED_DUE_DATE date DEFAULT NULL,
  RECEIVED_ON date DEFAULT NULL,
  COMPLETED_ON date DEFAULT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_account_transfer_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "account_transfer_result_id_seq";
CREATE TABLE account_transfer_result (
  ID integer NOT NULL default nextval('account_transfer_result_id_seq'),
  STATUS integer NOT NULL,
  RESULT_DATE date NOT NULL,
  AMOUNT integer NOT NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

CREATE TABLE billing_account_transfer_result (
  BILLING_ID integer NOT NULL,
  RESULT_ID integer NOT NULL,
  PRIMARY KEY (BILLING_ID, RESULT_ID),
  CONSTRAINT FK_billing_account_transfer_result_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE,
  CONSTRAINT FK_billing_account_transfer_result_RESULT_ID FOREIGN KEY (RESULT_ID) REFERENCES account_transfer_result (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "licence_change_request_id_seq";
CREATE TABLE licence_change_request (
  ID integer NOT NULL default nextval('licence_change_request_id_seq'),
  SPACE_ID integer NOT NULL,
  FROM_LICENCE_TYPE_ID integer NOT NULL,
  TO_LICENCE_TYPE_ID integer NOT NULL,
  CLOSE boolean NOT NULL default FALSE,
  CHANGED_ON date NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_licence_change_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_licence_change_request_FROM_LICENCE_TYPE_ID FOREIGN KEY (FROM_LICENCE_TYPE_ID) REFERENCES licence_type (ID),
  CONSTRAINT FK_licence_change_request_TO_LICENCE_TYPE_ID FOREIGN KEY (TO_LICENCE_TYPE_ID) REFERENCES licence_type (ID)  
);
CREATE INDEX "IX_licence_change_request_SPACE_ID" ON "licence_change_request" (SPACE_ID);

CREATE SEQUENCE "payment_change_request_id_seq";
CREATE TABLE payment_change_request (
  ID integer NOT NULL default nextval('payment_change_request_id_seq'),
  SPACE_ID integer NOT NULL,
  FROM_PAYMENT integer NOT NULL,
  TO_PAYMENT integer NOT NULL,
  CONTENT text,  
  CHANGED_ON date default NULL,  
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),  
  CONSTRAINT FK_payment_change_request_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE  
);
CREATE INDEX "IX_payment_change_request_SPACE_ID" ON "payment_change_request" (SPACE_ID);

CREATE TABLE space_remarks (
  SPACE_ID integer NOT NULL,
  CONTENT text,
  SPECIAL_SUPPORT integer default NULL,
  SPECIAL_SUPPORT_CONTENT text default NULL,
  SPECIAL_SUPPORT_CONSOLIDATED_BILLING_SPACES varchar(255) default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (SPACE_ID),
  CONSTRAINT FK_space_remarks_1 FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE TABLE space_information (
  SPACE_ID integer NOT NULL,
  CONTENT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (SPACE_ID),
  CONSTRAINT FK_space_information_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_space_information_SPACE_ID" ON "space_information" (SPACE_ID);

CREATE SEQUENCE "project_activity_id_seq";
CREATE TABLE project_activity (
  ID bigint NOT NULL default nextval('project_activity_id_seq'),
  PROJECT_ID integer NOT NULL,
  TYPE integer NOT NULL,
  CONTENT_JSON text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_project_activity_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_activity_PROJECT_ID_CREATED_TYPE_CREATED_USER_ID" ON "project_activity" (PROJECT_ID, CREATED, TYPE, CREATED_USER_ID);

CREATE TABLE user_recent_issue (
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  ISSUE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,ISSUE_ID),
  CONSTRAINT FK_user_recent_issue_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_issue_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_recent_issue_USER_ID_CREATED" ON "user_recent_issue" (USER_ID, CREATED);

CREATE TABLE user_recent_page (
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  PAGE_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID,PROJECT_ID,PAGE_ID),
  CONSTRAINT FK_user_recent_page_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_recent_page_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_recent_page_USER_ID_CREATED" ON "user_recent_page" (USER_ID, CREATED);

CREATE SEQUENCE "project_activity_notify_id_seq";
CREATE TABLE project_activity_notify (
  ID bigint NOT NULL default nextval('project_activity_notify_id_seq'),
  PROJECT_ACTIVITY_ID bigint NOT NULL,
  USER_ID integer NOT NULL,
  REASON integer,
  ALREADY_READ boolean NOT NULL DEFAULT FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_project_activity_notify_PROJECT_ACTIVITY_ID FOREIGN KEY (PROJECT_ACTIVITY_ID) REFERENCES project_activity (ID) ON DELETE CASCADE,
  CONSTRAINT FK_project_activity_notify_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_activity_notify_PROJECT_ACTIVITY_ID_USER_ID" ON "project_activity_notify" (PROJECT_ACTIVITY_ID, USER_ID);
CREATE INDEX "IX_project_activity_notify_USER_ID_CREATED" ON "project_activity_notify" (USER_ID, CREATED);

CREATE SEQUENCE "notify_resource_id_seq";
CREATE TABLE notify_resource (
  ID bigint NOT NULL default nextval('notify_resource_id_seq'),
  PROJECT_ACTIVITY_NOTIFY_ID bigint NOT NULL,
  RESOURCE varchar(255) NOT NULL default '',
  ALREADY_READ boolean NOT NULL DEFAULT FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_notify_resource_PROJECT_ACTIVITY_NOTIFY_ID FOREIGN KEY (PROJECT_ACTIVITY_NOTIFY_ID) REFERENCES project_activity_notify (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_notify_resource_PROJECT_ACTIVITY_NOTIFY_ID" ON "notify_resource" (PROJECT_ACTIVITY_NOTIFY_ID);
CREATE INDEX "IX_notify_resource_RESOURCE" ON "notify_resource" (RESOURCE);

CREATE SEQUENCE "issue_filter_condition_id_seq";
CREATE TABLE issue_filter_condition (
  ID integer NOT NULL default nextval('issue_filter_condition_id_seq'),
  USER_ID integer NOT NULL,
  PROJECT_ID integer default NULL,
  NAME text,
  CONDITION_XML text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_issue_filter_condition_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_filter_condition_USER_ID_UPDATED" ON "issue_filter_condition" (USER_ID, UPDATED);

CREATE SEQUENCE "user_ssh_key_id_seq";
CREATE TABLE user_ssh_key (
  ID integer NOT NULL default nextval('user_ssh_key_id_seq'),
  SPACE_ID integer NOT NULL,
  USER_ID integer NOT NULL,
  CONTENT text NOT NULL,
  FINGERPRINT varchar(47) NOT NULL,
  MEMO varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (SPACE_ID, FINGERPRINT),
  CONSTRAINT FK_user_ssh_key_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_ssh_key_USER_ID_FINGERPRINT" ON "user_ssh_key" (USER_ID, FINGERPRINT);

CREATE SEQUENCE "git_id_seq";
CREATE TABLE git (
  ID integer NOT NULL default nextval('git_id_seq'),
  PROJECT_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  COMMIT_ISSUE_UPDATE boolean default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (PROJECT_ID),
  CONSTRAINT FK_git_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_git_PROJECT_ID" ON "git" (PROJECT_ID);

CREATE SEQUENCE "repository_id_seq";
CREATE TABLE repository (
  ID integer NOT NULL default nextval('repository_id_seq'),
  PROJECT_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  NAME varchar(255) NOT NULL,
  DESCRIPTION varchar(255) default NULL,
  HOOK_URL text default NULL,
  DISPLAY_ORDER integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (PROJECT_ID, TYPE, NAME),
  CONSTRAINT FK_repository_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_repository_PROJECT_ID" ON "repository" (PROJECT_ID);

CREATE SEQUENCE "revision_id_seq";
CREATE TABLE revision (
  ID integer NOT NULL default nextval('revision_id_seq'),
  REPOSITORY_ID integer NOT NULL,
  REVISION varchar(255) NOT NULL,
  MESSAGE text,
  AUTHOR varchar(735),
  AUTHOR_MAIL_ADDRESS varchar(735),
  AUTHOR_USER_ID integer default NULL,
  COMMITTED_ON timestamp NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (REPOSITORY_ID, REVISION),
  CONSTRAINT FK_revesion_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE,
  CONSTRAINT FK_revesion_AUTHOR_USER_ID FOREIGN KEY (AUTHOR_USER_ID) REFERENCES users (ID) ON DELETE SET NULL
);
CREATE INDEX "IX_revision_REVISION" ON "revision" (REVISION);
CREATE INDEX "IX_REPOSITORY_ID_CREATED" ON "revision" (REPOSITORY_ID,CREATED);
CREATE INDEX "IX_revision_REPOSITORY_ID" ON "revision" (REPOSITORY_ID);
CREATE INDEX "IX_revision_AUTHOR_USER_ID" ON "revision" (AUTHOR_USER_ID);

CREATE SEQUENCE "revision_change_id_seq";
CREATE TABLE revision_change (
  ID integer NOT NULL default nextval('revision_change_id_seq'),
  REVISION_ID integer NOT NULL,
  CHANGE_TYPE varchar(1) NOT NULL,
  PATH text NOT NULL,
  PATH_TYPE varchar(1) NOT NULL,
  BASE_PATH text,
  BASE_REVISION varchar(255),
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_revision_change_REVISION_ID FOREIGN KEY (REVISION_ID) REFERENCES revision (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_revision_change_REVISION_ID" ON "revision_change" (REVISION_ID);

CREATE TABLE issue_revision (
  ISSUE_ID integer NOT NULL,
  LINK_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp default NULL,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ISSUE_ID,LINK_ID),
  CONSTRAINT FK_issue_revision_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_revision_LINK_ID FOREIGN KEY (LINK_ID) REFERENCES revision (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_revision_ISSUE_ID" ON "issue_revision" (ISSUE_ID);

CREATE SEQUENCE "job_page_updated_id_seq";
CREATE TABLE job_page_updated (
  ID bigint NOT NULL default nextval('job_page_updated_id_seq'),
  PAGE_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_job_page_updated_CREATED" ON "job_page_updated" (CREATED);

CREATE SEQUENCE "job_shared_file_updated_id_seq";
CREATE TABLE job_shared_file_updated (
  ID bigint NOT NULL default nextval('job_shared_file_updated_id_seq'),
  SHARED_FILE_ID integer NOT NULL,
  TYPE smallint NOT NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_job_shared_file_updated_CREATED" ON "job_shared_file_updated" (CREATED);

CREATE SEQUENCE "issue_multi_update_tx_id_seq";
CREATE TABLE issue_multi_update_tx (
  ID bigint NOT NULL default nextval('issue_multi_update_tx_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  REQUEST_JSON text,
  MAIL_SENT boolean NOT NULL default FALSE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_multi_update_tx_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_multi_update_tx_CREATED" ON "issue_multi_update_tx" (CREATED);

CREATE SEQUENCE "issue_multi_update_log_id_seq";
CREATE TABLE issue_multi_update_log (
  ID bigint NOT NULL default nextval('issue_multi_update_log_id_seq'),
  ISSUE_ID integer NOT NULL,
  TX_ID bigint NOT NULL,
  COMMENT_ID integer,
  RESULT boolean NOT NULL default TRUE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_multi_update_log_TX_ID FOREIGN KEY (TX_ID) REFERENCES issue_multi_update_tx (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_multi_update_log_TX_ID" ON "issue_multi_update_log" (TX_ID);

CREATE SEQUENCE "page_history_id_seq";
CREATE TABLE page_history (
  ID bigint NOT NULL default nextval('page_history_id_seq'),
  PAGE_ID integer NOT NULL default '0',
  VERSION integer NOT NULL default '0',
  NAME varchar(255) NOT NULL default '',
  CONTENT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_page_history_PAGE_ID FOREIGN KEY (PAGE_ID) REFERENCES page (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_page_history_PAGE_ID" ON "page_history" (PAGE_ID);

CREATE SEQUENCE "paypal_ipn_log_id_seq";
CREATE TABLE paypal_ipn_log (
  ID integer NOT NULL default nextval('paypal_ipn_log_id_seq'),
  SPACE_ID integer NOT NULL,
  TXN_TYPE text,
  PAYER_EMAIL text,
  REMOTE_ADDR text,
  ERROR boolean default FALSE,
  CONTENT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paypal_ipn_log_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "paypal_subscription_id_seq";
CREATE TABLE paypal_subscription (
  ID integer NOT NULL default nextval('paypal_subscription_id_seq'),
  SPACE_ID integer NOT NULL,
  PROFILE_ID text,
  PROFILE_STATUS text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paypal_subscription_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE TABLE paypal_subscription_billing (
  PAYPAL_SUBSCRIPTION_ID integer NOT NULL,
  BILLING_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PAYPAL_SUBSCRIPTION_ID,BILLING_ID),
  CONSTRAINT FK_paypal_subscription_billing_PAYPAL_SUBSCRIPTION_ID FOREIGN KEY (PAYPAL_SUBSCRIPTION_ID) REFERENCES paypal_subscription (ID) ON DELETE CASCADE,
  CONSTRAINT FK_paypal_subscription_billing_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE  
);

CREATE SEQUENCE "paygate_initial_id_seq";
CREATE TABLE paygate_initial (
  ID integer NOT NULL default nextval('paygate_initial_id_seq'),
  SPACE_ID integer NOT NULL,
  GOODS_NAME VARCHAR(255) NOT NULL,
  CARD_NUMBER VARCHAR(20) NOT NULL,
  EXPIRY_DATE timestamp NOT NULL,
  PROFILE_ID VARCHAR(64) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_initial_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "paygate_subscription_id_seq";
CREATE TABLE paygate_subscription (
  ID integer NOT NULL default nextval('paygate_subscription_id_seq'),
  PAYGATE_INITIAL_ID integer NOT NULL,
  TRANSACTION_ID varchar(64),
  STATUS int default 0 NOT NULL,
  RESULT text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_paygate_subscription_PAYGATE_INITIAL_ID FOREIGN KEY (PAYGATE_INITIAL_ID) REFERENCES paygate_initial (ID) ON DELETE CASCADE
);

CREATE TABLE paygate_subscription_billing (
  PAYGATE_SUBSCRIPTION_ID integer NOT NULL,
  BILLING_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PAYGATE_SUBSCRIPTION_ID, BILLING_ID),
  CONSTRAINT FK_paygate_subscription_billing_PAYGATE_SUBSCRIPTION_ID FOREIGN KEY (PAYGATE_SUBSCRIPTION_ID) REFERENCES paygate_subscription (ID) ON DELETE CASCADE,
  CONSTRAINT FK_paygate_subscription_billing_BILLING_ID FOREIGN KEY (BILLING_ID) REFERENCES billing (ID) ON DELETE CASCADE
);

CREATE SEQUENCE "licence_activation_log_id_seq";
CREATE TABLE licence_activation_log (
  ID bigint NOT NULL default nextval('licence_activation_log_id_seq'),
  TYPE integer NOT NULL,
  SPACE_ID integer NOT NULL default '0',
  SPACE_KEY varchar(20) NOT NULL default '',
  FROM_LICENCE_TYPE_ID integer,
  TO_LICENCE_TYPE_ID integer,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

CREATE SEQUENCE "project_theme_id_seq";
CREATE TABLE project_theme (
  ID integer NOT NULL default nextval('project_theme_id_seq'),
  PROJECT_ID integer NOT NULL,
  THEME_TYPE integer NOT NULL default '0',
  HEADER_IMAGE boolean default FALSE,
  HEADER_IMAGE_REPEAT boolean default TRUE,
  HEADER_IMAGE_ALIGN VARCHAR(7) default 0,
  HEADER_BACKGROUND_COLOR VARCHAR(7) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (PROJECT_ID),
  CONSTRAINT FK_project_theme_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_theme_PROJECT_ID" ON "project_theme" (PROJECT_ID);

CREATE SEQUENCE "login_history_id_seq";
CREATE TABLE login_history (
  ID bigint NOT NULL default nextval('login_history_id_seq'),
  LOCALE varchar(255),
  LOCAL_NAME varchar(255),
  LOCAL_ADDR varchar(255),
  LOCAL_PORT integer,
  REMOTE_HOST varchar(255),
  REMOTE_ADDR varchar(255),
  REMOTE_PORT integer,
  USER_AGENT varchar(255),
  ACCEPT_LANGUAGE varchar(255),
  ACCEPT_ENCODING varchar(255),
  ACCEPT_CHARSET varchar(255),
  CLIENT_TIMEZONE_OFFSET bigint,
  SPACE_ID bigint,
  USER_ID bigint,
  USER_USER_ID varchar(255),
  USER_LANG char(5),
  USER_TIMEZONE varchar(50),
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);

CREATE INDEX "IX_login_history_IX_USER_ID_UPDATED" ON "login_history" (USER_ID, UPDATED);
CREATE INDEX "IX_login_history_IX_UPDATED" ON "login_history" (UPDATED);

CREATE TABLE login_location (
  LOGIN_HISTORY_ID bigint NOT NULL,
  COUNTRY_CONFIDENCE integer,
  COUNTRY_GEONAME_ID varchar(255),
  COUNTRY_ISO_CODE varchar(255),
  COUNTRY_NAME varchar(255),
  CITY_CONFIDENCE integer,
  CITY_GEONAME_ID varchar(255),
  CITY_NAME varchar(255),
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (LOGIN_HISTORY_ID),
  CONSTRAINT FK_login_history_LOGIN_HISTORY_ID FOREIGN KEY (LOGIN_HISTORY_ID) REFERENCES login_history (ID) ON DELETE CASCADE
);

-- BLG-5224 プロジェクトの削除を物理削除から論理削除に変更する
CREATE SEQUENCE "job_queue_id_seq";
CREATE TABLE job_queue (
  ID bigint NOT NULL default nextval('job_queue_id_seq'),
  JOB_NAME varchar(255) NOT NULL,
  STATUS integer NOT NULL,
  STARTED timestamp default NULL,
  FINISHED timestamp default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_job_queue_JOB_NAME_STATUS_UPDATED" ON "job_queue" (JOB_NAME, STATUS, UPDATED);
CREATE INDEX "IX_job_queue_STATUS_UPDATED" ON "job_queue" (STATUS, UPDATED);

CREATE SEQUENCE "job_parameter_id_seq";
CREATE TABLE job_parameter (
  ID bigint NOT NULL default nextval('job_parameter_id_seq'),
  JOB_QUEUE_ID bigint NOT NULL,
  NAME varchar(255) NOT NULL,
  VALUE text NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_job_parameter_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_job_parameter_seq_JOB_PARAMETER_JOB_QUEUE_ID" ON "job_parameter" (JOB_QUEUE_ID);

CREATE SEQUENCE "job_blob_parameter_id_seq";
CREATE TABLE job_blob_parameter (
  ID bigint NOT NULL default nextval('job_blob_parameter_id_seq'),
  JOB_QUEUE_ID bigint NOT NULL,
  NAME varchar(255) NOT NULL,
  DATA bytea NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_job_blob_parameter_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_job_blob_parameter_JOB_BLOB_PARAMETER_JOB_QUEUE_ID" ON "job_parameter" (JOB_QUEUE_ID);

CREATE SEQUENCE "job_fail_cause_id_seq";
CREATE TABLE job_fail_cause (
  ID bigint NOT NULL default nextval('job_fail_cause_id_seq'),
  JOB_QUEUE_ID bigint NOT NULL,
  CAUSE text default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_job_fail_cause_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_job_fail_cause_JOB_FAIL_CAUSE_JOB_QUEUE_ID" ON "job_parameter" (JOB_QUEUE_ID);

--
-- メールによる課題登録ルール
--
CREATE SEQUENCE "issue_post_mail_rule_id_seq";
CREATE TABLE issue_post_mail_rule (
  ID integer NOT NULL default nextval('issue_post_mail_rule_id_seq'),
  PROJECT_ID integer NOT NULL,
  RULE_NAME varchar(30) NOT NULL, -- 設定名
  MAIL_ADDRESS varchar(255) NOT NULL,
  AUTO_SETTING_XML text NOT NULL,
  FILTERING_XML text NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (MAIL_ADDRESS),
  CONSTRAINT FK_post_issue_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_post_mail_rule_PROJECT_ID" ON "issue_post_mail_rule" (PROJECT_ID);

--
-- メールによる課題登録後のログ
--
CREATE SEQUENCE "issue_post_mail_log_id_seq";
CREATE TABLE issue_post_mail_log (
  ID integer NOT NULL default nextval('issue_post_mail_log_id_seq'),
  ERRORS text default NULL, -- エラー情報
  PROJECT_ID integer default NULL, -- プロジェクトID
  ISSUE_ID integer default NULL, -- 課題ID
  ISSUE_POST_MAIL_RULE_ID integer default NULL, -- 課題の自動設定ID
  MAIL_ADDRESS varchar(320) default NULL, -- 課題登録に使用した宛先メールアドレス
  SUBJECT text default NULL, -- メールの件名
  BODY text default NULL, -- メール本文
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_PROJECT_ID_CREATED" ON "issue_post_mail_log" (PROJECT_ID, CREATED);
CREATE INDEX "IX_CREATED" ON "issue_post_mail_log" (CREATED);

--
-- メールによる課題登録後のログ（メールのソースのみ）
--
CREATE SEQUENCE "issue_post_mail_source_id_seq";
CREATE TABLE issue_post_mail_source (
  ID integer NOT NULL default nextval('issue_post_mail_source_id_seq'),
  ISSUE_POST_MAIL_LOG_ID integer not NULL, -- メールによる課題登録ログ
  MAIL_SOURCE bytea not NULL, -- メールのソース
  CHARSET varchar(20) default NULL, -- 文字コード
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_post_mail_source_ISSUE_POST_MAIL_LOG_ID FOREIGN KEY (ISSUE_POST_MAIL_LOG_ID) REFERENCES issue_post_mail_log (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_ISSUE_POST_MAIL_LOG_ID" ON "issue_post_mail_source" (ISSUE_POST_MAIL_LOG_ID);

--
-- BLG-5332 Integrate Nulab Account (Single Sign-On)
--
CREATE SEQUENCE "nulab_account_id_seq";
CREATE TABLE nulab_account (
  ID integer NOT NULL default nextval('nulab_account_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  USER_ID integer NOT NULL,
  SYNCHRONIZE boolean default FALSE,
  NULAB_ID varchar(255) NOT NULL,
  INVITATION_NULAB_ID varchar(255) default NULL,
  UNIQUE_ID varchar(255),
  MAIL_ADDRESS varchar(320),
  NAME varchar(255),
  ROLE varchar(15) default NULL,
  USE_MFA boolean default NULL,
  ACCEPTED_INVITATION boolean NOT NULL DEFAULT TRUE,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (USER_ID),
  UNIQUE (INVITATION_NULAB_ID),
  CONSTRAINT FK_nulab_account_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE,
  CONSTRAINT FK_nulab_account_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_nulab_account_NULAB_ID" ON "nulab_account" (NULAB_ID);
CREATE INDEX "IX_nulab_account_NULAB_ACCOUNT_SPACE_ID_NULAB_ID" ON "nulab_account" (SPACE_ID, NULAB_ID);

CREATE TABLE user_original_data (
  USER_ID integer NOT NULL,
  MAIL_ADDRESS varchar(320) NOT NULL default '',
  NAME varchar(100) NOT NULL default '',
  ICON varchar(50) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  CONSTRAINT FK_user_original_data_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);

CREATE TABLE user_icon (
  USER_ID integer NOT NULL,
  DIRECTORY VARCHAR(255) NOT NULL,
  FILE_NAME VARCHAR(255) NOT NULL,
  WIDTH INTEGER default 0,
  HEIGHT INTEGER default 0,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (USER_ID),
  CONSTRAINT FK_user_icon_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);

--
-- Client Registration
--
CREATE TABLE oauth2_client (
  CLIENT_ID varchar(32) NOT NULL default '',
  NAME varchar(64) NOT NULL default '',
  DESCRIPTION varchar(255) NOT NULL default '',
  CLIENT_TYPE integer default 0,
  CLIENT_SECRET varchar(64) NOT NULL default '',
  GRANT_TYPE varchar(255) NOT NULL default '',
  REDIRECT_URI varchar(255) NOT NULL default '',
  DEFAULT_LANG VARCHAR(32)  NOT NULL DEFAULT '',
  ICON_URL VARCHAR(255) NOT NULL DEFAULT '',
  DISABLED boolean NOT NULL default FALSE,
  SITE_URL varchar(255) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (CLIENT_ID)
);
CREATE INDEX "IX_nulab_account_CREATED_USER_ID" ON "oauth2_client" (CREATED_USER_ID);

--
-- Client Description
--
CREATE SEQUENCE "oauth2_client_description_id_seq";
CREATE TABLE oauth2_client_description (
  ID integer NOT NULL default nextval('oauth2_client_description_id_seq'),
  CLIENT_ID VARCHAR(32) NOT NULL DEFAULT '',
  LANG VARCHAR(32) NOT NULL DEFAULT '',
  NAME VARCHAR(64) NOT NULL DEFAULT '',
  DESCRIPTION VARCHAR(1000) NOT NULL DEFAULT '',
  SITE_URI VARCHAR(255) NOT NULL DEFAULT '',
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (CLIENT_ID, LANG),
  CONSTRAINT FK_oauth2_client_description_CLIENT_ID FOREIGN KEY (CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
);
CREATE INDEX "IX_oauth2_client_description_CLIENT_ID" ON "oauth2_client_description" (CLIENT_ID);

--
-- Authorization Code Grant
-- 基本的に Backlog アプリ側から登録するデータ
--
CREATE TABLE oauth2_authorization_code (
  ID varchar(64) NOT NULL default '',
  CODE varchar(64) NOT NULL default '',
  USER_ID integer NOT NULL,
  OAUTH2_CLIENT_ID varchar(32) NOT NULL default '',
  STATE varchar(500) default NULL,
  REDIRECT_URI varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (CODE),
  CONSTRAINT FK_oauth2_authorization_code_OAUTH2_CLIENT_ID FOREIGN KEY (OAUTH2_CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
);
CREATE INDEX "IX_oauth2_authorization_code_CREATED_USER_ID" ON "oauth2_authorization_code" (USER_ID,OAUTH2_CLIENT_ID);

--
-- Access Token
--
CREATE TABLE oauth2_access_token (
  USER_ID integer NOT NULL,
  OAUTH2_CLIENT_ID varchar(32) NOT NULL default '',
  ACCESS_TOKEN varchar(64) NOT NULL default '',
  REFRESH_TOKEN varchar(64) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (USER_ID, OAUTH2_CLIENT_ID),
  UNIQUE (ACCESS_TOKEN),
  UNIQUE (REFRESH_TOKEN),
  CONSTRAINT FK_oauth2_access_token_OAUTH2_CLIENT_ID FOREIGN KEY (OAUTH2_CLIENT_ID) REFERENCES oauth2_client (CLIENT_ID) ON DELETE CASCADE
);
CREATE INDEX "IX_USER_ID" ON "oauth2_access_token" (USER_ID);

--
-- 課題キー カウントアップ
--
CREATE TABLE max_issue_identity (
  PROJECT_ID integer NOT NULL,
  MAX_KEY_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID),
  CONSTRAINT FK_max_issue_identity_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);


--
-- 一時添付ファイル
--
CREATE SEQUENCE "temporary_attachment_id_seq";
CREATE TABLE temporary_attachment (
  ID integer NOT NULL default nextval('temporary_attachment_id_seq'),
  NAME varchar(100) NOT NULL default '',
  SIZE integer NOT NULL default '0',
  CONTENT bytea,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_temporary_attachment_CREATED_USER_ID" ON "temporary_attachment" (CREATED_USER_ID);

--
-- API キー
--
CREATE TABLE api_key (
  API_KEY varchar(64) NOT NULL default '',
  USER_ID integer NOT NULL,
  SCOPE integer NOT NULL default '0',
  MEMO varchar(255) NOT NULL default '',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (API_KEY),
  CONSTRAINT FK_api_key_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_api_key_CREATED_USER_ID" ON "api_key" (CREATED_USER_ID);

--
-- 課題のカテゴリー毎のサマリー
--
CREATE SEQUENCE "issue_component_summary_id_seq";
CREATE TABLE issue_component_summary (
  ID integer NOT NULL default nextval('issue_component_summary_id_seq'),
  PROJECT_ID integer NOT NULL,
  COMPONENT_ID integer DEFAULT NULL,
  STATUS_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_component_summary_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_component_summary_COMPONENT_ID FOREIGN KEY (COMPONENT_ID) REFERENCES component (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_component_summary_PROJECT_ID" ON "issue_component_summary" (PROJECT_ID);
CREATE INDEX "IX_issue_component_summary_COMPONENT_ID" ON "issue_component_summary" (COMPONENT_ID);
CREATE INDEX "IX_issue_component_summary_PROJECT_ID_COMPONENT_ID_STATUS_ID" ON "issue_component_summary" (PROJECT_ID, COMPONENT_ID, STATUS_ID);

--
-- 課題のマイルストーン毎のサマリー
--
CREATE SEQUENCE "issue_fixed_version_summary_id_seq";
CREATE TABLE issue_fixed_version_summary (
  ID integer NOT NULL default nextval('issue_fixed_version_summary_id_seq'),
  PROJECT_ID integer NOT NULL,
  VERSION_ID integer DEFAULT NULL,
  STATUS_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_issue_fixed_version_summary_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_issue_fixed_version_summary_VERSION_ID FOREIGN KEY (VERSION_ID) REFERENCES version (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_issue_fixed_version_summary_PROJECT_ID" ON "issue_fixed_version_summary" (PROJECT_ID);
CREATE INDEX "IX_issue_fixed_version_summary_VERSION_ID" ON "issue_fixed_version_summary" (VERSION_ID);
CREATE INDEX "IX_issue_fixed_version_summary_PROJECT_ID_VERSION_ID_STATUS_ID" ON "issue_fixed_version_summary" (PROJECT_ID, VERSION_ID, STATUS_ID);

--
-- BLG-6050 Copy a short link for Find Issue
--
CREATE SEQUENCE "project_short_url_id_seq";
CREATE TABLE project_short_url (
  ID integer NOT NULL default nextval('project_short_url_id_seq'),
  PROJECT_ID integer NOT NULL,
  SHORT_URL_KEY varchar(20) NOT NULL,
  URL text NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (SHORT_URL_KEY),
  CONSTRAINT FK_project_short_url_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

CREATE INDEX "IX_KEY" ON "project_short_url" (SHORT_URL_KEY);
CREATE INDEX "IX_PROJECT_ID_URL" ON "project_short_url" (PROJECT_ID, URL);

--
-- Webhook
--
CREATE SEQUENCE "webhook_id_seq";
CREATE TABLE webhook (
  ID integer NOT NULL default nextval('webhook_id_seq'),
  PROJECT_ID integer NOT NULL default '0',
  NAME varchar(255) NOT NULL default '',
  DESCRIPTION varchar(255) NOT NULL default '',
  HOOK_URL text NOT NULL,
  ALL_EVENT boolean NOT NULL default FALSE,
  EVENTS varchar(255) NOT NULL default '',
  DISPLAY_ORDER integer NOT NULL default '0',
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_webhook_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_webhook_PROJECT_ID" ON "webhook" (PROJECT_ID);

--
-- マイレポートのBacklogTips
--
CREATE SEQUENCE "myreport_message_id_seq";
CREATE TABLE myreport_message (
  ID integer NOT NULL default nextval('myreport_message_id_seq'),
  ICON varchar(255) NOT NULL default '',
  LANG varchar(5) NOT NULL default '',
  COMMENT text NOT NULL,
  PAGE_NAME text,
  PAGE_URL text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
CREATE INDEX "IX_myreport_message_LANG" ON "myreport_message" (LANG);

CREATE SEQUENCE "webhook_execution_history_id_seq";
CREATE TABLE webhook_execution_history (
  ID bigint NOT NULL default nextval('webhook_execution_history_id_seq'),
  JOB_QUEUE_ID bigint NOT NULL,
  PROJECT_ID integer NOT NULL default '0',
  WEBHOOK_ID integer default NULL,
  NAME varchar(255) NOT NULL default '',
  HOOK_URL text NOT NULL,
  EVENT integer NOT NULL default '0',
  CONTENT text default NULL,
  STATUS_CODE integer default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  CONSTRAINT FK_webhook_execution_history_JOB_QUEUE_ID FOREIGN KEY (JOB_QUEUE_ID) REFERENCES job_queue (ID) ON DELETE CASCADE,
  CONSTRAINT FK_webhook_execution_history_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_webhook_execution_history_PROJECT_ID" ON "webhook_execution_history" (PROJECT_ID);

--
-- BLG-6902 project_activity テーブルの古いデータアーカイブ化の仕組みを各環境に展開する
--
CREATE TABLE archived_project_activity (
  ID bigint NOT NULL,
  PROJECT_ID integer NOT NULL default '0',
  TYPE integer NOT NULL,
  CONTENT_JSON text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  ARCHIVE_CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID)
);
-- インデックス名が長すぎるので区切る
CREATE INDEX "IX_archived_project_activity_PROJECT_ID_CREATED_TYPE_CREATED_US" ON "archived_project_activity" (PROJECT_ID, CREATED DESC, TYPE, CREATED_USER_ID);

CREATE SEQUENCE "project_activity_stat_id_seq";
CREATE TABLE project_activity_stat (
  ID integer NOT NULL default nextval('project_activity_stat_id_seq'),
  SPACE_ID integer NOT NULL default '0',
  TOTAL integer NOT NULL default '0',
  NOTIFY_COUNT integer NOT NULL default '0',
  LAST_ARCHIVED timestamp,
  LAST_ARCHIVED_RATIO integer,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (SPACE_ID),
  CONSTRAINT FK_project_activity_stat_SPACE_ID FOREIGN KEY (SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

--
-- PullRequest
--
CREATE SEQUENCE "pull_request_id_seq";
CREATE TABLE pull_request (
  ID integer NOT NULL default nextval('pull_request_id_seq'),
  PROJECT_ID integer NOT NULL default '0',
  REPOSITORY_ID integer NOT NULL default '0',
  NUMBER integer NOT NULL default '0',
  SUMMARY varchar(255) NOT NULL default '',
  DESCRIPTION text NOT NULL ,
  BASE varchar(1000) NOT NULL,
  BRANCH varchar(1000) NOT NULL,
  STATUS_ID integer NOT NULL,
  ASSIGNER_ID integer default NULL,
  ISSUE_ID integer default NULL,
  MERGE_COMMIT varchar(255) default NULL,
  BASE_COMMIT varchar(255) default NULL,
  BRANCH_COMMIT varchar(255) default NULL,
  CLOSED_AT timestamp default NULL,
  MERGED_AT timestamp default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (REPOSITORY_ID, NUMBER),
  CONSTRAINT FK_pull_request_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_pull_request_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE,
  CONSTRAINT FK_pull_request_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE SET NULL
);
CREATE INDEX "IX_pull_request_PROJECT_ID" ON "pull_request" (PROJECT_ID);
CREATE INDEX "IX_pull_request_REPOSITORY_ID" ON "pull_request" (REPOSITORY_ID);
CREATE INDEX "IX_pull_request_STATUS_ID" ON "pull_request" (STATUS_ID);
CREATE INDEX "IX_pull_request_ISSUE_ID" ON "pull_request" (ISSUE_ID);
CREATE INDEX "IX_pull_request_ASSIGNER_ID" ON "pull_request" (ASSIGNER_ID);

--
-- 課題キー カウントアップ
--
CREATE TABLE max_pull_request_number (
  REPOSITORY_ID integer NOT NULL,
  MAX_NUMBER integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (REPOSITORY_ID),
  CONSTRAINT FK_max_pull_request_number_REPOSITORY_ID FOREIGN KEY (REPOSITORY_ID) REFERENCES repository (ID) ON DELETE CASCADE
);

--
-- PullRequest comment
--
CREATE SEQUENCE "pull_request_comment_id_seq";
CREATE TABLE pull_request_comment (
  ID integer NOT NULL default nextval('pull_request_comment_id_seq'),
  PULL_REQUEST_ID integer NOT NULL,
  OLD_BLOB_ID varchar(255) default NULL,
  NEW_BLOB_ID varchar(255) default NULL,
  FILE_PATH text default NULL,
  POSITION integer default NULL,
  CONTENT text NOT NULL,
  CHANGELOG text,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_pull_request_PULL_REQUEST_ID FOREIGN KEY (PULL_REQUEST_ID) REFERENCES pull_request (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_pull_request_comment_PULL_REQUEST_ID" ON "pull_request_comment" (PULL_REQUEST_ID);
CREATE INDEX "IX_pull_request_comment_CREATED" ON "pull_request_comment" (CREATED);

--
-- Watch list
--
CREATE SEQUENCE "user_watch_id_seq";
CREATE TABLE user_watch (
  ID integer NOT NULL default nextval('user_watch_id_seq'),
  USER_ID integer NOT NULL,
  PROJECT_ID integer NOT NULL,
  TYPE integer NOT NULL,
  ISSUE_ID integer default NULL,
  LAST_NOTICE_CHECKED_TIME timestamp default NULL,
  LAST_CHECKED_TIME timestamp NOT NULL default CURRENT_TIMESTAMP,
  NOTE varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (ID),
  UNIQUE (USER_ID,TYPE,ISSUE_ID),
  CONSTRAINT FK_user_watch_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT FK_user_watch_ISSUE_ID FOREIGN KEY (ISSUE_ID) REFERENCES issue (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_user_watch_USER_ID_PROJECT_ID" ON "user_watch" (USER_ID,PROJECT_ID);
CREATE INDEX "IX_user_watch_USER_ID" ON "user_watch" (USER_ID);
CREATE INDEX "IX_user_watch_PROJECT_ID" ON "user_watch" (PROJECT_ID);
CREATE INDEX "IX_user_watch_ISSUE_ID" ON "user_watch" (ISSUE_ID);

--
-- Project setting
--
CREATE TABLE project_setting (
  PROJECT_ID integer NOT NULL,
  PROJECT_LEADER_CAN_EDIT_PROJECT_LEADER boolean NOT NULL,
  USE_WIKI_TREE_VIEW boolean NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY (PROJECT_ID),
  CONSTRAINT FK_project_setting_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE
);

--
-- プルリクエスト添付ファイル
--
CREATE SEQUENCE "pull_request_attachment_id_seq";
CREATE TABLE pull_request_attachment (
  ID integer NOT NULL default nextval('pull_request_attachment_id_seq'),
  PULL_REQUEST_ID integer NOT NULL default '0',
  NAME varchar(100) NOT NULL default '',
  SIZE integer NOT NULL default '0',
  PATH varchar(255) default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_pull_request_attachment_PULL_REQUEST_ID FOREIGN KEY (PULL_REQUEST_ID) REFERENCES pull_request (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_pull_request_attachment_PULL_REQUEST_ID" ON "pull_request_attachment" (PULL_REQUEST_ID);

--
-- プロジェクトに参加しているグループ
--
CREATE TABLE project_party (
  PROJECT_ID integer NOT NULL,
  PARTY_ID integer NOT NULL,
  PROJECT_LEADER  boolean default NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (PROJECT_ID,PARTY_ID),
  CONSTRAINT project_party_PROJECT_ID FOREIGN KEY (PROJECT_ID) REFERENCES project (ID) ON DELETE CASCADE,
  CONSTRAINT project_party_PARTY_ID FOREIGN KEY (PARTY_ID) REFERENCES party (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_project_party_PARTY_ID" ON "project_party" (PARTY_ID);
CREATE INDEX "IX_project_party_PROJECT_ID" ON "project_party" (PROJECT_ID);

--
-- スタンプ
--
CREATE SEQUENCE "stamp_id_seq";
CREATE TABLE stamp (
  ID integer NOT NULL default nextval('stamp_id_seq'),
  PROJECT_ID integer,
  URL VARCHAR(255) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID)
);
CREATE INDEX "IX_stamp_PROJECT_ID" ON "stamp" (PROJECT_ID);

CREATE SEQUENCE "information_read_user_id_seq";
CREATE TABLE information_read_user (
  ID integer NOT NULL default nextval('information_read_user_id_seq'),
  INFORMATION_ID integer NOT NULL,
  USER_ID integer NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  CONSTRAINT FK_information_user_INFORMATION_ID FOREIGN KEY (INFORMATION_ID) REFERENCES information (ID) ON DELETE CASCADE,
  CONSTRAINT FK_information_user_USER_ID FOREIGN KEY (USER_ID) REFERENCES users (ID) ON DELETE CASCADE
);
CREATE INDEX "IX_information_read_user_INFORMATION_ID" ON "information_read_user" (INFORMATION_ID);
CREATE INDEX "IX_information_read_user_USER_ID" ON "information_read_user" (USER_ID);

CREATE SEQUENCE "nulab_apps_space_id_seq";
CREATE TABLE nulab_apps_space (
  ID integer NOT NULL default nextval('nulab_apps_space_id_seq'),
  BACKLOG_SPACE_ID integer NOT NULL default 0,
  SPACE_KEY varchar(50) NOT NULL,
  NAME VARCHAR(100) NOT NULL,
  CREATED_USER_ID integer default NULL,
  CREATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  UPDATED_USER_ID integer default NULL,
  UPDATED timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (ID),
  UNIQUE (SPACE_KEY),
  CONSTRAINT FK_nulab_apps_space_BACKLOG_SPACE_ID FOREIGN KEY (BACKLOG_SPACE_ID) REFERENCES space (ID) ON DELETE CASCADE
);

BEGIN;

--
-- Dumping data for table `issue_type`
--
INSERT INTO default_issue_type VALUES (1,'ja','バグ',1,'#990000',NULL,'2005-04-19 03:23:59',NULL,'2005-04-18 17:31:06');
INSERT INTO default_issue_type VALUES (2,'ja','タスク',0,'#7ea800',NULL,'2005-05-15 00:47:12',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (3,'ja','要望',2,'#ff9200',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (4,'ja','その他',3,'#2779ca',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (5,'en','Bug',1,'#990000',NULL,'2005-04-19 03:23:59',NULL,'2005-04-18 17:31:06');
INSERT INTO default_issue_type VALUES (6,'en','Task',0,'#7ea800',NULL,'2005-05-15 00:47:12',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (7,'en','Request',2,'#ff9200',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (8,'en','Other',3,'#2779ca',NULL,'2005-05-15 00:49:53',NULL,'2007-09-24 15:31:31');
INSERT INTO default_issue_type VALUES (9,'zh_tw','Bug',1,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (10,'zh_tw','任務',0,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (11,'zh_tw','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (12,'zh_tw','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (13,'zh_cn','Bug',1,'#990000',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (14,'zh_cn','任务',0,'#7ea800',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (15,'zh_cn','要求',2,'#ff9200',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (16,'zh_cn','其他',3,'#2779ca',NULL,'2012-12-10 00:00:00',NULL,'2012-12-10 00:00:00');
INSERT INTO default_issue_type VALUES (17,'ko','버그',1,'#990000',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');
INSERT INTO default_issue_type VALUES (18,'ko','태스크',0,'#7ea800',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');
INSERT INTO default_issue_type VALUES (19,'ko','요망',2,'#ff9200',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');
INSERT INTO default_issue_type VALUES (20,'ko','그 외',3,'#2779ca',NULL,'2013-04-17 00:00:00',NULL,'2013-04-17 00:00:00');
INSERT INTO default_issue_type VALUES (21,'vi','Lỗi',1,'#990000',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');
INSERT INTO default_issue_type VALUES (22,'vi','Công việc',0,'#7ea800',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');
INSERT INTO default_issue_type VALUES (23,'vi','Yêu cầu',2,'#ff9200',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');
INSERT INTO default_issue_type VALUES (24,'vi','Ngoài ra',3,'#2779ca',NULL,'2014-04-24 00:00:00',NULL,'2014-04-24 00:00:00');

--
-- Dumping data for table `licence_type`
--

INSERT INTO licence_type VALUES (1,  '旧無料版',3,50,20,20,300,100,5242880,5242880,1,FALSE,0,FALSE,1048576,0,FALSE,FALSE,FALSE,TRUE,5242880,1,0,FALSE,FALSE,FALSE,TRUE,TRUE,TRUE,TRUE,FALSE,0,0,0,FALSE,NULL,FALSE,NULL,'2006-06-19 23:40:54',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (10, '旧フリー',1,10,0,0,0,0,20971520,5242880,1,FALSE,0,FALSE,1048576,0,FALSE,FALSE,FALSE,TRUE,5242880,1,0,FALSE,FALSE,FALSE,TRUE,TRUE,TRUE,TRUE,FALSE,0,0,0,FALSE,NULL,FALSE,NULL,'2006-06-19 23:41:49',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (20, '旧ベーシック',5,30,0,0,0,0,0,10485760,10,FALSE,0,TRUE,1048576,10,TRUE,TRUE,FALSE,TRUE,10485760,10,52428800,FALSE,FALSE,TRUE,TRUE,TRUE,TRUE,TRUE,FALSE,0,3000,2000,FALSE,NULL,FALSE,NULL,'2006-06-19 23:41:49',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (30, '旧プラス',30,0,0,0,0,0,0,10485760,20,TRUE,5,TRUE,1048576,20,TRUE,TRUE,FALSE,TRUE,10485760,20,104857600,FALSE,FALSE,TRUE,TRUE,TRUE,TRUE,TRUE,FALSE,0,6000,4800,FALSE,NULL,FALSE,NULL,'2006-06-19 23:41:49',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (40, '旧プレミアム',0,0,0,0,0,0,0,10485760,30,TRUE,5,TRUE,10485760,30,TRUE,TRUE,TRUE,TRUE,10485760,30,1073741824,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,FALSE,0,6000,9800,FALSE,NULL,FALSE,NULL,'2006-06-19 23:41:50',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (50, '旧マックス5',0,0,0,0,0,0,0,10485760,50,TRUE,5,TRUE,10485760,50,TRUE,TRUE,TRUE,TRUE,10485760,50,5368709120,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,20,6000,16800,FALSE,NULL,FALSE,NULL,'2007-09-25 00:31:31',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (60, '旧マックス25',0,0,0,0,0,0,0,10485760,50,TRUE,5,TRUE,10485760,50,TRUE,TRUE,TRUE,TRUE,10485760,50,26843545600,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,20,6000,29400,FALSE,NULL,FALSE,NULL,'2007-09-25 00:31:31',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (70, '旧マックス50',0,0,0,0,0,0,0,10485760,50,TRUE,5,TRUE,10485760,50,TRUE,TRUE,TRUE,TRUE,10485760,50,53687091200,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,20,6000,49350,FALSE,NULL,FALSE,NULL,'2007-09-25 00:31:31',NULL,'2007-09-24 15:31:31');
INSERT INTO licence_type VALUES (11, 'フリー',1,10,0,0,0,0,20971520,5242880,1,FALSE,0,FALSE,104857600,0,FALSE,FALSE,FALSE,TRUE,5242880,1,0,FALSE,FALSE,FALSE,TRUE,TRUE,TRUE,TRUE,FALSE,0,0,0,TRUE,NULL,FALSE,NULL,CURRENT_TIMESTAMP,NULL,CURRENT_TIMESTAMP);
INSERT INTO licence_type VALUES (21, 'スターター',5,30,0,0,0,0,0,10485760,10,FALSE,0,TRUE,1048576,10,TRUE,TRUE,FALSE,TRUE,10485760,10,1073741824,FALSE,FALSE,TRUE,TRUE,TRUE,TRUE,TRUE,FALSE,0,0,2000,TRUE,NULL,FALSE,NULL,CURRENT_TIMESTAMP,NULL,CURRENT_TIMESTAMP);
INSERT INTO licence_type VALUES (41, 'スタンダード',0,0,0,0,0,0,0,10485760,30,TRUE,5,TRUE,10485760,30,TRUE,TRUE,TRUE,TRUE,10485760,30,32212254720,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,FALSE,0,0,9800,TRUE,NULL,FALSE,NULL,CURRENT_TIMESTAMP,NULL,CURRENT_TIMESTAMP);
INSERT INTO licence_type VALUES (51, 'プレミアム',0,0,0,0,0,0,0,10485760,50,TRUE,5,TRUE,10485760,50,TRUE,TRUE,TRUE,TRUE,10485760,50,107374182400,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,20,0,16800,TRUE,NULL,FALSE,NULL,CURRENT_TIMESTAMP,NULL,CURRENT_TIMESTAMP);
INSERT INTO licence_type VALUES (81, 'プラチナ',0,0,0,0,0,0,0,10485760,50,TRUE,5000,TRUE,10485760,50,TRUE,TRUE,TRUE,TRUE,10485760,50,322122547200,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,TRUE,20,0,50000,TRUE,NULL,FALSE,NULL,CURRENT_TIMESTAMP,NULL,CURRENT_TIMESTAMP);
INSERT INTO licence_type VALUES (100,'パッケージライセンス',0,0,0,0,0,0,0,10485760,0,TRUE,65535,TRUE,10485760,0,FALSE,FALSE,FALSE,FALSE,10485760,0,0,TRUE,TRUE,TRUE,FALSE,FALSE,TRUE,TRUE,TRUE,100,0,0,FALSE,NULL,FALSE,NULL,'2006-06-19 23:41:50',NULL,'2007-02-28 01:34:18');

--
-- Dumping data for table `status`
--
INSERT INTO "status" VALUES (0,'新規作成',0,NULL,'2005-04-19 03:14:58',NULL,'2005-04-18 17:30:36');
INSERT INTO "status" VALUES (1,'未対応',1,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19');
INSERT INTO "status" VALUES (2,'処理中',2,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19');
INSERT INTO "status" VALUES (3,'処理済み',3,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19');
INSERT INTO "status" VALUES (4,'完了',4,0,'2005-04-19 03:14:58',0,'2004-11-21 10:01:19');

--
-- holiday
--
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-01-01', '元日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-01-11', '成人の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-02-11', '建国記念の日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-03-21', '春分の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-03-22', '振替休日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-04-29', '昭和の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-05-03', '憲法記念日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-05-04', 'みどりの日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-05-05', 'こどもの日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-07-19', '海の日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-09-20', '敬老の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-09-23', '秋分の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-10-11', '体育の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-11-03', '文化の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-11-23', '勤労感謝の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2010-12-23', '天皇誕生日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-01-01', '元日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-01-10', '成人の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-02-11', '建国記念の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-03-21', '春分の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-04-29', '昭和の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-05-03', '憲法記念日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-05-04', 'みどりの日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-05-05', 'こどもの日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-07-18', '海の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-09-19', '敬老の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-09-23', '秋分の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-10-10', '体育の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-11-03', '文化の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-11-23', '勤労感謝の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2011-12-23', '天皇誕生日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-01-01', '元日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-01-02', '振替休日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-01-09', '成人の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-02-11', '建国記念の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-03-20', '春分の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-04-29', '昭和の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-04-30', '振替休日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-05-03', '憲法記念日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-05-04', 'みどりの日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-05-05', 'こどもの日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-07-16', '海の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-09-17', '敬老の日', '2009-04-07', '2009-04-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-09-22', '秋分の日', '2009-04-08', '2009-04-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-10-08', '体育の日', '2009-04-09', '2009-04-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-11-03', '文化の日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-11-23', '勤労感謝の日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-12-23', '天皇誕生日', '2009-04-11', '2009-04-11');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2012-12-24', '振替休日', '2009-04-12', '2009-04-12');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-01', '元日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-01-14', '成人の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-02-11', '建国記念の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-03-20', '春分の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-04-29', '昭和の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-03', '憲法記念日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-04', 'みどりの日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-05', 'こどもの日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-05-06', '振替休日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-07-15', '海の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-16', '敬老の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-09-23', '秋分の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-10-14', '体育の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-03', '文化の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-04', '振替休日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-11-23', '勤労感謝の日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2013-12-23', '天皇誕生日', '2012-08-04', '2012-08-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-01', '元日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-01-13', '成人の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-02-11', '建国記念の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-03-21', '春分の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-04-29', '昭和の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-03', '憲法記念日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-04', 'みどりの日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-05', 'こどもの日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-05-06', '振替休日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-07-21', '海の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-15', '敬老の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-09-23', '秋分の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-10-13', '体育の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-03', '文化の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-23', '勤労感謝の日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-11-24', '振替休日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2014-12-23', '天皇誕生日', '2013-08-20', '2013-08-20');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-01', '元日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-01-12', '成人の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-02-11', '建国記念の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-03-21', '春分の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-04-29', '昭和の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-03', '憲法記念日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-04', 'みどりの日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-05', 'こどもの日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-05-06', '振替休日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-07-20', '海の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-21', '敬老の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-22', '振替休日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-09-23', '秋分の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-10-12', '体育の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-03', '文化の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-11-23', '勤労感謝の日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2015-12-23', '天皇誕生日', '2014-08-07', '2014-08-07');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-01-01', '元日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-01-11', '成人の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-02-11', '建国記念の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-03-20', '春分の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-03-21', '振替休日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-04-29', '昭和の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-03', '憲法記念日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-04', 'みどりの日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-05-05', 'こどもの日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-07-18', '海の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-08-11', '山の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-09-19', '敬老の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-09-22', '秋分の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-10-10', '体育の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-11-03', '文化の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-11-23', '勤労感謝の日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2016-12-23', '天皇誕生日', '2015-09-04', '2015-09-04');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-01-01', '元日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-01-02', '振替休日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-01-09', '成人の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-02-11', '建国記念の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-03-20', '春分の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-04-29', '昭和の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-05-03', '憲法記念日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-05-04', 'みどりの日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-05-05', 'こどもの日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-07-17', '海の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-08-11', '山の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-09-18', '敬老の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-09-23', '秋分の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-10-09', '体育の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-11-03', '文化の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-11-23', '勤労感謝の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2017-12-23', '天皇誕生日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-01-01', '元日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-01-08', '成人の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-02-11', '建国記念の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-02-12', '振替休日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-03-21', '春分の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-04-29', '昭和の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-04-30', '振替休日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-05-03', '憲法記念日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-05-04', 'みどりの日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-05-05', 'こどもの日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-07-16', '海の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-08-11', '山の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-09-17', '敬老の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-09-23', '秋分の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-09-24', '振替休日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-10-08', '体育の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-11-03', '文化の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-11-23', '勤労感謝の日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-12-23', '天皇誕生日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2018-12-24', '振替休日', '2016-12-01', '2016-12-01');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-01-01', '元日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-01-14', '成人の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-02-11', '建国記念の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-03-21', '春分の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-04-29', '昭和の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-03', '憲法記念日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-04', 'みどりの日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-05', 'こどもの日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-06', '振替休日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-07-15', '海の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-08-11', '山の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-08-12', '振替休日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-09-16', '敬老の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-09-23', '秋分の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-10-14', '体育の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-11-03', '文化の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-11-04', '振替休日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-11-23', '勤労感謝の日', '2018-10-29', '2018-10-29');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-04-30', '国民の休日', '2019-01-22', '2019-01-22');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-01', '天皇の即位の日', '2019-01-22', '2019-01-22');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-05-02', '国民の休日', '2019-01-22', '2019-01-22');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2019-10-22', '即位礼正殿の儀の行われる日', '2019-01-22', '2019-01-22');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-01-01', '元日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-01-13', '成人の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-02-11', '建国記念の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-02-23', '天皇誕生日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-02-24', '休日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-03-20', '春分の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-04-29', '昭和の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-03', '憲法記念日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-04', 'みどりの日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-05', 'こどもの日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-05-06', '休日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-07-23', '海の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-07-24', 'スポーツの日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-08-10', '山の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-09-21', '敬老の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-09-22', '秋分の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-11-03', '文化の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2020-11-23', '勤労感謝の日', '2019-09-03', '2019-09-03');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-01-01', '元日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-01-11', '成人の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-02-11', '建国記念の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-02-23', '天皇誕生日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-03-20', '春分の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-04-29', '昭和の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-05-03', '憲法記念日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-05-04', 'みどりの日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-05-05', 'こどもの日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-07-22', '海の日', '2020-12-15', '2020-12-15');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-07-23', 'スポーツの日', '2020-12-15', '2020-12-15');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-08-08', '山の日', '2020-12-15', '2020-12-15');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-08-09', '振替休日', '2020-12-15', '2020-12-15');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-09-20', '敬老の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-09-23', '秋分の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-11-03', '文化の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2021-11-23', '勤労感謝の日', '2020-09-09', '2020-09-09');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-01-01', '元日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-01-10', '成人の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-02-11', '建国記念の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-02-23', '天皇誕生日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-03-21', '春分の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-04-29', '昭和の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-05-03', '憲法記念日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-05-04', 'みどりの日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-05-05', 'こどもの日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-07-18', '海の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-08-11', '山の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-09-19', '敬老の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-09-23', '秋分の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-10-10', 'スポーツの日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-11-03', '文化の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2022-11-23', '勤労感謝の日', '2021-07-08', '2021-07-08');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-01-01', '元日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-01-02', '振替休日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-01-09', '成人の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-02-11', '建国記念の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-02-23', '天皇誕生日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-03-21', '春分の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-04-29', '昭和の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-05-03', '憲法記念日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-05-04', 'みどりの日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-05-05', 'こどもの日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-07-17', '海の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-08-11', '山の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-09-18', '敬老の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-09-23', '秋分の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-10-09', 'スポーツの日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-11-03', '文化の日', '2022-02-14', '2022-02-14');
INSERT INTO holiday (DATE, NAME, CREATED, UPDATED) VALUES ('2023-11-23', '勤労感謝の日', '2022-02-14', '2022-02-14');

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'タスクは適切な粒度で。大きすぎるタスクがあるときは、適度なサイズに分割するといいと思うよ。', '親子課題について', 'http://www.backlog.jp/kr/help/usersguide/subtasking/userguide1722.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '目標の日が決まっているときはマイルストーンを使うと便利だよ。', '発生バージョン/マイルストーン', 'http://www.backlog.jp/help/usersguide/version-milestone/userguide106.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ja', 'GitとかSubversionのコミットで課題の状態を更新できるとよ。', 'Backlog 小技集： Gitのコミットから課題の状態を更新する', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-5/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '管理者はプロジェクト毎に設定することもできるんだよ。', 'Backlog 小技集： プロジェクト毎に管理者を設定する', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-4/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'プロジェクト全体を把握したいときはガントチャートが便利だよ。', 'Backlogビデオチュートリアル「ガントチャート編」', 'https://www.youtube.com/watch?v=qPuOiN4cbK8', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'よく使う検索条件は保存しておくと時間短縮になるよ！', '検索条件の保存', 'http://www.backlog.jp/help/usersguide/search-issue/userguide1440.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ja', '受信メールが多すぎる場合、自分が受け取りたいメールだけを受信できるよう設定し直すことをオススメします。', 'Backlogがバージョンアップ、メール受信設定に機能が追加されました。', 'https://nulab-inc.com/ja/blog/backlog/new-mail-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '複数の課題をまとめて、状態変更したり担当者を替えたりできるんだよ。', 'Backlog 小技集：自分の課題をまとめて操作', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '「あの人にこのコメントを読んでほしい...」という時は「お知らせ」しておこう！', 'お知らせ機能の概要', 'http://www.backlog.jp/help/usersguide/notification/userguide1453.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'Wiki の見出しを元に自動的に目次を作ってくれるって知ってた？', 'Backlog記法の目次', 'http://www.backlog.jp/help/usersguide/rule-to-formatting-texts/userguide205.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '検索後の課題一覧を誰かに送りたいときは短いURLを送ったほうがスマートだよ！', 'Backlog 小技集： 短いURL', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'バーンダウンチャートでは、ざっくりとしたプロジェクトの進行状況が見れるんだよ。', 'バーンダウンチャートの概要', 'http://www.backlog.jp/help/usersguide/burn-down-chart/userguide289.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'このコメントのここがナイスアイデア！と思ったらその部分を選択してスターをつけるといいよ。', 'スターを付ける', 'http://www.backlog.jp/help/usersguide/star/userguide456.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '出先でプロジェクトの状況が気になったら、iPhone版のBacklogを見ればいいよ。', 'Backlog for iPhone の機能', 'http://www.backlog.jp/help/usersguide/mobile/userguide2354.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'あの人最近何やってるのかな...？と気になったらプロフィールで確認だ！', 'プロフィールの”最近の活動”', 'http://www.backlog.jp/help/usersguide/member/userguide1016.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ja', 'Gitでファイルをバージョン管理するとよかよ。', 'サルでもわかるGit入門', 'http://www.backlog.jp/git-guide/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '図を書いて説明したくなったら、Cacooで図を書いてそのURLを Wiki とかコメントに貼ればいいよ。', 'Cacooの図をBacklogに表示する方法', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'Markdown記法って人気あるよね。Backlogでも使えるよ。', 'プロジェクトの基本設定', 'http://www.backlog.jp/help/adminsguide/project-setting/userguide355.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'WikiはPDFで出力できるよ。Backlog を見れない人にはPDFで見せてね。', 'PDF出力', 'http://www.backlog.jp/help/usersguide/wiki/userguide218.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'BacklogにはWebフック機能もあって、外部システムと連携できるよ。', 'Git Webフック', 'http://www.backlog.jp/help/usersguide/git/userguide1710.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ja', 'お問い合わせメールなどの内容をBacklogの課題として手動で登録してる場合、簡単な設定で自動登録に変更することが可能です。', 'メールによる課題登録', 'http://www.backlog.jp/help/adminsguide/add-issues-via-email/userguide2306.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'ねぇ 知ってる？ヌーラボアカウントを使えば1つのユーザIDとパスワードで複数のBacklogスペースにログインできるんだよ。', 'ヌーラボアカウントとは', 'http://www.backlog.jp/help/usersguide/nulab-account/userguide2272.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'ねぇ 知ってる？ヌーラボアカウントを使えば1つのユーザIDとパスワードでCacooとかTypetalkにもログインできるんだよ。', 'ヌーラボアカウントとは', 'http://www.backlog.jp/help/usersguide/nulab-account/userguide2272.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '課題の件名はできるだけ具体的に。分かりやすさや後から探すときの検索しやすさが全然違うよ。', '件名', 'http://www.backlog.jp/help/usersguide/issue/userguide8.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'ガントチャートってどうやって使うの？という人は、とりあえず各タスクに開始日と期限日を入れるとガントチャートが表示されるよ。', 'ガントチャートの概要', 'http://www.backlog.jp/help/usersguide/gantt-chart/userguide274.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'リリース日を手動でカレンダーに登録してる人は、マイルストーンカレンダーを使うといいかもね。', 'マイルストーンカレンダー', 'http://www.backlog.jp/help/usersguide/project-home/userguide76.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', 'BacklogAPIで自分好みのBacklogアプリを作ってる人もいるんだって。すごいね！君もやってみない？', 'Backlog API', 'http://developer.nulab-inc.com/ja/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'Backlogは6言語に対応！外国人のプロジェクトメンバーがいたら教えてあげてね。', '多言語対応', 'http://www.backlog.jp/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '新規ユーザを登録するときにアイコンをデフォルト以外にしておくと、本人が自分が気に入ったアイコンを登録してくれる確率があがるらしいよ。', 'ユーザの追加', 'http://www.backlog.jp/help/adminsguide/user-setting/userguide325.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '議事録とか日報をWikiで書いている人はフォーマットを登録しておくと便利だよ。', 'Backlog 小技集： Wikiのコピー', 'https://nulab-inc.com/ja/blog/backlog/backlog-tips-6/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '「Backlogを使いこなそう」を見ると、今まで知らなかった機能が発見できるかもしれないよ。', 'Backlogを使いこなそう', 'http://www.backlog.jp/help/usersguide/issue/userguide1.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', 'チームで運用ルールを決めているなら、Wikiに書いて共有しよう！', 'Wiki', 'http://www.backlog.jp/help/usersguide/wiki/userguide209.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '上手くいったことも失敗したことも、すべてBacklogに書いておけば誰かの役に立つかもしない。', 'コメント', 'http://www.backlog.jp/help/usersguide/issue/userguide32.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ja', '「わざわざコメントするまでもないけど感謝の気持ちを表したい...」という時にもスターが使えるよ。', 'スターを付ける', 'http://www.backlog.jp/help/usersguide/star/userguide456.html', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ja', '課題の状態や担当者は状況に合わせてこまめに変更しよう。', '課題の状態', 'http://www.backlog.jp/help/usersguide/issue/userguide1.html', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'An issue has become too big to manage? Divide it into smaller issues!', 'Subtasking', 'http://backlogtool.com/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'If the due date is fixed, use the milestone feature.', 'Version/Milestone', 'http://backlogtool.com/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'The Ghantt chart is incredibly useful when you want to keep track of an entire project.', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Save frequently used search conditions to save time!', 'Saving search criteria', 'http://backlogtool.com/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'en', 'Receiving too many emails from Backlog? Check and modify your email settings!', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Change multiple issue statuses or assignees the easy way.', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Need to inform other members of an update or comment?  Use the notification feature!', 'Summary of notification feature', 'http://backlogtool.com/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Do you know how to add headings automatically to a Wiki?', 'Backlog:Index', 'http://backlogtool.com/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Send shortened URLs of issues to make them more managable for sharing!', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'The Burndown chart gives you a general idea of how the project is progressing.', 'Summary of Burndown Chart', 'http://backlogtool.com/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'If you think someone has just posted a great idea, add stars to it!', 'Add Star', 'http://backlogtool.com/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Check your project''s status on the iPhone app while you are out and about. ', 'Backlog for iPhone Features', 'http://backlogtool.com/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Curious to know what your colleagues are up to?  Check their recent activities on their Profile page.', 'Recent Activity in Profile', 'http://backlogtool.com/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'en', 'It is easy to manage multiple versions of files on Git.', 'Git Beginner''s Guide for Dummies', 'http://backlogtool.com/git-guide/en/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'A picture is worth a thousand words. You can post a Cacoo diagram''s URL in you comment or Wiki to give your ideas a visual aid. ', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Markdown, a popular formatting rule, can be used on Backlog too.', 'Project Setting', 'http://backlogtool.com/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Export a Wiki to PDF to share it with people who don''t have access to your Backlog space.', 'Export to PDF', 'http://backlogtool.com/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'With the webhook function of Backlog, you can connect it with external systems.', 'Git Webhook', 'http://backlogtool.com/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'en', 'Are you still adding issues mannually when you receive inquiries from your customers?  Check out our Help page on how to add them automatically!  ', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Did you know you access multiple Backlog spaces in a single sign-in by using the Nulab account?', 'About Nulab Account', 'http://backlogtool.com/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Tip of the week: Nulab Account is a convenient, single sign-in service that lets you sign in to your Backlog, Cacoo and Typetalk accounts with a single sign in.  ', 'About Nulab Account', 'http://backlogtool.com/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Make sure to give your issues a subject heading! It will save you a lot of time searching the issue later.  ', 'Subject Status', 'http://backlogtool.com/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Want to put your issue on the Ghantt chart? It''s simple! All you have to do is set the Start Date and Due Date.', 'Summary of Gantt Chart', 'http://backlogtool.com/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Sync your milestone schedule with your calendar so you won''t forget issue deadlines.', 'Milestone Calendar (iCalendar)', 'http://backlogtool.com/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'I heard some people are developing some cool new applications with the BacklogAPI. Why don''t you give it a try too?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Backlog supports six languages!  You can use Backlog with a multicultural team. ', 'Multilingual', 'http://backlogtool.com/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'New users are more likely to add their own icons if you pick an icon for them at the outset rather than use the default icon of Backlog. ', 'Add User', 'http://backlogtool.com/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Check out the Help pages to discover new features you haven''t learned about!', 'Backlog Help', 'http://backlogtool.com/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Use Wiki to share certain rules among the team!', 'Wiki', 'http://backlogtool.com/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Make a record of all successes and failures on Backlog so that other members can use them as a learning reference in future.', 'Comment', 'http://backlogtool.com/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'Show your appreciation with stars.', 'Add Star', 'http://backlogtool.com/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Make sure to update the issue status and assignee as you make progresses with the task.', 'Status of Issue', 'http://backlogtool.com/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'en', 'Of course you know that issues can be updated by Git and Subversion''s commits.', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'en', 'Administrators can be set for each project too!', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'en', 'If you create Wiki pages often, having formats, such as notes or daily report templates, will save your time.', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Một chủ đề trở nên quá lớn để quản lý? Hãy chia nó thành những chủ đề nhỏ hơn!', 'Về chủ đề cha', 'http://backlogtool.com/vn/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Nếu ngày hết hạn cố định, hãy sử dụng chức năng milestone.', 'Phiên bản phát sinh/ cột mốc', 'http://backlogtool.com/vn/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Biểu đồ Ghantt thì vô cùng hữu ích khi bạn muốn theo dõi toàn bộ dự án.', 'Video hướng dẫn Backlog Video "Hướng dẫn Gantt Chart"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Lưu thường xuyên những điều kiện tìm kiếm đã sử dụng để tiết kiệm thời gian!', 'Lưu điều kiện tìm kiếm', 'http://backlogtool.com/vn/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'vi', 'Nhận được quá nhiều email từ Backlog? Kiểm tra và sửa đổi các thiết lập email của bạn!', 'Cập nhật Backlog – Cải thiện chức năng thông báo bằng email', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Thay đổi trạng thái của nhiều chủ đề hoặc người được giao việc một cách dễ dàng.', 'Cập nhật nhiều chủ đề cùng lúc trên Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Cần thông báo đến những thành viên khác khi có cập nhật hoặc bình luận? Sử dụng chức năng gửi thông báo!', 'Khái quát về chức năng thông báo', 'http://backlogtool.com/vn/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Bạn có biết làm thế nào để thêm tiêu đề một cách tự động đến một Wiki?', 'Mục lục', 'http://backlogtool.com/vn/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Gửi URL rút gọn của chủ đề để giúp chúng dễ quản lý hơn khi chia sẻ!', 'Tạo URLs ngắn gọn để chia sẻ trên Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Các biểu đồ Burndown cung cấp cho bạn một cái nhìn tổng thể về tiến độ tiến triển của dự án.', 'Khái quát về biểu đồ Burn down', 'http://backlogtool.com/vn/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Nếu bạn nghĩ ai đó vừa đề xuất một ý tưởng tuyệt vời, hãy thêm những ngôi sao cho điều đó! ', 'Thêm vào ngôi sao', 'http://backlogtool.com/vn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Kiểm tra tình trạng dự án của bạn trên các ứng dụng iPhone trong khi bạn ra ngoài và về.', 'Tính năng của Backlog cho iPhone', 'http://backlogtool.com/vn/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tò mò muốn biết các đồng nghiệp của bạn đang làm những gì? Kiểm tra các hoạt động gần đây trên trang Profile của họ.', 'Hoạt động gần đây trong Profile', 'http://backlogtool.com/vn/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'vi', 'Thật dễ dàng để quản lý nhiều phiên bản của các tập tin trên Git.', 'Hướng dẫn sử dụng Git cho người mới bắt đầu', 'http://backlogtool.com/git-guide/vn/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Một bức hình có thể đáng giá hơn ngàn lời nói. Bạn có thể gửi URL của biểu đồ Cacoo trong bình luận hoặc Wiki để hỗ trợ trực quan cho việc đưa ra ý tưởng của bạn.', 'Làm thế nào để đưa biểu đồ Cacoo vào Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Markdown, một quy tắc định dạng phổ biến, cũng có thể sử dụng được trên Backlog.', 'Thiết lập cơ bản của dự án', 'http://backlogtool.com/vn/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Xuất một Wiki định dạng PDF để chia sẻ cho người không có quyền truy cập vào Backlog space của bạn.', 'Xuất ra PDF', 'http://backlogtool.com/vn/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Với các chức năng webhook của Backlog, bạn có thể kết nối với các hệ thống bên ngoài.', 'Git Webhook', 'http://backlogtool.com/vn/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'vi', 'Bạn vẫn thêm chủ đề một cách thủ công khi nhận được yêu cầu từ khách hàng? Hãy kiểm tra trang Trợ giúp của chúng tôi về cách thêm chủ đề tự động!', 'Thêm yêu cầu qua email như những chủ đề trên Backlog.', 'http://backlogtool.com/vn/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Bạn đã biết bạn truy cập nhiều Backlog space chỉ với một lần đăng nhập bằng cách sử dụng tài khoản Nulab?', 'Về tài khoản Nulab', 'http://backlogtool.com/vn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Mẹo trong tuần: Tài khoản Nulab là một dịch vụ tiện lợi, đăng nhập một lần nhưng có thể cho phép bạn đăng nhập vào tài khoản Backlog, Cacoo và Typetalk của bạn chỉ với việc đăng nhập một lần duy nhất. ', 'Về tài khoản Nulab', 'http://backlogtool.com/vn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Hãy chắc chắn đặt một đề mục cho chủ đề của bạn! Nó sẽ giúp bạn tiết kiệm rất nhiều thời gian tìm kiếm các chủ đề sau này.', 'Tên chủ đề', 'http://backlogtool.com/vn/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Bạn muốn đặt chủ đề của bạn trên biểu đồ Ghantt? Thật đơn giản! Tất cả bạn phải làm là thiết lập ngày bắt đầu và ngày hết hạn.', 'Khái quát biểu đồ Gantt', 'http://backlogtool.com/vn/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Đồng bộ hóa các milestone của bạn với lịch của bạn, bạn sẽ không bị quên ngày hết hạn của chủ đề.', 'Lịch cột mốc ( iCalendar )', 'http://backlogtool.com/vn/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tôi được biết một số người đang phát triển một vài ứng dụng rất "cool" với BacklogAPI. Tại sao bạn không thử dùng nó?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Backlog hỗ trợ sáu ngôn ngữ! Bạn có thể sử dụng Backlog với một đội ngũ đa văn hóa.', 'Đa ngôn ngữ', 'http://backlogtool.com/vn/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Người dùng mới thường thích thêm icon riêng của họ nếu bạn chọn một icon cho họ ngay từ đầu thay vì icon mặc định của Backlog.', 'Thêm người sử dụng', 'http://backlogtool.com/vn/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Kiểm tra các trang Trợ giúp để khám phá các tính năng mới mà bạn chưa biết!', 'Backlog Help', 'http://backlogtool.com/vn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Sử dụng Wiki để chia se một số quy định trong nhóm!', 'Wiki', 'http://backlogtool.com/vn/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Tạo một hồ sơ lưu trữ tất cả những thành công và thất bại trên Backlog để những thành viên khác có thể sử dụng chúng để rút kinh nghiệm cho tương lai.', 'Bình luận', 'http://backlogtool.com/vn/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Thể hiện sự cảm kích của bạn với những ngôi sao.', 'Thêm vào ngôi sao', 'http://backlogtool.com/vn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Hãy chắc chắn việc cập nhật trạng thái chủ đề và người được giao việc khi bạn thực hiện tiến trình công việc.', 'Trạng thái của chủ đề', 'http://backlogtool.com/vn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'vi', 'Hiển nhiên bạn biết rằng những chủ để có thể được cập nhật bằng Git và commit Subversion.', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'vi', 'Người quản trị cũng có thể được thiết lập cho từng dự án!', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'vi', 'Nếu bạn thường tạo ra các trang Wiki, có định dạng, chẳng hạn như ghi chú hay các mẫu báo cáo hàng ngày, sẽ tiết kiệm thời gian của bạn.', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '태스크는 적절한 크기로. 너무 큰 태스크가 있을 땐 적절한 크기로 나누는 편이 좋을 거야.', '부모자식 과제에 대하여', 'http://backlogtool.com/kr/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '기한일이 정해져 있을 땐 마일스톤을 사용하면 편리해.', '발생 버전/마일스톤', 'http://backlogtool.com/kr/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '프로젝트 전체를 파악하고 싶을 땐 갠트 차트가 편리해.', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '자주 사용하는 검색 조건을 저장해 두면 시간을 단축할 수 있어!', '검색 조건 저장', 'http://backlogtool.com/kr/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ko', '메일 수신함이 가득 차 있을 경우에는 자신이 받고 싶은 메일만을 수신할 수 있도록 설정할 것을 추천합니다.', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '복수의 과제를 한꺼번에 형식을 변경하거나 담당자를 바꾸는 일도 가능하지.', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '<저 사람이 이 코멘트를 읽어 주면 줬으면...> 할 땐 <공지>를 보내 봐!', '공지 기능의 개요', 'http://backlogtool.com/kr/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Wiki의 색인을 바탕으로 자동으로 목차를 만들어 주는 거 알고 있었어?', '목차', 'http://backlogtool.com/kr/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '검색 후의 과제 일람을 누군가에게 보내고 싶을 때에는 짧은 URL을 보내는 편이 스마트하지!', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '번다운 차트로 프로젝트의 진행 상황을 일목요연하게 볼 수 있어.', '번다운 차트 개요', 'http://backlogtool.com/kr/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '이 코멘트의 이 부분이 나이스 아이디어! 하고 감탄했다면 그 부분을 선택하여 별을 달아 주면 좋을 거야.', '스타를 단다', 'http://backlogtool.com/kr/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '외출했을 때 프로젝트의 상황을 알고 싶다면 iPhone판 Backlog를 보면 되지.', 'Backlog for iPhone의 기능', 'http://backlogtool.com/kr/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '그 사람 요새 무슨 일 하고 있을까..? 하고 궁금해졌다면 프로필 확인!', '프로필의 “최근 활동”', 'http://backlogtool.com/kr/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ko', 'Git로 파일을 버전 관리하면 완전 편하지.', '누구나 쉽게 이해할 수 있는 Git 입문 버전 관리를 완벽하게 이용해보자!', 'http://backlogtool.com/git-guide/kr/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '그림을 그려서 설명하고 싶다면 Cacoo로 그림을 그려서 그 URL을 Wiki나 코멘트에 붙여넣으면 될 거야.', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'Markdown 요새 인기 많지? Backlog에서도 사용할 수 있어.', '프로젝트의 기본 설정', 'http://backlogtool.com/kr/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Wiki는 PDF로 변환할 수 있어. Backlog를 볼 수 없는 사람에게는 PDF로 보여 줘!', 'PDF 출력', 'http://backlogtool.com/kr/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'Backlog에는 webhook기능도 있으니까 외부 시스템과 연계시킬 수도 있어.', 'Git Webhook', 'http://backlogtool.com/kr/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'ko', '문의 메일 등의 내용을 Backlog의 과제로써 수동으로 등록하고 있을 경우에는 간단한 설정으로 자동 등록으로 변경하는 것도 가능합니다.', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/kr/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '너 그거 알아? 누라보 계정을 사용하면 하나의 유저 아이디와 비밀먼호로 여러 Backlog스페이스에 로그인할 수 있어!', '누라보 계정이란', 'http://backlogtool.com/kr/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '너 그거 알아? 누라보 계정을 사용하면 하나의 유저 아이디와 비밀먼호로 Cacoo나 Typetalk에 로그인할 수 있다는 거.', '누라보 계정이란', 'http://backlogtool.com/kr/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '과제 제목은 될 수 있는 대로 구체적으로. 알기 쉽고, 나중에 찾을 때 검색하기도 아주 편리해.', '건명', 'http://backlogtool.com/kr/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '갠트 차트는 어떻게 사용해? 라는 사람에게. 먼저 각 태스크에 시작 날짜와 기한을 입력하면 갠트 차트가 뜰 거야.', '갠트 차트 개요', 'http://backlogtool.com/kr/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '릴리스 예정일을 수동으로 캘린더에 등록하고 있는 사람은 마일스톤 캘린더를 사용하면 좋을지도?', '마일스톤 캘린더 (iCalendar)', 'http://backlogtool.com/kr/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', 'BacklogAPI로 내 마음에 드는 Backlog앱을 만드는 사람도 있대. 끝내주지? 너도 해보지 않을래?', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', 'Backlog는 6개 국어로 제공된대. 외국인 프로젝트 멤버가 있다면 꼭 가르쳐줘!', '다언어 대응', 'http://backlogtool.com/kr/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '신규 유저를 등록할 때에는 초기에 설정된 아이콘을 바꿔 놓으면 다른 사람이 내 아이콘이 마음에 들어서 등록해 줄 확률이 오른대.', '유저 추가', 'http://backlogtool.com/kr/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '<Backlog 를 능숙히 써보자>를 보면 지금까지 몰랐던 기능을 발견할 수 있을지도 몰라!', 'Backlog Help', 'http://backlogtool.com/kr/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '팀에서 운용 규칙을 만들었다면 Wiki에 적어서 공유하자!', 'Wiki', 'http://backlogtool.com/kr/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '성공한 일도 실패한 일도 모두 다 Backlog에 적어 놓으면 누군가에게 도움이 될지도 몰라.', '코멘트', 'http://backlogtool.com/kr/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '<일부러 코멘트를 남길 필요까지는 없지만 감사의 마음은 전하고 싶은데..>라는 때에도 별을 사용할 수 있지.', '스타를 단다', 'http://backlogtool.com/kr/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '과제 상태나 담당자는 상황에 맞춰서 부지런히 변경하자.', '과제의 상태', 'http://backlogtool.com/kr/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'ko', 'Git 나 Subversion 의 커밋으로 과제 상태를 갱신할 수 있다는데?', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'ko', '관리자는 프로젝트별로 설정하는 일도 할 수 있어.', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'ko', '회의록이나 일보를 Wiki로 쓰는 사람은 포맷을 등록해 놓으면 편리할걸?', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', ' 一個課題裡有太多任務要管理，處理起來相當困難，怎麼辦？把課題分成更多子課題吧！', '主和子課題功能（Subtasking）', 'http://backlogtool.com/tw/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', ' 如果期限日已確定，試著使用里程碑來設定課題的階段進度。', '版本／里程碑', 'http://backlogtool.com/tw/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '甘特圖可以協助您輕鬆掌握專案的進度。', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '儲存常用的搜尋條件可以節省您更多時間呦！', '儲存搜尋課題的條件', 'http://backlogtool.com/tw/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_tw', '收到太多貝格樂寄來的電子郵件？快來檢查和變更您的郵件設定！', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '簡單快速變更多個課題的狀態或責任者。', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '更新或添加評論時想要通知其他的成員？使用通知功能就對了！', '通知功能概要', 'http://backlogtool.com/tw/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '您知道如何自動添加目次到Wiki嗎？', '目次', 'http://backlogtool.com/tw/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '建立課題的短URL以利於分享！', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '燃盡圖可以提供專案大概的進度狀態。', '燃盡圖概要', 'http://backlogtool.com/tw/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '快送個獎勵星星給剛剛提出超棒點子的成員！', '給予星星', 'http://backlogtool.com/tw/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '使用貝格樂iPhone App隨時隨地查看專案的最新狀態。', '貝格樂iPhone App的功能', 'http://backlogtool.com/tw/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '好奇最近同事們都在忙什麼嗎？查看他們個人簡介的「最近活動」就知道啦。', '個人簡介的「最近活動」', 'http://backlogtool.com/tw/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_tw', '使用Git輕鬆管理多個版本的檔案。', '連猴子都能懂的Git入門指南', 'http://backlogtool.com/git-guide/tw/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '千言萬語抵不過一張圖，在評論或Wiki貼上Cacoo圖表的URL，視覺化您的點子吧。 ', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '貝格樂支援Markdown格式化規則。', '專案基本設定', 'http://backlogtool.com/tw/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '將Wiki以PDF檔案匯出，和無法存取您的貝格樂空間的朋友分享。', 'PDF輸出', 'http://backlogtool.com/tw/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '具備Webhook功能，貝格樂也可以連接到外部系統。', 'Git Webhook', 'http://backlogtool.com/tw/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_tw', '您還在用手動方式將收到的客戶洽詢郵件建立成課題嗎？閱讀我們的支援頁面了解如何自動添加課題！', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/tw/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '只要登入Nulab帳號，您就可以一次使用多個貝格樂空間。', '關於Nulab帳號', 'http://backlogtool.com/tw/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '小知識分享：只要擁有一個Nulab帳號就可以同時登入貝格樂、Cacoo和Typetalk，Nulab帳號提供單一登入機制，方便使用。', '關於Nulab帳號', 'http://backlogtool.com/tw/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', ' 一定要幫您的課題訂一個標題！以後搜尋課題時就可以省去您大量的時間。', '標題', 'http://backlogtool.com/tw/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '想要在您的課題使用甘特圖？只要設定課題的開始日期和期限日就可以了，很簡單吧！', '甘特圖概要', 'http://backlogtool.com/tw/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '立刻同步里程碑時間表到您的行事曆，以避免忘記課題的期限日。', '里程碑行事曆', 'http://backlogtool.com/tw/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '有些開發者使用貝格樂API 開發了很酷的應用程式呦，您要不要也試試看？', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '貝格樂支援6種語言！最適合多元文化的工作團隊使用。', '多語言適用', 'http://backlogtool.com/tw/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '您知道嗎？在添加新用戶時，如果您幫新用戶選擇的圖標不是貝格樂內建的圖標時，他們會更想要變更及添加自己的圖標呦。 ', '添加用戶', 'http://backlogtool.com/tw/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '快來查看FAQ頁面，可以學習到您不知道的新功能呦。', 'Backlog Help', 'http://backlogtool.com/tw/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '運用Wiki來和工作團隊分享重要的規則條件。', 'Wiki', 'http://backlogtool.com/tw/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '建立一個記錄來儲存在貝格樂上所有成功和失敗案例，未來可以讓其他成員從中學習，吸取經驗。', '評論', 'http://backlogtool.com/tw/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '透過給予星星來表達您的讚賞。', '給予星星', 'http://backlogtool.com/tw/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '隨著任務的進展程度，確實做到即時更新課題和責任者。', '課題的狀態', 'http://backlogtool.com/tw/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_tw', '可以透過Git和Subversion的提交更新課題嗎？', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_tw', '每個專案都可以設定管理者！', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_tw', '如果您經常建立Wiki頁面，設定像是公告或每日報表等等的格式，會更節省您的時間。', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '课题太大了，管理有难度？请把它分成几个小课题吧！', '母子课题功能', 'http://backlogtool.com/cn/help/usersguide/subtasking/userguide1722/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果期限日已经确定了，就请使用里程碑功能吧。', '版本／里程碑', 'http://backlogtool.com/cn/help/usersguide/version-milestone/userguide106/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果您想了解整个项目的进度状况，甘特图必不可少喔。', 'Backlog Video Tutorial "Gantt Chart tutorial"', 'https://www.youtube.com/watch?v=p6Jpr90bsQw', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '保存常用的查询课题的条件可以节省不少时间！', '保存查询课题的条件', 'http://backlogtool.com/cn/help/usersguide/search-issue/userguide1440/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_cn', '收到太多来自贝格乐的电子邮件？请检查并变更您的邮件设置!', 'Backlog Update – Improved Email Notifications', 'https://nulab-inc.com/blog/backlog/new-email-settings/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '简单快捷地一次变更多个课题的状态或责任者。', 'Update Multiple Issues at Once on Backlog', 'https://nulab-inc.com/blog/backlog/update-multiple-issues-at-once-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想让其他成员知道您更新了课题或发布了评论？用通知功能噢！', '通知功能概述', 'http://backlogtool.com/cn/help/usersguide/notification/userguide1453/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '您知道怎样自动地添加Wiki标题吗？', '索引', 'http://backlogtool.com/cn/help/usersguide/rule-to-formatting-texts/userguide205/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想跟成员分享搜索出来的多个课题？发送简短URL会更方便！', 'Create Short, Sharable URLs on Backlog', 'http://nulab-inc.com/blog/backlog/backlog-tips-2/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '燃尽图让您大致了解项目的进展状况。', '燃尽图概述', 'http://backlogtool.com/cn/help/usersguide/burn-down-chart/userguide289/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '如果有成员发布了一个超棒的评论，给评论添加个星星吧！', '添加星星', 'http://backlogtool.com/cn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '当您出门在外时，可以使用iPhone app查看您的项目状态噢。', 'iPhone 贝格乐的功能', 'http://backlogtool.com/cn/help/usersguide/mobile/userguide2354/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '好奇您的同事们在忙些什么？查看他们的“用户资料” 页面上的 “最近的活动”就知道啦。', '“用户资料” 页面的 “最近的活动”', 'http://backlogtool.com/cn/help/usersguide/member/userguide1016/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_cn', '使用Git可以轻松管理多个版本的文件。', '猴子都能懂的GIT入门', 'http://backlogtool.com/git-guide/cn/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '一张图胜过千言万语。您可以在评论部分或Wiki张贴Cacoo 图表URL，能起到视觉辅助效果噢。', 'How to Display a diagram of Cacoo in Backlog', 'http://vimeo.com/7843559', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '贝格乐当然支持人气格式规则—Markdown啦。', '项目设置', 'http://backlogtool.com/cn/help/adminsguide/project-setting/userguide355/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '以PDF格式导出Wiki，然后跟不能访问您的贝格乐空间的人分享Wiki上的信息噢。', '以PDF格式导出', 'http://backlogtool.com/cn/help/usersguide/wiki/userguide218/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '由于具备webhook功能，贝格乐可以跟外部系统连接咯。', 'Git Webhook', 'http://backlogtool.com/cn/help/usersguide/git/userguide1710/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('postman.png', 'zh_cn', '您还在将客户的邮件逐个地添加为课题吗？请参阅我们的帮助页面看看怎样自动添加课题的！', 'Add email inquiries as issues on Backlog', 'http://backlogtool.com/cn/support-inquery-form/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '您知道吗？只用一个Nulab帐户就可以访问多个贝格乐空间哟。', '关于Nulab帐户', 'http://backlogtool.com/cn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '本周小贴士：Nulab帐户是一个简便的单点登录服务 ( Single Sign-On )。只需登录一个Nulab帐户，您就可以登入贝格乐，Cacoo 和 Typetalk。', '关于Nulab帐户', 'http://backlogtool.com/cn/help/usersguide/nulab-account/userguide2272/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '一定要给您的课题写上标题喔。有了标题以后就容易查询课题了。  ', '标题', 'http://backlogtool.com/cn/help/usersguide/issue/userguide8/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '想要把您的课题放上甘特图？简单，设定开始日和结束日就行了。', '甘特图概述', 'http://backlogtool.com/cn/help/usersguide/gantt-chart/userguide274/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '把您的里程碑日程表跟日历设定同步，您就不会忘记课题的期限日了。', '里程碑日历(iCalendar)', 'http://backlogtool.com/cn/help/usersguide/project-home/userguide76/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '我听说有人使用BacklogAPI开发出很酷的新应用程序。您也试试嘛。', 'Backlog API', 'http://developer.nulab-inc.com/docs/backlog/api/2/get-space', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '贝格乐支持6种语言！它是您的多元文化团队的最佳选择。', '多种语言', 'http://backlogtool.com/cn/tour/multilingual/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '注册新用户时，您给他们选一个图标，而不用贝格乐的默认图标。他们之后更有可能上载他们专属的图标喔。', '添加用户', 'http://backlogtool.com/cn/help/adminsguide/user-setting/userguide325/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '请看看帮助页面，发掘您不知道的新功能吧！', 'Backlog Help', 'http://backlogtool.com/cn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '要跟成员共享一些格式规则的话，请用Wiki吧！', 'Wiki', 'http://backlogtool.com/cn/help/usersguide/wiki/userguide209/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '在贝格乐上记录所有的成功和失败，以便其他成员日后可以参考学习噢。', '评论', 'http://backlogtool.com/cn/help/usersguide/issue/userguide32/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '点星星以表达您的谢意哟。', '添加星星', 'http://backlogtool.com/cn/help/usersguide/star/userguide456/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '在您执行任务取得进展时，不要忘记即时更新课题状态或责任者哦。', '课题的状态', 'http://backlogtool.com/cn/help/usersguide/issue/userguide1/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('monkey.png', 'zh_cn', '您肯定知道可以通过Git或Subversion提交来更新课题的，是不是？', 'Updating an issue from Git commit on Backlog', 'https://nulab-inc.com/blog/backlog/updating-issue-gits-commits-log', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla.png', 'zh_cn', '可以给每个项目设定管理员哦！', 'Setting up a project administrator on Backlog', 'https://nulab-inc.com/blog/backlog/project-administrator-backlog/', CURRENT_TIMESTAMP);
INSERT INTO myreport_message (ICON, LANG, COMMENT, PAGE_NAME, PAGE_URL, CREATED) VALUES ('gorilla2.png', 'zh_cn', '如果您经常要建立Wiki页面，使用格式 (例如：笔记或每日报告模板), 可以省时省力喔。', 'Backlog Tips & Tutorials: Copying Wiki pages', 'https://nulab-inc.com/blog/backlog/backlog-tips-copy-wiki/', CURRENT_TIMESTAMP);

INSERT INTO reserved_space_key (SPACE_KEY, IS_REGEXP) VALUES ('^usercontent.*$', TRUE);

UPDATE space SET NEED_INDEXING='1';

COMMIT;
